  #include <sys/utsname.h>
  #include <unistd.h>
  #include <fcntl.h>

#include "pxll.h"

static int lookup_field (int tag, int label);

static
inline
pxll_int
get_typecode (object * ob)
{
  if (IMMEDIATE(ob)) {
    if (IS_INTEGER(ob)) {
      return TC_INT;
    } else {
      return (pxll_int)ob & 0xff;
    }
  } else {
    return (pxll_int)*((pxll_int *)ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case (object * ob)
{
  if (is_immediate (ob)) {
    if (is_int (ob)) {
      return TC_INT;
    } else {
      return (pxll_int) ob;
    }
  } else {
    return (pxll_int)*((pxll_int *)ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case_noint (object * ob)
{
  if (is_immediate (ob)) {
    return (pxll_int) ob;
  } else {
    return (pxll_int) * ((pxll_int*) ob) & 0xff;
  }
}

// for pvcase/nvcase
static
inline
pxll_int
get_case_imm (object * ob)
{
  return (pxll_int)ob;
}

static
inline
pxll_int
get_case_tup (object * ob)
{
  return (pxll_int)*((pxll_int *)ob) & 0xff;
}

static
inline
pxll_int
get_imm_payload (object * ob)
{
  return ((pxll_int) ob) >> 8;
}

static
pxll_int
get_tuple_size (object * ob)
{
  header * h = (header *) ob;
  return (*h)>>8;
}

static
void
indent (int n)
{
  while (n--) {
    fprintf (stdout, "  ");
  }
}

void print_string (object * ob, int quoted);
void print_list (pxll_pair * l);

// this is kinda lame, it's part pretty-printer, part not.
static
object *
dump_object (object * ob, int depth)
{
  // indent (depth);
  if (depth > 100) {
    fprintf (stdout , "...");
    return (object *) PXLL_UNDEFINED;
  }
  if (!ob) {
    fprintf (stdout, "<null>");
  } else if (is_int (ob)) {
    // integer
    fprintf (stdout, "%zd", unbox (ob));
  } else {
    int tc = is_immediate (ob);
    switch (tc) {
    case TC_CHAR:
      if ((pxll_int)ob>>8 == 257) {
	// deliberately out-of-range character
	fprintf (stdout, "#\\eof");
      } else {
	char ch = ((char)((pxll_int)ob>>8));
	switch (ch) {
	case '\000': fprintf (stdout, "#\\nul"); break;
	case ' '   : fprintf (stdout, "#\\space"); break;
	case '\n'  : fprintf (stdout, "#\\newline"); break;
	case '\r'  : fprintf (stdout, "#\\return"); break;
	case '\t'  : fprintf (stdout, "#\\tab"); break;
	default    : fprintf (stdout, "#\\%c", ch);
	}
      }
      break;
    case TC_BOOL:
      fprintf (stdout, ((pxll_int)ob >> 8) & 0xff ? "#t" : "#f");
      break;
    case TC_NIL:
      fprintf (stdout, "()");
      break;
    case TC_UNDEFINED:
      fprintf (stdout, "#u");
      break;
    case TC_EMPTY_VECTOR:
      fprintf (stdout, "#()");
      break;
    case 0: {
      // structure
      header h = (header) (ob[0]);
      int tc = h & 0xff;
      switch (tc) {
      case TC_SAVE: {
	// XXX fix me - now holds saved registers
        pxll_save * s = (pxll_save* ) ob;
        fprintf (stdout, "<save pc=%p\n", s->pc);
        dump_object ((object *) s->lenv, depth+1); fprintf (stdout, "\n");
        dump_object ((object *) s->next, depth+1); fprintf (stdout, ">");
      }
        break;
      case TC_CLOSURE: {
        pxll_closure * c = (pxll_closure *) ob;
        //fprintf (stdout, "<closure pc=%p\n", c->pc);
        //dump_object ((object *) c->lenv, depth+1); fprintf (stdout, ">\n");
	fprintf (stdout, "<closure pc=%p lenv=%p>", c->pc, c->lenv);
      }
        break;
      case TC_TUPLE: {
        pxll_tuple * t = (pxll_tuple *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "<tuple\n");
        for (i=0; i < n-1; i++) {
          dump_object ((object *) t->val[i], depth + 1); fprintf (stdout, "\n");
        }
        dump_object ((object *) t->next, depth + 1);
        fprintf (stdout, ">");
      }
	break;
      case TC_VECTOR: {
        pxll_vector * t = (pxll_vector *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "#(");
        for (i=0; i < n; i++) {
          dump_object ((object *) t->val[i], depth+1);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, ")");
      }
	break;
      case TC_VEC16: {
        pxll_vec16 * t = (pxll_vec16 *) ob;
        pxll_int n = t->len;
        int i;
	fprintf (stdout, "#16(");
        for (i=0; i < n; i++) {
	  fprintf (stdout, "%d", t->data[i]);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, ")");
      }
	break;
      case TC_PAIR:
	print_list ((pxll_pair *) ob);
        break;
      case TC_STRING:
	print_string (ob, 1);
	break;
      case TC_BUFFER: {
	pxll_int n = get_tuple_size (ob);
	fprintf (stdout, "<buffer %" PRIuPTR " words %" PRIuPTR " bytes>", n, n * (sizeof(pxll_int)));
	break;
      }
      case TC_SYMBOL:
	print_string (ob[1], 0);
	break;
      default: {
        pxll_vector * t = (pxll_vector *) ob;
        pxll_int n = get_tuple_size (ob);
        int i;
	fprintf (stdout, "{u%d ", (tc - TC_USEROBJ)>>2);
        for (i=0; i < n; i++) {
          dump_object ((object *) t->val[i], depth+1);
	  if (i < n-1) {
	    fprintf (stdout, " ");
	  }
        }
        fprintf (stdout, "}");
      }
      }
    }
      break;
    case TC_USERIMM:
      // a user immediate unit-type...
      fprintf (stdout, "<u%" PRIuPTR ">", (((pxll_int)ob)>>8));
    }
  }
  return (object *) PXLL_UNDEFINED;
}

// for gdb...
void
DO (object * x)
{
  dump_object (x, 0);
  fprintf (stdout, "\n");
  fflush (stdout);
}

// for debugging
void
stack_depth_indent (object * k)
{
  while (k != PXLL_NIL) {
    k = k[1];
    fprintf (stderr, "  ");
  }
}

void
print_string (object * ob, int quoted)
{
  pxll_string * s = (pxll_string *) ob;
  char * ps = s->data;
  int i;
  //fprintf (stderr, "<printing string of len=%d (tuple-len=%d)>\n", s->len, get_tuple_size (ob));
  if (quoted) {
    fputc ('"', stdout);
  }
  for (i=0; i < (s->len); i++, ps++) {
    if (*ps == '"') {
      fputc ('\\', stdout);
      fputc ('"', stdout);
    } else {
      if (isprint(*ps)) {
	fputc (*ps, stdout);
      } else {
	fprintf (stdout, "\\0x%02x", *ps);
      }
    }
    if (i > 50) {
      fprintf (stdout, "...");
      break;
    }
  }
  if (quoted) {
    fputc ('"', stdout);
  }
}

void
print_list (pxll_pair * l)
{
  fprintf (stdout, "(");
  while (1) {
    object * car = l->car;
    object * cdr = l->cdr;
    dump_object (car, 0);
    if (cdr == PXLL_NIL) {
      fprintf (stdout, ")");
      break;
    } else if (!is_immediate (cdr) && GET_TYPECODE (*cdr) == TC_PAIR) {
      fprintf (stdout, " ");
      l = (pxll_pair *) cdr;
    } else {
      fprintf (stdout, " . ");
      dump_object (cdr, 0);
      fprintf (stdout, ")");
      break;
    }
  }
}

int
read_header (FILE * file)
{
  int depth = 0;
  // tiny lisp 'skipper' (as opposed to 'reader')
  do {
    char ch = fgetc (file);
    switch (ch) {
    case '(':
      depth++;
      break;
    case ')':
      depth--;
      break;
    case '"':
      while (fgetc (file) != '"') {
        // empty body
      }
      break;
    default:
      break;
    }
  } while (depth);
  // read terminating newline
  fgetc (file);
  return 0;
}

#ifndef NO_RANGE_CHECK
// used to check array references.  some day we might try to teach
//   the compiler when/how to skip doing this...
static
void
inline
range_check (unsigned int length, unsigned int index)
{
  if (index >= length) {
    fprintf (stderr, "array/string reference out of range: %d[%d]\n", length, index);
    abort();
  }
}
#else
static
void
inline
range_check (unsigned int length, unsigned int index)
{
}
#endif

pxll_int verbose_gc = 1;
pxll_int clear_fromspace = 0;
pxll_int clear_tospace = 0;

pxll_int vm (int argc, char * argv[]);

#include "rdtsc.h"

unsigned long long gc_ticks = 0;

static
void
clear_space (object * p, pxll_int n)
{
  while (n--) {
    *p++ = PXLL_NIL;
  }
}

int
main (int argc, char * argv[])
{
  heap0 = malloc (sizeof (object) * heap_size);
  heap1 = malloc (sizeof (object) * heap_size);
  if (!heap0 || !heap1) {
    fprintf (stderr, "unable to allocate heap\n");
    return -1;
  } else {
    unsigned long long t0, t1;
    pxll_int result;
    if (clear_tospace) {
      clear_space (heap0, heap_size);
    }
    t0 = rdtsc();
    result = vm (argc, argv);
    t1 = rdtsc();
    dump_object ((object *) result, 0);
    fprintf (stdout, "\n");
    fprintf (stderr, "{total ticks: %lld gc ticks: %lld}\n", t1 - t0, gc_ticks);
    return (int) result;
  }
}

// CONSTRUCTED LITERALS //
pxll_string constructed_0 = {STRING_HEADER(8), 8, "system: " };
pxll_string constructed_1 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_2 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_3 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_4 = {STRING_HEADER(6), 6, ".c -o " };
pxll_string constructed_5 = {STRING_HEADER(19), 19, " -fnested-functions" };
pxll_string constructed_6 = {STRING_HEADER(6), 6, "Darwin" };
pxll_string constructed_7 = {STRING_HEADER(3), 3, "gcc" };
pxll_string constructed_8 = {STRING_HEADER(12), 12, "-m64 -I. -g " };
pxll_string constructed_9 = {STRING_HEADER(6), 6, "CFLAGS" };
pxll_string constructed_10 = {STRING_HEADER(3), 3, "gcc" };
pxll_string constructed_11 = {STRING_HEADER(2), 2, "CC" };
pxll_string constructed_12 = {STRING_HEADER(13), 13, "compiling...\n" };
pxll_string constructed_13 = {STRING_HEADER(6), 6, "done.\n" };
pxll_string constructed_14 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_15 = {STRING_HEADER(10), 10, "  } break;" };
pxll_string constructed_16 = {STRING_HEADER(10), 10, "     case " };
pxll_string constructed_17 = {STRING_HEADER(9), 9, ": return " };
pxll_string constructed_18 = {STRING_HEADER(8), 8, "; break;" };
pxll_string constructed_19 = {STRING_HEADER(18), 18, "  switch (label) {" };
pxll_string constructed_20 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_21 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_22 = {STRING_HEADER(16), 16, "{ switch (tag) {" };
pxll_string constructed_23 = {STRING_HEADER(44), 44, "static int lookup_field (int tag, int label)" };
pxll_string constructed_24 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_25 = {STRING_HEADER(25), 25, "return (pxll_int) result;" };
pxll_string constructed_26 = {STRING_HEADER(8), 8, "Lreturn:" };
pxll_string constructed_27 = {STRING_HEADER(37), 37, "abcdefghijklmnopqrstuvwxyz_0123456789" };
pxll_string constructed_28 = {STRING_HEADER(5), 5, "_bang" };
pxll_string constructed_29 = {STRING_HEADER(6), 6, "_splat" };
pxll_string constructed_30 = {STRING_HEADER(9), 9, "_question" };
pxll_string constructed_31 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_32 = {STRING_HEADER(5), 5, "_plus" };
pxll_string constructed_33 = {STRING_HEADER(8), 8, "_percent" };
pxll_int constructed_34[] = {UPTR(34,21),UOHEAD(3,1),9474,UPTR0(33),UITAG(0),UOHEAD(3,1),11010,UPTR0(32),UPTR(34,1),UOHEAD(3,1),11522,UPTR0(31),UPTR(34,5),UOHEAD(3,1),16130,UPTR0(30),UPTR(34,9),UOHEAD(3,1),10754,UPTR0(29),UPTR(34,13),UOHEAD(3,1),8450,UPTR0(28),UPTR(34,17)};
pxll_string constructed_35 = {STRING_HEADER(5), 5, "minus" };
pxll_string constructed_36 = {STRING_HEADER(1), 1, "_" };
pxll_int constructed_37[] = {TC_NIL};
pxll_int constructed_38[] = {TC_NIL};
pxll_string constructed_39 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_40 = {STRING_HEADER(20), 20, "(pxll_int)PXLL_FALSE" };
pxll_string constructed_41 = {STRING_HEADER(5), 5, "false" };
// symbol false
pxll_int constructed_42[] = {UPTR(42,1), SYMBOL_HEADER, UPTR0(41)};
pxll_string constructed_43 = {STRING_HEADER(19), 19, "(pxll_int)PXLL_TRUE" };
pxll_string constructed_44 = {STRING_HEADER(4), 4, "true" };
// symbol true
pxll_int constructed_45[] = {UPTR(45,1), SYMBOL_HEADER, UPTR0(44)};
pxll_string constructed_46 = {STRING_HEADER(4), 4, "bool" };
// symbol bool
pxll_int constructed_47[] = {UPTR(47,1), SYMBOL_HEADER, UPTR0(46)};
pxll_string constructed_48 = {STRING_HEADER(6), 6, "TC_NIL" };
pxll_string constructed_49 = {STRING_HEADER(3), 3, "nil" };
// symbol nil
pxll_int constructed_50[] = {UPTR(50,1), SYMBOL_HEADER, UPTR0(49)};
pxll_string constructed_51 = {STRING_HEADER(4), 4, "list" };
// symbol list
pxll_int constructed_52[] = {UPTR(52,1), SYMBOL_HEADER, UPTR0(51)};
pxll_string constructed_53 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_54 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_55 = {STRING_HEADER(9), 9, "TC_SYMBOL" };
pxll_string constructed_56 = {STRING_HEADER(1), 1, "t" };
// symbol t
pxll_int constructed_57[] = {UPTR(57,1), SYMBOL_HEADER, UPTR0(56)};
pxll_string constructed_58 = {STRING_HEADER(6), 6, "symbol" };
// symbol symbol
pxll_int constructed_59[] = {UPTR(59,1), SYMBOL_HEADER, UPTR0(58)};
pxll_string constructed_60 = {STRING_HEADER(7), 7, "TC_PAIR" };
pxll_string constructed_61 = {STRING_HEADER(4), 4, "cons" };
// symbol cons
pxll_int constructed_62[] = {UPTR(62,1), SYMBOL_HEADER, UPTR0(61)};
pxll_string constructed_63 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_64 = {STRING_HEADER(1), 1, ")" };
pxll_int constructed_65[] = {TC_NIL};
pxll_string constructed_66 = {STRING_HEADER(3), 3, "..." };
// symbol ...
pxll_int constructed_67[] = {UPTR(67,1), SYMBOL_HEADER, UPTR0(66)};
pxll_string constructed_68 = {STRING_HEADER(79), 79, "Why, sometimes I've believed as many as six impossible things before breakfast." };
pxll_string constructed_69 = {STRING_HEADER(29), 29, "\n***\nRuntime Error, halting: " };
pxll_string constructed_70 = {STRING_HEADER(4), 4, "FUN_" };
pxll_string constructed_71 = {STRING_HEADER(12), 12, "PXLL_RETURN(" };
pxll_string constructed_72 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_73 = {STRING_HEADER(14), 14, " = (object *) " };
pxll_string constructed_74 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_75 = {STRING_HEADER(8), 8, "// dead " };
pxll_string constructed_76 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_77 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_78 = {STRING_HEADER(26), 26, " = (object*) &constructed_" };
pxll_string constructed_79 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_80 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_81 = {STRING_HEADER(26), 26, " = (object *) constructed_" };
pxll_string constructed_82 = {STRING_HEADER(4), 4, "[0];" };
pxll_string constructed_83 = {STRING_HEADER(6), 6, "string" };
// symbol string
pxll_int constructed_84[] = {UPTR(84,1), SYMBOL_HEADER, UPTR0(83)};
pxll_string constructed_85 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_86 = {STRING_HEADER(8), 8, "} else {" };
pxll_string constructed_87 = {STRING_HEADER(17), 17, "if PXLL_IS_TRUE(r" };
pxll_string constructed_88 = {STRING_HEADER(3), 3, ") {" };
pxll_string constructed_89 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_90 = {STRING_HEADER(8), 8, "} else {" };
pxll_string constructed_91 = {STRING_HEADER(16), 16, "if PXLL_IS_TRUE(" };
pxll_string constructed_92 = {STRING_HEADER(3), 3, ") {" };
pxll_string constructed_93 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_94 = {STRING_HEADER(5), 5, "arrow" };
// symbol arrow
pxll_int constructed_95[] = {UPTR(95,1), SYMBOL_HEADER, UPTR0(94)};
pxll_string constructed_96 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_97 = {STRING_HEADER(2), 2, "=r" };
pxll_string constructed_98 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_99 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_100 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_101 = {STRING_HEADER(3), 3, " = " };
pxll_string constructed_102 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_103 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_104 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_105 = {STRING_HEADER(8), 8, "[1] = &&" };
pxll_string constructed_106 = {STRING_HEADER(3), 3, "; r" };
pxll_string constructed_107 = {STRING_HEADER(11), 11, "[2] = lenv;" };
pxll_string constructed_108 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_109 = {STRING_HEADER(28), 28, " = allocate (TC_CLOSURE, 2);" };
pxll_string constructed_110 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_111 = {STRING_HEADER(15), 15, "check_heap (0);" };
pxll_string constructed_112 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_113 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_114 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_115 = {STRING_HEADER(7), 7, "// def " };
pxll_string constructed_116 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_117 = {STRING_HEADER(11), 11, " = varref (" };
pxll_string constructed_118 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_119 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_120 = {STRING_HEADER(8), 8, "varset (" };
pxll_string constructed_121 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_122 = {STRING_HEADER(3), 3, ", r" };
pxll_string constructed_123 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_124 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_125 = {STRING_HEADER(23), 23, " = allocate (TC_TUPLE, " };
pxll_string constructed_126 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_127 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_128 = {STRING_HEADER(12), 12, " = (object*)" };
pxll_string constructed_129 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_130 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_131 = {STRING_HEADER(13), 13, " = allocate (" };
pxll_string constructed_132 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_133 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_134 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_135 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_136 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_137 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_138 = {STRING_HEADER(1), 1, "[" };
pxll_string constructed_139 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_140 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_141 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_142 = {STRING_HEADER(10), 10, " = result;" };
pxll_string constructed_143 = {STRING_HEADER(24), 24, "; lenv = k[2]; k = k[1];" };
pxll_string constructed_144 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_145 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_146 = {STRING_HEADER(5), 5, " = k[" };
pxll_string constructed_147 = {STRING_HEADER(1), 1, "]" };
pxll_string constructed_148 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_149 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_150 = {STRING_HEADER(7), 7, "[1] = r" };
pxll_string constructed_151 = {STRING_HEADER(13), 13, "[2]; lenv = r" };
pxll_string constructed_152 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_153 = {STRING_HEADER(8), 8, "lenv = r" };
pxll_string constructed_154 = {STRING_HEADER(5), 5, "[2]; " };
pxll_string constructed_155 = {STRING_HEADER(7), 7, "goto *r" };
pxll_string constructed_156 = {STRING_HEADER(4), 4, "[1];" };
pxll_string constructed_157 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_158 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_159 = {STRING_HEADER(32), 32, "t[1] = k; t[2] = lenv; t[3] = &&" };
pxll_string constructed_160 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_161 = {STRING_HEADER(8), 8, "; k = t;" };
pxll_string constructed_162 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_163 = {STRING_HEADER(2), 2, "t[" };
pxll_string constructed_164 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_165 = {STRING_HEADER(23), 23, "t = allocate (TC_SAVE, " };
pxll_string constructed_166 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_167 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_168 = {STRING_HEADER(7), 7, "[1] = r" };
pxll_string constructed_169 = {STRING_HEADER(13), 13, "[2]; lenv = r" };
pxll_string constructed_170 = {STRING_HEADER(2), 2, "; " };
pxll_string constructed_171 = {STRING_HEADER(8), 8, "lenv = r" };
pxll_string constructed_172 = {STRING_HEADER(5), 5, "[2]; " };
pxll_string constructed_173 = {STRING_HEADER(7), 7, "goto *r" };
pxll_string constructed_174 = {STRING_HEADER(4), 4, "[1];" };
pxll_string constructed_175 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_176 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_177 = {STRING_HEADER(5), 5, "goto " };
pxll_string constructed_178 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_179 = {STRING_HEADER(5), 5, "lenv[" };
pxll_string constructed_180 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_181 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_182 = {STRING_HEADER(16), 16, "lenv = ((object " };
pxll_string constructed_183 = {STRING_HEADER(6), 6, ")lenv)" };
pxll_string constructed_184 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_185 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_186 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_187 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_188 = {STRING_HEADER(20), 20, "[1] = lenv; lenv = r" };
pxll_string constructed_189 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_190 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_191 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_192 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_193 = {STRING_HEADER(15), 15, "lenv = lenv[1];" };
pxll_string constructed_194 = {STRING_HEADER(13), 13, "ensure_heap (" };
pxll_string constructed_195 = {STRING_HEADER(9), 9, ", unbox(r" };
pxll_string constructed_196 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_197 = {STRING_HEADER(12), 12, "%ensure-heap" };
// symbol %ensure-heap
pxll_int constructed_198[] = {UPTR(198,1), SYMBOL_HEADER, UPTR0(197)};
pxll_string constructed_199 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_200 = {STRING_HEADER(7), 7, ")->val[" };
pxll_string constructed_201 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_202 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_203 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_204 = {STRING_HEADER(36), 36, ")->val[lookup_field((GET_TYPECODE(*r" };
pxll_string constructed_205 = {STRING_HEADER(17), 17, ")-TC_USEROBJ)>>2," };
pxll_string constructed_206 = {STRING_HEADER(6), 6, ")] = r" };
pxll_string constructed_207 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_208 = {STRING_HEADER(6), 6, "primop" };
pxll_string constructed_209 = {STRING_HEADER(11), 11, "%record-set" };
// symbol %record-set
pxll_int constructed_210[] = {UPTR(210,1), SYMBOL_HEADER, UPTR0(209)};
pxll_string constructed_211 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_212 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_213 = {STRING_HEADER(7), 7, ")->val[" };
pxll_string constructed_214 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_215 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_216 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_217 = {STRING_HEADER(36), 36, ")->val[lookup_field((GET_TYPECODE(*r" };
pxll_string constructed_218 = {STRING_HEADER(17), 17, ")-TC_USEROBJ)>>2," };
pxll_string constructed_219 = {STRING_HEADER(3), 3, ")];" };
pxll_string constructed_220 = {STRING_HEADER(11), 11, "%record-get" };
// symbol %record-get
pxll_int constructed_221[] = {UPTR(221,1), SYMBOL_HEADER, UPTR0(220)};
pxll_string constructed_222 = {STRING_HEADER(16), 16, "((pxll_vector*)r" };
pxll_string constructed_223 = {STRING_HEADER(14), 14, ")->val[unbox(r" };
pxll_string constructed_224 = {STRING_HEADER(6), 6, ")] = r" };
pxll_string constructed_225 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_226 = {STRING_HEADER(41), 41, "range_check (GET_TUPLE_LENGTH(*(object*)r" };
pxll_string constructed_227 = {STRING_HEADER(10), 10, "), unbox(r" };
pxll_string constructed_228 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_229 = {STRING_HEADER(10), 10, "%array-set" };
// symbol %array-set
pxll_int constructed_230[] = {UPTR(230,1), SYMBOL_HEADER, UPTR0(229)};
pxll_string constructed_231 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_232 = {STRING_HEADER(19), 19, " = ((pxll_vector*)r" };
pxll_string constructed_233 = {STRING_HEADER(14), 14, ")->val[unbox(r" };
pxll_string constructed_234 = {STRING_HEADER(3), 3, ")];" };
pxll_string constructed_235 = {STRING_HEADER(41), 41, "range_check (GET_TUPLE_LENGTH(*(object*)r" };
pxll_string constructed_236 = {STRING_HEADER(10), 10, "), unbox(r" };
pxll_string constructed_237 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_238 = {STRING_HEADER(10), 10, "%array-ref" };
// symbol %array-ref
pxll_int constructed_239[] = {UPTR(239,1), SYMBOL_HEADER, UPTR0(238)};
pxll_string constructed_240 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_241 = {STRING_HEADER(3), 3, "  r" };
pxll_string constructed_242 = {STRING_HEADER(5), 5, " = t;" };
pxll_string constructed_243 = {STRING_HEADER(21), 21, "  for (i=0; i<unbox(r" };
pxll_string constructed_244 = {STRING_HEADER(20), 20, "); i++) { t[i+1] = r" };
pxll_string constructed_245 = {STRING_HEADER(3), 3, "; }" };
pxll_string constructed_246 = {STRING_HEADER(40), 40, "  t = alloc_no_clear (TC_VECTOR, unbox(r" };
pxll_string constructed_247 = {STRING_HEADER(3), 3, "));" };
pxll_string constructed_248 = {STRING_HEADER(11), 11, "if (unbox(r" };
pxll_string constructed_249 = {STRING_HEADER(11), 11, ") == 0) { r" };
pxll_string constructed_250 = {STRING_HEADER(39), 39, " = (object *) TC_EMPTY_VECTOR; } else {" };
pxll_string constructed_251 = {STRING_HEADER(12), 12, "%make-vector" };
// symbol %make-vector
pxll_int constructed_252[] = {UPTR(252,1), SYMBOL_HEADER, UPTR0(251)};
pxll_string constructed_253 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_254 = {STRING_HEADER(13), 13, " = UOBJ_GET(r" };
pxll_string constructed_255 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_256 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_257 = {STRING_HEADER(6), 6, "%nvget" };
// symbol %nvget
pxll_int constructed_258[] = {UPTR(258,1), SYMBOL_HEADER, UPTR0(257)};
pxll_string constructed_259 = {STRING_HEADER(29), 29, "emit-primop: no such datatype" };
pxll_string constructed_260 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_261 = {STRING_HEADER(12), 12, " = (object*)" };
pxll_string constructed_262 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_263 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_264 = {STRING_HEADER(5), 5, " = t;" };
pxll_string constructed_265 = {STRING_HEADER(2), 2, "t[" };
pxll_string constructed_266 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_267 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_268 = {STRING_HEADER(20), 20, "t = alloc_no_clear (" };
pxll_string constructed_269 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_270 = {STRING_HEADER(2), 2, ");" };
pxll_string constructed_271 = {STRING_HEADER(6), 6, "%dtcon" };
// symbol %dtcon
pxll_int constructed_272[] = {UPTR(272,1), SYMBOL_HEADER, UPTR0(271)};
pxll_string constructed_273 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_274 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_275 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_276 = {STRING_HEADER(1), 1, "r" };
pxll_string constructed_277 = {STRING_HEADER(4), 4, " = r" };
pxll_string constructed_278 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_279 = {STRING_HEADER(7), 7, "fatbar_" };
pxll_string constructed_280 = {STRING_HEADER(8), 8, "_over: ;" };
pxll_string constructed_281 = {STRING_HEADER(7), 7, "fatbar_" };
pxll_string constructed_282 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_283 = {STRING_HEADER(12), 12, "goto fatbar_" };
pxll_string constructed_284 = {STRING_HEADER(6), 6, "_over;" };
pxll_string constructed_285 = {STRING_HEADER(12), 12, "goto fatbar_" };
pxll_string constructed_286 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_287 = {STRING_HEADER(16), 16, "lenv = ((object " };
pxll_string constructed_288 = {STRING_HEADER(6), 6, ")lenv)" };
pxll_string constructed_289 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_290 = {STRING_HEADER(3), 3, "[1]" };
pxll_string constructed_291 = {STRING_HEADER(1), 1, "*" };
pxll_string constructed_292 = {STRING_HEADER(11), 11, "emit-nvcase" };
pxll_string constructed_293 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_294 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_295 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_296 = {STRING_HEADER(8), 8, "} break;" };
pxll_string constructed_297 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_298 = {STRING_HEADER(6), 6, "case (" };
pxll_string constructed_299 = {STRING_HEADER(4), 4, "): {" };
pxll_string constructed_300 = {STRING_HEADER(8), 8, "switch (" };
pxll_string constructed_301 = {STRING_HEADER(3), 3, " (r" };
pxll_string constructed_302 = {STRING_HEADER(4), 4, ")) {" };
pxll_string constructed_303 = {STRING_HEADER(8), 8, "get_case" };
pxll_string constructed_304 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_305 = {STRING_HEADER(8), 8, "} break;" };
pxll_string constructed_306 = {STRING_HEADER(10), 10, "default: {" };
pxll_string constructed_307 = {STRING_HEADER(6), 6, "case (" };
pxll_string constructed_308 = {STRING_HEADER(4), 4, "): {" };
pxll_string constructed_309 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_310 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_311 = {STRING_HEADER(6), 6, "UOTAG(" };
pxll_string constructed_312 = {STRING_HEADER(32), 32, "variant constructor never called" };
pxll_string constructed_313 = {STRING_HEADER(25), 25, "switch (get_case_noint (r" };
pxll_string constructed_314 = {STRING_HEADER(4), 4, ")) {" };
pxll_string constructed_315 = {STRING_HEADER(22), 22, "pvcase else-clause NYI" };
pxll_string constructed_316 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_317 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_318 = {STRING_HEADER(3), 3, ": r" };
pxll_string constructed_319 = {STRING_HEADER(9), 9, " = heap0[" };
pxll_string constructed_320 = {STRING_HEADER(2), 2, "];" };
pxll_string constructed_321 = {STRING_HEADER(14), 14, "  switch (n) {" };
pxll_string constructed_322 = {STRING_HEADER(26), 26, "void gc_regs_out (int n) {" };
pxll_string constructed_323 = {STRING_HEADER(2), 2, "}}" };
pxll_string constructed_324 = {STRING_HEADER(7), 7, "  case " };
pxll_string constructed_325 = {STRING_HEADER(8), 8, ": heap1[" };
pxll_string constructed_326 = {STRING_HEADER(5), 5, "] = r" };
pxll_string constructed_327 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_328 = {STRING_HEADER(14), 14, "  switch (n) {" };
pxll_string constructed_329 = {STRING_HEADER(25), 25, "void gc_regs_in (int n) {" };
pxll_string constructed_330 = {STRING_HEADER(19), 19, "register object * r" };
pxll_string constructed_331 = {STRING_HEADER(1), 1, ";" };
pxll_string constructed_332 = {STRING_HEADER(37), 37, "pxll_int pxll_internal_symbols[] = {(" };
pxll_string constructed_333 = {STRING_HEADER(16), 16, "<<8)|TC_VECTOR, " };
pxll_string constructed_334 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_335 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_336 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_337 = {STRING_HEADER(3), 3, ",1)" };
pxll_int constructed_338[] = {TC_NIL};
pxll_string constructed_339 = {STRING_HEADER(24), 24, "pxll_string constructed_" };
pxll_string constructed_340 = {STRING_HEADER(18), 18, " = {STRING_HEADER(" };
pxll_string constructed_341 = {STRING_HEADER(3), 3, "), " };
pxll_string constructed_342 = {STRING_HEADER(3), 3, ", \"" };
pxll_string constructed_343 = {STRING_HEADER(4), 4, "\" };" };
pxll_int constructed_344[] = {TC_NIL};
pxll_string constructed_345 = {STRING_HEADER(2), 2, "\\\"" };
pxll_string constructed_346 = {STRING_HEADER(2), 2, "\\\\" };
pxll_string constructed_347 = {STRING_HEADER(2), 2, "\\t" };
pxll_string constructed_348 = {STRING_HEADER(2), 2, "\\n" };
pxll_string constructed_349 = {STRING_HEADER(2), 2, "\\r" };
pxll_string constructed_350 = {STRING_HEADER(1), 1, "0" };
pxll_string constructed_351 = {STRING_HEADER(2), 2, "00" };
pxll_string constructed_352 = {STRING_HEADER(3), 3, "000" };
pxll_string constructed_353 = {STRING_HEADER(30), 30, "unable to oct-encode character" };
pxll_int constructed_354[] = {TC_NIL};
pxll_string constructed_355 = {STRING_HEADER(21), 21, "pxll_int constructed_" };
pxll_string constructed_356 = {STRING_HEADER(11), 11, "[] = {UPTR(" };
pxll_string constructed_357 = {STRING_HEADER(26), 26, ",1), SYMBOL_HEADER, UPTR0(" };
pxll_string constructed_358 = {STRING_HEADER(3), 3, ")};" };
pxll_string constructed_359 = {STRING_HEADER(10), 10, "// symbol " };
pxll_string constructed_360 = {STRING_HEADER(21), 21, "pxll_int constructed_" };
pxll_string constructed_361 = {STRING_HEADER(6), 6, "[] = {" };
pxll_string constructed_362 = {STRING_HEADER(2), 2, "};" };
pxll_string constructed_363 = {STRING_HEADER(1), 1, "," };
pxll_int constructed_364[] = {TC_NIL};
pxll_string constructed_365 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_366 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_367 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_368 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_369 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_370 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_371 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_372 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_373 = {STRING_HEADER(14), 14, "<<8)|TC_VECTOR" };
pxll_string constructed_374 = {STRING_HEADER(5), 5, "UPTR(" };
pxll_string constructed_375 = {STRING_HEADER(3), 3, ",1)" };
pxll_string constructed_376 = {STRING_HEADER(15), 15, "unknown symbol?" };
pxll_string constructed_377 = {STRING_HEADER(6), 6, "UPTR0(" };
pxll_string constructed_378 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_379 = {STRING_HEADER(29), 29, "emit-constructed: lost string" };
pxll_string constructed_380 = {STRING_HEADER(6), 6, "TC_NIL" };
pxll_string constructed_381 = {STRING_HEADER(6), 6, "UITAG(" };
pxll_string constructed_382 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_383 = {STRING_HEADER(11), 11, "CONS_HEADER" };
pxll_string constructed_384 = {STRING_HEADER(7), 7, "UOHEAD(" };
pxll_string constructed_385 = {STRING_HEADER(1), 1, "," };
pxll_string constructed_386 = {STRING_HEADER(1), 1, ")" };
pxll_int constructed_387[] = {TC_NIL};
pxll_string constructed_388 = {STRING_HEADER(39), 39, "template strings not found in header.c?" };
pxll_int constructed_389[] = {TC_NIL};
pxll_string constructed_390 = {STRING_HEADER(8), 8, "header.c" };
pxll_string constructed_391 = {STRING_HEADER(10), 10, "#include <" };
pxll_string constructed_392 = {STRING_HEADER(1), 1, ">" };
pxll_string constructed_393 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_394 = {STRING_HEADER(16), 16, "\n-- C output --\n" };
pxll_string constructed_395 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_396 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_397 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_398 = {STRING_HEADER(22), 22, "\n-- variant labels --\n" };
pxll_string constructed_399 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_400 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_401 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_402 = {STRING_HEADER(15), 15, "\n-- symbols --\n" };
pxll_string constructed_403 = {STRING_HEADER(15), 15, "\n-- records --\n" };
pxll_string constructed_404 = {STRING_HEADER(14), 14, "\n-- labels --\n" };
pxll_string constructed_405 = {STRING_HEADER(17), 17, "\n-- datatypes --\n" };
pxll_string constructed_406 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_407 = {STRING_HEADER(2), 2, "  " };
pxll_int constructed_408[] = {TC_NIL};
pxll_int constructed_409[] = {TC_NIL};
pxll_string constructed_410 = {STRING_HEADER(16), 16, "unbound variable" };
pxll_string constructed_411 = {STRING_HEADER(15), 15, "empty sequence?" };
pxll_string constructed_412 = {STRING_HEADER(6), 6, "vector" };
// symbol vector
pxll_int constructed_413[] = {UPTR(413,1), SYMBOL_HEADER, UPTR0(412)};
pxll_string constructed_414 = {STRING_HEADER(11), 11, "constructor" };
// symbol constructor
pxll_int constructed_415[] = {UPTR(415,1), SYMBOL_HEADER, UPTR0(414)};
pxll_string constructed_416 = {STRING_HEADER(13), 13, "c-conditional" };
pxll_string constructed_417 = {STRING_HEADER(3), 3, "pop" };
pxll_int constructed_418[] = {TC_NIL};
pxll_string constructed_419 = {STRING_HEADER(28), 28, "c-call function in register?" };
pxll_string constructed_420 = {STRING_HEADER(20), 20, "c-call: no function?" };
pxll_string constructed_421 = {STRING_HEADER(5), 5, "%rset" };
// symbol %rset
pxll_int constructed_422[] = {UPTR(422,1), SYMBOL_HEADER, UPTR0(421)};
pxll_string constructed_423 = {STRING_HEADER(8), 8, "%raccess" };
// symbol %raccess
pxll_int constructed_424[] = {UPTR(424,1), SYMBOL_HEADER, UPTR0(423)};
pxll_int constructed_425[] = {TC_NIL};
pxll_string constructed_426 = {STRING_HEADER(6), 6, "%rmake" };
// symbol %rmake
pxll_int constructed_427[] = {UPTR(427,1), SYMBOL_HEADER, UPTR0(426)};
pxll_string constructed_428 = {STRING_HEADER(18), 18, "malformed %rextend" };
pxll_string constructed_429 = {STRING_HEADER(8), 8, "%rextend" };
// symbol %rextend
pxll_int constructed_430[] = {UPTR(430,1), SYMBOL_HEADER, UPTR0(429)};
pxll_string constructed_431 = {STRING_HEADER(23), 23, "c-record-extension: NYI" };
pxll_string constructed_432 = {STRING_HEADER(22), 22, "unknown variant label?" };
pxll_string constructed_433 = {STRING_HEADER(16), 16, "bad %vcon params" };
pxll_string constructed_434 = {STRING_HEADER(5), 5, "%vcon" };
// symbol %vcon
pxll_int constructed_435[] = {UPTR(435,1), SYMBOL_HEADER, UPTR0(434)};
pxll_string constructed_436 = {STRING_HEADER(7), 7, "%fatbar" };
// symbol %fatbar
pxll_int constructed_437[] = {UPTR(437,1), SYMBOL_HEADER, UPTR0(436)};
pxll_string constructed_438 = {STRING_HEADER(21), 21, "%fail without fatbar?" };
pxll_string constructed_439 = {STRING_HEADER(5), 5, "%fail" };
// symbol %fail
pxll_int constructed_440[] = {UPTR(440,1), SYMBOL_HEADER, UPTR0(439)};
pxll_string constructed_441 = {STRING_HEADER(12), 12, "%match-error" };
// symbol %match-error
pxll_int constructed_442[] = {UPTR(442,1), SYMBOL_HEADER, UPTR0(441)};
pxll_string constructed_443 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_444 = {STRING_HEADER(16), 16, "incomplete match" };
pxll_int constructed_445[] = {TC_NIL};
pxll_string constructed_446 = {STRING_HEADER(13), 13, "add-free-regs" };
pxll_string constructed_447 = {STRING_HEADER(3), 3, "top" };
// symbol top
pxll_int constructed_448[] = {UPTR(448,1), SYMBOL_HEADER, UPTR0(447)};
pxll_int constructed_449[] = {UPTR(449,1),CONS_HEADER,UPTR(448,1),TC_NIL};
pxll_int constructed_450[] = {TC_NIL};
pxll_string constructed_451 = {STRING_HEADER(28), 28, "apply-tenv: unbound variable" };
pxll_string constructed_452 = {STRING_HEADER(3), 3, "raw" };
// symbol raw
pxll_int constructed_453[] = {UPTR(453,1), SYMBOL_HEADER, UPTR0(452)};
pxll_string constructed_454 = {STRING_HEADER(26), 26, "strange constructor scheme" };
pxll_string constructed_455 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_456 = {STRING_HEADER(28), 28, "wrong number of args to cexp" };
pxll_string constructed_457 = {STRING_HEADER(20), 20, "malformed arrow type" };
pxll_string constructed_458 = {STRING_HEADER(21), 21, "malformed conditional" };
pxll_string constructed_459 = {STRING_HEADER(15), 15, "empty sequence?" };
pxll_int constructed_460[] = {TC_NIL};
pxll_int constructed_461[] = {TC_NIL};
pxll_string constructed_462 = {STRING_HEADER(11), 11, "empty call?" };
pxll_int constructed_463[] = {TC_NIL};
pxll_int constructed_464[] = {TC_NIL};
pxll_int constructed_465[] = {TC_NIL};
pxll_int constructed_466[] = {TC_NIL};
pxll_int constructed_467[] = {TC_NIL};
pxll_int constructed_468[] = {TC_NIL};
pxll_int constructed_469[] = {TC_NIL};
pxll_int constructed_470[] = {TC_NIL};
pxll_int constructed_471[] = {TC_NIL};
pxll_string constructed_472 = {STRING_HEADER(31), 31, "wrong number of args to primapp" };
pxll_string constructed_473 = {STRING_HEADER(15), 15, "type-of-primapp" };
pxll_string constructed_474 = {STRING_HEADER(4), 4, "rsum" };
// symbol rsum
pxll_int constructed_475[] = {UPTR(475,1), SYMBOL_HEADER, UPTR0(474)};
pxll_string constructed_476 = {STRING_HEADER(3), 3, "pre" };
// symbol pre
pxll_int constructed_477[] = {UPTR(477,1), SYMBOL_HEADER, UPTR0(476)};
pxll_string constructed_478 = {STRING_HEADER(7), 7, "product" };
// symbol product
pxll_int constructed_479[] = {UPTR(479,1), SYMBOL_HEADER, UPTR0(478)};
pxll_int constructed_480[] = {TC_NIL};
pxll_string constructed_481 = {STRING_HEADER(32), 32, "lookup-primapp: no such datatype" };
pxll_string constructed_482 = {STRING_HEADER(24), 24, "bad parameters to primop" };
pxll_int constructed_483[] = {TC_NIL};
pxll_int constructed_484[] = {TC_NIL};
pxll_string constructed_485 = {STRING_HEADER(32), 32, "lookup-primapp: no such datatype" };
pxll_string constructed_486 = {STRING_HEADER(8), 8, "rproduct" };
// symbol rproduct
pxll_int constructed_487[] = {UPTR(487,1), SYMBOL_HEADER, UPTR0(486)};
pxll_int constructed_488[] = {TC_NIL};
pxll_int constructed_489[] = {TC_NIL};
pxll_string constructed_490 = {STRING_HEADER(8), 8, "rdefault" };
// symbol rdefault
pxll_int constructed_491[] = {UPTR(491,1), SYMBOL_HEADER, UPTR0(490)};
pxll_int constructed_492[] = {TC_NIL};
pxll_string constructed_493 = {STRING_HEADER(3), 3, "abs" };
// symbol abs
pxll_int constructed_494[] = {UPTR(494,1), SYMBOL_HEADER, UPTR0(493)};
pxll_int constructed_495[] = {TC_NIL};
pxll_int constructed_496[] = {TC_NIL};
pxll_int constructed_497[] = {TC_NIL};
pxll_string constructed_498 = {STRING_HEADER(14), 14, "lookup-primapp" };
pxll_string constructed_499 = {STRING_HEADER(16), 16, "malformed pvcase" };
pxll_string constructed_500 = {STRING_HEADER(16), 16, "no such datatype" };
pxll_string constructed_501 = {STRING_HEADER(10), 10, "typing NYI" };
pxll_int constructed_502[] = {TC_NIL};
pxll_string constructed_503 = {STRING_HEADER(23), 23, "instantiate-type-scheme" };
pxll_string constructed_504 = {STRING_HEADER(10), 10, "typing...\n" };
pxll_int constructed_505[] = {TC_NIL};
pxll_string constructed_506 = {STRING_HEADER(3), 3, "pop" };
pxll_int constructed_507[] = {TC_NIL};
pxll_int constructed_508[] = {TC_NIL};
pxll_int constructed_509[] = {TC_NIL};
pxll_int constructed_510[] = {TC_NIL};
pxll_int constructed_511[] = {TC_NIL};
pxll_int constructed_512[] = {TC_NIL};
pxll_string constructed_513 = {STRING_HEADER(31), 31, "strongly-connected components:\n" };
pxll_int constructed_514[] = {TC_NIL};
pxll_string constructed_515 = {STRING_HEADER(7), 7, "lambda_" };
pxll_string constructed_516 = {STRING_HEADER(6), 6, "lambda" };
// symbol lambda
pxll_int constructed_517[] = {UPTR(517,1), SYMBOL_HEADER, UPTR0(516)};
pxll_int constructed_518[] = {TC_NIL};
pxll_int constructed_519[] = {TC_NIL};
pxll_string constructed_520 = {STRING_HEADER(2), 2, ".c" };
pxll_string constructed_521 = {STRING_HEADER(9), 9, "find-base" };
pxll_string constructed_522 = {STRING_HEADER(1), 1, "." };
pxll_string constructed_523 = {STRING_HEADER(3), 3, "scm" };
pxll_string constructed_524 = {STRING_HEADER(2), 2, "if" };
// symbol if
pxll_int constructed_525[] = {UPTR(525,1), SYMBOL_HEADER, UPTR0(524)};
pxll_string constructed_526 = {STRING_HEADER(4), 4, "set!" };
// symbol set!
pxll_int constructed_527[] = {UPTR(527,1), SYMBOL_HEADER, UPTR0(526)};
pxll_string constructed_528 = {STRING_HEADER(5), 5, "begin" };
// symbol begin
pxll_int constructed_529[] = {UPTR(529,1), SYMBOL_HEADER, UPTR0(528)};
pxll_string constructed_530 = {STRING_HEADER(8), 8, "function" };
// symbol function
pxll_int constructed_531[] = {UPTR(531,1), SYMBOL_HEADER, UPTR0(530)};
pxll_string constructed_532 = {STRING_HEADER(5), 5, "vcase" };
// symbol vcase
pxll_int constructed_533[] = {UPTR(533,1), SYMBOL_HEADER, UPTR0(532)};
pxll_string constructed_534 = {STRING_HEADER(9), 9, "let-splat" };
// symbol let-splat
pxll_int constructed_535[] = {UPTR(535,1), SYMBOL_HEADER, UPTR0(534)};
pxll_string constructed_536 = {STRING_HEADER(5), 5, "match" };
// symbol match
pxll_int constructed_537[] = {UPTR(537,1), SYMBOL_HEADER, UPTR0(536)};
pxll_string constructed_538 = {STRING_HEADER(8), 8, "cinclude" };
// symbol cinclude
pxll_int constructed_539[] = {UPTR(539,1), SYMBOL_HEADER, UPTR0(538)};
pxll_string constructed_540 = {STRING_HEADER(7), 7, "%nvcase" };
// symbol %nvcase
pxll_int constructed_541[] = {UPTR(541,1), SYMBOL_HEADER, UPTR0(540)};
pxll_string constructed_542 = {STRING_HEADER(6), 6, "%%cexp" };
// symbol %%cexp
pxll_int constructed_543[] = {UPTR(543,1), SYMBOL_HEADER, UPTR0(542)};
pxll_string constructed_544 = {STRING_HEADER(16), 16, "malformed %%cexp" };
pxll_string constructed_545 = {STRING_HEADER(20), 20, "malformed <cinclude>" };
pxll_int constructed_546[] = {TC_NIL};
pxll_int constructed_547[] = {TC_NIL};
pxll_string constructed_548 = {STRING_HEADER(3), 3, "let" };
// symbol let
pxll_int constructed_549[] = {UPTR(549,1), SYMBOL_HEADER, UPTR0(548)};
pxll_string constructed_550 = {STRING_HEADER(4), 4, "with" };
// symbol with
pxll_int constructed_551[] = {UPTR(551,1), SYMBOL_HEADER, UPTR0(550)};
pxll_string constructed_552 = {STRING_HEADER(26), 26, "malformed match expression" };
pxll_string constructed_553 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_554 = {STRING_HEADER(3), 3, "arg" };
pxll_string constructed_555 = {STRING_HEADER(1), 1, ":" };
pxll_int constructed_556[] = {TC_NIL};
pxll_int constructed_557[] = {TC_NIL};
pxll_int constructed_558[] = {TC_NIL};
pxll_int constructed_559[] = {TC_NIL};
pxll_int constructed_560[] = {TC_NIL};
pxll_string constructed_561 = {STRING_HEADER(4), 4, "else" };
// symbol else
pxll_int constructed_562[] = {UPTR(562,1), SYMBOL_HEADER, UPTR0(561)};
pxll_string constructed_563 = {STRING_HEADER(10), 10, "split-alts" };
pxll_int constructed_564[] = {TC_NIL};
pxll_string constructed_565 = {STRING_HEADER(1), 1, "_" };
// symbol _
pxll_int constructed_566[] = {UPTR(566,1), SYMBOL_HEADER, UPTR0(565)};
pxll_int constructed_567[] = {TC_NIL};
pxll_int constructed_568[] = {TC_NIL};
pxll_string constructed_569 = {STRING_HEADER(12), 12, "expand-vcase" };
pxll_string constructed_570 = {STRING_HEADER(18), 18, "malformed FUNCTION" };
pxll_string constructed_571 = {STRING_HEADER(16), 16, "malformed LAMBDA" };
pxll_string constructed_572 = {STRING_HEADER(30), 30, "malformed binding in LET-SPLAT" };
pxll_string constructed_573 = {STRING_HEADER(19), 19, "malformed LET-SPLAT" };
pxll_string constructed_574 = {STRING_HEADER(11), 11, "empty BEGIN" };
pxll_string constructed_575 = {STRING_HEADER(14), 14, "malformed set!" };
pxll_string constructed_576 = {STRING_HEADER(14), 14, "malformed <if>" };
pxll_int constructed_577[] = {TC_NIL};
pxll_string constructed_578 = {STRING_HEADER(1), 1, "o" };
// symbol o
pxll_int constructed_579[] = {UPTR(579,1), SYMBOL_HEADER, UPTR0(578)};
pxll_string constructed_580 = {STRING_HEADER(7), 7, "%method" };
// symbol %method
pxll_int constructed_581[] = {UPTR(581,1), SYMBOL_HEADER, UPTR0(580)};
pxll_int constructed_582[] = {TC_NIL};
pxll_int constructed_583[] = {TC_NIL};
pxll_int constructed_584[] = {TC_NIL};
pxll_string constructed_585 = {STRING_HEADER(20), 20, "malformed definition" };
pxll_string constructed_586 = {STRING_HEADER(2), 2, "->" };
// symbol ->
pxll_int constructed_587[] = {UPTR(587,1), SYMBOL_HEADER, UPTR0(586)};
pxll_string constructed_588 = {STRING_HEADER(18), 18, "malformed <define>" };
pxll_string constructed_589 = {STRING_HEADER(6), 6, "define" };
// symbol define
pxll_int constructed_590[] = {UPTR(590,1), SYMBOL_HEADER, UPTR0(589)};
pxll_int constructed_591[] = {TC_NIL};
pxll_string constructed_592 = {STRING_HEADER(2), 2, ")\n" };
pxll_string constructed_593 = {STRING_HEADER(2), 2, "\n\t" };
pxll_string constructed_594 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_595 = {STRING_HEADER(3), 3, ">\n\t" };
pxll_string constructed_596 = {STRING_HEADER(8), 8, "(macro <" };
pxll_string constructed_597 = {STRING_HEADER(28), 28, "no matching clause for macro" };
pxll_int constructed_598[] = {TC_NIL};
pxll_string constructed_599 = {STRING_HEADER(27), 27, "malformed macro definition:" };
pxll_string constructed_600 = {STRING_HEADER(27), 27, "malformed macro definition:" };
pxll_string constructed_601 = {STRING_HEADER(8), 8, "defmacro" };
// symbol defmacro
pxll_int constructed_602[] = {UPTR(602,1), SYMBOL_HEADER, UPTR0(601)};
pxll_string constructed_603 = {STRING_HEADER(25), 25, "malformed alt in datatype" };
pxll_string constructed_604 = {STRING_HEADER(23), 23, "no such alt in datatype" };
pxll_string constructed_605 = {STRING_HEADER(23), 23, "no such alt in datatype" };
pxll_string constructed_606 = {STRING_HEADER(18), 18, "malformed datatype" };
pxll_string constructed_607 = {STRING_HEADER(8), 8, "datatype" };
// symbol datatype
pxll_int constructed_608[] = {UPTR(608,1), SYMBOL_HEADER, UPTR0(607)};
pxll_int constructed_609[] = {TC_NIL};
pxll_int constructed_610[] = {TC_NIL};
pxll_string constructed_611 = {STRING_HEADER(3), 3, "fix" };
// symbol fix
pxll_int constructed_612[] = {UPTR(612,1), SYMBOL_HEADER, UPTR0(611)};
pxll_int constructed_613[] = {TC_NIL};
pxll_string constructed_614 = {STRING_HEADER(39), 39, "unexpected s-expression in transformer:" };
pxll_string constructed_615 = {STRING_HEADER(16), 16, "self/selfmac.scm" };
pxll_int constructed_616[] = {TC_NIL};
pxll_int constructed_617[] = {TC_NIL};
pxll_int constructed_618[] = {TC_NIL};
pxll_int constructed_619[] = {TC_NIL};
pxll_int constructed_620[] = {TC_NIL};
pxll_string constructed_621 = {STRING_HEADER(31), 31, "Usage: compile <irken-src-file>" };
pxll_string constructed_622 = {STRING_HEADER(28), 28, "// REGISTER_DECLARATIONS //\n" };
pxll_string constructed_623 = {STRING_HEADER(27), 27, "// CONSTRUCTED LITERALS //\n" };
pxll_string constructed_624 = {STRING_HEADER(95), 95, "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~ " };
pxll_string constructed_625 = {STRING_HEADER(1), 1, "L" };
pxll_int constructed_626[] = {TC_NIL};
pxll_int constructed_627[] = {TC_NIL};
pxll_int constructed_628[] = {TC_NIL};
pxll_int constructed_629[] = {TC_NIL};
pxll_string constructed_630 = {STRING_HEADER(1), 1, "?" };
// symbol ?
pxll_int constructed_631[] = {UPTR(631,1), SYMBOL_HEADER, UPTR0(630)};
pxll_string constructed_632 = {STRING_HEADER(3), 3, "int" };
// symbol int
pxll_int constructed_633[] = {UPTR(633,1), SYMBOL_HEADER, UPTR0(632)};
pxll_string constructed_634 = {STRING_HEADER(4), 4, "char" };
// symbol char
pxll_int constructed_635[] = {UPTR(635,1), SYMBOL_HEADER, UPTR0(634)};
pxll_string constructed_636 = {STRING_HEADER(9), 9, "undefined" };
// symbol undefined
pxll_int constructed_637[] = {UPTR(637,1), SYMBOL_HEADER, UPTR0(636)};
pxll_int constructed_638[] = {TC_NIL};
pxll_int constructed_639[] = {TC_NIL};
pxll_int constructed_640[] = {TC_NIL};
pxll_int constructed_641[] = {TC_NIL};
pxll_int constructed_642[] = {TC_NIL};
pxll_int constructed_643[] = {TC_NIL};
pxll_int constructed_644[] = {UPTR(644,10),CONS_HEADER,3330,TC_NIL,CONS_HEADER,2562,UPTR(644,1),CONS_HEADER,2306,UPTR(644,4),CONS_HEADER,8194,UPTR(644,7)};
pxll_string constructed_645 = {STRING_HEADER(10), 10, "0123456789" };
pxll_string constructed_646 = {STRING_HEADER(52), 52, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" };
pxll_string constructed_647 = {STRING_HEADER(7), 7, "()[]{}:" };
pxll_int constructed_648[] = {UPTR(648,10),CONS_HEADER,3330,TC_NIL,CONS_HEADER,2562,UPTR(648,1),CONS_HEADER,2306,UPTR(648,4),CONS_HEADER,8194,UPTR(648,7)};
pxll_int constructed_649[] = {UPTR(649,29),UOHEAD(3,1),14082,15,UITAG(0),UOHEAD(3,1),13826,13,UPTR(649,1),UOHEAD(3,1),13570,11,UPTR(649,5),UOHEAD(3,1),13314,9,UPTR(649,9),UOHEAD(3,1),13058,7,UPTR(649,13),UOHEAD(3,1),12802,5,UPTR(649,17),UOHEAD(3,1),12546,3,UPTR(649,21),UOHEAD(3,1),12290,1,UPTR(649,25)};
pxll_int constructed_650[] = {UPTR(650,37),UOHEAD(3,1),14594,19,UITAG(0),UOHEAD(3,1),14338,17,UPTR(650,1),UOHEAD(3,1),14082,15,UPTR(650,5),UOHEAD(3,1),13826,13,UPTR(650,9),UOHEAD(3,1),13570,11,UPTR(650,13),UOHEAD(3,1),13314,9,UPTR(650,17),UOHEAD(3,1),13058,7,UPTR(650,21),UOHEAD(3,1),12802,5,UPTR(650,25),UOHEAD(3,1),12546,3,UPTR(650,29),UOHEAD(3,1),12290,1,UPTR(650,33)};
pxll_int constructed_651[] = {UPTR(651,85),UOHEAD(3,1),17922,31,UITAG(0),UOHEAD(3,1),17666,29,UPTR(651,1),UOHEAD(3,1),17410,27,UPTR(651,5),UOHEAD(3,1),17154,25,UPTR(651,9),UOHEAD(3,1),16898,23,UPTR(651,13),UOHEAD(3,1),16642,21,UPTR(651,17),UOHEAD(3,1),26114,31,UPTR(651,21),UOHEAD(3,1),25858,29,UPTR(651,25),UOHEAD(3,1),25602,27,UPTR(651,29),UOHEAD(3,1),25346,25,UPTR(651,33),UOHEAD(3,1),25090,23,UPTR(651,37),UOHEAD(3,1),24834,21,UPTR(651,41),UOHEAD(3,1),14594,19,UPTR(651,45),UOHEAD(3,1),14338,17,UPTR(651,49),UOHEAD(3,1),14082,15,UPTR(651,53),UOHEAD(3,1),13826,13,UPTR(651,57),UOHEAD(3,1),13570,11,UPTR(651,61),UOHEAD(3,1),13314,9,UPTR(651,65),UOHEAD(3,1),13058,7,UPTR(651,69),UOHEAD(3,1),12802,5,UPTR(651,73),UOHEAD(3,1),12546,3,UPTR(651,77),UOHEAD(3,1),12290,1,UPTR(651,81)};
pxll_string constructed_652 = {STRING_HEADER(0), 0, "" };
pxll_int constructed_653[] = {UPTR(653,1),(16<<8)|TC_VECTOR,12290,12546,12802,13058,13314,13570,13826,14082,14338,14594,24834,25090,25346,25602,25858,26114};
pxll_string constructed_654 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_655 = {STRING_HEADER(30), 30, "malformed cexp template string" };
pxll_string constructed_656 = {STRING_HEADER(1), 1, "%" };
pxll_string constructed_657 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_658 = {STRING_HEADER(30), 30, "malformed cexp template string" };
pxll_string constructed_659 = {STRING_HEADER(9), 9, "(object*)" };
pxll_string constructed_660 = {STRING_HEADER(7), 7, "cstring" };
// symbol cstring
pxll_int constructed_661[] = {UPTR(661,1), SYMBOL_HEADER, UPTR0(660)};
pxll_string constructed_662 = {STRING_HEADER(10), 10, "PXLL_TEST(" };
pxll_string constructed_663 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_664 = {STRING_HEADER(4), 4, "box(" };
pxll_string constructed_665 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_666 = {STRING_HEADER(16), 16, "((pxll_string*)(" };
pxll_string constructed_667 = {STRING_HEADER(2), 2, "))" };
pxll_string constructed_668 = {STRING_HEADER(25), 25, "unknown raw type in %cexp" };
pxll_string constructed_669 = {STRING_HEADER(12), 12, "continuation" };
// symbol continuation
pxll_int constructed_670[] = {UPTR(670,1), SYMBOL_HEADER, UPTR0(669)};
pxll_string constructed_671 = {STRING_HEADER(16), 16, "(((pxll_vector*)" };
pxll_string constructed_672 = {STRING_HEADER(4), 4, ")+1)" };
pxll_string constructed_673 = {STRING_HEADER(6), 6, "buffer" };
// symbol buffer
pxll_int constructed_674[] = {UPTR(674,1), SYMBOL_HEADER, UPTR0(673)};
pxll_string constructed_675 = {STRING_HEADER(7), 7, "(char*)" };
pxll_string constructed_676 = {STRING_HEADER(16), 16, "((pxll_string*)(" };
pxll_string constructed_677 = {STRING_HEADER(8), 8, "))->data" };
pxll_string constructed_678 = {STRING_HEADER(6), 6, "unbox(" };
pxll_string constructed_679 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_680 = {STRING_HEADER(37), 37, "unexpected predicate in cexp type sig" };
pxll_string constructed_681 = {STRING_HEADER(27), 27, "expected immediate literal " };
pxll_string constructed_682 = {STRING_HEADER(17), 17, "inline: bad arity" };
pxll_int constructed_683[] = {TC_NIL};
pxll_string constructed_684 = {STRING_HEADER(2), 2, "_i" };
pxll_int constructed_685[] = {TC_NIL};
pxll_int constructed_686[] = {TC_NIL};
pxll_int constructed_687[] = {TC_NIL};
pxll_int constructed_688[] = {TC_NIL};
pxll_string constructed_689 = {STRING_HEADER(2), 2, "_i" };
pxll_int constructed_690[] = {TC_NIL};
pxll_string constructed_691 = {STRING_HEADER(43), 43, "inline-application - inlining non-function?" };
pxll_int constructed_692[] = {TC_NIL};
pxll_int constructed_693[] = {TC_NIL};
pxll_int constructed_694[] = {TC_NIL};
pxll_int constructed_695[] = {TC_NIL};
pxll_int constructed_696[] = {TC_NIL};
pxll_int constructed_697[] = {TC_NIL};
pxll_int constructed_698[] = {TC_NIL};
pxll_string constructed_699 = {STRING_HEADER(33), 33, "find-escaping-funs: failed lookup" };
pxll_int constructed_700[] = {TC_NIL};
pxll_int constructed_701[] = {TC_NIL};
pxll_int constructed_702[] = {TC_NIL};
pxll_string constructed_703 = {STRING_HEADER(11), 11, "simpleopt: " };
pxll_string constructed_704 = {STRING_HEADER(1), 1, "\n" };
pxll_int constructed_705[] = {TC_NIL};
pxll_int constructed_706[] = {TC_NIL};
pxll_string constructed_707 = {STRING_HEADER(3), 3, "moo" };
// symbol moo
pxll_int constructed_708[] = {UPTR(708,1), SYMBOL_HEADER, UPTR0(707)};
pxll_string constructed_709 = {STRING_HEADER(6), 6, "rlabel" };
// symbol rlabel
pxll_int constructed_710[] = {UPTR(710,1), SYMBOL_HEADER, UPTR0(709)};
pxll_string constructed_711 = {STRING_HEADER(10), 10, "type error" };
pxll_string constructed_712 = {STRING_HEADER(14), 14, "\nType Error:\n\t" };
pxll_string constructed_713 = {STRING_HEADER(2), 2, "\n\t" };
pxll_string constructed_714 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_715 = {STRING_HEADER(8), 8, "k/target" };
pxll_string constructed_716 = {STRING_HEADER(6), 6, "k/free" };
pxll_int constructed_717[] = {TC_NIL};
pxll_int constructed_718[] = {TC_NIL};
pxll_string constructed_719 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_720 = {STRING_HEADER(22), 22, "unhandled literal type" };
pxll_int constructed_721[] = {TC_NIL};
pxll_int constructed_722[] = {TC_NIL};
pxll_int constructed_723[] = {TC_NIL};
pxll_string constructed_724 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_725 = {STRING_HEADER(9), 9, "let_subst" };
// symbol let_subst
pxll_int constructed_726[] = {UPTR(726,1), SYMBOL_HEADER, UPTR0(725)};
pxll_string constructed_727 = {STRING_HEADER(6), 6, "letrec" };
// symbol letrec
pxll_int constructed_728[] = {UPTR(728,1), SYMBOL_HEADER, UPTR0(727)};
pxll_string constructed_729 = {STRING_HEADER(7), 7, "literal" };
// symbol literal
pxll_int constructed_730[] = {UPTR(730,1), SYMBOL_HEADER, UPTR0(729)};
pxll_string constructed_731 = {STRING_HEADER(5), 5, "quote" };
// symbol quote
pxll_int constructed_732[] = {UPTR(732,1), SYMBOL_HEADER, UPTR0(731)};
pxll_string constructed_733 = {STRING_HEADER(28), 28, "null primapp missing params?" };
pxll_string constructed_734 = {STRING_HEADER(14), 14, "syntax error: " };
pxll_string constructed_735 = {STRING_HEADER(16), 16, "syntax error 2: " };
pxll_int constructed_736[] = {TC_NIL};
pxll_int constructed_737[] = {TC_NIL};
pxll_int constructed_738[] = {TC_NIL};
pxll_int constructed_739[] = {TC_NIL};
pxll_int constructed_740[] = {TC_NIL};
pxll_int constructed_741[] = {TC_NIL};
pxll_string constructed_742 = {STRING_HEADER(15), 15, "unpack-bindings" };
pxll_int constructed_743[] = {TC_NIL};
pxll_string constructed_744 = {STRING_HEADER(16), 16, "malformed formal" };
pxll_string constructed_745 = {STRING_HEADER(7), 7, "varref " };
pxll_string constructed_746 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_747 = {STRING_HEADER(7), 7, "varset " };
pxll_string constructed_748 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_749 = {STRING_HEADER(8), 8, "literal " };
pxll_string constructed_750 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_751 = {STRING_HEADER(5), 5, "cexp " };
pxll_string constructed_752 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_753 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_754 = {STRING_HEADER(11), 11, "sequence : " };
pxll_string constructed_755 = {STRING_HEADER(14), 14, "conditional : " };
pxll_string constructed_756 = {STRING_HEADER(7), 7, "call : " };
pxll_string constructed_757 = {STRING_HEADER(9), 9, "function " };
pxll_string constructed_758 = {STRING_HEADER(2), 2, " (" };
pxll_string constructed_759 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_760 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_761 = {STRING_HEADER(5), 5, "fix (" };
pxll_string constructed_762 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_763 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_764 = {STRING_HEADER(7), 7, "nvcase " };
pxll_string constructed_765 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_766 = {STRING_HEADER(3), 3, ") (" };
pxll_string constructed_767 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_768 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_769 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_770 = {STRING_HEADER(6), 6, "subst " };
pxll_string constructed_771 = {STRING_HEADER(2), 2, "->" };
pxll_string constructed_772 = {STRING_HEADER(8), 8, "primapp " };
pxll_string constructed_773 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_774 = {STRING_HEADER(3), 3, " : " };
pxll_string constructed_775 = {STRING_HEADER(5), 5, "let (" };
pxll_string constructed_776 = {STRING_HEADER(4), 4, ") : " };
pxll_string constructed_777 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_778 = {STRING_HEADER(1), 1, " " };
pxll_int constructed_779[] = {TC_NIL};
pxll_string constructed_780 = {STRING_HEADER(2), 2, "#u" };
pxll_string constructed_781 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_782 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_783 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_784 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_785 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_786 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_787 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_788 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_789 = {STRING_HEADER(2), 2, "#(" };
pxll_string constructed_790 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_791 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_792 = {STRING_HEADER(20), 20, "unpack-fix: no body?" };
pxll_string constructed_793 = {STRING_HEADER(12), 12, "varref->name" };
pxll_string constructed_794 = {STRING_HEADER(4), 4, "  )\n" };
pxll_string constructed_795 = {STRING_HEADER(4), 4, "  (:" };
pxll_string constructed_796 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_797 = {STRING_HEADER(2), 2, ")\n" };
pxll_string constructed_798 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_799 = {STRING_HEADER(10), 10, "(datatype " };
pxll_int constructed_800[] = {TC_NIL};
pxll_int constructed_801[] = {TC_NIL};
pxll_int constructed_802[] = {TC_NIL};
pxll_int constructed_803[] = {TC_NIL};
pxll_int constructed_804[] = {TC_NIL};
pxll_string constructed_805 = {STRING_HEADER(1), 1, "." };
// symbol .
pxll_int constructed_806[] = {UPTR(806,1), SYMBOL_HEADER, UPTR0(805)};
pxll_string constructed_807 = {STRING_HEADER(17), 17, "malformed pattern" };
pxll_int constructed_808[] = {TC_NIL};
pxll_string constructed_809 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_810 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_811 = {STRING_HEADER(25), 25, "not a constructor pattern" };
pxll_string constructed_812 = {STRING_HEADER(15), 15, "stack underflow" };
pxll_string constructed_813 = {STRING_HEADER(15), 15, "stack underflow" };
pxll_int constructed_814[] = {TC_NIL};
pxll_string constructed_815 = {STRING_HEADER(21), 21, "not a literal pattern" };
pxll_string constructed_816 = {STRING_HEADER(20), 20, "not a record pattern" };
pxll_string constructed_817 = {STRING_HEADER(1), 1, "_" };
pxll_string constructed_818 = {STRING_HEADER(40), 40, "record pattern with different label sigs" };
pxll_string constructed_819 = {STRING_HEADER(6), 6, "record" };
// symbol record
pxll_int constructed_820[] = {UPTR(820,1), SYMBOL_HEADER, UPTR0(819)};
pxll_string constructed_821 = {STRING_HEADER(33), 33, "arity mismatch in variant pattern" };
pxll_int constructed_822[] = {TC_NIL};
pxll_int constructed_823[] = {TC_NIL};
pxll_string constructed_824 = {STRING_HEADER(39), 39, "more than one datatype in pattern match" };
pxll_string constructed_825 = {STRING_HEADER(8), 8, "variable" };
// symbol variable
pxll_int constructed_826[] = {UPTR(826,1), SYMBOL_HEADER, UPTR0(825)};
pxll_string constructed_827 = {STRING_HEADER(8), 8, "string=?" };
// symbol string=?
pxll_int constructed_828[] = {UPTR(828,1), SYMBOL_HEADER, UPTR0(827)};
pxll_string constructed_829 = {STRING_HEADER(3), 3, "eq?" };
// symbol eq?
pxll_int constructed_830[] = {UPTR(830,1), SYMBOL_HEADER, UPTR0(829)};
pxll_string constructed_831 = {STRING_HEADER(19), 19, "empty pattern list?" };
pxll_string constructed_832 = {STRING_HEADER(29), 29, "remove-first-pat: empty pats?" };
pxll_string constructed_833 = {STRING_HEADER(1), 1, "m" };
pxll_int constructed_834[] = {TC_NIL};
pxll_int constructed_835[] = {TC_NIL};
pxll_string constructed_836 = {STRING_HEADER(14), 14, "bad record sig" };
pxll_string constructed_837 = {STRING_HEADER(26), 26, "unable to get record sig: " };
pxll_string constructed_838 = {STRING_HEADER(1), 1, "\n" };
pxll_int constructed_839[] = {TC_NIL};
pxll_string constructed_840 = {STRING_HEADER(8), 8, "bad type" };
pxll_string constructed_841 = {STRING_HEADER(15), 15, "malformed type?" };
pxll_int constructed_842[] = {TC_NIL};
pxll_string constructed_843 = {STRING_HEADER(14), 14, "bad arrow type" };
pxll_string constructed_844 = {STRING_HEADER(19), 19, "malformed predicate" };
pxll_string constructed_845 = {STRING_HEADER(1), 1, "t" };
pxll_string constructed_846 = {STRING_HEADER(2), 2, "->" };
pxll_string constructed_847 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_848 = {STRING_HEADER(3), 3, ")->" };
pxll_string constructed_849 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_850 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_851 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_852 = {STRING_HEADER(2), 2, ", " };
pxll_string constructed_853 = {STRING_HEADER(18), 18, "expected sexp:list" };
pxll_string constructed_854 = {STRING_HEADER(13), 13, "expected list" };
pxll_int constructed_855[] = {TC_NIL};
pxll_int constructed_856[] = {TC_NIL};
pxll_int constructed_857[] = {TC_NIL};
pxll_string constructed_858 = {STRING_HEADER(36), 36, "unexpected args to ellipsis-sub-envs" };
pxll_int constructed_859[] = {TC_NIL};
pxll_int constructed_860[] = {TC_NIL};
pxll_string constructed_861 = {STRING_HEADER(2), 2, "()" };
pxll_string constructed_862 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_863 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_864 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_865 = {STRING_HEADER(1), 1, "(" };
pxll_string constructed_866 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_867 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_868 = {STRING_HEADER(1), 1, "\"" };
pxll_string constructed_869 = {STRING_HEADER(1), 1, "\"" };
pxll_string constructed_870 = {STRING_HEADER(2), 2, "#\\" };
pxll_string constructed_871 = {STRING_HEADER(2), 2, "#t" };
pxll_string constructed_872 = {STRING_HEADER(2), 2, "#f" };
pxll_string constructed_873 = {STRING_HEADER(2), 2, "#u" };
pxll_string constructed_874 = {STRING_HEADER(2), 2, "#(" };
pxll_string constructed_875 = {STRING_HEADER(1), 1, ")" };
pxll_string constructed_876 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_877 = {STRING_HEADER(1), 1, "{" };
pxll_string constructed_878 = {STRING_HEADER(1), 1, "}" };
pxll_string constructed_879 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_880 = {STRING_HEADER(1), 1, ":" };
pxll_string constructed_881 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_882 = {STRING_HEADER(1), 1, "." };
pxll_string constructed_883 = {STRING_HEADER(3), 3, "..." };
pxll_string constructed_884 = {STRING_HEADER(1), 1, "=" };
pxll_string constructed_885 = {STRING_HEADER(9), 9, "sexp->int" };
pxll_string constructed_886 = {STRING_HEADER(12), 12, "sexp->symbol" };
pxll_int constructed_887[] = {TC_NIL};
pxll_string constructed_888 = {STRING_HEADER(7), 7, "include" };
// symbol include
pxll_int constructed_889[] = {UPTR(889,1), SYMBOL_HEADER, UPTR0(888)};
pxll_int constructed_890[] = {TC_NIL};
pxll_string constructed_891 = {STRING_HEADER(13), 13, "bad hex digit" };
pxll_string constructed_892 = {STRING_HEADER(12), 12, "colon syntax" };
pxll_string constructed_893 = {STRING_HEADER(30), 30, "expected closing ]/} character" };
pxll_string constructed_894 = {STRING_HEADER(22), 22, "unexpected close-paren" };
pxll_string constructed_895 = {STRING_HEADER(3), 3, "nul" };
pxll_string constructed_896 = {STRING_HEADER(3), 3, "eof" };
pxll_string constructed_897 = {STRING_HEADER(3), 3, "tab" };
pxll_string constructed_898 = {STRING_HEADER(6), 6, "return" };
pxll_string constructed_899 = {STRING_HEADER(5), 5, "space" };
pxll_string constructed_900 = {STRING_HEADER(7), 7, "newline" };
pxll_string constructed_901 = {STRING_HEADER(22), 22, "bad character constant" };
pxll_string constructed_902 = {STRING_HEADER(12), 12, "syntax error" };
pxll_string constructed_903 = {STRING_HEADER(15), 15, "expected symbol" };
pxll_string constructed_904 = {STRING_HEADER(36), 36, "no dots allowed in constructor names" };
pxll_string constructed_905 = {STRING_HEADER(5), 5, "comma" };
// symbol comma
pxll_int constructed_906[] = {UPTR(906,1), SYMBOL_HEADER, UPTR0(905)};
pxll_int constructed_907[] = {TC_NIL};
pxll_string constructed_908 = {STRING_HEADER(30), 30, "bad backslash escape in string" };
pxll_int constructed_909[] = {TC_NIL};
pxll_string constructed_910 = {STRING_HEADER(30), 30, "expected '=' in record literal" };
pxll_int constructed_911[] = {TC_NIL};
pxll_string constructed_912 = {STRING_HEADER(22), 22, "unexpected end of file" };
pxll_string constructed_913 = {STRING_HEADER(18), 18, "bad decimal digit?" };
pxll_int constructed_914[] = {TC_NIL};
pxll_string constructed_915 = {STRING_HEADER(22), 22, "unexpected end-of-file" };
pxll_string constructed_916 = {STRING_HEADER(13), 13, "reading file " };
pxll_string constructed_917 = {STRING_HEADER(0), 0, "" };
pxll_string constructed_918 = {STRING_HEADER(13), 13, "open() failed" };
pxll_int constructed_919[] = {TC_NIL};
pxll_int constructed_920[] = {TC_NIL};
pxll_int constructed_921[] = {TC_NIL};
pxll_int constructed_922[] = {TC_NIL};
pxll_int constructed_923[] = {TC_NIL};
pxll_int constructed_924[] = {TC_NIL};
pxll_int constructed_925[] = {UPTR(925,1),(0<<8)|TC_VECTOR};
pxll_int constructed_926[] = {TC_NIL};
pxll_string constructed_927 = {STRING_HEADER(29), 29, "every2?: unequal-length lists" };
pxll_string constructed_928 = {STRING_HEADER(31), 31, "for-each2: unequal-length lists" };
pxll_int constructed_929[] = {TC_NIL};
pxll_int constructed_930[] = {TC_NIL};
pxll_string constructed_931 = {STRING_HEADER(26), 26, "map2: unequal-length lists" };
pxll_int constructed_932[] = {TC_NIL};
pxll_int constructed_933[] = {TC_NIL};
pxll_int constructed_934[] = {TC_NIL};
pxll_string constructed_935 = {STRING_HEADER(23), 23, "list index out of range" };
pxll_string constructed_936 = {STRING_HEADER(23), 23, "list index out of range" };
pxll_int constructed_937[] = {TC_NIL};
pxll_string constructed_938 = {STRING_HEADER(4), 4, "last" };
pxll_string constructed_939 = {STRING_HEADER(3), 3, "cdr" };
pxll_string constructed_940 = {STRING_HEADER(3), 3, "car" };
pxll_string constructed_941 = {STRING_HEADER(1), 1, " " };
pxll_string constructed_942 = {STRING_HEADER(17), 17, "lookup-label-code" };
pxll_string constructed_943 = {STRING_HEADER(25), 25, "vars-get-var: no such var" };
pxll_string constructed_944 = {STRING_HEADER(2), 2, "}\n" };
pxll_string constructed_945 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_946 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_947 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_948 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_949 = {STRING_HEADER(2), 2, "  " };
pxll_string constructed_950 = {STRING_HEADER(1), 1, "\n" };
pxll_string constructed_951 = {STRING_HEADER(4), 4, "name" };
pxll_string constructed_952 = {STRING_HEADER(5), 5, "flags" };
pxll_string constructed_953 = {STRING_HEADER(4), 4, "mult" };
pxll_string constructed_954 = {STRING_HEADER(5), 5, "calls" };
pxll_string constructed_955 = {STRING_HEADER(4), 4, "sets" };
pxll_string constructed_956 = {STRING_HEADER(4), 4, "refs" };
pxll_string constructed_957 = {STRING_HEADER(9), 9, "vars = {\n" };
pxll_int pxll_internal_symbols[] = {(79<<8)|TC_VECTOR, UPTR(42,1), UPTR(45,1), UPTR(47,1), UPTR(50,1), UPTR(52,1), UPTR(57,1), UPTR(59,1), UPTR(62,1), UPTR(67,1), UPTR(84,1), UPTR(95,1), UPTR(198,1), UPTR(210,1), UPTR(221,1), UPTR(230,1), UPTR(239,1), UPTR(252,1), UPTR(258,1), UPTR(272,1), UPTR(413,1), UPTR(415,1), UPTR(422,1), UPTR(424,1), UPTR(427,1), UPTR(430,1), UPTR(435,1), UPTR(437,1), UPTR(440,1), UPTR(442,1), UPTR(448,1), UPTR(453,1), UPTR(475,1), UPTR(477,1), UPTR(479,1), UPTR(487,1), UPTR(491,1), UPTR(494,1), UPTR(517,1), UPTR(525,1), UPTR(527,1), UPTR(529,1), UPTR(531,1), UPTR(533,1), UPTR(535,1), UPTR(537,1), UPTR(539,1), UPTR(541,1), UPTR(543,1), UPTR(549,1), UPTR(551,1), UPTR(562,1), UPTR(566,1), UPTR(579,1), UPTR(581,1), UPTR(587,1), UPTR(590,1), UPTR(602,1), UPTR(608,1), UPTR(612,1), UPTR(631,1), UPTR(633,1), UPTR(635,1), UPTR(637,1), UPTR(661,1), UPTR(670,1), UPTR(674,1), UPTR(708,1), UPTR(710,1), UPTR(726,1), UPTR(728,1), UPTR(730,1), UPTR(732,1), UPTR(806,1), UPTR(820,1), UPTR(826,1), UPTR(828,1), UPTR(830,1), UPTR(889,1), UPTR(906,1)};

pxll_int
vm (int argc, char * argv[])
{
  register object * lenv = PXLL_NIL;
  register object * k = PXLL_NIL;
// REGISTER_DECLARATIONS //
  register object * r0;
  register object * r1;
  register object * r2;
  register object * r3;
  register object * r4;
  register object * r5;
  register object * r6;
  register object * r7;
  void gc_regs_in (int n) {
    switch (n) {
    case 8: heap1[10] = r7;
    case 7: heap1[9] = r6;
    case 6: heap1[8] = r5;
    case 5: heap1[7] = r4;
    case 4: heap1[6] = r3;
    case 3: heap1[5] = r2;
    case 2: heap1[4] = r1;
    case 1: heap1[3] = r0;
  }}
  void gc_regs_out (int n) {
    switch (n) {
    case 8: r7 = heap0[10];
    case 7: r6 = heap0[9];
    case 6: r5 = heap0[8];
    case 5: r4 = heap0[7];
    case 4: r3 = heap0[6];
    case 3: r2 = heap0[5];
    case 2: r1 = heap0[4];
    case 1: r0 = heap0[3];
  }}
  object * top = PXLL_NIL; // top-level (i.e. 'global') environment
  object * t = 0; // temp - for swaps & building tuples
  object * result;
  object * limit = heap0 + (heap_size - head_room);
  object * freep = heap0;
  int i; // loop counter
  
#define PXLL_RETURN(d)	result = r##d; goto *k[3]

#include "gc.c"

  // check heap is called at the top of each allocating function.
  //  [by locating the check at the top, we avoid considering any
  //   registers as roots of the gc...]
  void check_heap (int nfree) {
    if (freep >= limit) {
      uint64_t t0, t1;
      t0 = rdtsc();
      gc_flip (nfree);
      t1 = rdtsc();
      gc_ticks += t1 - t0;
    }
  }

  void ensure_heap (int nfree, pxll_int size) {
    if (freep + size + 1 >= limit) {
      uint64_t t0, t1;
      t0 = rdtsc();
      gc_flip (nfree);
      t1 = rdtsc();
      gc_ticks += t1 - t0;
    }
  }

  object * allocate (pxll_int tc, pxll_int size) {
    object * save = freep;
    *freep = (object*) (size<<8 | (tc & 0xff));
#if 1
    // at least on the g5, this technique is considerably faster than using memset
    //   in gc_flip() to 'pre-clear' the heap... probably a cache effect...
    while (size--) {
      // this keeps gc from being confused by partially-filled objects.
      *(++freep) = PXLL_NIL;
    }
    ++freep;
#else
    // if you use this version, be sure to set <clear_tospace>!
    freep += size + 1;
#endif
    return save;  
  }

  // this is emitted by the backend for %make-tuple
  object * alloc_no_clear (pxll_int tc, pxll_int size) {
    object * save = freep;
    *freep = (object*) (size<<8 | (tc & 0xff));
    freep += size + 1;
    return save;  
  }

  // gcc inlines/unrolls these nicely, they allow more compact code
  inline object * varref (pxll_int depth, pxll_int index)
  {
    object * walk = lenv;
    while (depth--) {
      walk = walk[1];
    }
    return walk[index+2];
  }

  inline void varset (pxll_int depth, pxll_int index, object * val)
  {
    object * walk = lenv;
    while (depth--) {
      walk = walk[1];
    }
    walk[index+2] = val;
  }

  
  // these could probably be written in irken...
  pxll_int dump_image (char * filename, object * closure) {
    FILE * dump_file = fopen (filename, "wb");
    pxll_int offset;
    pxll_int size;
    object * start;
    // do a gc for a compact dump
    closure = gc_dump (closure);
    // for now, start at the front of the heap
    start = heap0;
    size = freep - start;
    offset = (pxll_int) heap0;
    // XXX add endian indicator...
    fprintf (dump_file, "(pxll image %" PRIuPTR " %p)\n", sizeof (pxll_int), start);
    fwrite (&offset, sizeof(pxll_int), 1, dump_file);
    fwrite (&size, sizeof(pxll_int), 1, dump_file);
    fwrite (start, sizeof(pxll_int), size, dump_file);
    fclose (dump_file);
    return size;
  }

  object * load_image (char * filename) {
    FILE * load_file = fopen (filename, "rb");
    if (!load_file) {
      abort();
    } else {
      object * start, * thunk;
      pxll_int size;
      read_header (load_file);	// XXX verify header...
      fread (&start, sizeof(pxll_int), 1, load_file);
      fread (&size, sizeof(pxll_int), 1, load_file);
      fread (heap1, sizeof(pxll_int), size, load_file);
      fprintf (stderr, "size=%d\n", (int) size);
      // relocate heap0
      gc_relocate (4, heap1, heap1 + size, start - heap1);
      // replace roots
      lenv  = (object *) heap1[0];
      k     = (object *) heap1[1];
      top   = (object *) heap1[2];
      thunk = (object *) heap1[3];
      freep = heap1 + size;
      // swap heaps
      { object * temp = heap0; heap0 = heap1; heap1 = temp; }
      return thunk;
    }
  }

  k = allocate (TC_SAVE, 3);
  k[1] = (object *) PXLL_NIL; // top of stack
  k[2] = (object *) PXLL_NIL; // null environment
  k[3] = &&Lreturn; // continuation that will return from this function.
  // --- BEGIN USER PROGRAM ---
  r0 = allocate (TC_TUPLE, 191);
  r0[1] = lenv; lenv = r0;
  // def list:cons_3
  goto L0;
  FUN_list_3acons_3:
    check_heap (0);
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L0:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list_3acons_3; r1[2] = lenv;
  r0[2] = r1;
  // def sexp:symbol_19
  goto L1;
  FUN_sexp_3asymbol_19:
    check_heap (0);
    r0 = varref (0, 0);
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3asymbol_19; r1[2] = lenv;
  r0[3] = r1;
  // def sexp:int_23
  goto L2;
  FUN_sexp_3aint_23:
    check_heap (0);
    r0 = varref (0, 0);
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3aint_23; r1[2] = lenv;
  r0[4] = r1;
  // def vars-get-var_255
  goto L3;
  FUN_vars_get_var_255:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (1, 0);
    r2 = ((pxll_vector*)r2)->val[14];
    r1[2] = r2;
    r2 = varref (2, 74);
    r1[3] = r2;
    r2 = varref (1, 1);
    r1[4] = r2;
    r2 = varref (2, 70);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L4; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L4:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 146);
        r2 = (object *) 5;
        r1 = box(unbox(r2)+unbox(r1));
        r0[2] = r1;
        r0 = (object*) &constructed_957;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_957;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 16);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_956;
        r3[3] = r4;
        r4 = varref (5, 57);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L5; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L5:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_955;
        r3[3] = r4;
        r4 = varref (5, 57);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L6; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L6:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_954;
        r3[3] = r4;
        r4 = varref (5, 57);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L7; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L7:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 13;
        r3[2] = r4;
        r4 = (object*) &constructed_953;
        r3[3] = r4;
        r4 = varref (5, 57);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L8; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cpad_380;
        L8:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[5] = r3;
        r3 = allocate (TC_TUPLE, 4);
        r4 = varref (2, 0);
        r3[2] = r4;
        r4 = (object*) &constructed_952;
        r3[3] = r4;
        r4 = (object *) 262;
        r3[4] = r4;
        r4 = varref (5, 56);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L9; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
        L9:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[6] = r3;
        r3 = allocate (TC_TUPLE, 4);
        r4 = (object *) 61;
        r3[2] = r4;
        r4 = (object*) &constructed_951;
        r3[3] = r4;
        r4 = (object *) 6;
        r3[4] = r4;
        r4 = varref (5, 56);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L10; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
        L10:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[7] = r3;
        r3 = (object*)TC_NIL;
        r2[8] = r3;
        r3 = varref (0, 6);
        r4 = (object*) &constructed_950;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = varref (0, 7);
        r4 = varref (0, 5);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = varref (0, 8);
        r4 = (object*) &constructed_949;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r3 = varref (0, 9);
        r4 = varref (0, 4);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[12] = r3;
        r3 = varref (0, 10);
        r4 = varref (0, 3);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[13] = r3;
        r3 = varref (0, 11);
        r4 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[14] = r3;
        r3 = varref (0, 12);
        r4 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[15] = r3;
        r3 = varref (0, 13);
        r4 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[16] = r3;
        r2 = varref (0, 14);
        r3 = (object*) &constructed_948;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (4, 45);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L11; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L11:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        r0 = box(((pxll_string*)(r0))->len);
        r1 = varref (0, 0);
        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_830_i11
        goto L12;
        FUN_lambda_830_i11:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 22);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (2, 1);
          r4 = ((pxll_vector*)r4)->val[3];
          r3[2] = r4;
          r4 = varref (6, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L13; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L13:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = varref (0, 0);
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = varref (6, 56);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L14; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L14:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (2, 1);
          r4 = ((pxll_vector*)r4)->val[4];
          r3[2] = r4;
          r4 = varref (6, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L15; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L15:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = varref (0, 2);
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = varref (6, 56);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L16; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L16:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[5] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (2, 1);
          r4 = ((pxll_vector*)r4)->val[0];
          r3[2] = r4;
          r4 = varref (6, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L17; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L17:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[6] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = varref (0, 4);
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = varref (6, 56);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L18; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L18:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[7] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (2, 1);
          r4 = ((pxll_vector*)r4)->val[2];
          r3[2] = r4;
          r4 = varref (6, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L19; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L19:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[8] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 13;
          r3[2] = r4;
          r4 = varref (0, 6);
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = varref (6, 56);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L20; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L20:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[9] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (2, 1);
          r4 = ((pxll_vector*)r4)->val[1];
          r3[2] = r4;
          r4 = varref (6, 118);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L21; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_flags_repr_508;
          L21:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[10] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = varref (3, 0);
          r3[2] = r4;
          r4 = varref (0, 8);
          r3[3] = r4;
          r4 = (object *) 262;
          r3[4] = r4;
          r4 = varref (6, 56);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L22; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L22:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[11] = r3;
          r3 = varref (2, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (3, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[12] = r3;
          r3 = allocate (TC_TUPLE, 4);
          r4 = (object *) 61;
          r3[2] = r4;
          r4 = varref (0, 10);
          r3[3] = r4;
          r4 = (object *) 6;
          r3[4] = r4;
          r4 = varref (6, 56);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L23; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
          L23:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[13] = r3;
          r3 = (object*)TC_NIL;
          r2[14] = r3;
          r3 = varref (0, 12);
          r4 = (object*) &constructed_947;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[15] = r3;
          r3 = varref (0, 13);
          r4 = varref (0, 11);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[16] = r3;
          r3 = varref (0, 14);
          r4 = (object*) &constructed_946;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[17] = r3;
          r3 = varref (0, 15);
          r4 = varref (0, 9);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[18] = r3;
          r3 = varref (0, 16);
          r4 = varref (0, 7);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[19] = r3;
          r3 = varref (0, 17);
          r4 = varref (0, 5);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[20] = r3;
          r3 = varref (0, 18);
          r4 = varref (0, 3);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[21] = r3;
          r3 = varref (0, 19);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[22] = r3;
          r2 = varref (0, 20);
          r3 = (object*) &constructed_945;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (5, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L24; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L24:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 0);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          PXLL_RETURN(0);
        L12:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_830_i11; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[14];
        r0[3] = r1;
        r1 = varref (3, 71);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L25; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L25:
        ; lenv = k[2]; k = k[1];
        r0 = (object*) &constructed_944;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_944;
        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_943;
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (2, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L3:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_vars_get_var_255; r1[2] = lenv;
  r0[5] = r1;
  // def vars-set-flag!_257
  goto L26;
  FUN_vars_set_flag_bang_257:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (1, 1);
    r1[3] = r2;
    r2 = varref (2, 3);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L27; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
    L27:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r0[2] = r1;
    r0 = varref (2, 2);
    r1 = varref (0, 0);
    r0 = box(unbox(r1)|(1<<unbox(r0)));
    lenv = lenv[1];
    r0 = r0;
    r1 = varref (0, 0);
    ((pxll_vector*)r1)->val[1] = r0;
    PXLL_RETURN(0);
  L26:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_vars_set_flag_bang_257; r1[2] = lenv;
  r0[6] = r1;
  // def add-var_259
  goto L28;
  FUN_add_var_259:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (1, 1);
    r2 = ((pxll_vector*)r2)->val[14];
    r1[2] = r2;
    r2 = varref (2, 74);
    r1[3] = r2;
    r2 = varref (1, 0);
    r1[4] = r2;
    r2 = varref (2, 70);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L29; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L29:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 5);
        r1 = varref (1, 1);
        r1 = ((pxll_vector*)r1)->val[14];
        r0[2] = r1;
        r1 = varref (2, 74);
        r0[3] = r1;
        r1 = varref (1, 0);
        r0[4] = r1;
        r1 = allocate (UOTAG(22), 5);
        r2 = (object *) 1;
        r1[1] = r2;
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = (object *) 1;
        r1[4] = r2;
        r2 = (object *) 1;
        r1[5] = r2;
        r0[5] = r1;
        r1 = varref (2, 69);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L30; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
        L30:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = varref (1, 1);
        ((pxll_vector*)r1)->val[14] = r0;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L28:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_add_var_259; r1[2] = lenv;
  r0[7] = r1;
  // def add-vars_260
  goto L31;
  FUN_add_vars_260:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def add_655
    goto L32;
    FUN_add_655:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (2, 1);
      r0[3] = r1;
      r1 = varref (3, 5);
      r0[1] = r1[2]; lenv = r0; goto FUN_add_var_259;
    L32:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_655; r1[2] = lenv;
    r0[2] = r1;
    // def search_656
    goto L33;
    FUN_search_656:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 0);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (5, 33);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L34; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
          L34:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 0);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (5, 33);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L35; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
          L35:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (5, 33);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L36; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
          L36:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (4, 1);
          r0[3] = r1;
          r1 = varref (5, 5);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L37; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_add_var_259;
          L37:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_391;
        }
      }
      r0=r0;
      goto fatbar_391_over;
      fatbar_391:
      r0 = (object *) 14;
      r0=r0;
      fatbar_391_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (1, 1);
      r0[2] = r1;
      r1 = varref (0, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (3, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L33:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_search_656; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN_search_656;
  L31:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_add_vars_260; r1[2] = lenv;
  r0[8] = r1;
  // def lookup-label-code_262
  goto L38;
  FUN_lookup_label_code_262:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_668
    goto L39;
    FUN_loop_668:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_942;
          r0[2] = r1;
          r1 = varref (2, 0);
          r0[3] = r1;
          r1 = varref (3, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (4, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = varref (0, 1);
                PXLL_RETURN(0);
              } else {
                r0 = varref (1, 1);
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                goto FUN_loop_668;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L39:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_668; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 1);
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_668;
  L38:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lookup_label_code_262; r1[2] = lenv;
  r0[9] = r1;
  // def =_270
  goto L40;
  FUN__3d_270:
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    PXLL_RETURN(0);
  L40:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__3d_270; r1[2] = lenv;
  r0[10] = r1;
  // def <_272
  goto L41;
  FUN__3c_272:
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L41:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__3c_272; r1[2] = lenv;
  r0[11] = r1;
  // def +_278
  goto L42;
  FUN__plus_278:
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = box(unbox(r1)+unbox(r0));
    PXLL_RETURN(0);
  L42:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__plus_278; r1[2] = lenv;
  r0[12] = r1;
  // def eq?_294
  goto L43;
  FUN_eq_question_294:
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = PXLL_TEST(r1==r0);
    PXLL_RETURN(0);
  L43:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_eq_question_294; r1[2] = lenv;
  r0[13] = r1;
  // def error1_303
  goto L44;
  FUN_error1_303:
    r0 = (object *) 2562;
    box(fputc (GET_CHAR(r0), stdout));
    r0 = varref (0, 0);
    r0 = box(((pxll_string*)(r0))->len);
    r1 = varref (0, 0);
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_941;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_941;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = varref (0, 1);
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = varref (0, 1);
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
    PXLL_RETURN(0);
  L44:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_error1_303; r1[2] = lenv;
  r0[14] = r1;
  // def id_306
  goto L45;
  FUN_id_306:
    r0 = varref (0, 0);
    PXLL_RETURN(0);
  L45:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_id_306; r1[2] = lenv;
  r0[15] = r1;
  // def ^call/cc_307
  goto L46;
  FUN__5ecall_2fcc_307:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = k;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_1109
    goto L47;
    FUN_lambda_1109:
      r0 = varref (0, 0);
      r1 = varref (1, 0);
      r0 = (k=r1, r0);
      PXLL_RETURN(0);
    L47:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_1109; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (1, 0);
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L46:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN__5ecall_2fcc_307; r1[2] = lenv;
  r0[16] = r1;
  // def pair->first_310
  goto L48;
  FUN_pair__3efirst_310:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case_noint (r0)) {
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L48:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pair__3efirst_310; r1[2] = lenv;
  r0[17] = r1;
  // def pair->second_311
  goto L49;
  FUN_pair__3esecond_311:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case_noint (r0)) {
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L49:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pair__3esecond_311; r1[2] = lenv;
  r0[18] = r1;
  // def car_318
  goto L50;
  FUN_car_318:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_940;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_940;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L50:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_car_318; r1[2] = lenv;
  r0[19] = r1;
  // def cdr_319
  goto L51;
  FUN_cdr_319:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_939;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_939;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L51:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cdr_319; r1[2] = lenv;
  r0[20] = r1;
  // def reverse-onto_320
  goto L52;
  FUN_reverse_onto_320:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = varref (1, 1);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = varref (2, 19);
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
      } break;
    }
    PXLL_RETURN(0);
  L52:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_reverse_onto_320; r1[2] = lenv;
  r0[21] = r1;
  // def length_323
  goto L53;
  FUN_length_323:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def fun_781
    goto L54;
    FUN_fun_781:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (0, 1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (1, 1);
          r1 = (object *) 3;
          r0 = box(unbox(r1)+unbox(r0));
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_fun_781;
        } break;
      }
      PXLL_RETURN(0);
    L54:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fun_781; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_fun_781;
  L53:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_length_323; r1[2] = lenv;
  r0[22] = r1;
  // def last_326
  goto L55;
  FUN_last_326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_938;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_938;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = varref (0, 0);
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_390;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_390_over;
        fatbar_390:
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = varref (2, 21);
        r0[1] = r1[2]; lenv = r0; goto FUN_last_326;
        fatbar_390_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L55:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_last_326; r1[2] = lenv;
  r0[23] = r1;
  // def member?_327
  goto L56;
  FUN_member_question_327:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r0[3] = r1;
        r1 = varref (1, 2);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L57; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L57:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (1, 2);
          r0[4] = r1;
          r1 = varref (2, 22);
          r0[1] = r1[2]; lenv = r0; goto FUN_member_question_327;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L56:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_member_question_327; r1[2] = lenv;
  r0[24] = r1;
  // def member-eq?_328
  goto L58;
  FUN_member_eq_question_328:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (2, 23);
          r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_328;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L58:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_member_eq_question_328; r1[2] = lenv;
  r0[25] = r1;
  // def remove-eq_329
  goto L59;
  FUN_remove_eq_329:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_937[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (1, 0);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (2, 0);
          r1[2] = r2;
          r2 = varref (1, 1);
          r1[3] = r2;
          r2 = varref (3, 24);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L60; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_remove_eq_329;
          L60:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L59:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_remove_eq_329; r1[2] = lenv;
  r0[26] = r1;
  // def nth_330
  goto L61;
  FUN_nth_330:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_936;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_936;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) 1;
        r1 = varref (1, 1);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } else {
          goto fatbar_389;
        }
        PXLL_RETURN(0);
        goto fatbar_389_over;
        fatbar_389:
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = (object *) 3;
        r2 = varref (1, 1);
        r1 = box(unbox(r2)-unbox(r1));
        r0[3] = r1;
        r1 = varref (2, 25);
        r0[1] = r1[2]; lenv = r0; goto FUN_nth_330;
        fatbar_389_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L61:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_nth_330; r1[2] = lenv;
  r0[27] = r1;
  // def index-eq_331
  goto L62;
  FUN_index_eq_331:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_810
    goto L63;
    FUN_loop_810:
      check_heap (0);
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object*) &constructed_69;
          r0 = box(((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_935;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_935;
          r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (3, 0);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 0);
            PXLL_RETURN(0);
          } else {
            r0 = (object *) 3;
            r1 = varref (1, 0);
            r0 = box(unbox(r1)+unbox(r0));
            r1 = varref (0, 1);
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            lenv[3] = r1;
            goto FUN_loop_810;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L63:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_810; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = varref (1, 1);
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_810;
  L62:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_index_eq_331; r1[2] = lenv;
  r0[28] = r1;
  // def slice_332
  goto L64;
  FUN_slice_332:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 1);
    r2 = varref (1, 2);
    r1 = box(unbox(r2)-unbox(r1));
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) constructed_933[0];
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_818
      goto L65;
      FUN_loop_818:
        check_heap (0);
        r0 = varref (2, 1);
        r1 = varref (0, 1);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
          r0 = (object *) 3;
          r1 = varref (0, 1);
          r0 = box(unbox(r1)+unbox(r0));
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (3, 18);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L66; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
          L66:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r2 = varref (0, 2);
          lenv[2] = r1;
          lenv[3] = r0;
          lenv[4] = r2;
          goto FUN_loop_818;
        } else {
          r0 = varref (2, 2);
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (4, 17);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L67; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
            L67:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (1, 2);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = varref (0, 1);
            r1 = box(unbox(r2)+unbox(r1));
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = varref (3, 18);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L68; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_cdr_319;
            L68:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv[2] = r2;
            lenv[3] = r1;
            lenv[4] = r0;
            goto FUN_loop_818;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 2);
            r0[2] = r1;
            r1 = (object *) constructed_37[0];
            r0[3] = r1;
            r1 = varref (3, 19);
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L65:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_818; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 4);
      r1 = varref (1, 0);
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) constructed_934[0];
      r0[4] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_818;
    }
    PXLL_RETURN(0);
  L64:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_slice_332; r1[2] = lenv;
  r0[29] = r1;
  // def range_333
  goto L69;
  FUN_range_333:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_823
    goto L70;
    FUN_loop_823:
      check_heap (0);
      r0 = (object *) 1;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } else {
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        r1 = (object *) 3;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)-unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_823;
      }
      PXLL_RETURN(0);
    L70:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_823; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 3;
    r2 = varref (1, 0);
    r1 = box(unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = (object*)TC_NIL;
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_823;
  L69:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_range_333; r1[2] = lenv;
  r0[30] = r1;
  // def n-of_334
  goto L71;
  FUN_n_of_334:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_828
    goto L72;
    FUN_loop_828:
      check_heap (0);
      r0 = (object *) 1;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<=unbox(r0))) {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } else {
        r0 = varref (0, 1);
        r1 = varref (2, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        r1 = (object *) 3;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)-unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_828;
      }
      PXLL_RETURN(0);
    L72:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_828; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = (object*)TC_NIL;
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_828;
  L71:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_n_of_334; r1[2] = lenv;
  r0[31] = r1;
  // def map_335
  goto L73;
  FUN_map_335:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_932[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (1, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L74; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L74:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = varref (0, 1);
        r1[3] = r2;
        r2 = varref (2, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L75; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L75:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r0 = varref (0, 3);
        r1 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L73:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_map_335; r1[2] = lenv;
  r0[32] = r1;
  // def map2_336
  goto L76;
  FUN_map2_336:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) constructed_930[0];
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_388;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (1, 2);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (2, 2);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (2, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L77; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L77:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = varref (2, 0);
            r1[2] = r2;
            r2 = varref (1, 1);
            r1[3] = r2;
            r2 = varref (0, 1);
            r1[4] = r2;
            r2 = varref (3, 31);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L78; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map2_336;
            L78:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = varref (0, 3);
            r1 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_388;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_388_over;
    fatbar_388:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_931;
    r0[2] = r1;
    r1 = allocate (UOTAG(0), 2);
    r2 = varref (0, 1);
    r1[1] = r2;
    r2 = varref (0, 2);
    r1[2] = r2;
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_388_over: ;
    PXLL_RETURN(0);
  L76:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_map2_336; r1[2] = lenv;
  r0[33] = r1;
  // def filter_337
  goto L79;
  FUN_filter_337:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_929[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L80; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L80:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (2, 0);
          r1[2] = r2;
          r2 = varref (1, 1);
          r1[3] = r2;
          r2 = varref (3, 32);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L81; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_filter_337;
          L81:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (2, 32);
          r0[1] = r1[2]; lenv = r0; goto FUN_filter_337;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L79:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_filter_337; r1[2] = lenv;
  r0[34] = r1;
  // def for-each_338
  goto L82;
  FUN_for_each_338:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L83; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L83:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 1);
        r0[3] = r1;
        r1 = varref (2, 33);
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      } break;
    }
    PXLL_RETURN(0);
  L82:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_for_each_338; r1[2] = lenv;
  r0[35] = r1;
  // def for-each2_339
  goto L84;
  FUN_for_each2_339:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_387;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (1, 2);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (2, 2);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (2, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L85; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L85:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (2, 0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r0[3] = r1;
            r1 = varref (0, 1);
            r0[4] = r1;
            r1 = varref (3, 34);
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_339;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_387;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_387_over;
    fatbar_387:
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_928;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_928;
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_387_over: ;
    PXLL_RETURN(0);
  L84:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_for_each2_339; r1[2] = lenv;
  r0[36] = r1;
  // def fold_340
  goto L86;
  FUN_fold_340:
    check_heap (0);
    r0 = varref (0, 2);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L87; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L87:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = varref (0, 1);
        r2 = varref (1, 0);
        lenv = ((object *)lenv)[1];
        lenv[2] = r2;
        lenv[3] = r0;
        lenv[4] = r1;
        goto FUN_fold_340;
      } break;
    }
    PXLL_RETURN(0);
  L86:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_fold_340; r1[2] = lenv;
  r0[37] = r1;
  // def foldr_341
  goto L88;
  FUN_foldr_341:
    check_heap (0);
    r0 = varref (0, 2);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (0, 1);
        r1[4] = r2;
        r2 = varref (2, 36);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L89; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_foldr_341;
        L89:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (1, 0);
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      } break;
    }
    PXLL_RETURN(0);
  L88:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_foldr_341; r1[2] = lenv;
  r0[38] = r1;
  // def some?_342
  goto L90;
  FUN_some_question_342:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L91; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L91:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (2, 37);
          r0[1] = r1[2]; lenv = r0; goto FUN_some_question_342;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L90:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_some_question_342; r1[2] = lenv;
  r0[39] = r1;
  // def every?_343
  goto L92;
  FUN_every_question_343:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L93; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L93:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (2, 38);
          r0[1] = r1[2]; lenv = r0; goto FUN_every_question_343;
        } else {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L92:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_every_question_343; r1[2] = lenv;
  r0[40] = r1;
  // def every2?_344
  goto L94;
  FUN_every2_question_344:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_386;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (1, 2);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (2, 2);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (2, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L95; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L95:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r1 = varref (2, 0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r0[3] = r1;
              r1 = varref (0, 1);
              r0[4] = r1;
              r1 = varref (3, 39);
              r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_344;
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_386;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_386_over;
    fatbar_386:
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_927;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_927;
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_386_over: ;
    PXLL_RETURN(0);
  L94:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_every2_question_344; r1[2] = lenv;
  r0[41] = r1;
  // def pack_346
  goto L96;
  FUN_pack_346:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def pack2_889
    goto L97;
    FUN_pack2_889:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 1);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (4, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L98; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L98:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r0 = varref (0, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (1, 2);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L99; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L99:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (1, 1);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            r1 = varref (1, 2);
            r2 = varref (0, 1);
            lenv = ((object *)lenv)[1];
            lenv[2] = r2;
            lenv[3] = r0;
            lenv[4] = r1;
            goto FUN_pack2_889;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 1);
            r1[2] = r2;
            r2 = (object *) constructed_37[0];
            r1[3] = r2;
            r2 = varref (5, 19);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L100; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
            L100:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = varref (1, 1);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = (object*)TC_NIL;
            r2[2] = r3;
            r2 = varref (0, 0);
            r3 = varref (2, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r2 = varref (1, 0);
            r1[4] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L101; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pack2_889;
            L101:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = varref (0, 1);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L97:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pack2_889; r1[2] = lenv;
    r0[2] = r1;
    r0 = varref (1, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_926[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r1 = varref (0, 0);
        r2 = varref (1, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = varref (0, 0);
        r0[4] = r1;
        r1 = varref (1, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_pack2_889;
      } break;
    }
    PXLL_RETURN(0);
  L96:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pack_346; r1[2] = lenv;
  r0[42] = r1;
  // def list->vector_348
  goto L102;
  FUN_list__3evector_348:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_902
    goto L103;
    FUN_recur_902:
      check_heap (0);
      r0 = varref (0, 2);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (1, 1);
          r1 = varref (0, 0);
          r2 = varref (1, 0);
          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
          ((pxll_vector*)r2)->val[unbox(r0)] = r1;
          r0 = (object *) 3;
          r1 = varref (1, 1);
          r0 = box(unbox(r1)+unbox(r0));
          r1 = varref (0, 1);
          r2 = varref (1, 0);
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_recur_902;
        } break;
      }
      PXLL_RETURN(0);
    L103:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_902; r1[2] = lenv;
    r0[2] = r1;
    r0 = varref (1, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_925[0];
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r1[2] = r2;
        r2 = varref (3, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L104; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L104:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (0, 1);
        ensure_heap (1, unbox(r1));
        r1 = varref (0, 0);
        r2 = varref (0, 1);
        if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
          t = alloc_no_clear (TC_VECTOR, unbox(r2));
          for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
          r1 = t;
        }
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (0, 2);
        r0[2] = r1;
        r1 = (object *) 1;
        r0[3] = r1;
        r1 = varref (2, 0);
        r0[4] = r1;
        r1 = varref (1, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_recur_902;
      } break;
    }
    PXLL_RETURN(0);
  L102:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list__3evector_348; r1[2] = lenv;
  r0[43] = r1;
  // def sort_350
  goto L105;
  FUN_sort_350:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def halve_923
    goto L106;
    FUN_halve_923:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (UOTAG(0), 2);
          r1 = varref (0, 0);
          r0[1] = r1;
          r1 = (object *) constructed_923[0];
          r0[2] = r1;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (UOTAG(0), 2);
              r1 = varref (1, 0);
              r0[1] = r1;
              r1 = (object *) constructed_924[0];
              r0[2] = r1;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_385;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_385_over;
          fatbar_385:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 1);
          r1[2] = r2;
          r2 = varref (3, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L107; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_halve_923;
          L107:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = allocate (UOTAG(0), 2);
              r1 = varref (0, 1);
              r2 = varref (2, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[1] = r1;
              r1 = varref (0, 0);
              r0[2] = r1;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
          fatbar_385_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L106:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_halve_923; r1[2] = lenv;
    r0[2] = r1;
    // def merge-sort_924
    goto L108;
    FUN_merge_sort_924:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_384;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_384_over;
      fatbar_384:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (2, 0);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L109; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_halve_923;
      L109:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (3, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L110; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_merge_sort_924;
          L110:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = varref (3, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L111; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_merge_sort_924;
          L111:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_927_i161
          goto L112;
          FUN_loop_927_i161:
            check_heap (0);
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = varref (0, 1);
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (1, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = varref (1, 0);
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (2, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (2, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = varref (1, 0);
                    r0[2] = r1;
                    r1 = varref (0, 0);
                    r0[3] = r1;
                    r1 = varref (8, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L113; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L113:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    if PXLL_IS_TRUE(r0) {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (2, 1);
                      r1[2] = r2;
                      r2 = varref (1, 1);
                      r3 = varref (1, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[3] = r2;
                      r2 = varref (4, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L114; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_927_i161;
                      L114:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = varref (0, 0);
                      r1 = varref (2, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (2, 1);
                      r3 = varref (2, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[2] = r2;
                      r2 = varref (1, 1);
                      r1[3] = r2;
                      r2 = varref (4, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L115; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_927_i161;
                      L115:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = varref (0, 0);
                      r1 = varref (1, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    }
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L112:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_927_i161; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 2);
          r0[2] = r1;
          r1 = varref (1, 3);
          r0[3] = r1;
          r1 = varref (0, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_927_i161;
        } break;
      }
      PXLL_RETURN(0);
      fatbar_384_over: ;
      PXLL_RETURN(0);
    L108:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_merge_sort_924; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 1);
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN_merge_sort_924;
  L105:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sort_350; r1[2] = lenv;
  r0[44] = r1;
  // def substring_355
  goto L116;
  FUN_substring_355:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 1);
    r2 = varref (1, 2);
    r1 = box(unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = box(string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = varref (0, 0);
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = varref (1, 1);
    r1 = (object *) 1;
    r2 = varref (1, 0);
    r3 = varref (0, 0);
    r4 = varref (0, 1);
    (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
    r0 = varref (0, 1);
    PXLL_RETURN(0);
  L116:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_substring_355; r1[2] = lenv;
  r0[45] = r1;
  // def char->string_358
  goto L117;
  FUN_char__3estring_358:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 3;
    r1 = box(string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = (object *) 3;
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
    r0 = (object *) 1;
    r1 = varref (1, 0);
    r2 = varref (0, 0);
    (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
    r0 = varref (0, 0);
    PXLL_RETURN(0);
  L117:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_char__3estring_358; r1[2] = lenv;
  r0[46] = r1;
  // def string-concat_362
  goto L118;
  FUN_string_concat_362:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def loop_972
    goto L119;
    FUN_loop_972:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (0, 1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = box(((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (2, 1);
          r0 = box(unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_972;
        } break;
      }
      PXLL_RETURN(0);
    L119:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_loop_972; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (2, 0);
    r1[2] = r2;
    r2 = (object *) 1;
    r1[3] = r2;
    r2 = varref (0, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L120; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_loop_972;
    L120:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = box(string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = varref (0, 0);
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_979
    goto L121;
    FUN_loop_979:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (2, 1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = box(((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = varref (2, 1);
          r2 = varref (1, 0);
          r3 = varref (0, 0);
          r4 = varref (4, 1);
          r0 = (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = box(((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (2, 1);
          r0 = box(unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_979;
        } break;
      }
      PXLL_RETURN(0);
    L121:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_979; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (2, 0);
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_979;
  L118:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_concat_362; r1[2] = lenv;
  r0[47] = r1;
  // def string-join_363
  goto L122;
  FUN_string_join_363:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def sj_986
    goto L123;
    FUN_sj_986:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (3, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L124; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L124:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (3, 45);
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (2, 1);
              r3 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (0, 0);
              r1[2] = r2;
              r2 = (object *) constructed_37[0];
              r1[3] = r2;
              r2 = varref (5, 19);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L125; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
              L125:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = varref (4, 45);
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
            } break;
            default: {
              goto fatbar_383;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_383_over;
          fatbar_383:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (2, 1);
          r2 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (4, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_sj_986;
          fatbar_383_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L123:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_sj_986; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (1, 0);
      r0[2] = r1;
      r1 = varref (2, 45);
      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
    } else {
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (1, 0);
      r0[2] = r1;
      r1 = (object *) constructed_922[0];
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_sj_986;
    }
    PXLL_RETURN(0);
  L122:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_join_363; r1[2] = lenv;
  r0[48] = r1;
  // def string-split_364
  goto L126;
  FUN_string_split_364:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_993
    goto L127;
    FUN_loop_993:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (3, 0);
      r1 = box(((pxll_string*)(r1))->len);
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = varref (1, 0);
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (3, 0);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (1, 0);
        r1[4] = r2;
        r2 = varref (4, 43);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L128; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
        L128:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (1, 2);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = (object *) constructed_37[0];
        r0[3] = r1;
        r1 = varref (4, 19);
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r2 = varref (3, 0);
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = varref (1, 0);
        r2 = varref (3, 0);
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[2] = r1;
        r0 = varref (3, 1);
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = varref (3, 0);
          r1[2] = r2;
          r2 = varref (1, 1);
          r1[3] = r2;
          r2 = varref (1, 0);
          r1[4] = r2;
          r2 = varref (4, 43);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L129; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
          L129:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (1, 2);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = (object *) 3;
          r2 = varref (0, 0);
          r1 = box(unbox(r2)+unbox(r1));
          r2 = (object *) 3;
          r3 = varref (0, 0);
          r2 = box(unbox(r3)+unbox(r2));
          lenv[2] = r2;
          lenv[3] = r1;
          lenv[4] = r0;
          goto FUN_loop_993;
        } else {
          r0 = (object *) 3;
          r1 = varref (0, 0);
          r0 = box(unbox(r1)+unbox(r0));
          r1 = varref (0, 1);
          r2 = varref (0, 2);
          lenv[2] = r0;
          lenv[3] = r1;
          lenv[4] = r2;
          goto FUN_loop_993;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L127:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_993; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = (object *) constructed_921[0];
    r0[4] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_993;
  L126:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_split_364; r1[2] = lenv;
  r0[49] = r1;
  // def string-compare_365
  goto L130;
  FUN_string_compare_365:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = varref (1, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[3] = r1;
    r1 = varref (0, 1);
    r2 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
      r1 = varref (0, 0);
      r1=r1;
    } else {
      r1 = varref (0, 1);
      r1=r1;
    }
    r2 = varref (1, 1);
    r3 = varref (1, 0);
    r1 = box(memcmp (((pxll_string*)(r3))->data, ((pxll_string*)(r2))->data, unbox(r1)));
    r0[4] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 2);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
      r0 = varref (0, 1);
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } else {
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
          r0 = (object *) -1;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 3;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    } else {
      r0 = varref (0, 2);
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L130:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_compare_365; r1[2] = lenv;
  r0[50] = r1;
  // def string-find_366
  goto L131;
  FUN_string_find_366:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = varref (1, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[3] = r1;
    r0 = varref (0, 0);
    r1 = varref (0, 1);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
      r0 = (object *) -1;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1006
      goto L132;
      FUN_loop_1006:
        check_heap (0);
        r0 = varref (2, 0);
        r1 = varref (0, 1);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = varref (0, 1);
          r1 = varref (0, 0);
          r0 = box(unbox(r1)-unbox(r0));
          PXLL_RETURN(0);
        } else {
          r0 = varref (2, 1);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) -1;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r2 = varref (4, 0);
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = varref (1, 1);
            r2 = varref (4, 0);
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[2] = r1;
            r1 = varref (1, 0);
            r2 = varref (4, 1);
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = varref (1, 0);
            r2 = varref (4, 1);
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[3] = r1;
            r0 = varref (0, 1);
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r1 = varref (0, 1);
              r0 = box(unbox(r1)+unbox(r0));
              r1 = (object *) 3;
              r2 = varref (0, 0);
              r1 = box(unbox(r2)+unbox(r1));
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_1006;
            } else {
              r0 = (object *) 3;
              r1 = varref (0, 0);
              r0 = box(unbox(r1)+unbox(r0));
              r1 = (object *) 1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1006;
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L132:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1006; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1006;
    }
    PXLL_RETURN(0);
  L131:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_find_366; r1[2] = lenv;
  r0[51] = r1;
  // def string<?_368
  goto L133;
  FUN_string_3c_question_368:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (1, 1);
    r1[3] = r2;
    r2 = varref (2, 48);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L134; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
    L134:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L133:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string_3c_question_368; r1[2] = lenv;
  r0[52] = r1;
  // def zero-terminate_370
  goto L135;
  FUN_zero_terminate_370:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = (object *) 3;
    r2 = varref (0, 0);
    r1 = box(unbox(r2)-unbox(r1));
    r0[3] = r1;
    r1 = varref (0, 1);
    r2 = varref (1, 0);
    range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
    r1 = varref (0, 1);
    r2 = varref (1, 0);
    r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
    r0[4] = r1;
    r0 = (object *) 2;
    r1 = varref (0, 2);
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = varref (0, 0);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = box(((pxll_string*)(r1))->len);
      r0[2] = r1;
      r1 = (object *) 3;
      r2 = varref (0, 0);
      r1 = box(unbox(r2)+unbox(r1));
      r0[3] = r1;
      r1 = varref (0, 1);
      r1 = box(string_tuple_length (unbox(r1)));
      ensure_heap (1, unbox(r1));
      r1 = varref (0, 1);
      r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
      r0[4] = r1;
      r0 = (object *) 1;
      r1 = (object *) 1;
      r2 = varref (1, 0);
      r3 = varref (0, 0);
      r4 = varref (0, 2);
      (memcpy (((pxll_string*)(r4))->data+unbox(r1), ((pxll_string*)(r2))->data+unbox(r0), unbox(r3)), PXLL_UNDEFINED);
      r0 = varref (0, 0);
      r1 = varref (0, 2);
      range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
      r0 = varref (0, 0);
      r1 = (object *) 2;
      r2 = varref (0, 2);
      (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
      r0 = varref (0, 2);
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L135:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_zero_terminate_370; r1[2] = lenv;
  r0[53] = r1;
  // def list->string_371
  goto L136;
  FUN_list__3estring_371:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L137; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L137:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = box(string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = varref (0, 0);
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1020
    goto L138;
    FUN_loop_1020:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (2, 1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (1, 1);
          r1 = varref (3, 1);
          range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
          r0 = varref (1, 1);
          r1 = varref (0, 0);
          r2 = varref (3, 1);
          (((pxll_string*)(r2))->data[unbox(r0)] = GET_CHAR (r1), PXLL_UNDEFINED);
          r0 = (object *) 3;
          r1 = varref (1, 1);
          r0 = box(unbox(r1)+unbox(r0));
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_1020;
        } break;
      }
      PXLL_RETURN(0);
    L138:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1020; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (2, 0);
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1020;
  L136:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_list__3estring_371; r1[2] = lenv;
  r0[54] = r1;
  // def string->list_372
  goto L139;
  FUN_string__3elist_372:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1026
    goto L140;
    FUN_loop_1026:
      check_heap (0);
      r0 = (object *) 1;
      r1 = varref (0, 1);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 3;
        r2 = varref (1, 1);
        r1 = box(unbox(r2)-unbox(r1));
        r0[2] = r1;
        r1 = varref (0, 0);
        r2 = varref (3, 0);
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = varref (0, 0);
        r2 = varref (3, 0);
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[3] = r1;
        r0 = varref (1, 0);
        r1 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 3;
        r2 = varref (0, 1);
        r1 = box(unbox(r2)-unbox(r1));
        lenv[2] = r0;
        lenv[3] = r1;
        goto FUN_loop_1026;
      }
      PXLL_RETURN(0);
    L140:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1026; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = box(((pxll_string*)(r1))->len);
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1026;
  L139:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string__3elist_372; r1[2] = lenv;
  r0[55] = r1;
  // def int->string_374
  goto L141;
  FUN_int__3estring_374:
    check_heap (0);
    r0 = varref (0, 0);
    r1 = (object *) 1;
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 12290;
      r0[2] = r1;
      r1 = varref (1, 44);
      r0[1] = r1[2]; lenv = r0; goto FUN_char__3estring_358;
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1035
      goto L142;
      FUN_loop_1035:
        check_heap (0);
        r0 = varref (0, 0);
        r1 = (object *) 1;
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r2 = varref (2, 0);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
            r1 = varref (0, 1);
            r2 = (object *) 11522;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r1=r1;
          } else {
            r1 = varref (0, 1);
            r1=r1;
          }
          r0[2] = r1;
          r1 = varref (3, 52);
          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
        } else {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 21;
          r2 = varref (1, 0);
          r1 = box(unbox(r2) % unbox(r1));
          r0[2] = r1;
          r1 = varref (0, 0);
          r2 = (object *) 97;
          r1 = box(unbox(r2)+unbox(r1));
          r0[3] = r1;
          r1 = varref (0, 1);
          r1 = TO_CHAR(unbox(r1));
          r0[4] = r1;
          r0 = varref (1, 1);
          r1 = varref (0, 2);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = (object *) 21;
          r2 = varref (0, 0);
          r1 = box(unbox(r2)/unbox(r1));
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_1035;
        }
        PXLL_RETURN(0);
      L142:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1035; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r2 = varref (1, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
        r1 = varref (1, 0);
        r2 = (object *) 1;
        r1 = box(unbox(r2)-unbox(r1));
        r1=r1;
      } else {
        r1 = varref (1, 0);
        r1=r1;
      }
      r0[2] = r1;
      r1 = (object *) constructed_920[0];
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1035;
    }
    PXLL_RETURN(0);
  L141:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_int__3estring_374; r1[2] = lenv;
  r0[56] = r1;
  // def int->hex-string_375
  goto L143;
  FUN_int__3ehex_string_375:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_1039
    goto L144;
    FUN_loop_1039:
      check_heap (0);
      r0 = varref (0, 0);
      r1 = (object *) 1;
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) 1;
        r2 = varref (2, 0);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
          r1 = varref (0, 1);
          r2 = (object *) 11522;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r1=r1;
        } else {
          r1 = varref (0, 1);
          r1=r1;
        }
        r0[2] = r1;
        r1 = varref (3, 52);
        r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 31;
        r2 = varref (1, 0);
        r1 = box(unbox(r2)&unbox(r1));
        r2 = varref (4, 147);
        range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
        r1 = ((pxll_vector*)r2)->val[unbox(r1)];
        r0[2] = r1;
        r0 = varref (1, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 9;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)>>unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN_loop_1039;
      }
      PXLL_RETURN(0);
    L144:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1039; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) 1;
    r2 = varref (1, 0);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
      r1 = varref (1, 0);
      r2 = (object *) 1;
      r1 = box(unbox(r2)-unbox(r1));
      r1=r1;
    } else {
      r1 = varref (1, 0);
      r1=r1;
    }
    r0[2] = r1;
    r1 = (object *) constructed_919[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1039;
  L143:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_int__3ehex_string_375; r1[2] = lenv;
  r0[57] = r1;
  // def pad_377
  goto L145;
  FUN_pad_377:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = varref (1, 0);
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
      r0 = varref (1, 1);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r2 = varref (2, 0);
      r1 = box(unbox(r2)-unbox(r1));
      r0[2] = r1;
      r0 = varref (2, 2);
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (1, 0);
        r3[2] = r4;
        r4 = (object *) 8194;
        r3[3] = r4;
        r4 = varref (4, 29);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L146; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_n_of_334;
        L146:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = varref (4, 52);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L147; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_list__3estring_371;
        L147:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = varref (3, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = varref (0, 2);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (3, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (1, 0);
        r3[2] = r4;
        r4 = (object *) 8194;
        r3[3] = r4;
        r4 = varref (4, 29);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L148; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_n_of_334;
        L148:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = varref (4, 52);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L149; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_list__3estring_371;
        L149:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = varref (0, 2);
        r2 = varref (3, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (3, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L145:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pad_377; r1[2] = lenv;
  r0[58] = r1;
  // def cpad_380
  goto L150;
  FUN_cpad_380:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r1 = varref (0, 0);
    r2 = varref (1, 0);
    r1 = box(unbox(r2)-unbox(r1));
    r0[3] = r1;
    r1 = (object *) 5;
    r2 = varref (0, 1);
    r1 = box(unbox(r2)/unbox(r1));
    r0[4] = r1;
    r1 = varref (0, 2);
    r2 = varref (0, 0);
    r1 = box(unbox(r2)+unbox(r1));
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (0, 3);
    r1[2] = r2;
    r2 = varref (1, 1);
    r1[3] = r2;
    r2 = (object *) 262;
    r1[4] = r2;
    r2 = varref (2, 56);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L151; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pad_377;
    L151:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 4);
    r0[3] = r1;
    r1 = (object *) 6;
    r0[4] = r1;
    r1 = varref (2, 56);
    r0[1] = r1[2]; lenv = r0; goto FUN_pad_377;
  L150:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cpad_380; r1[2] = lenv;
  r0[59] = r1;
  // def copy-cstring_382
  goto L152;
  FUN_copy_cstring_382:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = box(strlen((char*)r1));
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = box(string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = varref (0, 0);
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[3] = r1;
    r0 = varref (1, 0);
    r1 = varref (0, 0);
    r2 = varref (0, 1);
    (memcpy (((pxll_string*)(r2))->data, (char*)r0, unbox(r1)), PXLL_UNDEFINED);
    r0 = varref (0, 1);
    PXLL_RETURN(0);
  L152:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_copy_cstring_382; r1[2] = lenv;
  r0[60] = r1;
  // def open_383
  goto L153;
  FUN_open_383:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 51);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L154; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_370;
    L154:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r2 = varref (1, 1);
    r3 = varref (1, 2);
    r1 = box(open (((pxll_string*)(r1))->data, unbox(r2), unbox(r3)));
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>=unbox(r0))) {
      r0 = varref (0, 0);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_918;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (2, 51);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L155; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_370;
      L155:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = varref (2, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    }
    PXLL_RETURN(0);
  L153:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_open_383; r1[2] = lenv;
  r0[61] = r1;
  // def file/open-read_390
  goto L156;
  FUN_file_2fopen_read_390:
    check_heap (0);
    r0 = allocate (UOTAG(21), 4);
    r1 = (object *) 32769;
    r1 = box(string_tuple_length (unbox(r1)));
    ensure_heap (1, unbox(r1));
    r1 = (object *) 32769;
    r1 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r1))), ((pxll_string*)(t))->len = unbox(r1), t);
    r0[1] = r1;
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (1, 148);
    r1[3] = r2;
    r2 = (object *) 1;
    r1[4] = r2;
    r2 = varref (1, 59);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L157; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_open_383;
    L157:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = (object *) 1;
    r0[4] = r1;
    PXLL_RETURN(0);
  L156:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fopen_read_390; r1[2] = lenv;
  r0[62] = r1;
  // def file/fill-buffer_395
  goto L158;
  FUN_file_2ffill_buffer_395:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[2];
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = varref (0, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[4] = r1;
    r1 = varref (0, 1);
    r2 = varref (0, 2);
    r3 = varref (0, 0);
    r1 = box(read (unbox(r3), ((pxll_string*)(r1))->data, unbox(r2)));
    r0[5] = r1;
    r1 = varref (0, 3);
    r0[6] = r1;
    r0 = varref (0, 4);
    r1 = varref (1, 0);
    ((pxll_vector*)r1)->val[1] = r0;
    r0 = (object *) 1;
    r1 = varref (1, 0);
    ((pxll_vector*)r1)->val[3] = r0;
    r0 = varref (0, 4);
    PXLL_RETURN(0);
  L158:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2ffill_buffer_395; r1[2] = lenv;
  r0[63] = r1;
  // def file/read-buffer_396
  goto L159;
  FUN_file_2fread_buffer_396:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = varref (1, 0);
      r0 = ((pxll_vector*)r0)->val[1];
      r1 = varref (1, 0);
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = allocate (TC_TUPLE, 4);
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[3] = r1;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[1];
      r0[4] = r1;
      r1 = varref (2, 43);
      r0[1] = r1[2]; lenv = r0; goto FUN_substring_355;
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (2, 61);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L160; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2ffill_buffer_395;
      L160:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object*) &constructed_917;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (1, 0);
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = varref (1, 0);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = varref (1, 0);
        r2 = ((pxll_vector*)r2)->val[1];
        r1[4] = r2;
        r2 = varref (2, 43);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L161; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
        L161:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = varref (1, 0);
        ((pxll_vector*)r1)->val[1] = r0;
        r0 = (object *) 1;
        r1 = varref (1, 0);
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L159:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fread_buffer_396; r1[2] = lenv;
  r0[64] = r1;
  // def file/read-char_397
  goto L162;
  FUN_file_2fread_char_397:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = varref (0, 0);
      r0 = box(unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      r1 = varref (0, 0);
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = (object *) 3;
      r2 = varref (0, 1);
      r1 = box(unbox(r2)-unbox(r1));
      r0[4] = r1;
      r0 = varref (0, 2);
      r1 = varref (0, 0);
      range_check (((pxll_string *)(((pxll_string*)(r1))))->len, unbox(r0));
      r0 = varref (0, 2);
      r1 = varref (0, 0);
      r0 = TO_CHAR(((unsigned char *)((pxll_string*)(r1))->data)[unbox(r0)]);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (2, 61);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L163; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2ffill_buffer_395;
      L163:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 65794;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 63);
        r0[1] = r1[2]; lenv = r0; goto FUN_file_2fread_char_397;
      }
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L162:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_file_2fread_char_397; r1[2] = lenv;
  r0[65] = r1;
  // def alist/lookup_405
  goto L164;
  FUN_alist_2flookup_405:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = varref (1, 1);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 2);
          r0[2] = r1;
          r1 = varref (1, 1);
          r0[3] = r1;
          r1 = varref (2, 64);
          r0[1] = r1[2]; lenv = r0; goto FUN_alist_2flookup_405;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L164:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2flookup_405; r1[2] = lenv;
  r0[66] = r1;
  // def alist/get_407
  goto L165;
  FUN_alist_2fget_407:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (1, 1);
    r1[3] = r2;
    r2 = varref (2, 64);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L166; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
    L166:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 2);
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (2, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      } break;
    }
    PXLL_RETURN(0);
  L165:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2fget_407; r1[2] = lenv;
  r0[67] = r1;
  // def alist/iterate_408
  goto L167;
  FUN_alist_2fiterate_408:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (0, 1);
        r0[3] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L168; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L168:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 2);
        r0[3] = r1;
        r1 = varref (2, 66);
        r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
      } break;
    }
    PXLL_RETURN(0);
  L167:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2fiterate_408; r1[2] = lenv;
  r0[68] = r1;
  // def alist->keys_410
  goto L169;
  FUN_alist__3ekeys_410:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object*)TC_NIL;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (2, 67);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L170; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist__3ekeys_410;
        L170:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = varref (0, 2);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L169:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist__3ekeys_410; r1[2] = lenv;
  r0[69] = r1;
  // def alist/length_412
  goto L171;
  FUN_alist_2flength_412:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 68);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L172; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flength_412;
        L172:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = (object *) 3;
        r0 = box(unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L171:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_alist_2flength_412; r1[2] = lenv;
  r0[70] = r1;
  // def tree/insert_414
  goto L173;
  FUN_tree_2finsert_414:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def ins_1190
    goto L174;
    FUN_ins_1190:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(2)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = (object*)UITAG(2);
          r0[2] = r1;
          r1 = (object*)UITAG(2);
          r0[3] = r1;
          r0 = varref (3, 3);
          r1 = varref (0, 1);
          r2 = varref (3, 2);
          r3 = varref (0, 0);
          t = alloc_no_clear (UOTAG(0),4);
          t[1] = r3;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 2);
          r0[2] = r1;
          r1 = varref (0, 2);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L175; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L175:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L176; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_ins_1190;
            L176:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (1, 3);
            r1 = varref (1, 1);
            r2 = varref (1, 2);
            r3 = varref (0, 0);
            t = alloc_no_clear (UOTAG(0),4);
            t[1] = r3;
            t[2] = r1;
            t[3] = r2;
            t[4] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 2);
            r0[2] = r1;
            r1 = varref (3, 2);
            r0[3] = r1;
            r1 = varref (3, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L177; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L177:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 1);
              r1[2] = r2;
              r2 = varref (3, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L178; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_ins_1190;
              L178:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (1, 3);
              r1 = varref (0, 0);
              r2 = varref (1, 2);
              r3 = varref (1, 0);
              t = alloc_no_clear (UOTAG(0),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 2);
          r0[2] = r1;
          r1 = varref (0, 2);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L179; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L179:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L180; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_ins_1190;
            L180:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 5);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,2);
                r0[4] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,3);
                r0[5] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 7);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,2);
                    r0[4] = r1;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,3);
                    r0[5] = r1;
                    r1 = varref (0, 3);
                    r2 = varref (0, 1);
                    r3 = varref (0, 2);
                    r4 = varref (0, 0);
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = varref (3, 3);
                    r2 = varref (3, 1);
                    r3 = varref (3, 2);
                    r4 = varref (1, 1);
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r0 = varref (1, 3);
                    r1 = varref (0, 5);
                    r2 = varref (1, 2);
                    r3 = varref (0, 4);
                    t = alloc_no_clear (UOTAG(0),4);
                    t[1] = r3;
                    t[2] = r1;
                    t[3] = r2;
                    t[4] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_380;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_380_over;
                fatbar_380:
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 7);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,2);
                    r0[4] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,3);
                    r0[5] = r1;
                    r1 = varref (1, 3);
                    r2 = varref (0, 0);
                    r3 = varref (1, 2);
                    r4 = varref (1, 0);
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = varref (3, 3);
                    r2 = varref (3, 1);
                    r3 = varref (3, 2);
                    r4 = varref (0, 1);
                    t = alloc_no_clear (UOTAG(1),4);
                    t[1] = r4;
                    t[2] = r2;
                    t[3] = r3;
                    t[4] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r0 = varref (0, 3);
                    r1 = varref (0, 5);
                    r2 = varref (0, 2);
                    r3 = varref (0, 4);
                    t = alloc_no_clear (UOTAG(0),4);
                    t[1] = r3;
                    t[2] = r1;
                    t[3] = r2;
                    t[4] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_379;
                  }
                }
                PXLL_RETURN(0);
                fatbar_380_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_379;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_379_over;
            fatbar_379:
            r0 = varref (1, 3);
            r1 = varref (1, 1);
            r2 = varref (1, 2);
            r3 = varref (0, 0);
            t = alloc_no_clear (UOTAG(1),4);
            t[1] = r3;
            t[2] = r1;
            t[3] = r2;
            t[4] = r0;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_379_over: ;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 2);
            r0[2] = r1;
            r1 = varref (3, 2);
            r0[3] = r1;
            r1 = varref (3, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L181; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L181:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 1);
              r1[2] = r2;
              r2 = varref (3, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L182; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_ins_1190;
              L182:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 5);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,2);
                  r0[4] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,3);
                  r0[5] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,2);
                      r0[4] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,3);
                      r0[5] = r1;
                      r1 = varref (3, 3);
                      r2 = varref (0, 0);
                      r3 = varref (3, 2);
                      r4 = varref (3, 0);
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[6] = r1;
                      r1 = varref (1, 3);
                      r2 = varref (1, 1);
                      r3 = varref (1, 2);
                      r4 = varref (0, 1);
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[7] = r1;
                      r0 = varref (0, 3);
                      r1 = varref (0, 5);
                      r2 = varref (0, 2);
                      r3 = varref (0, 4);
                      t = alloc_no_clear (UOTAG(0),4);
                      t[1] = r3;
                      t[2] = r1;
                      t[3] = r2;
                      t[4] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_382;
                    }
                  }
                  PXLL_RETURN(0);
                  goto fatbar_382_over;
                  fatbar_382:
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,2);
                      r0[4] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,3);
                      r0[5] = r1;
                      r1 = varref (3, 3);
                      r2 = varref (1, 0);
                      r3 = varref (3, 2);
                      r4 = varref (3, 0);
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[6] = r1;
                      r1 = varref (0, 3);
                      r2 = varref (0, 1);
                      r3 = varref (0, 2);
                      r4 = varref (0, 0);
                      t = alloc_no_clear (UOTAG(1),4);
                      t[1] = r4;
                      t[2] = r2;
                      t[3] = r3;
                      t[4] = r1;
                      r1 = t;
                      r0[7] = r1;
                      r0 = varref (1, 3);
                      r1 = varref (0, 5);
                      r2 = varref (1, 2);
                      r3 = varref (0, 4);
                      t = alloc_no_clear (UOTAG(0),4);
                      t[1] = r3;
                      t[2] = r1;
                      t[3] = r2;
                      t[4] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_381;
                    }
                  }
                  PXLL_RETURN(0);
                  fatbar_382_over: ;
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_381;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_381_over;
              fatbar_381:
              r0 = varref (1, 3);
              r1 = varref (0, 0);
              r2 = varref (1, 2);
              r3 = varref (1, 0);
              t = alloc_no_clear (UOTAG(1),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
              fatbar_381_over: ;
              PXLL_RETURN(0);
            } else {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L174:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_ins_1190; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (2, 0);
    r1[2] = r2;
    r2 = varref (1, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L183; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_ins_1190;
    L183:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = varref (0, 3);
        r1 = varref (0, 1);
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (UOTAG(1),4);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        t[4] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_378;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_378_over;
    fatbar_378:
    r0 = varref (0, 0);
    PXLL_RETURN(0);
    fatbar_378_over: ;
    PXLL_RETURN(0);
  L173:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2finsert_414; r1[2] = lenv;
  r0[71] = r1;
  // def tree/member_415
  goto L184;
  FUN_tree_2fmember_415:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def member0_1240
    goto L185;
    FUN_member0_1240:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(2)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 2);
          r0[2] = r1;
          r1 = varref (0, 2);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L186; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L186:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (0, 0);
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_member0_1240;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 2);
            r0[2] = r1;
            r1 = varref (3, 2);
            r0[3] = r1;
            r1 = varref (3, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L187; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L187:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (0, 1);
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_member0_1240;
            } else {
              r0 = varref (0, 3);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,3);
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 2);
          r0[2] = r1;
          r1 = varref (0, 2);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L188; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L188:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (0, 0);
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_member0_1240;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 2);
            r0[2] = r1;
            r1 = varref (3, 2);
            r0[3] = r1;
            r1 = varref (3, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L189; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L189:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (0, 1);
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_member0_1240;
            } else {
              r0 = varref (0, 3);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L185:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_member0_1240; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_member0_1240;
  L184:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2fmember_415; r1[2] = lenv;
  r0[72] = r1;
  // def tree/inorder_416
  goto L190;
  FUN_tree_2finorder_416:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (UITAG(2)): {
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (2, 71);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L191; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L191:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 2);
        r0[2] = r1;
        r1 = varref (0, 3);
        r0[3] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L192; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L192:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 1);
        r0[3] = r1;
        r1 = varref (2, 71);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L193; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L193:
        ; lenv = k[2]; k = k[1];
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,3);
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (2, 71);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L194; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L194:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 2);
        r0[2] = r1;
        r1 = varref (0, 3);
        r0[3] = r1;
        r1 = varref (1, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L195; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L195:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 1);
        r0[3] = r1;
        r1 = varref (2, 71);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L196; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finorder_416;
        L196:
        ; lenv = k[2]; k = k[1];
        r0 = (object *) 6;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L190:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_tree_2finorder_416; r1[2] = lenv;
  r0[73] = r1;
  // def symbol->string_420
  goto L197;
  FUN_symbol__3estring_420:
    check_heap (0);
    r0 = varref (0, 0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r0 = varref (0, 0);
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L197:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol__3estring_420; r1[2] = lenv;
  r0[74] = r1;
  // def string->symbol_422
  goto L198;
  FUN_string__3esymbol_422:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (2, 153);
    r1[2] = r2;
    r2 = varref (2, 50);
    r1[3] = r2;
    r2 = varref (1, 0);
    r1[4] = r2;
    r2 = varref (2, 70);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L199; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L199:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        t = alloc_no_clear (TC_SYMBOL,1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = varref (3, 153);
        r0[2] = r1;
        r1 = varref (3, 50);
        r0[3] = r1;
        r1 = varref (0, 0);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[4] = r1;
        r1 = varref (0, 0);
        r0[5] = r1;
        r1 = varref (3, 69);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L200; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
        L200:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (3, 153, r0);
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L198:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_string__3esymbol_422; r1[2] = lenv;
  r0[75] = r1;
  // def symbol<?_423
  goto L201;
  FUN_symbol_3c_question_423:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = varref (2, 0);
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = varref (0, 0);
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[2] = r1;
    r1 = varref (1, 1);
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = varref (2, 1);
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = varref (0, 0);
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (0, 1);
    r1[3] = r2;
    r2 = varref (2, 48);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L202; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
    L202:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 2);
    r0 = PXLL_TEST(unbox(r1)<unbox(r0));
    PXLL_RETURN(0);
  L201:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_3c_question_423; r1[2] = lenv;
  r0[76] = r1;
  // def char-class_425
  goto L203;
  FUN_char_class_425:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 513;
    ensure_heap (1, unbox(r1));
    r1 = (object *) 6;
    r2 = (object *) 513;
    if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
      t = alloc_no_clear (TC_VECTOR, unbox(r2));
      for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
      r1 = t;
    }
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def in-class?_1291
    goto L204;
    FUN_in_class_question_1291:
      r0 = varref (0, 0);
      r0 = box(GET_CHAR(r0));
      r1 = varref (2, 0);
      range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r0));
      r0 = ((pxll_vector*)r1)->val[unbox(r0)];
      PXLL_RETURN(0);
    L204:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_in_class_question_1291; r1[2] = lenv;
    r0[2] = r1;
    // def loop_1293
    goto L205;
    FUN_loop_1293:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (1, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          r0 = box(GET_CHAR(r0));
          r1 = (object *) 262;
          r2 = varref (3, 0);
          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
          ((pxll_vector*)r2)->val[unbox(r0)] = r1;
          r0 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_1293;
        } break;
      }
      PXLL_RETURN(0);
    L205:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1293; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (2, 0);
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1293;
  L203:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_char_class_425; r1[2] = lenv;
  r0[77] = r1;
  // def reader_426
  goto L206;
  FUN_reader_426:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) 65794;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 10);
    r0[1] = lenv; lenv = r0;
    // def skip-whitespace_1303
    goto L207;
    FUN_skip_whitespace_1303:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1324
      goto L208;
      FUN_loop_1324:
        check_heap (0);
        r0 = (object *) 65794;
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 15106;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop_1322_i343
            goto L209;
            FUN_loop_1322_i343:
              check_heap (0);
              r0 = (object *) 2562;
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_376;
              }
              PXLL_RETURN(0);
              goto fatbar_376_over;
              fatbar_376:
              r0 = (object *) 3330;
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_377;
              }
              PXLL_RETURN(0);
              goto fatbar_377_over;
              fatbar_377:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = varref (7, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L210; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L210:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (6, 0, r0);
              r0 = varref (0, 0);
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L211; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L211:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              lenv[2] = r0;
              goto FUN_loop_1322_i343;
              fatbar_377_over: ;
              PXLL_RETURN(0);
              fatbar_376_over: ;
              PXLL_RETURN(0);
            L209:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop_1322_i343; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (5, 0);
            r1[2] = r2;
            r1 = varref (6, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L212; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L212:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            varset (5, 0, r1);
            r1 = varref (0, 0);
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L213; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_loop_1322_i343;
            L213:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (4, 0);
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (4, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L214; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L214:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (3, 0, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = varref (3, 0);
            lenv[2] = r0;
            goto FUN_loop_1324;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (5, 162);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L215; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L215:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (4, 0);
              r0[2] = r1;
              r0 = varref (5, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L216; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L216:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (4, 0, r0);
              r0 = varref (0, 0);
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (4, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (4, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L217; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L217:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (3, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (3, 0);
              lenv[2] = r0;
              goto FUN_loop_1324;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L208:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1324; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L218; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L218:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (2, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (2, 0);
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1324;
    L207:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_skip_whitespace_1303; r1[2] = lenv;
    r0[2] = r1;
    // def read-atom_1304
    goto L219;
    FUN_read_atom_1304:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) 12290;
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1329
      goto L220;
      FUN_loop_1329:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 0);
        r0[2] = r1;
        r0 = (object *) 65794;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = varref (5, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L221; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L221:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (4, 0, r0);
        } else {
          r0 = (object *) 14;
        }
        r0 = varref (4, 0);
        varset (2, 2, r0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 2);
        r0[2] = r1;
        r0 = (object *) 11778;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = varref (0, 0);
          r0 = box(unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
        } else {
          r0 = (object *) 14;
        }
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 7;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (2, 2);
            r0[2] = r1;
            r1 = varref (6, 163);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L222; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L222:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = (object *) 7;
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_372;
        }
        r0=r0;
        goto fatbar_372_over;
        fatbar_372:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 5;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 13;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (2, 2);
            r0[2] = r1;
            r1 = varref (6, 163);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L223; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L223:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 13;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (2, 2);
              r0[2] = r1;
              r1 = varref (6, 164);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L224; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L224:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_373;
        }
        r0=r0;
        goto fatbar_373_over;
        fatbar_373:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (2, 2);
            r0[2] = r1;
            r1 = varref (6, 163);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L225; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L225:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (2, 2);
              r0[2] = r1;
              r1 = varref (6, 164);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L226; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L226:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_374;
        }
        r0=r0;
        goto fatbar_374_over;
        fatbar_374:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 9;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 2);
            r0[2] = r1;
            r0 = (object *) 11522;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (2, 2);
              r0[2] = r1;
              r1 = varref (6, 164);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L227; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L227:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (2, 2);
                r0[2] = r1;
                r1 = varref (6, 163);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L228; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L228:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                if PXLL_IS_TRUE(r0) {
                  r0 = (object *) 15;
                  r0=r0;
                } else {
                  r0 = (object *) 7;
                  r0=r0;
                }
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_375;
        }
        r0=r0;
        goto fatbar_375_over;
        fatbar_375:
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_68;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_68;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        r0=r0;
        fatbar_375_over: ;
        r0=r0;
        fatbar_374_over: ;
        r0=r0;
        fatbar_373_over: ;
        r0=r0;
        fatbar_372_over: ;
        varset (2, 0, r0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 9;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(unbox(r1)<unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 0);
          r0[2] = r1;
          r1 = varref (6, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L229; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L229:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (5, 0, r1);
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (1, 0);
          r0[4] = r1;
          r0 = varref (0, 2);
          r1 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          lenv[2] = r0;
          goto FUN_loop_1329;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 0);
          r0[2] = r1;
          r0 = (object *) 9;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object*) &constructed_69;
            r0 = box(((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_915;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_915;
            r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 0);
            r0[2] = r1;
            r0 = (object *) 15;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = varref (5, 0);
              r0[2] = r1;
              r1 = varref (6, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L230; t[4] = r0; k = t;
              lenv = r1[2]; goto *r1[1];
              L230:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              varset (5, 0, r1);
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (1, 0);
              r0[4] = r1;
              r0 = varref (0, 2);
              r1 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              varset (0, 0, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (UOTAG(4), 4);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 0);
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (7, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L231; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L231:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = varref (6, 52);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L232; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L232:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[1] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (3, 0);
            r1[2] = r2;
            r1 = (object *) 13;
            r2 = varref (0, 0);
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (6, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L233; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L233:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = varref (2, 1);
            r0[4] = r1;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L220:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1329; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_914[0];
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1329;
    L219:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_atom_1304; r1[2] = lenv;
    r0[3] = r1;
    // def read_1308
    goto L234;
    FUN_read_1308:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L235; t[4] = r0; k = t;
      lenv = r1[2]; goto FUN_skip_whitespace_1303;
      L235:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (4, 0);
      r2[2] = r3;
      r2 = (object *) 65794;
      r3 = varref (0, 0);
      r2 = PXLL_TEST(r3==r2);
      lenv = lenv[1];
      r2 = r2;
      if PXLL_IS_TRUE(r2) {
        r2 = varref (4, 0);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L236; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L236:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        varset (3, 0, r2);
      } else {
        r2 = (object *) 14;
      }
      r2 = varref (3, 0);
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 10498;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_69;
        r1 = box(((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_894;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_894;
        r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_333;
      }
      r1=r1;
      goto fatbar_333_over;
      fatbar_333:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 8962;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = varref (5, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L237; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L237:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (4, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L238; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L238:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (3, 0, r1);
        } else {
          r1 = (object *) 14;
        }
        r1 = varref (3, 0);
        varset (0, 0, r1);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 10242;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 5);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L239; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_list_1313;
          L239:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(7),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_335;
        }
        r1=r1;
        goto fatbar_335_over;
        fatbar_335:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 29954;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L240; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L240:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_336;
        }
        r1=r1;
        goto fatbar_336_over;
        fatbar_336:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 21762;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L241; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L241:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_337;
        }
        r1=r1;
        goto fatbar_337_over;
        fatbar_337:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 26114;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L242; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L242:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_338;
        }
        r1=r1;
        goto fatbar_338_over;
        fatbar_338:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 17922;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L243; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L243:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_339;
        }
        r1=r1;
        goto fatbar_339_over;
        fatbar_339:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 29698;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L244; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L244:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_340;
        }
        r1=r1;
        goto fatbar_340_over;
        fatbar_340:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 21506;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L245; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L245:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_341;
        }
        r1=r1;
        goto fatbar_341_over;
        fatbar_341:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 28418;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L246; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L246:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 7);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L247; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_oct_int_1318;
          L247:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_342;
        }
        r1=r1;
        goto fatbar_342_over;
        fatbar_342:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 20226;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L248; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L248:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 7);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L249; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_oct_int_1318;
          L249:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_343;
        }
        r1=r1;
        goto fatbar_343_over;
        fatbar_343:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 30722;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L250; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L250:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 6);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L251; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_hex_int_1317;
          L251:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_344;
        }
        r1=r1;
        goto fatbar_344_over;
        fatbar_344:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 22530;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L252; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L252:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 6);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L253; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_hex_int_1317;
          L253:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_345;
        }
        r1=r1;
        goto fatbar_345_over;
        fatbar_345:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 23554;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 0);
          r1[2] = r2;
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L254; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L254:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 1);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L255; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto FUN_read_atom_1304;
          L255:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          switch (get_case_noint (r1)) {
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 0);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = varref (1, 0);
              r2 = UOBJ_GET(r2,2);
              r1[3] = r2;
              r1 = (object *) 3;
              r2 = varref (0, 1);
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 1;
                r3 = varref (1, 0);
                range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                r2 = (object *) 1;
                r3 = varref (1, 0);
                r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_348;
              }
              r1=r1;
              goto fatbar_348_over;
              fatbar_348:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_895;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L256; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L256:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_349;
              }
              r1=r1;
              goto fatbar_349_over;
              fatbar_349:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_896;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L257; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L257:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 65794;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_350;
              }
              r1=r1;
              goto fatbar_350_over;
              fatbar_350:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_897;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L258; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L258:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2306;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_351;
              }
              r1=r1;
              goto fatbar_351_over;
              fatbar_351:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_898;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L259; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L259:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 3330;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_352;
              }
              r1=r1;
              goto fatbar_352_over;
              fatbar_352:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_899;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L260; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L260:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 8194;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_353;
              }
              r1=r1;
              goto fatbar_353_over;
              fatbar_353:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_900;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L261; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L261:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2562;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_347;
              }
              r1=r1;
              fatbar_353_over: ;
              r1=r1;
              fatbar_352_over: ;
              r1=r1;
              fatbar_351_over: ;
              r1=r1;
              fatbar_350_over: ;
              r1=r1;
              fatbar_349_over: ;
              r1=r1;
              fatbar_348_over: ;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
          }
          r1=r1;
          goto fatbar_347_over;
          fatbar_347:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_901;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (6, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L262; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L262:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_347_over: ;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_346;
        }
        r1=r1;
        goto fatbar_346_over;
        fatbar_346:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_902;
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (5, 12);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L263; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
        L263:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r1=r1;
        fatbar_346_over: ;
        r1=r1;
        fatbar_345_over: ;
        r1=r1;
        fatbar_344_over: ;
        r1=r1;
        fatbar_343_over: ;
        r1=r1;
        fatbar_342_over: ;
        r1=r1;
        fatbar_341_over: ;
        r1=r1;
        fatbar_340_over: ;
        r1=r1;
        fatbar_339_over: ;
        r1=r1;
        fatbar_338_over: ;
        r1=r1;
        fatbar_337_over: ;
        r1=r1;
        fatbar_336_over: ;
        r1=r1;
        fatbar_335_over: ;
        r1=r1;
      } else {
        goto fatbar_334;
      }
      r1=r1;
      goto fatbar_334_over;
      fatbar_334:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 14850;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = varref (5, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L264; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L264:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = varref (3, 1);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L265; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_atom_1304;
        L265:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (0, 0);
        switch (get_case_noint (r2)) {
          default: {
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 0);
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r3 = varref (1, 0);
            r3 = UOBJ_GET(r3,1);
            r2[3] = r3;
            r3 = varref (1, 0);
            r3 = UOBJ_GET(r3,3);
            r2[4] = r3;
            r2 = varref (0, 1);
            switch (get_case (r2)) {
              case ((pxll_int)PXLL_TRUE): {
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_903;
                r2[2] = r3;
                r3 = varref (0, 0);
                r2[3] = r3;
                r3 = varref (7, 12);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L266; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_303;
                L266:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = (object *) 1;
                r3 = varref (0, 2);
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = varref (0, 0);
                  r2[2] = r3;
                  r3 = varref (7, 73);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L267; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_422;
                  L267:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r2=r2;
                } else {
                  goto fatbar_355;
                }
                r2=r2;
                goto fatbar_355_over;
                fatbar_355:
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_904;
                r2[2] = r3;
                r3 = varref (0, 0);
                r2[3] = r3;
                r3 = varref (7, 12);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L268; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_303;
                L268:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
                fatbar_355_over: ;
                r2=r2;
              } break;
            }
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
          } break;
        }
        r1[3] = r2;
        r1 = varref (0, 1);
        r2 = (object *) constructed_50[0];
        t = alloc_no_clear (UOTAG(9),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_354;
      }
      r1=r1;
      goto fatbar_354_over;
      fatbar_354:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 11266;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = varref (5, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L269; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L269:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_906[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L270; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1308;
        L270:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_356;
      }
      r1=r1;
      goto fatbar_356_over;
      fatbar_356:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 9986;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = varref (5, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L271; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L271:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_732[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L272; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1308;
        L272:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_357;
      }
      r1=r1;
      goto fatbar_357_over;
      fatbar_357:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 8706;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = varref (5, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L273; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L273:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1364_i452_i523
        goto L274;
        FUN_loop_1364_i452_i523:
          check_heap (0);
          r0 = (object *) 23554;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 0);
            r0[2] = r1;
            r0 = varref (7, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L275; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L275:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (6, 0, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 0);
            r0[2] = r1;
            r0 = varref (7, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L276; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L276:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (6, 0, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = r0;
            varset (0, 0, r0);
            r0 = (object *) 23554;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L277; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L277:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              r1 = varref (0, 1);
              r2 = (object *) 23554;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523;
            } else {
              goto fatbar_360;
            }
            PXLL_RETURN(0);
            goto fatbar_360_over;
            fatbar_360:
            r0 = (object *) 8706;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L278; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L278:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              r1 = varref (0, 1);
              r2 = (object *) 8706;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523;
            } else {
              goto fatbar_361;
            }
            PXLL_RETURN(0);
            goto fatbar_361_over;
            fatbar_361:
            r0 = (object *) 29698;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L279; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L279:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              r1 = varref (0, 1);
              r2 = (object *) 2306;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523;
            } else {
              goto fatbar_362;
            }
            PXLL_RETURN(0);
            goto fatbar_362_over;
            fatbar_362:
            r0 = (object *) 28162;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L280; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L280:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              r1 = varref (0, 1);
              r2 = (object *) 2562;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523;
            } else {
              goto fatbar_363;
            }
            PXLL_RETURN(0);
            goto fatbar_363_over;
            fatbar_363:
            r0 = (object *) 22530;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L281; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L281:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (5, 4);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L282; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto FUN_read_hex_code_1311;
              L282:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = varref (1, 1);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523;
            } else {
              goto fatbar_364;
            }
            PXLL_RETURN(0);
            goto fatbar_364_over;
            fatbar_364:
            r0 = (object *) 30722;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 0);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (6, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L283; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L283:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 0, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 0);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (5, 4);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L284; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto FUN_read_hex_code_1311;
              L284:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = varref (1, 1);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523;
            } else {
              goto fatbar_365;
            }
            PXLL_RETURN(0);
            goto fatbar_365_over;
            fatbar_365:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_908;
            r0[2] = r1;
            r1 = varref (0, 1);
            r0[3] = r1;
            r1 = varref (7, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            fatbar_365_over: ;
            PXLL_RETURN(0);
            fatbar_364_over: ;
            PXLL_RETURN(0);
            fatbar_363_over: ;
            PXLL_RETURN(0);
            fatbar_362_over: ;
            PXLL_RETURN(0);
            fatbar_361_over: ;
            PXLL_RETURN(0);
            fatbar_360_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_359;
          }
          PXLL_RETURN(0);
          goto fatbar_359_over;
          fatbar_359:
          r0 = (object *) 8706;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 0);
            r0[2] = r1;
            r0 = varref (7, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L285; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L285:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (6, 0, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (1, 1);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (8, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L286; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L286:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (8, 52);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L287; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L287:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(2),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            goto fatbar_366;
          }
          PXLL_RETURN(0);
          goto fatbar_366_over;
          fatbar_366:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (6, 0);
          r0[2] = r1;
          r0 = varref (7, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L288; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L288:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (6, 0, r0);
          r0 = varref (0, 0);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (6, 0);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (6, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L289; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L289:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (5, 0, r0);
          } else {
            r0 = (object *) 14;
          }
          r0 = varref (5, 0);
          r1 = varref (0, 1);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_1364_i452_i523;
          fatbar_366_over: ;
          PXLL_RETURN(0);
          fatbar_359_over: ;
          PXLL_RETURN(0);
        L274:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1364_i452_i523; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (5, 0);
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = varref (0, 0);
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = varref (5, 0);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L290; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L290:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          varset (4, 0, r2);
        } else {
          r2 = (object *) 14;
        }
        r2 = varref (4, 0);
        r1[2] = r2;
        r2 = (object *) constructed_907[0];
        r1[3] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L291; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1364_i452_i523;
        L291:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_358;
      }
      r1=r1;
      goto fatbar_358_over;
      fatbar_358:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 31490;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 0);
        r1[2] = r2;
        r1 = varref (5, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L292; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L292:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1371_i483_i523
        goto L293;
        FUN_loop_1371_i483_i523:
          check_heap (0);
          r0 = varref (4, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L294; ; k = t;
          lenv = r0[2]; goto FUN_skip_whitespace_1303;
          L294:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (7, 0);
          r1[2] = r2;
          r1 = (object *) 65794;
          r2 = varref (0, 0);
          r1 = PXLL_TEST(r2==r1);
          lenv = lenv[1];
          r1 = r1;
          if PXLL_IS_TRUE(r1) {
            r1 = varref (7, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L295; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L295:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            varset (6, 0, r1);
          } else {
            r1 = (object *) 14;
          }
          r1 = varref (6, 0);
          r0[2] = r1;
          r0 = (object *) 32002;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 0);
            r0[2] = r1;
            r0 = varref (8, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L296; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L296:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (7, 0, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 0);
            r1[2] = r2;
            r2 = (object *) constructed_37[0];
            r1[3] = r2;
            r2 = varref (9, 19);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L297; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
            L297:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(8),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def loop_1376_i490_i523
            goto L298;
            FUN_loop_1376_i490_i523:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (0, 1);
              r0[2] = r1;
              r1 = varref (11, 165);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L299; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L299:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 262;
                r0=r0;
              } else {
                r0 = (object *) 11778;
                r1 = varref (0, 1);
                r0 = PXLL_TEST(r1==r0);
                r0=r0;
              }
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (10, 0);
                r0[2] = r1;
                r0 = varref (11, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L300; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L300:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (10, 0, r0);
                r0 = varref (0, 0);
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (10, 0);
                r0[2] = r1;
                r0 = (object *) 65794;
                r1 = varref (0, 0);
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = varref (10, 0);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L301; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L301:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  varset (9, 0, r0);
                } else {
                  r0 = (object *) 14;
                }
                r0 = varref (9, 0);
                r1 = varref (0, 0);
                r2 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r2 = (object *) 6;
                lenv[2] = r1;
                lenv[3] = r0;
                lenv[4] = r2;
                goto FUN_loop_1376_i490_i523;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (0, 0);
                r2[2] = r3;
                r3 = (object *) constructed_37[0];
                r2[3] = r3;
                r3 = varref (11, 19);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L302; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                L302:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (11, 52);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L303; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
                L303:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (11, 73);
                r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_422;
              }
              PXLL_RETURN(0);
            L298:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_loop_1376_i490_i523; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r2 = (object *) constructed_911[0];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (9, 0);
            r2[2] = r3;
            r2 = (object *) 65794;
            r3 = varref (0, 0);
            r2 = PXLL_TEST(r3==r2);
            lenv = lenv[1];
            r2 = r2;
            if PXLL_IS_TRUE(r2) {
              r2 = varref (9, 0);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L304; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L304:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              varset (8, 0, r2);
            } else {
              r2 = (object *) 14;
            }
            r2 = varref (8, 0);
            r1[3] = r2;
            r2 = (object *) 6;
            r1[4] = r2;
            r2 = varref (0, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L305; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_loop_1376_i490_i523;
            L305:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r0 = (object *) constructed_67[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 6;
              t = alloc_no_clear (UOTAG(4),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = varref (0, 0);
              r2 = varref (1, 0);
              t = alloc_no_clear (UOTAG(0),2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[3] = r1;
              r0 = varref (3, 0);
              r1 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              goto FUN_loop_1371_i483_i523;
            } else {
              r0 = varref (6, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L306; ; k = t;
              lenv = r0[2]; goto FUN_skip_whitespace_1303;
              L306:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (9, 0);
              r1[2] = r2;
              r1 = (object *) 65794;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = varref (9, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L307; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L307:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                varset (8, 0, r1);
              } else {
                r1 = (object *) 14;
              }
              r1 = varref (8, 0);
              r0[2] = r1;
              r1 = (object *) 15618;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(r2==r1);
              r0[3] = r1;
              r0 = (object *) 6;
              r1 = varref (0, 1);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_910;
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[3] = r1;
                r1 = varref (9, 12);
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (8, 0);
                r0[2] = r1;
                r0 = varref (9, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L308; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L308:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (8, 0, r0);
                r0 = varref (0, 0);
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (7, 2);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L309; t[4] = r0; k = t;
                lenv = r1[2]; goto FUN_read_1308;
                L309:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r2 = varref (2, 0);
                t = alloc_no_clear (UOTAG(0),2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = varref (4, 0);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                lenv = ((object ***)lenv)[1][1][1];
                lenv[2] = r0;
                goto FUN_loop_1371_i483_i523;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L293:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1371_i483_i523; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) constructed_909[0];
        r1[2] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L310; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1371_i483_i523;
        L310:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_367;
      }
      r1=r1;
      goto fatbar_367_over;
      fatbar_367:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 10242;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (3, 5);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L311; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_list_1313;
        L311:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_368;
      }
      r1=r1;
      goto fatbar_368_over;
      fatbar_368:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_69;
        r1 = box(((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_912;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_912;
        r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_369;
      }
      r1=r1;
      goto fatbar_369_over;
      fatbar_369:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 1);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L312; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto FUN_read_atom_1304;
      L312:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = varref (0, 0);
      switch (get_case_noint (r1)) {
        default: {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,2);
          r1[4] = r2;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,3);
          r1[5] = r2;
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case ((pxll_int)PXLL_TRUE): {
              r1 = allocate (TC_TUPLE, 5);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) 1;
              r3 = varref (1, 0);
              range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
              r2 = (object *) 1;
              r3 = varref (1, 0);
              r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
              r1[2] = r2;
              r2 = (object *) 11522;
              r3 = varref (0, 0);
              r2 = PXLL_TEST(r3==r2);
              r1[3] = r2;
              r2 = varref (0, 1);
              if PXLL_IS_TRUE(r2) {
                r2 = (object *) 3;
                r2=r2;
              } else {
                r2 = (object *) 1;
                r2=r2;
              }
              r1[4] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              // def loop_1384_i511_i523
              goto L313;
              FUN_loop_1384_i511_i523:
                check_heap (0);
                r0 = varref (3, 2);
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = varref (2, 1);
                  if PXLL_IS_TRUE(r0) {
                    r0 = varref (0, 1);
                    r1 = (object *) 1;
                    r0 = box(unbox(r1)-unbox(r0));
                    PXLL_RETURN(0);
                  } else {
                    r0 = varref (0, 1);
                    PXLL_RETURN(0);
                  }
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (11, 155);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r3 = varref (4, 0);
                  range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                  r2 = varref (1, 0);
                  r3 = varref (4, 0);
                  r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                  r1[3] = r2;
                  r2 = varref (11, 64);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L314; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                  L314:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UITAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_913;
                      r0[2] = r1;
                      r1 = varref (4, 0);
                      r0[3] = r1;
                      r1 = varref (11, 12);
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = (object *) 21;
                      r2 = varref (3, 1);
                      r1 = box(unbox(r2)*unbox(r1));
                      r0[2] = r1;
                      r0 = varref (1, 0);
                      r1 = varref (0, 0);
                      r0 = box(unbox(r1)+unbox(r0));
                      lenv = lenv[1];
                      r0 = r0;
                      r1 = (object *) 3;
                      r2 = varref (2, 0);
                      r1 = box(unbox(r2)+unbox(r1));
                      lenv = ((object **)lenv)[1][1];
                      lenv[2] = r1;
                      lenv[3] = r0;
                      goto FUN_loop_1384_i511_i523;
                    } break;
                  }
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              L313:
              r3 = allocate (TC_CLOSURE, 2);
              r3[1] = &&FUN_loop_1384_i511_i523; r3[2] = lenv;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 2);
              r2[2] = r3;
              r3 = (object *) 1;
              r2[3] = r3;
              r3 = varref (0, 0);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L315; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_loop_1384_i511_i523;
              L315:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[5] = r2;
              r1 = varref (0, 3);
              t = alloc_no_clear (UOTAG(5),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              r1 = (object *) 1;
              r2 = varref (0, 3);
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (1, 0);
                r2[2] = r3;
                r3 = varref (8, 73);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L316; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_422;
                L316:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_370;
              }
              r1=r1;
              goto fatbar_370_over;
              fatbar_370:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 0);
              r2 = box(((pxll_string*)(r2))->len);
              r1[2] = r2;
              r1 = varref (0, 0);
              r2 = varref (1, 3);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (1, 0);
                r2[2] = r3;
                r3 = varref (8, 73);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L317; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_422;
                L317:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                // def loop_1333_i522_i523
                goto L318;
                FUN_loop_1333_i522_i523:
                  check_heap (0);
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = varref (1, 0);
                          r1[2] = r2;
                          r2 = varref (11, 73);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L319; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
                          L319:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = varref (0, 0);
                          t = alloc_no_clear (UOTAG(1),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_371;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_371_over;
                      fatbar_371:
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 1);
                      r1[2] = r2;
                      r2 = varref (3, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L320; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_loop_1333_i522_i523;
                      L320:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 0);
                      r1[2] = r2;
                      r2 = varref (11, 73);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L321; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
                      L321:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      r1 = varref (0, 0);
                      t = alloc_no_clear (UOTAG(10),2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                      fatbar_371_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = (object*) &constructed_69;
                      r0 = box(((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_69;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_68;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_68;
                      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L318:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_loop_1333_i522_i523; r2[2] = lenv;
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 3);
                r4 = varref (2, 0);
                r3[2] = r4;
                r4 = (object *) 11778;
                r3[3] = r4;
                r4 = varref (9, 47);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L322; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_string_split_364;
                L322:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (0, 0);
                r2[2] = r3;
                r3 = (object *) constructed_37[0];
                r2[3] = r3;
                r3 = varref (9, 19);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L323; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                L323:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (0, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L324; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_loop_1333_i522_i523;
                L324:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              }
              r1=r1;
              fatbar_370_over: ;
              r1=r1;
            } break;
          }
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
      fatbar_369_over: ;
      r1=r1;
      fatbar_368_over: ;
      r1=r1;
      fatbar_367_over: ;
      r1=r1;
      fatbar_358_over: ;
      r1=r1;
      fatbar_357_over: ;
      r1=r1;
      fatbar_356_over: ;
      r1=r1;
      fatbar_354_over: ;
      r1=r1;
      fatbar_334_over: ;
      r1=r1;
      fatbar_333_over: ;
      lenv = lenv[1];
      r1 = r1;
      r0[2] = r1;
      r0 = varref (1, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L325; ; k = t;
      lenv = r0[2]; goto FUN_skip_whitespace_1303;
      L325:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (4, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L326; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L326:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 0);
      r0[2] = r1;
      r0 = (object *) 14850;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (4, 0);
        r0[2] = r1;
        r0 = varref (5, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L327; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L327:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (4, 0, r0);
        r0 = varref (0, 0);
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L328; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_read_1308;
        L328:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (2, 0);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (1, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (2, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (UOTAG(9),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_330;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_330;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_330_over;
        fatbar_330:
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_50[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 7);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_581[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = varref (1, 1);
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[3] = r1;
              r1 = (object*)TC_NIL;
              r0[4] = r1;
              r1 = varref (0, 2);
              r2 = varref (4, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = varref (0, 3);
              r2 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[6] = r1;
              r1 = varref (0, 4);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[7] = r1;
              r0 = varref (0, 5);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_331;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_331;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_331_over;
        fatbar_331:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_892;
        r0[2] = r1;
        r1 = allocate (UOTAG(0), 2);
        r2 = varref (2, 0);
        r1[1] = r2;
        r2 = varref (0, 0);
        r1[2] = r2;
        r0[3] = r1;
        r1 = varref (6, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        fatbar_331_over: ;
        PXLL_RETURN(0);
        fatbar_330_over: ;
        PXLL_RETURN(0);
      } else {
        goto fatbar_329;
      }
      PXLL_RETURN(0);
      goto fatbar_329_over;
      fatbar_329:
      r0 = (object *) 23298;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (5, 0);
        r1[2] = r2;
        r1 = varref (6, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L329; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L329:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (5, 0, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L330; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto FUN_read_1308;
        L330:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (4, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L331; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_skip_whitespace_1303;
        L331:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (7, 0);
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = varref (0, 0);
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = varref (7, 0);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L332; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L332:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          varset (6, 0, r2);
        } else {
          r2 = (object *) 14;
        }
        r2 = varref (6, 0);
        r1[2] = r2;
        r1 = (object *) 23810;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (6, 0);
          r1[2] = r2;
          r1 = varref (7, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L333; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L333:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (6, 0, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = varref (0, 0);
          r1=r1;
        } else {
          r1 = (object*) &constructed_69;
          r1 = box(((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_893;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_893;
          r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
          r1=r1;
        }
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = (object *) constructed_239[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = (object*)TC_NIL;
        r0[5] = r1;
        r1 = varref (0, 3);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = varref (0, 4);
        r2 = varref (2, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = varref (0, 5);
        r2 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = varref (0, 6);
        r2 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[9] = r1;
        r0 = varref (0, 7);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_332;
      }
      PXLL_RETURN(0);
      goto fatbar_332_over;
      fatbar_332:
      r0 = varref (1, 0);
      PXLL_RETURN(0);
      fatbar_332_over: ;
      PXLL_RETURN(0);
      fatbar_329_over: ;
      PXLL_RETURN(0);
    L234:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_1308; r1[2] = lenv;
    r0[4] = r1;
    // def read-hex-digit_1310
    goto L334;
    FUN_read_hex_digit_1310:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (5, 154);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (5, 64);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L335; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L335:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*) &constructed_69;
          r0 = box(((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_891;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_891;
          r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L334:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_digit_1310; r1[2] = lenv;
    r0[5] = r1;
    // def read-hex-code_1311
    goto L336;
    FUN_read_hex_code_1311:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (3, 0);
      r2[2] = r3;
      r2 = varref (4, 0);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L337; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L337:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      varset (3, 0, r2);
      r2 = varref (0, 0);
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (1, 3);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L338; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_read_hex_digit_1310;
      L338:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (3, 0);
      r2[2] = r3;
      r2 = varref (4, 0);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L339; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L339:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      varset (3, 0, r2);
      r2 = varref (0, 0);
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (1, 3);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L340; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_read_hex_digit_1310;
      L340:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = (object *) 17;
      r2 = varref (0, 0);
      r1 = box(unbox(r2)<<unbox(r1));
      r0[4] = r1;
      r1 = varref (0, 1);
      r2 = varref (0, 2);
      r1 = box(unbox(r2)+unbox(r1));
      r0[5] = r1;
      r0 = varref (0, 3);
      r0 = TO_CHAR(unbox(r0));
      PXLL_RETURN(0);
    L336:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_code_1311; r1[2] = lenv;
    r0[6] = r1;
    // def read-list_1313
    goto L341;
    FUN_read_list_1313:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 0);
      r0[2] = r1;
      r0 = varref (3, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L342; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L342:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      varset (2, 0, r0);
      r0 = varref (0, 0);
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1367
      goto L343;
      FUN_loop_1367:
        check_heap (0);
        r0 = varref (2, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L344; ; k = t;
        lenv = r0[2]; goto FUN_skip_whitespace_1303;
        L344:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (5, 0);
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L345; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L345:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 0, r1);
        } else {
          r1 = (object *) 14;
        }
        r1 = varref (4, 0);
        r0[2] = r1;
        r0 = (object *) 10498;
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 0);
          r0[2] = r1;
          r0 = varref (6, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L346; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L346:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (5, 0, r0);
          r0 = varref (0, 0);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (6, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (4, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L347; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_read_1308;
          L347:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (2, 0);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r0;
          goto FUN_loop_1367;
        }
        PXLL_RETURN(0);
      L343:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1367; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_890[0];
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1367;
    L341:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_list_1313; r1[2] = lenv;
    r0[7] = r1;
    // def read-hex-int_1317
    goto L348;
    FUN_read_hex_int_1317:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L349; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L349:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (2, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (2, 0);
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = varref (0, 1);
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = varref (4, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L350; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L350:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (3, 0, r0);
        r0 = varref (0, 0);
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1390
      goto L351;
      FUN_loop_1390:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (7, 154);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (7, 64);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L352; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L352:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 0);
            r0[2] = r1;
            r0 = varref (8, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L353; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L353:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (7, 0, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 0);
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (7, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L354; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L354:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (6, 0, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = varref (6, 0);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 33;
            r3 = varref (3, 0);
            r2 = box(unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = varref (1, 0);
            r2 = varref (0, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1390;
          } break;
          default: {
            r0 = varref (3, 1);
            if PXLL_IS_TRUE(r0) {
              r0 = varref (1, 0);
              r1 = (object *) 1;
              r0 = box(unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L351:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1390; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (4, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L355; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L355:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 0);
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1390;
    L348:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_int_1317; r1[2] = lenv;
    r0[8] = r1;
    // def read-oct-int_1318
    goto L356;
    FUN_read_oct_int_1318:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L357; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L357:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (2, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (2, 0);
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = varref (0, 1);
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = varref (4, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L358; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L358:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (3, 0, r0);
        r0 = varref (0, 0);
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1396
      goto L359;
      FUN_loop_1396:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (7, 156);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (7, 64);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L360; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L360:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 0);
            r0[2] = r1;
            r0 = varref (8, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L361; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L361:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (7, 0, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 0);
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (7, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L362; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L362:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (6, 0, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = varref (6, 0);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 17;
            r3 = varref (3, 0);
            r2 = box(unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = varref (1, 0);
            r2 = varref (0, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1396;
          } break;
          default: {
            r0 = varref (3, 1);
            if PXLL_IS_TRUE(r0) {
              r0 = varref (1, 0);
              r1 = (object *) 1;
              r0 = box(unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L359:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1396; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (4, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L363; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L363:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 0);
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1396;
    L356:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_oct_int_1318; r1[2] = lenv;
    r0[9] = r1;
    // def loop_1403_i656
    goto L364;
    FUN_loop_1403_i656:
      check_heap (0);
      r0 = varref (1, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L365; ; k = t;
      lenv = r0[2]; goto FUN_skip_whitespace_1303;
      L365:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (4, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L366; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L366:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 0, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 0);
      r0[2] = r1;
      r0 = (object *) 65794;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = (object *) constructed_37[0];
        r0[3] = r1;
        r1 = varref (4, 19);
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L367; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_read_1308;
        L367:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_889[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = varref (1, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r2 = varref (11, 77);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L368; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_427;
                                  L368:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (0, 0);
                                  r1[2] = r2;
                                  r2 = (object *) constructed_37[0];
                                  r1[3] = r2;
                                  r2 = varref (11, 19);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L369; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                  L369:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (0, 1);
                                  r1[2] = r2;
                                  r2 = (object *) constructed_37[0];
                                  r1[3] = r2;
                                  r2 = varref (11, 19);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L370; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                  L370:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = varref (7, 0);
                                  r0[3] = r1;
                                  r1 = varref (11, 19);
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L371; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                                  L371:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = result;
                                  lenv = lenv[1];
                                  r0 = r0;
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  lenv[2] = r0;
                                  goto FUN_loop_1403_i656;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_328;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_328;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_328;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_328;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_328;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_328;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_328;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_328_over;
        fatbar_328:
        r0 = varref (1, 0);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_loop_1403_i656;
        fatbar_328_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L364:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1403_i656; r1[2] = lenv;
    r0[10] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) constructed_887[0];
    r0[2] = r1;
    r1 = varref (0, 8);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_1403_i656;
  L206:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_reader_426; r1[2] = lenv;
  r0[78] = r1;
  // def read-file_427
  goto L372;
  FUN_read_file_427:
    check_heap (0);
    r0 = (object*) &constructed_916;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_916;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = varref (0, 0);
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 60);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L373; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_file_2fopen_read_390;
    L373:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    // def lambda_6435
    goto L374;
    FUN_lambda_6435:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (2, 63);
      r0[1] = r1[2]; lenv = r0; goto FUN_file_2fread_char_397;
    L374:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_6435; r1[2] = lenv;
    r0[3] = r1;
    r1 = (object *) 65794;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 10);
    r0[1] = lenv; lenv = r0;
    // def skip-whitespace_1303_i0
    goto L375;
    FUN_skip_whitespace_1303_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1324_i0
      goto L376;
      FUN_loop_1324_i0:
        check_heap (0);
        r0 = (object *) 65794;
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 15106;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop_1322_i343_i0
            goto L377;
            FUN_loop_1322_i343_i0:
              check_heap (0);
              r0 = (object *) 2562;
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_326;
              }
              PXLL_RETURN(0);
              goto fatbar_326_over;
              fatbar_326:
              r0 = (object *) 3330;
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                goto fatbar_327;
              }
              PXLL_RETURN(0);
              goto fatbar_327_over;
              fatbar_327:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = varref (6, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L378; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L378:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (6, 2, r0);
              r0 = varref (0, 0);
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L379; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L379:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              lenv[2] = r0;
              goto FUN_loop_1322_i343_i0;
              fatbar_327_over: ;
              PXLL_RETURN(0);
              fatbar_326_over: ;
              PXLL_RETURN(0);
            L377:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop_1322_i343_i0; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (5, 2);
            r1[2] = r2;
            r1 = varref (5, 1);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L380; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L380:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            varset (5, 2, r1);
            r1 = varref (0, 0);
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L381; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L381:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (4, 2);
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (3, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L382; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L382:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (3, 2, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = varref (3, 2);
            lenv[2] = r0;
            goto FUN_loop_1324_i0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (5, 162);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L383; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L383:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (4, 2);
              r0[2] = r1;
              r0 = varref (4, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L384; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L384:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (4, 2, r0);
              r0 = varref (0, 0);
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (4, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (3, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L385; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L385:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (3, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (3, 2);
              lenv[2] = r0;
              goto FUN_loop_1324_i0;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L376:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1324_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (2, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L386; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L386:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (2, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (2, 2);
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L375:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_skip_whitespace_1303_i0; r1[2] = lenv;
    r0[2] = r1;
    // def read-atom_1304_i0
    goto L387;
    FUN_read_atom_1304_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = (object *) 1;
      r0[3] = r1;
      r1 = (object *) 12290;
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1329_i0
      goto L388;
      FUN_loop_1329_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 2);
        r0[2] = r1;
        r0 = (object *) 65794;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = varref (4, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L389; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L389:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (4, 2, r0);
        } else {
          r0 = (object *) 14;
        }
        r0 = varref (4, 2);
        varset (2, 2, r0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 2);
        r0[2] = r1;
        r0 = (object *) 11778;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = varref (0, 0);
          r0 = box(unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
        } else {
          r0 = (object *) 14;
        }
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 7;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (2, 2);
            r0[2] = r1;
            r1 = varref (6, 163);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L390; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L390:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = (object *) 7;
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_322;
        }
        r0=r0;
        goto fatbar_322_over;
        fatbar_322:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 5;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 13;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (2, 2);
            r0[2] = r1;
            r1 = varref (6, 163);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L391; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L391:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 13;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (2, 2);
              r0[2] = r1;
              r1 = varref (6, 164);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L392; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L392:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_323;
        }
        r0=r0;
        goto fatbar_323_over;
        fatbar_323:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 11;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (2, 2);
            r0[2] = r1;
            r1 = varref (6, 163);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L393; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L393:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 11;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (2, 2);
              r0[2] = r1;
              r1 = varref (6, 164);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L394; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L394:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = (object *) 7;
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_324;
        }
        r0=r0;
        goto fatbar_324_over;
        fatbar_324:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object *) 9;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 2);
            r0[2] = r1;
            r0 = (object *) 11522;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = (object *) 3;
              r0=r0;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (2, 2);
              r0[2] = r1;
              r1 = varref (6, 164);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L395; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L395:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 5;
                r0=r0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (2, 2);
                r0[2] = r1;
                r1 = varref (6, 163);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L396; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L396:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                if PXLL_IS_TRUE(r0) {
                  r0 = (object *) 15;
                  r0=r0;
                } else {
                  r0 = (object *) 7;
                  r0=r0;
                }
                r0=r0;
              }
              r0=r0;
            }
            r0=r0;
          }
          r0=r0;
        } else {
          goto fatbar_325;
        }
        r0=r0;
        goto fatbar_325_over;
        fatbar_325:
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_68;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_68;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        r0=r0;
        fatbar_325_over: ;
        r0=r0;
        fatbar_324_over: ;
        r0=r0;
        fatbar_323_over: ;
        r0=r0;
        fatbar_322_over: ;
        varset (2, 0, r0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 0);
        r0[2] = r1;
        r0 = (object *) 9;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(unbox(r1)<unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 2);
          r0[2] = r1;
          r1 = varref (5, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L397; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L397:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (5, 2, r1);
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (1, 0);
          r0[4] = r1;
          r0 = varref (0, 2);
          r1 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          lenv[2] = r0;
          goto FUN_loop_1329_i0;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 0);
          r0[2] = r1;
          r0 = (object *) 9;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = (object*) &constructed_69;
            r0 = box(((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_915;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_915;
            r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 0);
            r0[2] = r1;
            r0 = (object *) 15;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = varref (5, 2);
              r0[2] = r1;
              r1 = varref (5, 1);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L398; t[4] = r0; k = t;
              lenv = r1[2]; goto *r1[1];
              L398:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              varset (5, 2, r1);
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (1, 0);
              r0[4] = r1;
              r0 = varref (0, 2);
              r1 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              varset (0, 0, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (UOTAG(4), 4);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 0);
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (7, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L399; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L399:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = varref (6, 52);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L400; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L400:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[1] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (3, 0);
            r1[2] = r2;
            r1 = (object *) 13;
            r2 = varref (0, 0);
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (6, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L401; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L401:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = varref (2, 1);
            r0[4] = r1;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L388:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1329_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_914[0];
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L387:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_atom_1304_i0; r1[2] = lenv;
    r0[3] = r1;
    // def read_1308_i0
    goto L402;
    FUN_read_1308_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L403; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L403:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (4, 2);
      r2[2] = r3;
      r2 = (object *) 65794;
      r3 = varref (0, 0);
      r2 = PXLL_TEST(r3==r2);
      lenv = lenv[1];
      r2 = r2;
      if PXLL_IS_TRUE(r2) {
        r2 = varref (3, 1);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L404; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L404:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        varset (3, 2, r2);
      } else {
        r2 = (object *) 14;
      }
      r2 = varref (3, 2);
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 10498;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_69;
        r1 = box(((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_894;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_894;
        r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_283;
      }
      r1=r1;
      goto fatbar_283_over;
      fatbar_283:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 8962;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L405; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L405:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L406; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L406:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (3, 2, r1);
        } else {
          r1 = (object *) 14;
        }
        r1 = varref (3, 2);
        varset (0, 0, r1);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 10242;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 5);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L407; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L407:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(7),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_285;
        }
        r1=r1;
        goto fatbar_285_over;
        fatbar_285:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 29954;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L408; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L408:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_286;
        }
        r1=r1;
        goto fatbar_286_over;
        fatbar_286:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 21762;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L409; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L409:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object*)UITAG(6);
          r1=r1;
        } else {
          goto fatbar_287;
        }
        r1=r1;
        goto fatbar_287_over;
        fatbar_287:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 26114;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L410; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L410:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_288;
        }
        r1=r1;
        goto fatbar_288_over;
        fatbar_288:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 17922;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L411; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L411:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_289;
        }
        r1=r1;
        goto fatbar_289_over;
        fatbar_289:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 29698;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L412; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L412:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_290;
        }
        r1=r1;
        goto fatbar_290_over;
        fatbar_290:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 21506;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L413; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L413:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = (object *) 262;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r1=r1;
        } else {
          goto fatbar_291;
        }
        r1=r1;
        goto fatbar_291_over;
        fatbar_291:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 28418;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L414; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L414:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 7);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L415; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L415:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_292;
        }
        r1=r1;
        goto fatbar_292_over;
        fatbar_292:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 20226;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L416; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L416:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 7);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L417; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L417:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_293;
        }
        r1=r1;
        goto fatbar_293_over;
        fatbar_293:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 30722;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L418; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L418:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 6);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L419; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L419:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_294;
        }
        r1=r1;
        goto fatbar_294_over;
        fatbar_294:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 22530;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L420; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L420:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 6);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L421; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L421:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(5),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_295;
        }
        r1=r1;
        goto fatbar_295_over;
        fatbar_295:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r1[2] = r2;
        r1 = (object *) 23554;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (4, 2);
          r1[2] = r2;
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L422; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L422:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 1);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L423; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L423:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          switch (get_case_noint (r1)) {
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 0);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = varref (1, 0);
              r2 = UOBJ_GET(r2,2);
              r1[3] = r2;
              r1 = (object *) 3;
              r2 = varref (0, 1);
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 1;
                r3 = varref (1, 0);
                range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                r2 = (object *) 1;
                r3 = varref (1, 0);
                r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_298;
              }
              r1=r1;
              goto fatbar_298_over;
              fatbar_298:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_895;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L424; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L424:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_299;
              }
              r1=r1;
              goto fatbar_299_over;
              fatbar_299:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_896;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L425; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L425:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 65794;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_300;
              }
              r1=r1;
              goto fatbar_300_over;
              fatbar_300:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_897;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L426; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L426:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2306;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_301;
              }
              r1=r1;
              goto fatbar_301_over;
              fatbar_301:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_898;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L427; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L427:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 3330;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_302;
              }
              r1=r1;
              goto fatbar_302_over;
              fatbar_302:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_899;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L428; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L428:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 8194;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                goto fatbar_303;
              }
              r1=r1;
              goto fatbar_303_over;
              fatbar_303:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object*) &constructed_900;
              r2[3] = r3;
              r3 = varref (8, 48);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L429; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
              L429:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = (object *) 1;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) 2562;
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r1;
                r1 = t;
                r1=r1;
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_297;
              }
              r1=r1;
              fatbar_303_over: ;
              r1=r1;
              fatbar_302_over: ;
              r1=r1;
              fatbar_301_over: ;
              r1=r1;
              fatbar_300_over: ;
              r1=r1;
              fatbar_299_over: ;
              r1=r1;
              fatbar_298_over: ;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
          }
          r1=r1;
          goto fatbar_297_over;
          fatbar_297:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_901;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (6, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L430; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L430:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_297_over: ;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } else {
          goto fatbar_296;
        }
        r1=r1;
        goto fatbar_296_over;
        fatbar_296:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_902;
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (5, 12);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L431; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
        L431:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r1=r1;
        fatbar_296_over: ;
        r1=r1;
        fatbar_295_over: ;
        r1=r1;
        fatbar_294_over: ;
        r1=r1;
        fatbar_293_over: ;
        r1=r1;
        fatbar_292_over: ;
        r1=r1;
        fatbar_291_over: ;
        r1=r1;
        fatbar_290_over: ;
        r1=r1;
        fatbar_289_over: ;
        r1=r1;
        fatbar_288_over: ;
        r1=r1;
        fatbar_287_over: ;
        r1=r1;
        fatbar_286_over: ;
        r1=r1;
        fatbar_285_over: ;
        r1=r1;
      } else {
        goto fatbar_284;
      }
      r1=r1;
      goto fatbar_284_over;
      fatbar_284:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 14850;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L432; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L432:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = varref (3, 1);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L433; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L433:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (0, 0);
        switch (get_case_noint (r2)) {
          default: {
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 0);
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r3 = varref (1, 0);
            r3 = UOBJ_GET(r3,1);
            r2[3] = r3;
            r3 = varref (1, 0);
            r3 = UOBJ_GET(r3,3);
            r2[4] = r3;
            r2 = varref (0, 1);
            switch (get_case (r2)) {
              case ((pxll_int)PXLL_TRUE): {
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_903;
                r2[2] = r3;
                r3 = varref (0, 0);
                r2[3] = r3;
                r3 = varref (7, 12);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L434; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_303;
                L434:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = (object *) 1;
                r3 = varref (0, 2);
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = varref (0, 0);
                  r2[2] = r3;
                  r3 = varref (7, 73);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L435; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_422;
                  L435:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r2=r2;
                } else {
                  goto fatbar_305;
                }
                r2=r2;
                goto fatbar_305_over;
                fatbar_305:
                r2 = allocate (TC_TUPLE, 3);
                r3 = (object*) &constructed_904;
                r2[2] = r3;
                r3 = varref (0, 0);
                r2[3] = r3;
                r3 = varref (7, 12);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L436; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_error1_303;
                L436:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
                fatbar_305_over: ;
                r2=r2;
              } break;
            }
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
          } break;
        }
        r1[3] = r2;
        r1 = varref (0, 1);
        r2 = (object *) constructed_50[0];
        t = alloc_no_clear (UOTAG(9),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_304;
      }
      r1=r1;
      goto fatbar_304_over;
      fatbar_304:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 11266;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L437; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L437:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_906[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L438; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L438:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_306;
      }
      r1=r1;
      goto fatbar_306_over;
      fatbar_306:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 9986;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L439; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L439:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_732[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L440; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L440:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_307;
      }
      r1=r1;
      goto fatbar_307_over;
      fatbar_307:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 8706;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L441; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L441:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1364_i452_i523_i0
        goto L442;
        FUN_loop_1364_i452_i523_i0:
          check_heap (0);
          r0 = (object *) 23554;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 2);
            r0[2] = r1;
            r0 = varref (6, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L443; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L443:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (6, 2, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 2);
            r0[2] = r1;
            r0 = varref (6, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L444; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L444:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (6, 2, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = r0;
            varset (0, 0, r0);
            r0 = (object *) 23554;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L445; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L445:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              r1 = varref (0, 1);
              r2 = (object *) 23554;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523_i0;
            } else {
              goto fatbar_310;
            }
            PXLL_RETURN(0);
            goto fatbar_310_over;
            fatbar_310:
            r0 = (object *) 8706;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L446; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L446:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              r1 = varref (0, 1);
              r2 = (object *) 8706;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523_i0;
            } else {
              goto fatbar_311;
            }
            PXLL_RETURN(0);
            goto fatbar_311_over;
            fatbar_311:
            r0 = (object *) 29698;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L447; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L447:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              r1 = varref (0, 1);
              r2 = (object *) 2306;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523_i0;
            } else {
              goto fatbar_312;
            }
            PXLL_RETURN(0);
            goto fatbar_312_over;
            fatbar_312:
            r0 = (object *) 28162;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L448; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L448:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              r1 = varref (0, 1);
              r2 = (object *) 2562;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523_i0;
            } else {
              goto fatbar_313;
            }
            PXLL_RETURN(0);
            goto fatbar_313_over;
            fatbar_313:
            r0 = (object *) 22530;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L449; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L449:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (5, 4);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L450; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L450:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = varref (1, 1);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523_i0;
            } else {
              goto fatbar_314;
            }
            PXLL_RETURN(0);
            goto fatbar_314_over;
            fatbar_314:
            r0 = (object *) 30722;
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (6, 2);
              r0[2] = r1;
              r0 = (object *) 65794;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = varref (5, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L451; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L451:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (5, 2, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = varref (5, 2);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (5, 4);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L452; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L452:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = varref (1, 1);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1364_i452_i523_i0;
            } else {
              goto fatbar_315;
            }
            PXLL_RETURN(0);
            goto fatbar_315_over;
            fatbar_315:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_908;
            r0[2] = r1;
            r1 = varref (0, 1);
            r0[3] = r1;
            r1 = varref (7, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            fatbar_315_over: ;
            PXLL_RETURN(0);
            fatbar_314_over: ;
            PXLL_RETURN(0);
            fatbar_313_over: ;
            PXLL_RETURN(0);
            fatbar_312_over: ;
            PXLL_RETURN(0);
            fatbar_311_over: ;
            PXLL_RETURN(0);
            fatbar_310_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_309;
          }
          PXLL_RETURN(0);
          goto fatbar_309_over;
          fatbar_309:
          r0 = (object *) 8706;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 2);
            r0[2] = r1;
            r0 = varref (6, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L453; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L453:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (6, 2, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (1, 1);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (8, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L454; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L454:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (8, 52);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L455; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
            L455:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(2),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            goto fatbar_316;
          }
          PXLL_RETURN(0);
          goto fatbar_316_over;
          fatbar_316:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (6, 2);
          r0[2] = r1;
          r0 = varref (6, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L456; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L456:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (6, 2, r0);
          r0 = varref (0, 0);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (6, 2);
          r0[2] = r1;
          r0 = (object *) 65794;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (5, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L457; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L457:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (5, 2, r0);
          } else {
            r0 = (object *) 14;
          }
          r0 = varref (5, 2);
          r1 = varref (0, 1);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_1364_i452_i523_i0;
          fatbar_316_over: ;
          PXLL_RETURN(0);
          fatbar_309_over: ;
          PXLL_RETURN(0);
        L442:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1364_i452_i523_i0; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (5, 2);
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = varref (0, 0);
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = varref (4, 1);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L458; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L458:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          varset (4, 2, r2);
        } else {
          r2 = (object *) 14;
        }
        r2 = varref (4, 2);
        r1[2] = r2;
        r2 = (object *) constructed_907[0];
        r1[3] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L459; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L459:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_308;
      }
      r1=r1;
      goto fatbar_308_over;
      fatbar_308:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 31490;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        r1[2] = r2;
        r1 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L460; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L460:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (4, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1371_i483_i523_i0
        goto L461;
        FUN_loop_1371_i483_i523_i0:
          check_heap (0);
          r0 = varref (4, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L462; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L462:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (7, 2);
          r1[2] = r2;
          r1 = (object *) 65794;
          r2 = varref (0, 0);
          r1 = PXLL_TEST(r2==r1);
          lenv = lenv[1];
          r1 = r1;
          if PXLL_IS_TRUE(r1) {
            r1 = varref (6, 1);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L463; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L463:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            varset (6, 2, r1);
          } else {
            r1 = (object *) 14;
          }
          r1 = varref (6, 2);
          r0[2] = r1;
          r0 = (object *) 32002;
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 2);
            r0[2] = r1;
            r0 = varref (7, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L464; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L464:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (7, 2, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 0);
            r1[2] = r2;
            r2 = (object *) constructed_37[0];
            r1[3] = r2;
            r2 = varref (9, 19);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L465; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
            L465:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(8),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def loop_1376_i490_i523_i0
            goto L466;
            FUN_loop_1376_i490_i523_i0:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (0, 1);
              r0[2] = r1;
              r1 = varref (11, 165);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L467; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L467:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = (object *) 262;
                r0=r0;
              } else {
                r0 = (object *) 11778;
                r1 = varref (0, 1);
                r0 = PXLL_TEST(r1==r0);
                r0=r0;
              }
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (10, 2);
                r0[2] = r1;
                r0 = varref (10, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L468; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L468:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (10, 2, r0);
                r0 = varref (0, 0);
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (10, 2);
                r0[2] = r1;
                r0 = (object *) 65794;
                r1 = varref (0, 0);
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = varref (9, 1);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L469; ; k = t;
                  lenv = r0[2]; goto *r0[1];
                  L469:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  varset (9, 2, r0);
                } else {
                  r0 = (object *) 14;
                }
                r0 = varref (9, 2);
                r1 = varref (0, 0);
                r2 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r2 = (object *) 6;
                lenv[2] = r1;
                lenv[3] = r0;
                lenv[4] = r2;
                goto FUN_loop_1376_i490_i523_i0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (0, 0);
                r2[2] = r3;
                r3 = (object *) constructed_37[0];
                r2[3] = r3;
                r3 = varref (11, 19);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L470; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                L470:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (11, 52);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L471; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_list__3estring_371;
                L471:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (11, 73);
                r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_422;
              }
              PXLL_RETURN(0);
            L466:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_loop_1376_i490_i523_i0; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r2 = (object *) constructed_911[0];
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (9, 2);
            r2[2] = r3;
            r2 = (object *) 65794;
            r3 = varref (0, 0);
            r2 = PXLL_TEST(r3==r2);
            lenv = lenv[1];
            r2 = r2;
            if PXLL_IS_TRUE(r2) {
              r2 = varref (8, 1);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L472; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L472:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              varset (8, 2, r2);
            } else {
              r2 = (object *) 14;
            }
            r2 = varref (8, 2);
            r1[3] = r2;
            r2 = (object *) 6;
            r1[4] = r2;
            r2 = varref (0, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L473; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L473:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r0 = (object *) constructed_67[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 6;
              t = alloc_no_clear (UOTAG(4),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = varref (0, 0);
              r2 = varref (1, 0);
              t = alloc_no_clear (UOTAG(0),2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[3] = r1;
              r0 = varref (3, 0);
              r1 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              goto FUN_loop_1371_i483_i523_i0;
            } else {
              r0 = varref (6, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L474; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L474:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (9, 2);
              r1[2] = r2;
              r1 = (object *) 65794;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = varref (8, 1);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L475; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L475:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                varset (8, 2, r1);
              } else {
                r1 = (object *) 14;
              }
              r1 = varref (8, 2);
              r0[2] = r1;
              r1 = (object *) 15618;
              r2 = varref (0, 0);
              r1 = PXLL_TEST(r2==r1);
              r0[3] = r1;
              r0 = (object *) 6;
              r1 = varref (0, 1);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_910;
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[3] = r1;
                r1 = varref (9, 12);
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (8, 2);
                r0[2] = r1;
                r0 = varref (8, 1);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L476; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L476:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                varset (8, 2, r0);
                r0 = varref (0, 0);
                lenv = lenv[1];
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (7, 2);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L477; t[4] = r0; k = t;
                lenv = r1[2]; goto *r1[1];
                L477:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r2 = varref (2, 0);
                t = alloc_no_clear (UOTAG(0),2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = varref (4, 0);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                lenv = ((object ***)lenv)[1][1][1];
                lenv[2] = r0;
                goto FUN_loop_1371_i483_i523_i0;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L461:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1371_i483_i523_i0; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) constructed_909[0];
        r1[2] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L478; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L478:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_317;
      }
      r1=r1;
      goto fatbar_317_over;
      fatbar_317:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 10242;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (3, 5);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L479; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L479:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } else {
        goto fatbar_318;
      }
      r1=r1;
      goto fatbar_318_over;
      fatbar_318:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = (object*) &constructed_69;
        r1 = box(((pxll_string*)(r1))->len);
        r2 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
        r1 = (object*) &constructed_912;
        dump_object (r1, 0); fprintf (stdout, "\n");
        r1 = (object*) &constructed_912;
        r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
        r1=r1;
      } else {
        goto fatbar_319;
      }
      r1=r1;
      goto fatbar_319_over;
      fatbar_319:
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 1);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L480; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L480:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = varref (0, 0);
      switch (get_case_noint (r1)) {
        default: {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,2);
          r1[4] = r2;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,3);
          r1[5] = r2;
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case ((pxll_int)PXLL_TRUE): {
              r1 = allocate (TC_TUPLE, 5);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) 1;
              r3 = varref (1, 0);
              range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
              r2 = (object *) 1;
              r3 = varref (1, 0);
              r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
              r1[2] = r2;
              r2 = (object *) 11522;
              r3 = varref (0, 0);
              r2 = PXLL_TEST(r3==r2);
              r1[3] = r2;
              r2 = varref (0, 1);
              if PXLL_IS_TRUE(r2) {
                r2 = (object *) 3;
                r2=r2;
              } else {
                r2 = (object *) 1;
                r2=r2;
              }
              r1[4] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              // def loop_1384_i511_i523_i0
              goto L481;
              FUN_loop_1384_i511_i523_i0:
                check_heap (0);
                r0 = varref (3, 2);
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = varref (2, 1);
                  if PXLL_IS_TRUE(r0) {
                    r0 = varref (0, 1);
                    r1 = (object *) 1;
                    r0 = box(unbox(r1)-unbox(r0));
                    PXLL_RETURN(0);
                  } else {
                    r0 = varref (0, 1);
                    PXLL_RETURN(0);
                  }
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (11, 155);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r3 = varref (4, 0);
                  range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
                  r2 = varref (1, 0);
                  r3 = varref (4, 0);
                  r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
                  r1[3] = r2;
                  r2 = varref (11, 64);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L482; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                  L482:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UITAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_913;
                      r0[2] = r1;
                      r1 = varref (4, 0);
                      r0[3] = r1;
                      r1 = varref (11, 12);
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = (object *) 21;
                      r2 = varref (3, 1);
                      r1 = box(unbox(r2)*unbox(r1));
                      r0[2] = r1;
                      r0 = varref (1, 0);
                      r1 = varref (0, 0);
                      r0 = box(unbox(r1)+unbox(r0));
                      lenv = lenv[1];
                      r0 = r0;
                      r1 = (object *) 3;
                      r2 = varref (2, 0);
                      r1 = box(unbox(r2)+unbox(r1));
                      lenv = ((object **)lenv)[1][1];
                      lenv[2] = r1;
                      lenv[3] = r0;
                      goto FUN_loop_1384_i511_i523_i0;
                    } break;
                  }
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              L481:
              r3 = allocate (TC_CLOSURE, 2);
              r3[1] = &&FUN_loop_1384_i511_i523_i0; r3[2] = lenv;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 2);
              r2[2] = r3;
              r3 = (object *) 1;
              r2[3] = r3;
              r3 = varref (0, 0);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L483; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto *r3[1];
              L483:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[5] = r2;
              r1 = varref (0, 3);
              t = alloc_no_clear (UOTAG(5),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              r1 = (object *) 1;
              r2 = varref (0, 3);
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (1, 0);
                r2[2] = r3;
                r3 = varref (8, 73);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L484; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_422;
                L484:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                goto fatbar_320;
              }
              r1=r1;
              goto fatbar_320_over;
              fatbar_320:
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 0);
              r2 = box(((pxll_string*)(r2))->len);
              r1[2] = r2;
              r1 = varref (0, 0);
              r2 = varref (1, 3);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (1, 0);
                r2[2] = r3;
                r3 = varref (8, 73);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L485; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string__3esymbol_422;
                L485:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                // def loop_1333_i522_i523_i0
                goto L486;
                FUN_loop_1333_i522_i523_i0:
                  check_heap (0);
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = varref (1, 0);
                          r1[2] = r2;
                          r2 = varref (11, 73);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L487; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
                          L487:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = varref (0, 0);
                          t = alloc_no_clear (UOTAG(1),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_321;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_321_over;
                      fatbar_321:
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 1);
                      r1[2] = r2;
                      r2 = varref (3, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L488; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L488:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 0);
                      r1[2] = r2;
                      r2 = varref (11, 73);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L489; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
                      L489:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      r1 = varref (0, 0);
                      t = alloc_no_clear (UOTAG(10),2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      PXLL_RETURN(0);
                      fatbar_321_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = (object*) &constructed_69;
                      r0 = box(((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_69;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_68;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_68;
                      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L486:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_loop_1333_i522_i523_i0; r2[2] = lenv;
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 3);
                r4 = varref (2, 0);
                r3[2] = r4;
                r4 = (object *) 11778;
                r3[3] = r4;
                r4 = varref (9, 47);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L490; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_string_split_364;
                L490:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (0, 0);
                r2[2] = r3;
                r3 = (object *) constructed_37[0];
                r2[3] = r3;
                r3 = varref (9, 19);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L491; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                L491:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (0, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L492; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L492:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              }
              r1=r1;
              fatbar_320_over: ;
              r1=r1;
            } break;
          }
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
      fatbar_319_over: ;
      r1=r1;
      fatbar_318_over: ;
      r1=r1;
      fatbar_317_over: ;
      r1=r1;
      fatbar_308_over: ;
      r1=r1;
      fatbar_307_over: ;
      r1=r1;
      fatbar_306_over: ;
      r1=r1;
      fatbar_304_over: ;
      r1=r1;
      fatbar_284_over: ;
      r1=r1;
      fatbar_283_over: ;
      lenv = lenv[1];
      r1 = r1;
      r0[2] = r1;
      r0 = varref (1, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L493; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L493:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L494; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L494:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 2);
      r0[2] = r1;
      r0 = (object *) 14850;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (4, 2);
        r0[2] = r1;
        r0 = varref (4, 1);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L495; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L495:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (4, 2, r0);
        r0 = varref (0, 0);
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L496; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L496:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (2, 0);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (1, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (2, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (UOTAG(9),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_280;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_280;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_280_over;
        fatbar_280:
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_50[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 7);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_581[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[2] = r1;
              r1 = varref (1, 1);
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r0[3] = r1;
              r1 = (object*)TC_NIL;
              r0[4] = r1;
              r1 = varref (0, 2);
              r2 = varref (4, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = varref (0, 3);
              r2 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[6] = r1;
              r1 = varref (0, 4);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[7] = r1;
              r0 = varref (0, 5);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_281;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_281;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_281_over;
        fatbar_281:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_892;
        r0[2] = r1;
        r1 = allocate (UOTAG(0), 2);
        r2 = varref (2, 0);
        r1[1] = r2;
        r2 = varref (0, 0);
        r1[2] = r2;
        r0[3] = r1;
        r1 = varref (6, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        fatbar_281_over: ;
        PXLL_RETURN(0);
        fatbar_280_over: ;
        PXLL_RETURN(0);
      } else {
        goto fatbar_279;
      }
      PXLL_RETURN(0);
      goto fatbar_279_over;
      fatbar_279:
      r0 = (object *) 23298;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (5, 2);
        r1[2] = r2;
        r1 = varref (5, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L497; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L497:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (5, 2, r1);
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (4, 2);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L498; t[4] = r0; t[5] = r1; k = t;
        lenv = r2[2]; goto *r2[1];
        L498:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (4, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L499; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L499:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (7, 2);
        r2[2] = r3;
        r2 = (object *) 65794;
        r3 = varref (0, 0);
        r2 = PXLL_TEST(r3==r2);
        lenv = lenv[1];
        r2 = r2;
        if PXLL_IS_TRUE(r2) {
          r2 = varref (6, 1);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L500; t[4] = r0; t[5] = r1; k = t;
          lenv = r2[2]; goto *r2[1];
          L500:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          varset (6, 2, r2);
        } else {
          r2 = (object *) 14;
        }
        r2 = varref (6, 2);
        r1[2] = r2;
        r1 = (object *) 23810;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (6, 2);
          r1[2] = r2;
          r1 = varref (6, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L501; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L501:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (6, 2, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = varref (0, 0);
          r1=r1;
        } else {
          r1 = (object*) &constructed_69;
          r1 = box(((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_893;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_893;
          r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
          r1=r1;
        }
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = (object *) constructed_239[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = (object*)TC_NIL;
        r0[5] = r1;
        r1 = varref (0, 3);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = varref (0, 4);
        r2 = varref (2, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = varref (0, 5);
        r2 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = varref (0, 6);
        r2 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[9] = r1;
        r0 = varref (0, 7);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_282;
      }
      PXLL_RETURN(0);
      goto fatbar_282_over;
      fatbar_282:
      r0 = varref (1, 0);
      PXLL_RETURN(0);
      fatbar_282_over: ;
      PXLL_RETURN(0);
      fatbar_279_over: ;
      PXLL_RETURN(0);
    L402:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_1308_i0; r1[2] = lenv;
    r0[4] = r1;
    // def read-hex-digit_1310_i0
    goto L502;
    FUN_read_hex_digit_1310_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (5, 154);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (5, 64);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L503; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L503:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*) &constructed_69;
          r0 = box(((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_891;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_891;
          r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L502:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_digit_1310_i0; r1[2] = lenv;
    r0[5] = r1;
    // def read-hex-code_1311_i0
    goto L504;
    FUN_read_hex_code_1311_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (3, 2);
      r2[2] = r3;
      r2 = varref (3, 1);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L505; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L505:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      varset (3, 2, r2);
      r2 = varref (0, 0);
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (1, 3);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L506; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L506:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (3, 2);
      r2[2] = r3;
      r2 = varref (3, 1);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L507; t[4] = r0; t[5] = r1; k = t;
      lenv = r2[2]; goto *r2[1];
      L507:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      varset (3, 2, r2);
      r2 = varref (0, 0);
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (1, 3);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L508; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L508:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = (object *) 17;
      r2 = varref (0, 0);
      r1 = box(unbox(r2)<<unbox(r1));
      r0[4] = r1;
      r1 = varref (0, 1);
      r2 = varref (0, 2);
      r1 = box(unbox(r2)+unbox(r1));
      r0[5] = r1;
      r0 = varref (0, 3);
      r0 = TO_CHAR(unbox(r0));
      PXLL_RETURN(0);
    L504:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_code_1311_i0; r1[2] = lenv;
    r0[6] = r1;
    // def read-list_1313_i0
    goto L509;
    FUN_read_list_1313_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 2);
      r0[2] = r1;
      r0 = varref (2, 1);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L510; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L510:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      varset (2, 2, r0);
      r0 = varref (0, 0);
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1367_i0
      goto L511;
      FUN_loop_1367_i0:
        check_heap (0);
        r0 = varref (2, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L512; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L512:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (5, 2);
        r1[2] = r2;
        r1 = (object *) 65794;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L513; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L513:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          varset (4, 2, r1);
        } else {
          r1 = (object *) 14;
        }
        r1 = varref (4, 2);
        r0[2] = r1;
        r0 = (object *) 10498;
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 2);
          r0[2] = r1;
          r0 = varref (5, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L514; ; k = t;
          lenv = r0[2]; goto *r0[1];
          L514:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (5, 2, r0);
          r0 = varref (0, 0);
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (6, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (4, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L515; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L515:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (2, 0);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r0;
          goto FUN_loop_1367_i0;
        }
        PXLL_RETURN(0);
      L511:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1367_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) constructed_890[0];
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L509:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_list_1313_i0; r1[2] = lenv;
    r0[7] = r1;
    // def read-hex-int_1317_i0
    goto L516;
    FUN_read_hex_int_1317_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (2, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L517; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L517:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (2, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (2, 2);
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = varref (0, 1);
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 2);
        r0[2] = r1;
        r0 = varref (3, 1);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L518; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L518:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (3, 2, r0);
        r0 = varref (0, 0);
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1390_i0
      goto L519;
      FUN_loop_1390_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (7, 154);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (7, 64);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L520; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L520:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 2);
            r0[2] = r1;
            r0 = varref (7, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L521; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L521:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (7, 2, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 2);
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (6, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L522; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L522:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (6, 2, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = varref (6, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 33;
            r3 = varref (3, 0);
            r2 = box(unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = varref (1, 0);
            r2 = varref (0, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1390_i0;
          } break;
          default: {
            r0 = varref (3, 1);
            if PXLL_IS_TRUE(r0) {
              r0 = varref (1, 0);
              r1 = (object *) 1;
              r0 = box(unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L519:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1390_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L523; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L523:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 2);
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L516:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_hex_int_1317_i0; r1[2] = lenv;
    r0[8] = r1;
    // def read-oct-int_1318_i0
    goto L524;
    FUN_read_oct_int_1318_i0:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (3, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (2, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L525; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L525:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (2, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (2, 2);
      r0[2] = r1;
      r1 = (object *) 11522;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      r0[3] = r1;
      r0 = varref (0, 1);
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 2);
        r0[2] = r1;
        r0 = varref (3, 1);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L526; ; k = t;
        lenv = r0[2]; goto *r0[1];
        L526:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (3, 2, r0);
        r0 = varref (0, 0);
        lenv = lenv[1];
        r0 = (object *) 14;
      } else {
        r0 = (object *) 14;
      }
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1396_i0
      goto L527;
      FUN_loop_1396_i0:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (7, 156);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (7, 64);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L528; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L528:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 2);
            r0[2] = r1;
            r0 = varref (7, 1);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L529; ; k = t;
            lenv = r0[2]; goto *r0[1];
            L529:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            varset (7, 2, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (7, 2);
            r0[2] = r1;
            r0 = (object *) 65794;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (6, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L530; ; k = t;
              lenv = r0[2]; goto *r0[1];
              L530:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              varset (6, 2, r0);
            } else {
              r0 = (object *) 14;
            }
            r0 = varref (6, 2);
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) 17;
            r3 = varref (3, 0);
            r2 = box(unbox(r3)*unbox(r2));
            r1[2] = r2;
            r1 = varref (1, 0);
            r2 = varref (0, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_1396_i0;
          } break;
          default: {
            r0 = varref (3, 1);
            if PXLL_IS_TRUE(r0) {
              r0 = varref (1, 0);
              r1 = (object *) 1;
              r0 = box(unbox(r1)-unbox(r0));
              PXLL_RETURN(0);
            } else {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L527:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1396_i0; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L531; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L531:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 2);
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L524:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_read_oct_int_1318_i0; r1[2] = lenv;
    r0[9] = r1;
    // def loop_1403_i656_i0
    goto L532;
    FUN_loop_1403_i656_i0:
      check_heap (0);
      r0 = varref (1, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L533; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L533:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (4, 2);
      r1[2] = r2;
      r1 = (object *) 65794;
      r2 = varref (0, 0);
      r1 = PXLL_TEST(r2==r1);
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (3, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L534; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L534:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        varset (3, 2, r1);
      } else {
        r1 = (object *) 14;
      }
      r1 = varref (3, 2);
      r0[2] = r1;
      r0 = (object *) 65794;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = (object *) constructed_37[0];
        r0[3] = r1;
        r1 = varref (4, 19);
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L535; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L535:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_889[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = varref (1, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r2 = varref (11, 77);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L536; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_427;
                                  L536:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (0, 0);
                                  r1[2] = r2;
                                  r2 = (object *) constructed_37[0];
                                  r1[3] = r2;
                                  r2 = varref (11, 19);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L537; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                  L537:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (0, 1);
                                  r1[2] = r2;
                                  r2 = (object *) constructed_37[0];
                                  r1[3] = r2;
                                  r2 = varref (11, 19);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L538; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                  L538:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = varref (7, 0);
                                  r0[3] = r1;
                                  r1 = varref (11, 19);
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L539; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                                  L539:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = result;
                                  lenv = lenv[1];
                                  r0 = r0;
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  lenv[2] = r0;
                                  goto FUN_loop_1403_i656_i0;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_278;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_278;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_278;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_278;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_278;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_278;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_278;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_278_over;
        fatbar_278:
        r0 = varref (1, 0);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_loop_1403_i656_i0;
        fatbar_278_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L532:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_1403_i656_i0; r1[2] = lenv;
    r0[10] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) constructed_887[0];
    r0[2] = r1;
    r1 = varref (0, 8);
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L372:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_read_file_427; r1[2] = lenv;
  r0[79] = r1;
  // def sexp->symbol_429
  goto L540;
  FUN_sexp__3esymbol_429:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_277;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_277_over;
    fatbar_277:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_886;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_277_over: ;
    PXLL_RETURN(0);
  L540:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp__3esymbol_429; r1[2] = lenv;
  r0[80] = r1;
  // def sexp->int_430
  goto L541;
  FUN_sexp__3eint_430:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_276;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_276_over;
    fatbar_276:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_885;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_276_over: ;
    PXLL_RETURN(0);
  L541:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp__3eint_430; r1[2] = lenv;
  r0[81] = r1;
  // def field=?_431
  goto L542;
  FUN_field_3d_question_431:
    check_heap (0);
    r0 = varref (0, 0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = varref (1, 1);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 1);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = varref (2, 1);
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = varref (0, 0);
    r1 = varref (1, 0);
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (1, 1);
      r0[2] = r1;
      r1 = varref (0, 1);
      r0[3] = r1;
      r1 = varref (3, 81);
      r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_432;
    } else {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L542:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_field_3d_question_431; r1[2] = lenv;
  r0[82] = r1;
  // def sexp=?_432
  goto L543;
  FUN_sexp_3d_question_432:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(6)): {
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (UITAG(6)): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (3, 48);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L544; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
            L544:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) 1;
            r1 = varref (0, 1);
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(3)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (3, 81);
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (0, 0);
            r0[4] = r1;
            r1 = varref (3, 39);
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_344;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (3, 81);
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (0, 0);
            r0[4] = r1;
            r1 = varref (3, 39);
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_344;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(8)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (3, 80);
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (0, 0);
            r0[4] = r1;
            r1 = varref (3, 39);
            r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_344;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = varref (0, 1);
              r1 = varref (1, 1);
              r0 = PXLL_TEST(r1==r0);
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (3, 81);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L545; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_432;
            L545:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (0, 1);
              r1 = varref (1, 1);
              r0 = PXLL_TEST(r1==r0);
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_275;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_275_over;
    fatbar_275:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_275_over: ;
    PXLL_RETURN(0);
  L543:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sexp_3d_question_432; r1[2] = lenv;
  r0[83] = r1;
  // def repr-field_434
  goto L546;
  FUN_repr_field_434:
    check_heap (0);
    r0 = varref (0, 0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r0 = (object *) constructed_67[0];
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object*) &constructed_883;
      PXLL_RETURN(0);
    } else {
      goto fatbar_274;
    }
    PXLL_RETURN(0);
    goto fatbar_274_over;
    fatbar_274:
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 6);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 0);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = varref (2, 0);
    r3 = UOBJ_GET(r3,0);
    r2[2] = r3;
    r2 = varref (0, 0);
    lenv = lenv[1];
    r2 = r2;
    r2=r2;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = varref (1, 1);
    r2[2] = r3;
    r3 = varref (3, 83);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L547; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_repr_435;
    L547:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = (object*)TC_NIL;
    r1[4] = r2;
    r2 = varref (0, 2);
    r3 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[5] = r2;
    r2 = varref (0, 3);
    r3 = (object*) &constructed_884;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[6] = r2;
    r1 = varref (0, 4);
    r2 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = varref (2, 45);
    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
    fatbar_274_over: ;
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L546:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_repr_field_434; r1[2] = lenv;
  r0[84] = r1;
  // def repr_435
  goto L548;
  FUN_repr_435:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (3, 83);
        r3[2] = r4;
        r4 = varref (1, 0);
        r3[3] = r4;
        r4 = varref (3, 30);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L549; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
        L549:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_867;
        r2[3] = r3;
        r3 = varref (3, 46);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L550; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L550:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_866;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_865;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r2 = varref (0, 0);
        r3 = (object*) &constructed_869;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = varref (1, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = varref (0, 2);
        r2 = (object*) &constructed_868;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 44);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L551; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L551:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = varref (0, 2);
        r2 = (object*) &constructed_870;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case ((pxll_int)PXLL_TRUE): {
            r0 = (object*) &constructed_871;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_872;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 54);
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_374;
      } break;
      case (UITAG(6)): {
        r0 = (object*) &constructed_873;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (3, 83);
        r3[2] = r4;
        r4 = varref (1, 0);
        r3[3] = r4;
        r4 = varref (3, 30);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L552; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
        L552:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_876;
        r2[3] = r3;
        r3 = varref (3, 46);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L553; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L553:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_875;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_874;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (3, 82);
        r3[2] = r4;
        r4 = varref (1, 0);
        r3[3] = r4;
        r4 = varref (3, 30);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L554; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
        L554:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_879;
        r2[3] = r3;
        r3 = varref (3, 46);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L555; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L555:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_878;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_877;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) constructed_50[0];
        r3 = varref (1, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
          r2 = (object*) &constructed_881;
          r2=r2;
        } else {
          r2 = varref (1, 0);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = varref (2, 0);
          r3 = UOBJ_GET(r3,0);
          r2[2] = r3;
          r2 = varref (0, 0);
          lenv = lenv[1];
          r2 = r2;
          r2=r2;
          r2=r2;
        }
        r1[2] = r2;
        r2 = varref (1, 1);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (2, 1);
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = varref (0, 0);
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = (object*) &constructed_880;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 83);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L556; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_repr_435;
        L556:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (1, 1);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (2, 1);
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = varref (0, 0);
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = (object*) &constructed_882;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
    }
    PXLL_RETURN(0);
  L548:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_repr_435; r1[2] = lenv;
  r0[85] = r1;
  // def indent_436
  goto L557;
  FUN_indent_436:
    check_heap (0);
    r0 = (object *) 1;
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) 262;
      PXLL_RETURN(0);
    } else {
      goto fatbar_273;
    }
    PXLL_RETURN(0);
    goto fatbar_273_over;
    fatbar_273:
    r0 = (object*) &constructed_864;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_864;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 3;
    r2 = varref (0, 0);
    r1 = box(unbox(r2)-unbox(r1));
    r0[2] = r1;
    r1 = varref (1, 84);
    r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
    fatbar_273_over: ;
    PXLL_RETURN(0);
  L557:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_indent_436; r1[2] = lenv;
  r0[86] = r1;
  // def pp-size-field_437
  goto L558;
  FUN_pp_size_field_437:
    check_heap (0);
    r0 = varref (0, 0);
    r0 = allocate (TC_TUPLE, 7);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r1 = varref (0, 0);
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 0);
    r2 = UOBJ_GET(r2,0);
    r1[2] = r2;
    r1 = varref (0, 0);
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
    r0[4] = r1;
    r1 = varref (0, 2);
    r1 = box(((pxll_string*)(r1))->len);
    r0[5] = r1;
    r1 = (object *) 3;
    r2 = varref (0, 3);
    r1 = box(unbox(r2)+unbox(r1));
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 1);
    r1[2] = r2;
    r2 = varref (2, 86);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L559; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_438;
    L559:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[7] = r1;
    r0 = varref (0, 5);
    r1 = varref (0, 4);
    r0 = box(unbox(r1)+unbox(r0));
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L558:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_size_field_437; r1[2] = lenv;
  r0[87] = r1;
  // def pp-size_438
  goto L560;
  FUN_pp_size_438:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (2, 10);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 20);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L561; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
        L561:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (0, 0);
        r2 = (object *) 3;
        r1 = box(unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 86);
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (2, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L562; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L562:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (2, 36);
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_341;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[3] = r1;
        r0 = varref (0, 1);
        r0 = box(((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r1 = box(((pxll_string*)(r1))->len);
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = (object *) 5;
        r0 = box(unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        t = alloc_no_clear (UOTAG(3),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (2, 83);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L563; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
        L563:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        r0 = box(((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = (object *) 5;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 54);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L564; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_int__3estring_374;
        L564:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        r0 = box(((pxll_string*)(r0))->len);
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = (object *) 5;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (2, 10);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 20);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L565; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
        L565:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (0, 0);
        r2 = (object *) 5;
        r1 = box(unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 86);
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (2, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L566; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L566:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (2, 36);
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_341;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (2, 10);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 20);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L567; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
        L567:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 3;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)+unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 85);
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (2, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L568; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L568:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (2, 36);
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_341;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 8);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (0, 0);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[4] = r1;
        r1 = varref (0, 2);
        r1 = box(((pxll_string*)(r1))->len);
        r0[5] = r1;
        r1 = varref (0, 1);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 1);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[6] = r1;
        r1 = varref (0, 4);
        r1 = box(((pxll_string*)(r1))->len);
        r0[7] = r1;
        r1 = varref (0, 5);
        r2 = varref (0, 3);
        r1 = box(unbox(r2)+unbox(r1));
        r0[8] = r1;
        r0 = varref (0, 6);
        r1 = (object *) 3;
        r0 = box(unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 86);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L569; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_438;
        L569:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (0, 1);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 1);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[5] = r1;
        r1 = varref (0, 3);
        r1 = box(((pxll_string*)(r1))->len);
        r0[6] = r1;
        r1 = varref (0, 4);
        r2 = varref (0, 2);
        r1 = box(unbox(r2)+unbox(r1));
        r0[7] = r1;
        r0 = varref (0, 5);
        r1 = (object *) 3;
        r0 = box(unbox(r1)+unbox(r0));
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L560:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_size_438; r1[2] = lenv;
  r0[88] = r1;
  // def pp_439
  goto L570;
  FUN_pp_439:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 1);
    r1[2] = r2;
    r2 = varref (2, 86);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L571; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_pp_size_438;
    L571:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 161;
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)<unbox(r0))) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (2, 1);
      r1[2] = r2;
      r2 = varref (3, 83);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L572; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
      L572:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      r0 = box(((pxll_string*)(r0))->len);
      r1 = varref (0, 0);
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    } else {
      r0 = varref (1, 1);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (2, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*) &constructed_861;
              r0 = box(((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_861;
              r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = (object*) &constructed_863;
              r0 = box(((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_863;
              (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (3, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (4, 87);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L573; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
              L573:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_7210
              goto L574;
              FUN_lambda_7210:
                check_heap (0);
                r0 = (object *) 2562;
                box(fputc (GET_CHAR(r0), stdout));
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 3;
                r2 = varref (4, 0);
                r1 = box(unbox(r2)+unbox(r1));
                r0[2] = r1;
                r1 = varref (5, 84);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L575; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
                L575:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object *) 3;
                r2 = varref (4, 0);
                r1 = box(unbox(r2)+unbox(r1));
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[3] = r1;
                r1 = varref (5, 87);
                r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
              L574:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_7210; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (0, 1);
              r0[3] = r1;
              r1 = varref (4, 33);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L576; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
              L576:
              ; lenv = k[2]; k = k[1];
              r0 = (object*) &constructed_862;
              r0 = box(((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_862;
              r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_272;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_272_over;
      fatbar_272:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (2, 1);
      r1[2] = r2;
      r2 = varref (3, 83);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L577; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
      L577:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      r0 = box(((pxll_string*)(r0))->len);
      r1 = varref (0, 0);
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
      fatbar_272_over: ;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L570:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_439; r1[2] = lenv;
  r0[89] = r1;
  // def matches-list?_441
  goto L578;
  FUN_matches_list_question_441:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_270;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_67[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 3);
                      // def lambda_7300
                      goto L579;
                      FUN_lambda_7300:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = varref (3, 0);
                        r0[2] = r1;
                        r1 = varref (0, 0);
                        r0[3] = r1;
                        r1 = varref (5, 89);
                        r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_443;
                      L579:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN_lambda_7300; r1[2] = lenv;
                      r0[2] = r1;
                      r1 = varref (3, 1);
                      r0[3] = r1;
                      r1 = varref (4, 38);
                      r0[1] = r1[2]; lenv = r0; goto FUN_every_question_343;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_271;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_271;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_271;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_271;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_271_over;
        fatbar_271:
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (3, 89);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L580; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_443;
            L580:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            if PXLL_IS_TRUE(r0) {
              r0 = varref (0, 1);
              r1 = varref (1, 1);
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_matches_list_question_441;
            } else {
              r0 = (object *) 6;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_270;
          }
        }
        PXLL_RETURN(0);
        fatbar_271_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_270_over;
    fatbar_270:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_270_over: ;
    PXLL_RETURN(0);
  L578:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_matches_list_question_441; r1[2] = lenv;
  r0[90] = r1;
  // def matches-pattern?_443
  goto L581;
  FUN_matches_pattern_question_443:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (2, 0);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        r0[2] = r1;
        r1 = (object *) 1;
        r2 = varref (0, 0);
        range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
        r1 = (object *) 1;
        r2 = varref (0, 0);
        r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
        r0[3] = r1;
        r0 = (object *) 15362;
        r1 = varref (0, 1);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = varref (1, 1);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = varref (2, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (2, 0);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = varref (0, 0);
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
              r0[3] = r1;
              r1 = varref (0, 1);
              r1 = box(((pxll_string*)(r1))->len);
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) 3;
              r2 = varref (1, 2);
              r1 = box(unbox(r2)-unbox(r1));
              r0[2] = r1;
              r1 = varref (0, 0);
              r2 = varref (1, 1);
              range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
              r1 = varref (0, 0);
              r2 = varref (1, 1);
              r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
              r0[3] = r1;
              r0 = (object *) 15874;
              r1 = varref (0, 1);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 4);
                r2 = varref (1, 1);
                r1[2] = r2;
                r2 = (object *) 3;
                r1[3] = r2;
                r2 = (object *) 3;
                r3 = varref (1, 2);
                r2 = box(unbox(r3)-unbox(r2));
                r1[4] = r2;
                r2 = varref (4, 43);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L582; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
                L582:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (2, 0);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = varref (0, 0);
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (0, 0);
                r1[2] = r2;
                r2 = varref (0, 1);
                r1[3] = r2;
                r2 = varref (4, 48);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L583; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
                L583:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = (object *) 1;
                r1 = varref (0, 2);
                r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                PXLL_RETURN(0);
              } else {
                r0 = (object *) 6;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_269;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_269_over;
          fatbar_269:
          r0 = (object *) 6;
          PXLL_RETURN(0);
          fatbar_269_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 262;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (3, 88);
            r0[1] = r1[2]; lenv = r0; goto FUN_matches_list_question_441;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_268;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_268;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_268_over;
    fatbar_268:
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    r0 = PXLL_TEST(r1==r0);
    PXLL_RETURN(0);
    fatbar_268_over: ;
    PXLL_RETURN(0);
  L581:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_matches_pattern_question_443; r1[2] = lenv;
  r0[91] = r1;
  // def get-ellipsis-nestings_444
  goto L584;
  FUN_get_ellipsis_nestings_444:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def dolist_1516
    goto L585;
    FUN_dolist_1516:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_67[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = varref (1, 1);
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = varref (3, 0);
                        r1[2] = r2;
                        r2 = varref (7, 90);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L586; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
                        L586:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = varref (0, 0);
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = (object*)TC_NIL;
                        r0[4] = r1;
                        r0 = varref (0, 2);
                        r1 = varref (0, 1);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_267;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_267;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_267;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_267;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_267_over;
          fatbar_267:
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (5, 90);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L587; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
          L587:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 1);
          r1[2] = r2;
          r2 = varref (3, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L588; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_dolist_1516;
          L588:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (5, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L589; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L589:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (5, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          fatbar_267_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_266;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_266_over;
      fatbar_266:
      r0 = (object *) constructed_860[0];
      PXLL_RETURN(0);
      fatbar_266_over: ;
      PXLL_RETURN(0);
    L585:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_dolist_1516; r1[2] = lenv;
    r0[2] = r1;
    r0 = varref (1, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_dolist_1516;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (2, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_265;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_265_over;
    fatbar_265:
    r0 = (object *) constructed_859[0];
    PXLL_RETURN(0);
    fatbar_265_over: ;
    PXLL_RETURN(0);
  L584:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_ellipsis_nestings_444; r1[2] = lenv;
  r0[92] = r1;
  // def intersect?_445
  goto L590;
  FUN_intersect_question_445:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            r0 = PXLL_TEST(r1==r0);
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_264;
          }
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_7564
            goto L591;
            FUN_lambda_7564:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_7560
              goto L592;
              FUN_lambda_7560:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (1, 0);
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[3] = r1;
                r1 = varref (5, 91);
                r0[1] = r1[2]; lenv = r0; goto FUN_intersect_question_445;
              L592:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_7560; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (1, 0);
              r0[3] = r1;
              r1 = varref (4, 37);
              r0[1] = r1[2]; lenv = r0; goto FUN_some_question_342;
            L591:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_7564; r1[2] = lenv;
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (3, 37);
            r0[1] = r1[2]; lenv = r0; goto FUN_some_question_342;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_264;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_264;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_264_over;
    fatbar_264:
    r0 = (object *) 6;
    PXLL_RETURN(0);
    fatbar_264_over: ;
    PXLL_RETURN(0);
  L590:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_intersect_question_445; r1[2] = lenv;
  r0[93] = r1;
  // def ellipsis-sub-envs_446
  goto L593;
  FUN_ellipsis_sub_envs_446:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_857[0];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = varref (0, 1);
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = varref (4, 0);
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[2] = r1;
                        r1 = varref (1, 0);
                        r0[3] = r1;
                        r1 = varref (5, 91);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L594; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_intersect_question_445;
                        L594:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        if PXLL_IS_TRUE(r0) {
                          r0 = varref (0, 0);
                          PXLL_RETURN(0);
                        } else {
                          r0 = varref (3, 1);
                          r1 = varref (4, 0);
                          lenv = ((object ****)lenv)[1][1][1][1];
                          lenv[2] = r1;
                          lenv[3] = r0;
                          goto FUN_ellipsis_sub_envs_446;
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ****)lenv)[1][1][1][1];
                        goto fatbar_263;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_263;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_263;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_263;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_263_over;
    fatbar_263:
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_858;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_858;
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_263_over: ;
    PXLL_RETURN(0);
  L593:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_ellipsis_sub_envs_446; r1[2] = lenv;
  r0[94] = r1;
  // def get-bindings_447
  goto L595;
  FUN_get_bindings_447:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def dolist_1544
    goto L596;
    FUN_dolist_1544:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_67[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = varref (1, 1);
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 10);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = varref (3, 0);
                        r1[2] = r2;
                        r2 = varref (7, 90);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L597; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
                        L597:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = varref (0, 0);
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        // def lambda_7680
                        goto L598;
                        FUN_lambda_7680:
                          check_heap (0);
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (5, 0);
                          r1[2] = r2;
                          r2 = varref (1, 0);
                          r1[3] = r2;
                          r2 = varref (9, 93);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L599; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_get_bindings_447;
                          L599:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = varref (0, 0);
                          t = alloc_no_clear (UOTAG(0),1);
                          t[1] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        L598:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN_lambda_7680; r2[2] = lenv;
                        r1[2] = r2;
                        r2 = varref (4, 1);
                        r1[3] = r2;
                        r2 = varref (7, 30);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L600; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                        L600:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r1 = varref (0, 2);
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[5] = r1;
                        r1 = (object*)TC_NIL;
                        r0[6] = r1;
                        r1 = varref (0, 4);
                        r2 = varref (0, 3);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[7] = r1;
                        r1 = varref (0, 5);
                        r2 = varref (0, 1);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        r0[8] = r1;
                        r1 = varref (0, 6);
                        t = alloc_no_clear (UOTAG(0),1);
                        t[1] = r1;
                        r1 = t;
                        r0[9] = r1;
                        r1 = (object*)TC_NIL;
                        r0[10] = r1;
                        r0 = varref (0, 8);
                        r1 = varref (0, 7);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object **)lenv)[1][1];
                        goto fatbar_262;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_262;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_262;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_262;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_262_over;
          fatbar_262:
          r0 = varref (1, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = varref (2, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (2, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (1, 0);
              r1[2] = r2;
              r2 = varref (0, 0);
              r1[3] = r2;
              r2 = varref (5, 93);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L601; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_get_bindings_447;
              L601:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (1, 1);
              r1[2] = r2;
              r2 = varref (0, 1);
              r1[3] = r2;
              r2 = varref (3, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L602; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_dolist_1544;
              L602:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[5] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (0, 2);
              r1[2] = r2;
              r2 = (object *) constructed_37[0];
              r1[3] = r2;
              r2 = varref (5, 19);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L603; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
              L603:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (0, 3);
              r0[3] = r1;
              r1 = varref (5, 19);
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_261;
            }
          }
          PXLL_RETURN(0);
          fatbar_262_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_261;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_261_over;
      fatbar_261:
      r0 = (object *) constructed_856[0];
      PXLL_RETURN(0);
      fatbar_261_over: ;
      PXLL_RETURN(0);
    L596:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_dolist_1544; r1[2] = lenv;
    r0[2] = r1;
    r0 = varref (1, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object*)TC_NIL;
        r0[3] = r1;
        r1 = varref (0, 1);
        r2 = varref (2, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = varref (0, 2);
        r2 = varref (2, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = varref (0, 3);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[6] = r1;
        r1 = (object*)TC_NIL;
        r0[7] = r1;
        r0 = varref (0, 5);
        r1 = varref (0, 4);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (2, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (2, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN_dolist_1544;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_260;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_260;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_260_over;
    fatbar_260:
    r0 = (object *) constructed_855[0];
    PXLL_RETURN(0);
    fatbar_260_over: ;
    PXLL_RETURN(0);
  L595:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_bindings_447; r1[2] = lenv;
  r0[95] = r1;
  // def expand-pattern_449
  goto L604;
  FUN_expand_pattern_449:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (2, 95);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L605; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_450;
        L605:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def loop_1560_i791
        goto L606;
        FUN_loop_1560_i791:
          check_heap (0);
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*)UITAG(1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = varref (1, 0);
                                  r1 = varref (7, 0);
                                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                    r0 = varref (0, 0);
                                    t = alloc_no_clear (UOTAG(0),1);
                                    t[1] = r0;
                                    r0 = t;
                                    PXLL_RETURN(0);
                                  } else {
                                    r0 = varref (4, 1);
                                    lenv = ((object *****)lenv)[1][1][1][1][1];
                                    lenv[2] = r0;
                                    goto FUN_loop_1560_i791;
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_259;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_259;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_259;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_259;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_259;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_259_over;
              fatbar_259:
              r0 = varref (0, 1);
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_loop_1560_i791;
              fatbar_259_over: ;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L606:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_loop_1560_i791; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 1);
        r1[2] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L607; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_loop_1560_i791;
        L607:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = varref (1, 0);
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_258;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_258_over;
    fatbar_258:
    r0 = varref (0, 0);
    PXLL_RETURN(0);
    fatbar_258_over: ;
    PXLL_RETURN(0);
  L604:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_expand_pattern_449; r1[2] = lenv;
  r0[96] = r1;
  // def expand-list_450
  goto L608;
  FUN_expand_list_450:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def sexp/append_1578
    goto L609;
    FUN_sexp_2fappend_1578:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (4, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L610; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L610:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (1, 1);
          r0[3] = r1;
          r1 = varref (4, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } break;
        default: {
          goto fatbar_257;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_257_over;
      fatbar_257:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_854;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_854;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_257_over: ;
      PXLL_RETURN(0);
    L609:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_sexp_2fappend_1578; r1[2] = lenv;
    r0[2] = r1;
    r0 = varref (1, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (2, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_67[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 5);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (3, 0);
                  r1[2] = r2;
                  r2 = varref (6, 90);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L611; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_get_ellipsis_nestings_444;
                  L611:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (0, 0);
                  r1[2] = r2;
                  r2 = varref (5, 1);
                  r1[3] = r2;
                  r2 = varref (6, 92);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L612; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_ellipsis_sub_envs_446;
                  L612:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = varref (0, 1);
                  switch (get_case (r1)) {
                    case (UOTAG(0)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = allocate (TC_TUPLE, 3);
                      // def lambda_7954
                      goto L613;
                      FUN_lambda_7954:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = varref (5, 0);
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = varref (0, 0);
                        r1[2] = r2;
                        r2 = varref (7, 1);
                        r1[3] = r2;
                        r2 = varref (6, 0);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L614; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_sexp_2fappend_1578;
                        L614:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = varref (8, 94);
                        r0[1] = r1[2]; lenv = r0; goto FUN_expand_pattern_449;
                      L613:
                      r2 = allocate (TC_CLOSURE, 2);
                      r2[1] = &&FUN_lambda_7954; r2[2] = lenv;
                      r1[2] = r2;
                      r2 = varref (0, 0);
                      r1[3] = r2;
                      r2 = varref (7, 30);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L615; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                      L615:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      goto fatbar_256;
                    }
                  }
                  r1=r1;
                  goto fatbar_256_over;
                  fatbar_256:
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object*) &constructed_853;
                  r1[2] = r2;
                  r2 = varref (0, 1);
                  r1[3] = r2;
                  r2 = varref (6, 12);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L616; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                  L616:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                  fatbar_256_over: ;
                  r0[4] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (2, 1);
                  r1[2] = r2;
                  r2 = varref (5, 1);
                  r1[3] = r2;
                  r2 = varref (6, 95);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L617; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_450;
                  L617:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[5] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (0, 2);
                  r1[2] = r2;
                  r2 = (object *) constructed_37[0];
                  r1[3] = r2;
                  r2 = varref (6, 19);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L618; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                  L618:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = varref (0, 3);
                  r0[3] = r1;
                  r1 = varref (6, 19);
                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                } else {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_255;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_255;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_255;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_255_over;
        fatbar_255:
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = varref (3, 1);
        r1[3] = r2;
        r2 = varref (4, 94);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L619; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_pattern_449;
        L619:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 1);
        r1[2] = r2;
        r2 = varref (3, 1);
        r1[3] = r2;
        r2 = varref (4, 95);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L620; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_list_450;
        L620:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_255_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_254;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_254_over;
    fatbar_254:
    r0 = varref (1, 0);
    PXLL_RETURN(0);
    fatbar_254_over: ;
    PXLL_RETURN(0);
  L608:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_expand_list_450; r1[2] = lenv;
  r0[97] = r1;
  // def pred_453
  goto L621;
  FUN_pred_453:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (UOTAG(20), 3);
    r2 = (object*)UITAG(1);
    r1[1] = r2;
    r2 = (object*)UITAG(1);
    r1[2] = r2;
    r2 = (object *) 6;
    r1[3] = r2;
    r0[2] = r1;
    r0 = varref (1, 1);
    r1 = varref (0, 0);
    r2 = varref (1, 0);
    t = alloc_no_clear (UOTAG(1),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L621:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pred_453; r1[2] = lenv;
  r0[98] = r1;
  // def new-tvar_455
  goto L622;
  FUN_new_tvar_455:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 166);
    r1 = ((pxll_vector*)r1)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L623; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L623:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (UOTAG(20), 3);
    r2 = (object*)UITAG(1);
    r1[1] = r2;
    r2 = (object*)UITAG(1);
    r1[2] = r2;
    r2 = (object *) 6;
    r1[3] = r2;
    r0[3] = r1;
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    t = alloc_no_clear (UOTAG(0),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L622:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_new_tvar_455; r1[2] = lenv;
  r0[99] = r1;
  // def rlabel_460
  goto L624;
  FUN_rlabel_460:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_710[0];
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r1[1] = lenv; lenv = r1;
    r2 = (object*)TC_NIL;
    r1[2] = r2;
    r2 = varref (0, 0);
    r3 = varref (1, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[3] = r2;
    r2 = varref (0, 1);
    r3 = varref (1, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[4] = r2;
    r1 = varref (0, 2);
    r2 = varref (1, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = varref (1, 96);
    r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
  L624:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_rlabel_460; r1[2] = lenv;
  r0[100] = r1;
  // def type-repr_464
  goto L625;
  FUN_type_repr_464:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 54);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L626; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L626:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = varref (0, 2);
        r2 = (object*) &constructed_845;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_95[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 6);
                      r1[1] = lenv; lenv = r1;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = varref (1, 0);
                      r2[2] = r3;
                      r3 = varref (5, 99);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L627; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_464;
                      L627:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = varref (2, 0);
                      r2[2] = r3;
                      r3 = varref (5, 99);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L628; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_464;
                      L628:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[3] = r2;
                      r2 = (object*)TC_NIL;
                      r1[4] = r2;
                      r2 = varref (0, 2);
                      r3 = varref (0, 1);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[5] = r2;
                      r2 = varref (0, 3);
                      r3 = (object*) &constructed_846;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[6] = r2;
                      r1 = varref (0, 4);
                      r2 = varref (0, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r2;
                      t[2] = r1;
                      r1 = t;
                      lenv = lenv[1];
                      r1 = r1;
                      r0[2] = r1;
                      r1 = varref (4, 45);
                      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_252;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_252;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_252_over;
              fatbar_252:
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 7);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = allocate (TC_TUPLE, 3);
              r4 = varref (4, 99);
              r3[2] = r4;
              r4 = varref (1, 1);
              r3[3] = r4;
              r4 = varref (4, 30);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L629; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
              L629:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = (object*) &constructed_849;
              r2[3] = r3;
              r3 = varref (4, 46);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L630; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
              L630:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = varref (4, 99);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L631; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_type_repr_464;
              L631:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = (object*)TC_NIL;
              r1[4] = r2;
              r2 = varref (0, 2);
              r3 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = varref (0, 3);
              r3 = (object*) &constructed_848;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = varref (0, 4);
              r3 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[7] = r2;
              r1 = varref (0, 5);
              r2 = (object*) &constructed_847;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = varref (3, 45);
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
              fatbar_252_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_251;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_251;
        }
        PXLL_RETURN(0);
        goto fatbar_251_over;
        fatbar_251:
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = varref (0, 0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_253;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_253_over;
        fatbar_253:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 7);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (2, 0);
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = varref (0, 0);
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (3, 99);
        r3[2] = r4;
        r4 = varref (1, 1);
        r3[3] = r4;
        r4 = varref (3, 30);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L632; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
        L632:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_852;
        r2[3] = r3;
        r3 = varref (3, 46);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L633; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L633:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = (object*) &constructed_851;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = varref (0, 4);
        r3 = (object*) &constructed_850;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r1 = varref (0, 5);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_253_over: ;
        PXLL_RETURN(0);
        fatbar_251_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L625:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_repr_464; r1[2] = lenv;
  r0[101] = r1;
  // def type->trec_466
  goto L634;
  FUN_type__3etrec_466:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L634:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type__3etrec_466; r1[2] = lenv;
  r0[102] = r1;
  // def type-find_467
  goto L635;
  FUN_type_find_467:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 100);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L636; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type__3etrec_466;
    L636:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = varref (1, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (3, 101);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L637; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
        L637:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        r1 = varref (1, 0);
        ((pxll_vector*)r1)->val[1] = r0;
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L635:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_find_467; r1[2] = lenv;
  r0[103] = r1;
  // def type-union_468
  goto L638;
  FUN_type_union_468:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 101);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L639; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
    L639:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 1);
    r1[2] = r2;
    r2 = varref (2, 101);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L640; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
    L640:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = varref (1, 1);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = varref (0, 0);
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = varref (2, 0);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = varref (0, 0);
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[2] = r1;
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = varref (2, 0);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = varref (0, 0);
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = varref (2, 0);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            r1 = varref (0, 0);
            ((pxll_vector*)r1)->val[1] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L638:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_type_union_468; r1[2] = lenv;
  r0[104] = r1;
  // def parse-type*_469
  goto L641;
  FUN_parse_type_splat_469:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    // def arrow-type?_1667
    goto L642;
    FUN_arrow_type_question_1667:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_587[0];
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 262;
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_250;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_250;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_250_over;
          fatbar_250:
          r0 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_arrow_type_question_1667;
          fatbar_250_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L642:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_arrow_type_question_1667; r1[2] = lenv;
    r0[2] = r1;
    // def parse-list_1670
    goto L643;
    FUN_parse_list_1670:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_732[0];
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = varref (1, 1);
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (2, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (2, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = varref (0, 0);
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = varref (1, 1);
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = varref (7, 1);
                            r1[2] = r2;
                            r2 = varref (1, 0);
                            r1[3] = r2;
                            r2 = varref (7, 1);
                            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,49)];
                            r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L644; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto *r2[1];
                            L644:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r0 = varref (0, 0);
                            switch (get_case (r0)) {
                              case (UOTAG(0)): {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (1, 0);
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r0 = varref (0, 0);
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (9, 97);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L645; t[4] = r0; k = t;
                                lenv = r1[2]; goto FUN_new_tvar_455;
                                L645:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[2] = r1;
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = varref (8, 1);
                                r0[2] = r1;
                                r1 = varref (2, 0);
                                r0[3] = r1;
                                r1 = varref (0, 0);
                                r0[4] = r1;
                                r1 = varref (8, 1);
                                r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,49)];
                                r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,15)];
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L646; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L646:
                                ; lenv = k[2]; k = k[1];
                                r0 = varref (0, 0);
                                PXLL_RETURN(0);
                              } break;
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_247;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_247;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_247;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_247_over;
                fatbar_247:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_841;
                r0[2] = r1;
                r1 = varref (1, 1);
                r0[3] = r1;
                r1 = varref (5, 12);
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                fatbar_247_over: ;
                PXLL_RETURN(0);
              } else {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_246;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_246;
            }
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_246;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_246_over;
      fatbar_246:
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (1, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L647; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_arrow_type_question_1667;
      L647:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_1682_i854
        goto L648;
        FUN_loop_1682_i854:
          check_heap (0);
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_587[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = varref (1, 1);
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (2, 1);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (2, 1);
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = varref (0, 1);
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = varref (1, 0);
                            r1[2] = r2;
                            r2 = varref (7, 3);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L649; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_parse_1672;
                            L649:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = varref (4, 0);
                            r1[2] = r2;
                            r2 = (object *) constructed_37[0];
                            r1[3] = r2;
                            r2 = varref (9, 19);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L650; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                            L650:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[3] = r1;
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = (object *) constructed_95[0];
                            r0[2] = r1;
                            r1 = varref (0, 1);
                            r2 = varref (0, 0);
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r2;
                            t[2] = r1;
                            r1 = t;
                            r0[3] = r1;
                            r1 = varref (9, 96);
                            r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
                          } break;
                          default: {
                            lenv = ((object **)lenv)[1][1];
                            goto fatbar_248;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_248;
                      }
                    }
                    PXLL_RETURN(0);
                  } else {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_248;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_248;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_248_over;
              fatbar_248:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 0);
              r1[2] = r2;
              r2 = varref (5, 3);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L651; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_parse_1672;
              L651:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = varref (0, 1);
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_1682_i854;
              fatbar_248_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_843;
              r0[2] = r1;
              r1 = varref (2, 0);
              r0[3] = r1;
              r1 = varref (5, 12);
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            } break;
          }
          PXLL_RETURN(0);
        L648:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_1682_i854; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_842[0];
        r0[2] = r1;
        r1 = varref (1, 0);
        r0[3] = r1;
        r1 = varref (0, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_1682_i854;
      } else {
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (0, 0);
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (3, 3);
                r1[2] = r2;
                r2 = varref (1, 1);
                r1[3] = r2;
                r2 = varref (5, 30);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L652; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                L652:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = varref (5, 96);
                r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_249;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_249;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_249_over;
        fatbar_249:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_844;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (3, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        fatbar_249_over: ;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
      fatbar_246_over: ;
      PXLL_RETURN(0);
    L643:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_list_1670; r1[2] = lenv;
    r0[3] = r1;
    // def parse-field-list_1671
    goto L653;
    FUN_parse_field_list_1671:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_67[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 1);
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = varref (5, 97);
                lenv = r0[2]; goto FUN_new_tvar_455;
              } break;
              default: {
                goto fatbar_245;
              }
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_245;
          }
          PXLL_RETURN(0);
          goto fatbar_245_over;
          fatbar_245:
          r0 = allocate (TC_TUPLE, 4);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) constructed_480[0];
          r1[3] = r2;
          r2 = varref (5, 96);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L654; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
          L654:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (1, 1);
          r2[2] = r3;
          r3 = varref (4, 3);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L655; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_parse_1672;
          L655:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) constructed_477[0];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[3] = r2;
          r2 = varref (6, 96);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L656; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
          L656:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 1);
          r1[2] = r2;
          r2 = varref (3, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L657; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_parse_field_list_1671;
          L657:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = varref (5, 98);
          r0[1] = r1[2]; lenv = r0; goto FUN_rlabel_460;
          fatbar_245_over: ;
          PXLL_RETURN(0);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) constructed_494[0];
          r1[2] = r2;
          r2 = (object *) constructed_492[0];
          r1[3] = r2;
          r2 = varref (4, 96);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L658; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
          L658:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_491[0];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r1 = varref (0, 0);
          r2 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r1 = varref (4, 96);
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } break;
      }
      PXLL_RETURN(0);
    L653:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_field_list_1671; r1[2] = lenv;
    r0[4] = r1;
    // def parse_1672
    goto L659;
    FUN_parse_1672:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (4, 173);
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (4, 64);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L660; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
          L660:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (0, 0);
              r0[2] = r1;
              r1 = (object *) constructed_839[0];
              r0[3] = r1;
              r1 = varref (4, 96);
              r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
            } break;
          }
          PXLL_RETURN(0);
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[1] = r1[2]; lenv = r0; goto FUN_parse_list_1670;
        } break;
        case (UOTAG(8)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (2, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L661; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_parse_field_list_1671;
          L661:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) constructed_487[0];
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r1 = varref (0, 0);
          r2 = varref (1, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r1 = varref (4, 96);
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } break;
        default: {
          goto fatbar_244;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_244_over;
      fatbar_244:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_840;
      r0[2] = r1;
      r1 = varref (2, 0);
      r0[3] = r1;
      r1 = varref (3, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      fatbar_244_over: ;
      PXLL_RETURN(0);
    L659:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_parse_1672; r1[2] = lenv;
    r0[5] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 3);
    r0[1] = r1[2]; lenv = r0; goto FUN_parse_1672;
  L641:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_parse_type_splat_469; r1[2] = lenv;
  r0[105] = r1;
  // def get-record-sig_471
  goto L662;
  FUN_get_record_sig_471:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_487[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def loop_1718
                  goto L663;
                  FUN_loop_1718:
                    check_heap (0);
                    r0 = varref (0, 0);
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = (object *) constructed_491[0];
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = varref (1, 1);
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_242;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_242_over;
                        fatbar_242:
                        r0 = (object *) constructed_708[0];
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = varref (0, 1);
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = varref (3, 1);
                                      r1 = varref (0, 0);
                                      lenv = ((object ***)lenv)[1][1][1];
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN_loop_1718;
                                    } break;
                                    default: {
                                      lenv = ((object **)lenv)[1][1];
                                      goto fatbar_243;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_243;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_243;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_243;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_243_over;
                        fatbar_243:
                        r0 = (object *) constructed_710[0];
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 0);
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 0);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = varref (1, 1);
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (2, 1);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = varref (2, 1);
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = varref (0, 0);
                                      switch (get_case (r0)) {
                                        case (UOTAG(1)): {
                                          r0 = allocate (TC_TUPLE, 2);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (1, 0);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r0 = (object *) constructed_477[0];
                                          r1 = varref (0, 0);
                                          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                            r0 = varref (1, 1);
                                            switch (get_case (r0)) {
                                              case (TC_PAIR): {
                                                r0 = allocate (TC_TUPLE, 3);
                                                r0[1] = lenv; lenv = r0;
                                                r1 = varref (2, 1);
                                                r1 = UOBJ_GET(r1,0);
                                                r0[2] = r1;
                                                r1 = varref (2, 1);
                                                r1 = UOBJ_GET(r1,1);
                                                r0[3] = r1;
                                                r0 = varref (0, 1);
                                                switch (get_case (r0)) {
                                                  case (TC_NIL): {
                                                    r0 = varref (6, 1);
                                                    r1 = varref (3, 0);
                                                    t = alloc_no_clear (TC_PAIR,2);
                                                    t[1] = r1;
                                                    t[2] = r0;
                                                    r0 = t;
                                                    r1 = varref (0, 0);
                                                    lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                    lenv[2] = r1;
                                                    lenv[3] = r0;
                                                    goto FUN_loop_1718;
                                                  } break;
                                                  default: {
                                                    lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                    goto fatbar_241;
                                                  }
                                                }
                                                PXLL_RETURN(0);
                                              } break;
                                              default: {
                                                lenv = ((object *****)lenv)[1][1][1][1][1];
                                                goto fatbar_241;
                                              }
                                            }
                                            PXLL_RETURN(0);
                                          } else {
                                            lenv = ((object *****)lenv)[1][1][1][1][1];
                                            goto fatbar_241;
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object ****)lenv)[1][1][1][1];
                                          goto fatbar_241;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_241;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_241;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_241;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_241;
                        }
                        PXLL_RETURN(0);
                        fatbar_243_over: ;
                        PXLL_RETURN(0);
                        fatbar_242_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        r0 = varref (0, 1);
                        r1 = (object *) constructed_67[0];
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                    goto fatbar_241_over;
                    fatbar_241:
                    r0 = (object *) constructed_835[0];
                    PXLL_RETURN(0);
                    fatbar_241_over: ;
                    PXLL_RETURN(0);
                  L663:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_loop_1718; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (2, 0);
                  r1[2] = r2;
                  r2 = (object *) constructed_834[0];
                  r1[3] = r2;
                  r2 = varref (0, 0);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L664; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_loop_1718;
                  L664:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = varref (4, 74);
                  r0[2] = r1;
                  r1 = varref (0, 0);
                  r0[3] = r1;
                  r1 = varref (4, 42);
                  r0[1] = r1[2]; lenv = r0; goto FUN_sort_350;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_240;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_240;
            }
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_240;
        }
        PXLL_RETURN(0);
        goto fatbar_240_over;
        fatbar_240:
        r0 = (object *) constructed_708[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = varref (0, 0);
                      lenv = ((object ***)lenv)[1][1][1];
                      lenv[2] = r0;
                      goto FUN_get_record_sig_471;
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_239;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_239;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_239;
            }
          }
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_239;
        }
        PXLL_RETURN(0);
        fatbar_240_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_239;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_239_over;
    fatbar_239:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 5);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (2, 0);
    r3[2] = r4;
    r4 = varref (3, 99);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L665; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
    L665:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = varref (0, 1);
    r4 = (object*) &constructed_838;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r3 = varref (0, 2);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r2 = varref (0, 3);
    r3 = (object*) &constructed_837;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (2, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L666; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L666:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    r0 = box(((pxll_string*)(r0))->len);
    r1 = varref (0, 0);
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_836;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_239_over: ;
    PXLL_RETURN(0);
  L662:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_record_sig_471; r1[2] = lenv;
  r0[106] = r1;
  // def make-counter_474
  goto L667;
  FUN_make_counter_474:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    // def inc_1748
    goto L668;
    FUN_inc_1748:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (3, 0);
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = (object *) 3;
      r0 = box(unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      varset (2, 0, r0);
      r0 = varref (0, 0);
      PXLL_RETURN(0);
    L668:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_inc_1748; r1[2] = lenv;
    r0[2] = r1;
    // def get_1749
    goto L669;
    FUN_get_1749:
      r0 = varref (1, 0);
      PXLL_RETURN(0);
    L669:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_get_1749; r1[2] = lenv;
    r0[3] = r1;
    r0 = allocate (UOTAG(19), 2);
    r1 = varref (0, 1);
    r0[1] = r1;
    r1 = varref (0, 0);
    r0[2] = r1;
    PXLL_RETURN(0);
  L667:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_counter_474; r1[2] = lenv;
  r0[107] = r1;
  // def new-match-var_478
  goto L670;
  FUN_new_match_var_478:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (1, 176);
    r4 = ((pxll_vector*)r4)->val[1];
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L671; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    lenv = r4[2]; goto *r4[1];
    L671:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[2] = r4;
    r4 = varref (1, 54);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L672; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
    L672:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = varref (0, 1);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = varref (0, 2);
    r3 = (object*) &constructed_833;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (0, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L673; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L673:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (0, 73);
    r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_422;
  L670:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_new_match_var_478; r1[2] = lenv;
  r0[108] = r1;
  // def notdotdotdot_479
  goto L674;
  FUN_notdotdotdot_479:
    check_heap (0);
    r0 = varref (0, 0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r0 = (object *) constructed_67[0];
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    } else {
      lenv = ((object *)lenv)[1];
      goto fatbar_238;
    }
    PXLL_RETURN(0);
    PXLL_RETURN(0);
    goto fatbar_238_over;
    fatbar_238:
    r0 = (object *) 262;
    PXLL_RETURN(0);
    fatbar_238_over: ;
    PXLL_RETURN(0);
  L674:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_notdotdotdot_479; r1[2] = lenv;
  r0[109] = r1;
  // def compile-pattern_480
  goto L675;
  FUN_compile_pattern_480:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 20);
    r0[1] = lenv; lenv = r0;
    // def remove-first-pat_1776
    goto L676;
    FUN_remove_first_pat_1776:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,1);
      r0[3] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (1, 1);
          r1 = varref (0, 1);
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          lenv = ((object *)lenv)[1];
          goto fatbar_237;
        }
      }
      PXLL_RETURN(0);
      PXLL_RETURN(0);
      goto fatbar_237_over;
      fatbar_237:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_832;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_832;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_237_over: ;
      PXLL_RETURN(0);
    L676:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_remove_first_pat_1776; r1[2] = lenv;
    r0[2] = r1;
    // def first-pattern-kind_1777
    goto L677;
    FUN_first_pattern_kind_1777:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = (object *) constructed_730[0];
              PXLL_RETURN(0);
            } break;
            case (UOTAG(1)): {
              r0 = (object *) constructed_826[0];
              PXLL_RETURN(0);
            } break;
            case (UOTAG(2)): {
              r0 = (object *) constructed_415[0];
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = (object *) constructed_820[0];
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          lenv = ((object *)lenv)[1];
          goto fatbar_236;
        }
      }
      PXLL_RETURN(0);
      PXLL_RETURN(0);
      goto fatbar_236_over;
      fatbar_236:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_831;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_831;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_236_over: ;
      PXLL_RETURN(0);
    L677:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_first_pattern_kind_1777; r1[2] = lenv;
    r0[3] = r1;
    // def compare-first-patterns_1778
    goto L678;
    FUN_compare_first_patterns_1778:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (2, 1);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L679; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1777;
      L679:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 1);
      r1[2] = r2;
      r2 = varref (2, 1);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L680; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1777;
      L680:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = varref (0, 1);
      r1 = varref (0, 0);
      r0 = PXLL_TEST(r1==r0);
      PXLL_RETURN(0);
    L678:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compare_first_patterns_1778; r1[2] = lenv;
    r0[4] = r1;
    // def compile-match_1779
    goto L681;
    FUN_compile_match_1779:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = varref (0, 2);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[2] = r1;
              r0 = varref (0, 0);
              PXLL_RETURN(0);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_235;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_235_over;
      fatbar_235:
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (1, 1);
      r1[2] = r2;
      r2 = varref (2, 2);
      r1[3] = r2;
      r2 = varref (4, 40);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L682; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pack_346;
      L682:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (5, 20);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L683; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
      L683:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (4, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L684; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L684:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (1, 2);
        r0[4] = r1;
        r1 = varref (2, 4);
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_group_1780;
      } else {
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_9994
        goto L685;
        FUN_lambda_9994:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (2, 0);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (2, 2);
          r0[4] = r1;
          r1 = varref (3, 4);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L686; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_group_1780;
          L686:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (2, 2, r0);
          PXLL_RETURN(0);
        L685:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_9994; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = (object *) constructed_37[0];
        r1[3] = r2;
        r2 = varref (4, 19);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L687; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
        L687:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (4, 33);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L688; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        L688:
        ; lenv = k[2]; k = k[1];
        r0 = varref (1, 2);
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
      fatbar_235_over: ;
      PXLL_RETURN(0);
    L681:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compile_match_1779; r1[2] = lenv;
    r0[5] = r1;
    // def compile-group_1780
    goto L689;
    FUN_compile_group_1780:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (1, 1);
      r2[2] = r3;
      r3 = varref (4, 17);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L690; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
      L690:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = varref (2, 1);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L691; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_first_pattern_kind_1777;
      L691:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) constructed_820[0];
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (3, 1);
        r3[2] = r4;
        r4 = varref (6, 17);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L692; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_car_318;
        L692:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = varref (0, 0);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (1, 0);
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = varref (0, 0);
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L693; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L693:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (3, 7);
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (0, 0);
        r2[2] = r3;
        r3 = varref (3, 9);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L694; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1786;
        L694:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = varref (5, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L695; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L695:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_10268_i916
        goto L696;
        FUN_lambda_10268_i916:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 0);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = varref (2, 0);
          r3 = UOBJ_GET(r3,0);
          r2[2] = r3;
          r2 = varref (0, 0);
          lenv = lenv[1];
          r2 = r2;
          r2=r2;
          r1[2] = r2;
          r2 = varref (7, 17);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L697; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
          L697:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (5, 7);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (0, 0);
          r2[2] = r3;
          r3 = varref (5, 9);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L698; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1786;
          L698:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (7, 30);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L699; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
          L699:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = varref (7, 11);
          r1[2] = r2;
          r2 = varref (2, 1);
          r1[3] = r2;
          r2 = varref (0, 1);
          r1[4] = r2;
          r2 = varref (7, 39);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L700; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_every2_question_344;
          L700:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 2);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_818;
            r0[2] = r1;
            r1 = varref (3, 1);
            r0[3] = r1;
            r1 = varref (6, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L696:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_10268_i916; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 1);
        r1[2] = r2;
        r2 = varref (5, 18);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L701; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
        L701:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (5, 33);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L702; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        L702:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 13);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (3, 0);
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = varref (6, 25);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L703; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
        L703:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10298_i916
        goto L704;
        FUN_lambda_10298_i916:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = varref (2, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (3, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = (object*) &constructed_817;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = varref (0, 4);
          r3 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (7, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L705; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L705:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (7, 73);
          r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_422;
        L704:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10298_i916; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (6, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L706; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L706:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10327_i916
        goto L707;
        FUN_lambda_10327_i916:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (2, 0);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 8);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (0, 0);
          r3[2] = r4;
          r4 = varref (8, 17);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L708; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_car_318;
          L708:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = varref (6, 9);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L709; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3efieldpairs_1786;
          L709:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (8, 30);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L710; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
          L710:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (8, 18);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L711; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
          L711:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (0, 1);
          r2[2] = r3;
          r3 = (object *) constructed_37[0];
          r2[3] = r3;
          r3 = varref (8, 19);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L712; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
          L712:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = varref (0, 2);
          r1[3] = r2;
          r2 = varref (8, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L713; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L713:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = varref (1, 0);
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (2, 0);
          r2 = UOBJ_GET(r2,1);
          r1[2] = r2;
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
          r0[6] = r1;
          r0 = varref (0, 4);
          r1 = varref (0, 3);
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        L707:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10327_i916; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (3, 1);
        r1[3] = r2;
        r2 = varref (6, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L714; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L714:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (6, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L715; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L715:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_1907_i916
        goto L716;
        FUN__24loop_1907_i916:
          check_heap (0);
          r0 = varref (2, 3);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 1);
            r0[2] = r1;
            r1 = (object *) constructed_37[0];
            r0[3] = r1;
            r1 = varref (8, 19);
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          } else {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 1);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (9, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L717; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L717:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = varref (3, 0);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 1);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (9, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L718; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L718:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = varref (0, 3);
            r2 = varref (0, 2);
            t = alloc_no_clear (UOTAG(10),2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = (object*)TC_NIL;
            r0[7] = r1;
            r1 = varref (0, 5);
            r2 = varref (0, 4);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = varref (0, 6);
            r2 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = varref (0, 7);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[10] = r1;
            r0 = varref (1, 1);
            r1 = varref (0, 8);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = varref (0, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN__24loop_1907_i916;
          }
          PXLL_RETURN(0);
        L716:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_1907_i916; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L719; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_1907_i916;
        L719:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[6] = r1;
        r1 = (object *) constructed_549[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[7] = r1;
        r1 = varref (0, 4);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[8] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (4, 0);
        r3[2] = r4;
        r4 = varref (7, 18);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L720; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cdr_319;
        L720:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (1, 1);
        r3[2] = r4;
        r4 = (object *) constructed_37[0];
        r3[3] = r4;
        r4 = varref (7, 19);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L721; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
        L721:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = varref (0, 0);
        r2[3] = r3;
        r3 = varref (7, 19);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L722; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
        L722:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (0, 2);
        r1[3] = r2;
        r2 = varref (3, 2);
        r1[4] = r2;
        r2 = varref (4, 3);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L723; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1779;
        L723:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[9] = r1;
        r1 = (object*)TC_NIL;
        r0[10] = r1;
        r1 = varref (0, 8);
        r2 = varref (0, 7);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[11] = r1;
        r1 = varref (0, 9);
        r2 = varref (0, 6);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[12] = r1;
        r1 = varref (0, 10);
        r2 = varref (0, 5);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[13] = r1;
        r0 = varref (0, 11);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } else {
        goto fatbar_229;
      }
      PXLL_RETURN(0);
      goto fatbar_229_over;
      fatbar_229:
      r0 = (object *) constructed_415[0];
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 9);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (2, 1);
        r2[2] = r3;
        r3 = varref (5, 17);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L724; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
        L724:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (3, 16);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L725; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_rule__3econstructor_dt_1797;
        L725:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (3, 16);
        r1[2] = r2;
        r2 = varref (2, 1);
        r1[3] = r2;
        r2 = varref (3, 12);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L726; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_collect_1793;
        L726:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (5, 67);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L727; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist__3ekeys_410;
        L727:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 2);
        r2[2] = r3;
        r3 = varref (6, 20);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L728; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
        L728:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object *) 3;
        r3 = varref (0, 0);
        r2 = PXLL_TEST(unbox(r3)==unbox(r2));
        r1[3] = r2;
        r1 = (object *) 6;
        r2 = varref (0, 1);
        r1 = PXLL_TEST(r2==r1);
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_824;
          r1[2] = r2;
          r2 = varref (0, 2);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L729; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L729:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
        } else {
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (3, 17);
          r1[2] = r2;
          r2 = varref (2, 1);
          r1[3] = r2;
          r2 = varref (3, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L730; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_collect_1793;
          L730:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
        }
        r0[5] = r1;
        r1 = (object *) 1;
        r0[6] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (4, 0);
        r2 = ((pxll_vector*)r2)->val[1];
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (2, 1);
        r3[2] = r4;
        r4 = varref (5, 17);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L731; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_car_318;
        L731:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = varref (3, 16);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L732; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_rule__3econstructor_dt_1797;
        L732:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = varref (5, 64);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L733; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L733:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[7] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 2);
        r1[2] = r2;
        r2 = varref (5, 174);
        r1[3] = r2;
        r2 = varref (5, 81);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L734; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_sexp_3d_question_432;
        L734:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (2, 2);
          r1=r1;
        } else {
          r1 = varref (5, 175);
          r1=r1;
        }
        r0[8] = r1;
        r1 = (object *) constructed_823[0];
        r0[9] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_10989_i954
        goto L735;
        FUN_lambda_10989_i954:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (2, 5);
          switch (get_case (r1)) {
            case (UITAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = varref (2, 1);
              r5 = ((pxll_vector*)r5)->val[4];
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L736; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              lenv = r5[2]; goto *r5[1];
              L736:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r4 = varref (0, 0);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = varref (1, 0);
              r5 = UOBJ_GET(r5,0);
              r4[2] = r5;
              r4 = varref (0, 0);
              lenv = lenv[1];
              r4 = r4;
              r4=r4;
              lenv = lenv[1];
              r4 = r4;
              r3[2] = r4;
              r4 = varref (7, 17);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L737; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_car_318;
              L737:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = varref (5, 15);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L738; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pattern__3esubs_1796;
              L738:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L739; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L739:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } break;
            default: {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = varref (3, 5);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (2, 0);
              r2[2] = r3;
              r3 = varref (0, 0);
              r3 = ((pxll_vector*)r3)->val[1];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L740; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto *r3[1];
              L740:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r1 = varref (0, 1);
              r1 = ((pxll_vector*)r1)->val[0];
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
          }
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (7, 106);
          r1[3] = r2;
          r2 = varref (5, 18);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L741; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1802;
          L741:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = varref (0, 0);
          ensure_heap (1, unbox(r1));
          r1 = (object *) 262;
          r2 = varref (0, 0);
          if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
            t = alloc_no_clear (TC_VECTOR, unbox(r2));
            for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
            r1 = t;
          }
          r0[4] = r1;
          r1 = (object *) constructed_822[0];
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def frob-rule_1968_i954
          goto L742;
          FUN_frob_rule_1968_i954:
            check_heap (0);
            r0 = varref (0, 0);
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = varref (10, 17);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L743; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
            L743:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (8, 15);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L744; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3esubs_1796;
            L744:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 2);
            r1[2] = r2;
            r2 = varref (11, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L745; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L745:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = varref (4, 0);
            r2 = varref (0, 0);
            r1 = PXLL_TEST(unbox(r2)==unbox(r1));
            r0[3] = r1;
            r0 = (object *) 6;
            r1 = varref (0, 1);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_821;
              r0[2] = r1;
              r1 = varref (7, 1);
              r0[3] = r1;
              r1 = varref (10, 12);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L746; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
              L746:
              ; lenv = k[2]; k = k[1];
              r0 = result;
            } else {
              r0 = (object *) 14;
            }
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (11, 17);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L747; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
            L747:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (9, 15);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L748; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3esubs_1796;
            L748:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (11, 18);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L749; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
            L749:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (11, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L750; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L750:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (0, 1);
            r1[3] = r2;
            r2 = varref (11, 19);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L751; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
            L751:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = varref (1, 1);
            r2 = varref (0, 2);
            t = alloc_no_clear (UOTAG(0),2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[5] = r1;
            r0 = varref (4, 3);
            r1 = varref (0, 3);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (3, 3, r0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (4, 0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_1974_i954
            goto L752;
            FUN__24loop_1974_i954:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (4, 2);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (14, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L753; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L753:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_566[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = (object *) 14;
                      r0=r0;
                    } else {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_231;
                    }
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } break;
                  default: {
                    goto fatbar_231;
                  }
                }
                r0=r0;
                goto fatbar_231_over;
                fatbar_231:
                r0 = varref (1, 0);
                r1 = (object *) 6;
                r2 = varref (7, 2);
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
                ((pxll_vector*)r2)->val[unbox(r0)] = r1;
                r0=r0;
                fatbar_231_over: ;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_1974_i954;
              }
              PXLL_RETURN(0);
            L752:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_1974_i954; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_1974_i954;
            PXLL_RETURN(0);
          L742:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_frob_rule_1968_i954; r1[2] = lenv;
          r0[2] = r1;
          r0 = (object *) 3;
          r1 = varref (3, 4);
          r0 = box(unbox(r1)+unbox(r0));
          varset (3, 4, r0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (2, 1);
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L754; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L754:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = varref (8, 33);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L755; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
          L755:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (2, 0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def $loop_1979_i954
          goto L756;
          FUN__24loop_1979_i954:
            check_heap (0);
            r0 = varref (2, 0);
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (0, 1);
              r0[2] = r1;
              r1 = (object *) constructed_37[0];
              r0[3] = r1;
              r1 = varref (11, 19);
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r2 = varref (5, 2);
              range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
              r1 = ((pxll_vector*)r2)->val[unbox(r1)];
              if PXLL_IS_TRUE(r1) {
                r1 = (object *) constructed_566[0];
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (5, 1);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (12, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L757; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L757:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              }
              r0[2] = r1;
              r0 = varref (1, 1);
              r1 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = (object *) 3;
              r2 = varref (0, 0);
              r1 = box(unbox(r2)+unbox(r1));
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN__24loop_1979_i954;
            }
            PXLL_RETURN(0);
          L756:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN__24loop_1979_i954; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = (object*)TC_NIL;
          r1[3] = r2;
          r2 = varref (0, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L758; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN__24loop_1979_i954;
          L758:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 10);
          r0[1] = lenv; lenv = r0;
          r1 = varref (4, 0);
          r2 = (object *) constructed_50[0];
          t = alloc_no_clear (UOTAG(9),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (10, 1);
          r1[2] = r2;
          r2 = varref (1, 1);
          r1[3] = r2;
          r2 = varref (10, 30);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L759; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
          L759:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = varref (0, 1);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = varref (0, 2);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (8, 0);
          r3[2] = r4;
          r4 = varref (11, 18);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L760; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_cdr_319;
          L760:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = allocate (TC_TUPLE, 3);
          r4 = varref (4, 1);
          r3[2] = r4;
          r4 = (object *) constructed_37[0];
          r3[3] = r4;
          r4 = varref (11, 19);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L761; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
          L761:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = varref (0, 0);
          r2[3] = r3;
          r3 = varref (11, 19);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L762; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
          L762:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (3, 3);
          r1[3] = r2;
          r2 = varref (5, 6);
          r1[4] = r2;
          r2 = varref (8, 3);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L763; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1779;
          L763:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = (object*)TC_NIL;
          r0[7] = r1;
          r1 = varref (0, 5);
          r2 = varref (0, 4);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r1 = varref (0, 6);
          r2 = varref (0, 3);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[9] = r1;
          r1 = varref (0, 7);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[10] = r1;
          r0 = varref (5, 7);
          r1 = varref (0, 8);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (4, 7, r0);
          PXLL_RETURN(0);
        L735:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_10989_i954; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (0, 3);
        r0[3] = r1;
        r1 = varref (5, 66);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L764; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
        L764:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 5);
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 5);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r2 = ((pxll_vector*)r2)->val[3];
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L765; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L765:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = varref (0, 0);
            r2 = varref (3, 4);
            r1 = PXLL_TEST(unbox(r2)<unbox(r1));
            lenv = lenv[1];
            r1 = r1;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 6);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_562[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = (object*)TC_NIL;
              r1[3] = r2;
              r2 = varref (0, 1);
              r3 = varref (3, 6);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = varref (0, 2);
              r3 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = varref (0, 3);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[6] = r2;
              r1 = varref (3, 7);
              r2 = varref (0, 4);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              varset (2, 7, r1);
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 12);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_533[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[2] = r2;
            r2 = varref (1, 0);
            r2 = ((pxll_vector*)r2)->val[7];
            r1[3] = r2;
            r2 = varref (0, 1);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (5, 0);
            r2[2] = r3;
            r3 = varref (8, 17);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L766; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
            L766:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[5] = r2;
            r2 = varref (0, 3);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = (object*)TC_NIL;
            r1[7] = r2;
            r2 = varref (0, 5);
            r3 = varref (0, 4);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r2 = varref (0, 6);
            r3 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[9] = r2;
            r2 = varref (0, 7);
            r3 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[10] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (3, 7);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (8, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L767; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L767:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[11] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = allocate (TC_TUPLE, 3);
            r4 = varref (0, 8);
            r3[2] = r4;
            r4 = (object *) constructed_37[0];
            r3[3] = r4;
            r4 = varref (8, 19);
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L768; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
            L768:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = varref (0, 9);
            r2[3] = r3;
            r3 = varref (8, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L769; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L769:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[12] = r2;
            r1 = varref (0, 10);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 9);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_533[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (4, 0);
            r2[2] = r3;
            r3 = varref (7, 17);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L770; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
            L770:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = varref (0, 1);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = (object*)TC_NIL;
            r1[5] = r2;
            r2 = varref (0, 3);
            r3 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = varref (0, 4);
            r3 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (2, 7);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (7, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L771; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L771:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[8] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = allocate (TC_TUPLE, 3);
            r4 = varref (0, 5);
            r3[2] = r4;
            r4 = (object *) constructed_37[0];
            r3[3] = r4;
            r4 = varref (7, 19);
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L772; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
            L772:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = varref (0, 6);
            r2[3] = r3;
            r3 = varref (7, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L773; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L773:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[9] = r2;
            r1 = varref (0, 7);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (7, 174);
        r2 = varref (4, 2);
        r1 = PXLL_TEST(r2==r1);
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (3, 2);
          r0[3] = r1;
          r1 = varref (4, 5);
          r0[1] = r1[2]; lenv = r0; goto FUN_fatbar_1781;
        } else {
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } else {
        goto fatbar_230;
      }
      PXLL_RETURN(0);
      goto fatbar_230_over;
      fatbar_230:
      r0 = (object *) constructed_826[0];
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L774; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L774:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_10173_i1011
        goto L775;
        FUN_lambda_10173_i1011:
          check_heap (0);
          r0 = varref (0, 0);
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (7, 18);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L776; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
          L776:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r2 = varref (2, 0);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (0, 0);
          r2[2] = r3;
          r3 = varref (7, 17);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L777; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
          L777:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (0, 1);
          r1[4] = r2;
          r2 = varref (5, 6);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L778; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_subst_1782;
          L778:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = varref (0, 3);
          r1 = varref (0, 2);
          t = alloc_no_clear (UOTAG(0),2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
          PXLL_RETURN(0);
        L775:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_10173_i1011; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (2, 1);
        r1[3] = r2;
        r2 = varref (5, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L779; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L779:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r1[2] = r2;
        r2 = varref (5, 18);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L780; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
        L780:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (0, 1);
        r0[3] = r1;
        r1 = varref (2, 2);
        r0[4] = r1;
        r1 = varref (3, 3);
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_match_1779;
      } else {
        goto fatbar_232;
      }
      PXLL_RETURN(0);
      goto fatbar_232_over;
      fatbar_232:
      r0 = (object *) constructed_730[0];
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_1920_i1014
        goto L781;
        FUN_loop_1920_i1014:
          check_heap (0);
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = varref (0, 1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (8, 17);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L782; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_car_318;
              L782:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r3 = varref (0, 0);
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = varref (1, 0);
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = varref (0, 0);
              lenv = lenv[1];
              r3 = r3;
              r3=r3;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (7, 17);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L783; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
              L783:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (5, 10);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L784; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1790;
              L784:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = varref (0, 2);
              switch (get_case (r1)) {
                case (UOTAG(2)): {
                  r1 = (object *) constructed_828[0];
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_234;
                }
              }
              r1=r1;
              goto fatbar_234_over;
              fatbar_234:
              r1 = (object *) constructed_830[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r1;
              r1 = t;
              r1=r1;
              fatbar_234_over: ;
              r0[5] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = allocate (TC_TUPLE, 20);
              r1[1] = lenv; lenv = r1;
              r2 = (object *) constructed_525[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (5, 0);
              r2[2] = r3;
              r3 = varref (8, 17);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L785; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
              L785:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = varref (0, 1);
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[4] = r2;
              r2 = (object*)TC_NIL;
              r1[5] = r2;
              r2 = varref (0, 3);
              r3 = varref (1, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = (object *) constructed_732[0];
              t = alloc_no_clear (UOTAG(1),1);
              t[1] = r2;
              r2 = t;
              r1[7] = r2;
              r2 = varref (0, 4);
              r3 = varref (0, 5);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[8] = r2;
              r2 = varref (0, 6);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[9] = r2;
              r2 = (object*)TC_NIL;
              r1[10] = r2;
              r2 = varref (0, 8);
              r3 = varref (0, 7);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[11] = r2;
              r2 = varref (0, 9);
              r3 = varref (0, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[12] = r2;
              r2 = varref (0, 10);
              r3 = varref (1, 3);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[13] = r2;
              r2 = varref (0, 11);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r2;
              r2 = t;
              r1[14] = r2;
              r2 = allocate (TC_TUPLE, 4);
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (5, 0);
              r3[2] = r4;
              r4 = varref (8, 18);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L786; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_cdr_319;
              L786:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = varref (6, 0);
              r3[2] = r4;
              r4 = varref (1, 0);
              r3[3] = r4;
              r4 = varref (8, 30);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L787; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
              L787:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = varref (8, 175);
              r2[4] = r3;
              r3 = varref (6, 3);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L788; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_compile_match_1779;
              L788:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[15] = r2;
              r2 = (object*)TC_NIL;
              r1[16] = r2;
              r2 = varref (0, 14);
              r3 = varref (8, 175);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[17] = r2;
              r2 = varref (0, 15);
              r3 = varref (0, 13);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[18] = r2;
              r2 = varref (0, 16);
              r3 = varref (0, 12);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[19] = r2;
              r2 = varref (0, 17);
              r3 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[20] = r2;
              r1 = varref (0, 18);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = varref (1, 1);
              r0[3] = r1;
              r1 = varref (5, 5);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L789; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_fatbar_1781;
              L789:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r1 = varref (0, 1);
              lenv = ((object *)lenv)[1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_1920_i1014;
            } break;
          }
          PXLL_RETURN(0);
        L781:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_1920_i1014; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 1);
        r1[2] = r2;
        r2 = varref (3, 11);
        r1[3] = r2;
        r2 = varref (5, 40);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L790; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_pack_346;
        L790:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (2, 2);
        r0[3] = r1;
        r1 = varref (0, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_1920_i1014;
      } else {
        goto fatbar_233;
      }
      PXLL_RETURN(0);
      goto fatbar_233_over;
      fatbar_233:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_68;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_68;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_233_over: ;
      PXLL_RETURN(0);
      fatbar_232_over: ;
      PXLL_RETURN(0);
      fatbar_230_over: ;
      PXLL_RETURN(0);
      fatbar_229_over: ;
      PXLL_RETURN(0);
    L689:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_compile_group_1780; r1[2] = lenv;
    r0[6] = r1;
    // def fatbar_1781
    goto L791;
    FUN_fatbar_1781:
      check_heap (0);
      r0 = varref (3, 175);
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } else {
        r0 = varref (3, 175);
        r1 = varref (0, 1);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 8);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) 6;
          t = alloc_no_clear (UOTAG(4),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r1 = varref (0, 1);
          r2 = varref (1, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = varref (0, 2);
          r2 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = varref (0, 3);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[6] = r1;
          r1 = (object *) constructed_437[0];
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[7] = r1;
          r1 = varref (0, 4);
          r2 = varref (0, 5);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r0 = varref (0, 6);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L791:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fatbar_1781; r1[2] = lenv;
    r0[7] = r1;
    // def subst_1782
    goto L792;
    FUN_subst_1782:
      check_heap (0);
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_566[0];
          r2 = varref (1, 0);
          r1 = PXLL_TEST(r2==r1);
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 12);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_726[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[2] = r1;
            r1 = varref (1, 0);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = varref (2, 0);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = (object*)TC_NIL;
            r0[5] = r1;
            r1 = varref (0, 3);
            r2 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = varref (0, 4);
            r2 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = varref (0, 5);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = (object*)TC_NIL;
            r0[9] = r1;
            r1 = varref (0, 7);
            r2 = varref (2, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[10] = r1;
            r1 = varref (0, 8);
            r2 = varref (0, 6);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[11] = r1;
            r1 = varref (0, 9);
            r2 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[12] = r1;
            r0 = varref (0, 10);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = varref (1, 2);
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_228;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_228_over;
      fatbar_228:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_68;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_68;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_228_over: ;
      PXLL_RETURN(0);
    L792:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_subst_1782; r1[2] = lenv;
    r0[8] = r1;
    // def fieldpair->label_1784
    goto L793;
    FUN_fieldpair__3elabel_1784:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = varref (0, 0);
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L793:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fieldpair__3elabel_1784; r1[2] = lenv;
    r0[9] = r1;
    // def fieldpair->pattern_1785
    goto L794;
    FUN_fieldpair__3epattern_1785:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,1);
      r0[2] = r1;
      r0 = varref (0, 0);
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L794:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_fieldpair__3epattern_1785; r1[2] = lenv;
    r0[10] = r1;
    // def pattern->fieldpairs_1786
    goto L795;
    FUN_pattern__3efieldpairs_1786:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(3)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_227;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_227_over;
      fatbar_227:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_816;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_816;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_227_over: ;
      PXLL_RETURN(0);
    L795:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3efieldpairs_1786; r1[2] = lenv;
    r0[11] = r1;
    // def pattern->literal_1790
    goto L796;
    FUN_pattern__3eliteral_1790:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_226;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_226_over;
      fatbar_226:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_815;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_815;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_226_over: ;
      PXLL_RETURN(0);
    L796:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3eliteral_1790; r1[2] = lenv;
    r0[12] = r1;
    // def first-literal=?_1791
    goto L797;
    FUN_first_literal_3d_question_1791:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = varref (1, 1);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 1);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (1, 0);
      r2[2] = r3;
      r3 = varref (5, 17);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L798; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
      L798:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = varref (3, 10);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L799; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1790;
      L799:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (0, 0);
      r2[2] = r3;
      r3 = varref (5, 17);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L800; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
      L800:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = varref (3, 10);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L801; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_pattern__3eliteral_1790;
      L801:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = varref (5, 81);
      r0[1] = r1[2]; lenv = r0; goto FUN_sexp_3d_question_432;
      PXLL_RETURN(0);
      PXLL_RETURN(0);
    L797:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_first_literal_3d_question_1791; r1[2] = lenv;
    r0[13] = r1;
    // def collect_1793
    goto L802;
    FUN_collect_1793:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop_1929
      goto L803;
      FUN_loop_1929:
        check_heap (0);
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = varref (0, 0);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L804; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L804:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (0, 2);
            r1[3] = r2;
            r2 = varref (6, 64);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L805; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L805:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = varref (0, 3);
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_814[0];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 6);
                r1[1] = lenv; lenv = r1;
                // def push_1752_i1116
                goto L806;
                FUN_push_1752_i1116:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (3, 0);
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  r1 = varref (1, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  varset (2, 0, r0);
                  PXLL_RETURN(0);
                L806:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_push_1752_i1116; r2[2] = lenv;
                r1[2] = r2;
                // def pop_1753_i1116
                goto L807;
                FUN_pop_1753_i1116:
                  check_heap (0);
                  r0 = varref (1, 0);
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = (object*) &constructed_69;
                      r0 = box(((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_69;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_813;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_813;
                      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = varref (0, 0);
                      r0[4] = r1;
                      r0 = varref (0, 1);
                      varset (2, 0, r0);
                      r0 = varref (0, 2);
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L807:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_pop_1753_i1116; r2[2] = lenv;
                r1[3] = r2;
                // def get_1754_i1116
                goto L808;
                FUN_get_1754_i1116:
                  r0 = varref (1, 0);
                  PXLL_RETURN(0);
                L808:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_get_1754_i1116; r2[2] = lenv;
                r1[4] = r2;
                // def top_1755_i1116
                goto L809;
                FUN_top_1755_i1116:
                  check_heap (0);
                  r0 = varref (1, 0);
                  switch (get_case (r0)) {
                    case (TC_NIL): {
                      r0 = (object*) &constructed_69;
                      r0 = box(((pxll_string*)(r0))->len);
                      r1 = (object*) &constructed_69;
                      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                      r0 = (object*) &constructed_812;
                      dump_object (r0, 0); fprintf (stdout, "\n");
                      r0 = (object*) &constructed_812;
                      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = varref (0, 0);
                      PXLL_RETURN(0);
                    } break;
                  }
                  PXLL_RETURN(0);
                L809:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_top_1755_i1116; r2[2] = lenv;
                r1[5] = r2;
                // def stack-length_1756_i1116
                goto L810;
                FUN_stack_length_1756_i1116:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = varref (1, 0);
                  r0[2] = r1;
                  r1 = varref (8, 20);
                  r0[1] = r1[2]; lenv = r0; goto FUN_length_323;
                L810:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_stack_length_1756_i1116; r2[2] = lenv;
                r1[6] = r2;
                r1 = allocate (UOTAG(18), 5);
                r2 = varref (0, 2);
                r1[1] = r2;
                r2 = varref (0, 4);
                r1[2] = r2;
                r2 = varref (0, 1);
                r1[3] = r2;
                r2 = varref (0, 0);
                r1[4] = r2;
                r2 = varref (0, 3);
                r1[5] = r2;
                lenv = lenv[1];
                r1 = r1;
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (1, 0);
                r0[2] = r1;
                r1 = varref (0, 1);
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L811; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L811:
                ; lenv = k[2]; k = k[1];
                r0 = varref (0, 1);
                r1 = varref (2, 0);
                r2 = varref (1, 2);
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                r1 = varref (1, 1);
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_1929;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 3);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (1, 0);
                r0[2] = r1;
                r1 = varref (0, 0);
                r1 = ((pxll_vector*)r1)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L812; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L812:
                ; lenv = k[2]; k = k[1];
                r0 = varref (1, 1);
                r1 = varref (2, 0);
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN_loop_1929;
              } break;
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L803:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop_1929; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*)UITAG(0);
      r0[2] = r1;
      r1 = varref (1, 1);
      r0[3] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop_1929;
    L802:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_collect_1793; r1[2] = lenv;
    r0[14] = r1;
    // def pattern->dt_1794
    goto L813;
    FUN_pattern__3edt_1794:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_225;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_225_over;
      fatbar_225:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_811;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_811;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_225_over: ;
      PXLL_RETURN(0);
    L813:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3edt_1794; r1[2] = lenv;
    r0[15] = r1;
    // def pattern->alt_1795
    goto L814;
    FUN_pattern__3ealt_1795:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_224;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_224_over;
      fatbar_224:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_810;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_810;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_224_over: ;
      PXLL_RETURN(0);
    L814:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3ealt_1795; r1[2] = lenv;
    r0[16] = r1;
    // def pattern->subs_1796
    goto L815;
    FUN_pattern__3esubs_1796:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[2] = r1;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_223;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_223_over;
      fatbar_223:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_809;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_809;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_223_over: ;
      PXLL_RETURN(0);
    L815:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_pattern__3esubs_1796; r1[2] = lenv;
    r0[17] = r1;
    // def rule->constructor-dt_1797
    goto L816;
    FUN_rule__3econstructor_dt_1797:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = varref (4, 17);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L817; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
      L817:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (2, 13);
      r0[1] = r1[2]; lenv = r0; goto FUN_pattern__3edt_1794;
      PXLL_RETURN(0);
    L816:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_rule__3econstructor_dt_1797; r1[2] = lenv;
    r0[18] = r1;
    // def rule->constructor-alt_1798
    goto L818;
    FUN_rule__3econstructor_alt_1798:
      check_heap (0);
      r0 = varref (0, 0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = varref (4, 17);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L819; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
      L819:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (2, 14);
      r0[1] = r1[2]; lenv = r0; goto FUN_pattern__3ealt_1795;
      PXLL_RETURN(0);
    L818:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_rule__3econstructor_alt_1798; r1[2] = lenv;
    r0[19] = r1;
    // def nthunk_1802
    goto L820;
    FUN_nthunk_1802:
      check_heap (0);
      r0 = (object *) 1;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) constructed_808[0];
        PXLL_RETURN(0);
      } else {
        goto fatbar_222;
      }
      PXLL_RETURN(0);
      goto fatbar_222_over;
      fatbar_222:
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 1);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L821; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L821:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = (object *) 3;
      r3 = varref (1, 0);
      r2 = box(unbox(r3)-unbox(r2));
      r1[2] = r2;
      r2 = varref (1, 1);
      r1[3] = r2;
      r2 = varref (2, 18);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L822; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1802;
      L822:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = varref (0, 1);
      r1 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
      fatbar_222_over: ;
      PXLL_RETURN(0);
    L820:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_nthunk_1802; r1[2] = lenv;
    r0[20] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def loop_1826_i1180
    goto L823;
    FUN_loop_1826_i1180:
      check_heap (0);
      r0 = varref (0, 2);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 1);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (5, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_587[0];
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = varref (1, 1);
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (2, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (2, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (4, 0);
                    r1[2] = r2;
                    r2 = (object *) constructed_37[0];
                    r1[3] = r2;
                    r2 = varref (9, 19);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L824; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                    L824:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (8, 1);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L825; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L825:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = varref (0, 1);
                    r2 = varref (0, 0);
                    t = alloc_no_clear (UOTAG(0),2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[4] = r1;
                    r0 = varref (4, 1);
                    r1 = varref (0, 2);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = varref (0, 1);
                    r2 = (object *) constructed_802[0];
                    lenv = ((object ***)lenv)[1][1][1];
                    lenv[2] = r2;
                    lenv[3] = r0;
                    lenv[4] = r1;
                    goto FUN_loop_1826_i1180;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_217;
                  }
                }
                PXLL_RETURN(0);
              } else {
                lenv = ((object *)lenv)[1];
                goto fatbar_217;
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_217;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_217_over;
          fatbar_217:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          // def parse-fieldpair_1804_i906_i1180
          goto L826;
          FUN_parse_fieldpair_1804_i906_i1180:
            check_heap (0);
            r0 = varref (0, 0);
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (2, 1);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L827; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_kind_1805_i906_i1180;
            L827:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = varref (0, 2);
            r1 = varref (0, 0);
            t = alloc_no_clear (UOTAG(0),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
            PXLL_RETURN(0);
          L826:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_parse_fieldpair_1804_i906_i1180; r2[2] = lenv;
          r1[2] = r2;
          // def kind_1805_i906_i1180
          goto L828;
          FUN_kind_1805_i906_i1180:
            check_heap (0);
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(8)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (2, 0);
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (10, 107);
                r2[2] = r3;
                r3 = varref (0, 0);
                r2[3] = r3;
                r3 = varref (10, 32);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L829; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_filter_337;
                L829:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = varref (10, 30);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L830; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                L830:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r0 = varref (0, 1);
                t = alloc_no_clear (UOTAG(3),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(4)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(r1) {
                  r1 = (object *) constructed_45[0];
                  r1=r1;
                } else {
                  r1 = (object *) constructed_42[0];
                  r1=r1;
                }
                r0[3] = r1;
                r0 = varref (0, 1);
                r1 = (object *) constructed_803[0];
                r2 = (object *) constructed_47[0];
                t = alloc_no_clear (UOTAG(2),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = (object *) constructed_50[0];
                    r1 = (object *) constructed_804[0];
                    r2 = (object *) constructed_52[0];
                    t = alloc_no_clear (UOTAG(2),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = varref (0, 0);
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = (object *) constructed_806[0];
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = varref (0, 0);
                                  r0[2] = r1;
                                  r1 = varref (5, 1);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_kind_1805_i906_i1180;
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_221;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_221;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_221;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_221_over;
                        fatbar_221:
                        r0 = (object *) constructed_732[0];
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 0);
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 0);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = varref (1, 1);
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 0);
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r1;
                                      r1 = t;
                                      r0[2] = r1;
                                      r0 = varref (0, 0);
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r0;
                                      r0 = t;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_220;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_220;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_220;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_220;
                        }
                        PXLL_RETURN(0);
                        fatbar_221_over: ;
                        PXLL_RETURN(0);
                      } break;
                      case (UOTAG(9)): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = varref (4, 1);
                        r1[2] = r2;
                        r2 = varref (1, 1);
                        r1[3] = r2;
                        r2 = varref (12, 30);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L831; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                        L831:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[4] = r1;
                        r0 = varref (0, 1);
                        r1 = varref (0, 2);
                        r2 = varref (0, 0);
                        t = alloc_no_clear (UOTAG(2),3);
                        t[1] = r2;
                        t[2] = r0;
                        t[3] = r1;
                        r0 = t;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        goto fatbar_220;
                      }
                    }
                    PXLL_RETURN(0);
                    goto fatbar_220_over;
                    fatbar_220:
                    r0 = allocate (TC_TUPLE, 6);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (4, 1);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L832; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_kind_1805_i906_i1180;
                    L832:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 1);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r2;
                    r2 = t;
                    r1[2] = r2;
                    r2 = varref (4, 1);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L833; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_kind_1805_i906_i1180;
                    L833:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = (object*)TC_NIL;
                    r0[4] = r1;
                    r1 = varref (0, 2);
                    r2 = varref (0, 1);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[5] = r1;
                    r1 = varref (0, 3);
                    r2 = varref (0, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r0 = (object *) constructed_62[0];
                    r1 = varref (0, 4);
                    r2 = (object *) constructed_52[0];
                    t = alloc_no_clear (UOTAG(2),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                    fatbar_220_over: ;
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
                goto fatbar_219_over;
                fatbar_219:
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_807;
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[3] = r1;
                r1 = varref (10, 12);
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                fatbar_219_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_218;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_218_over;
            fatbar_218:
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_218_over: ;
            PXLL_RETURN(0);
          L828:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_kind_1805_i906_i1180; r2[2] = lenv;
          r1[3] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (2, 0);
          r1[2] = r2;
          r2 = varref (0, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L834; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_kind_1805_i906_i1180;
          L834:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r0 = varref (2, 0);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (1, 1);
          r2 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          lenv[4] = r2;
          goto FUN_loop_1826_i1180;
          fatbar_217_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L823:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_loop_1826_i1180; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 4);
    r2 = (object *) constructed_801[0];
    r1[2] = r2;
    r2 = (object *) constructed_800[0];
    r1[3] = r2;
    r2 = varref (3, 3);
    r1[4] = r2;
    r2 = varref (0, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L835; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_loop_1826_i1180;
    L835:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (1, 0);
    r3[2] = r4;
    r4 = varref (4, 17);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L836; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_car_318;
    L836:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r2 = varref (0, 0);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = varref (1, 0);
    r3 = UOBJ_GET(r3,0);
    r2[2] = r3;
    r2 = varref (0, 0);
    lenv = lenv[1];
    r2 = r2;
    r2=r2;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (3, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L837; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L837:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (2, 2);
    switch (get_case (r1)) {
      case (TC_NIL): {
        r1 = (object *) 262;
        r1=r1;
      } break;
      default: {
        goto fatbar_216;
      }
    }
    r1=r1;
    goto fatbar_216_over;
    fatbar_216:
    r1 = (object *) 6;
    r1=r1;
    fatbar_216_over: ;
    if PXLL_IS_TRUE(r1) {
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (0, 1);
      r1[2] = r2;
      r2 = varref (3, 106);
      r1[3] = r2;
      r2 = varref (1, 18);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L838; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_nthunk_1802;
      L838:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r1=r1;
    } else {
      r1 = varref (2, 2);
      r1=r1;
    }
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (0, 2);
    r1[2] = r2;
    r2 = varref (0, 0);
    r1[3] = r2;
    r2 = varref (3, 174);
    r1[4] = r2;
    r2 = varref (1, 3);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L839; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_compile_match_1779;
    L839:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r0 = allocate (UOTAG(0), 2);
    r1 = varref (0, 2);
    r0[1] = r1;
    r1 = varref (0, 3);
    r0[2] = r1;
    PXLL_RETURN(0);
  L675:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_compile_pattern_480; r1[2] = lenv;
  r0[110] = r1;
  // def print-datatype_483
  goto L840;
  FUN_print_datatype_483:
    check_heap (0);
    r0 = (object*) &constructed_799;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_799;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[7];
    r0[2] = r1;
    r0 = varref (0, 0);
    r0 = dump_object (r0, 0); fprintf (stdout, "\n");
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_13664
    goto L841;
    FUN_lambda_13664:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = varref (2, 0);
      r3 = allocate (TC_TUPLE, 2);
      r3[1] = lenv; lenv = r3;
      r4 = varref (3, 0);
      r4 = UOBJ_GET(r4,0);
      r3[2] = r4;
      r3 = varref (0, 0);
      lenv = lenv[1];
      r3 = r3;
      r3=r3;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 3);
      r4 = allocate (TC_TUPLE, 3);
      r5 = varref (4, 99);
      r4[2] = r5;
      r5 = varref (2, 1);
      r5 = ((pxll_vector*)r5)->val[3];
      r4[3] = r5;
      r5 = varref (4, 30);
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L842; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
      L842:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = (object*) &constructed_798;
      r3[3] = r4;
      r4 = varref (4, 46);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L843; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
      L843:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = varref (0, 2);
      r4 = (object*) &constructed_797;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = varref (0, 3);
      r4 = varref (0, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = varref (0, 4);
      r4 = (object*) &constructed_796;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = varref (0, 5);
      r4 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = varref (0, 6);
      r3 = (object*) &constructed_795;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (3, 45);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L844; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L844:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      r0 = box(((pxll_string*)(r0))->len);
      r1 = varref (0, 0);
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      PXLL_RETURN(0);
    L841:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_13664; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[6];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L845; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L845:
    ; lenv = k[2]; k = k[1];
    r0 = (object*) &constructed_794;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_794;
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    PXLL_RETURN(0);
  L840:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_print_datatype_483; r1[2] = lenv;
  r0[111] = r1;
  // def make-node_488
  goto L846;
  FUN_make_node_488:
    check_heap (0);
    r0 = allocate (UOTAG(17), 6);
    r1 = (object *) 1;
    r0[1] = r1;
    r1 = varref (1, 177);
    r1 = ((pxll_vector*)r1)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L847; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L847:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 4);
    // def lambda_13682_i1541
    goto L848;
    FUN_lambda_13682_i1541:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r0 = varref (1, 1);
      r1 = varref (0, 0);
      r0 = box(unbox(r1)+unbox(r0));
      PXLL_RETURN(0);
    L848:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_13682_i1541; r2[2] = lenv;
    r1[2] = r2;
    r2 = (object *) 3;
    r1[3] = r2;
    r2 = varref (0, 1);
    r1[4] = r2;
    r2 = varref (1, 35);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L849; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_fold_340;
    L849:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (0, 1);
    r0[4] = r1;
    r1 = varref (0, 0);
    r0[5] = r1;
    r1 = varref (1, 178);
    r0[6] = r1;
    PXLL_RETURN(0);
  L846:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_node_488; r1[2] = lenv;
  r0[112] = r1;
  // def varref->name_491
  goto L850;
  FUN_varref__3ename_491:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_215;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_215_over;
    fatbar_215:
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_793;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_793;
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_215_over: ;
    PXLL_RETURN(0);
  L850:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_varref__3ename_491; r1[2] = lenv;
  r0[113] = r1;
  // def node/if_495
  goto L851;
  FUN_node_2fif_495:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = varref (0, 0);
    r2 = varref (1, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = varref (0, 1);
    r2 = varref (1, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = varref (0, 2);
    r2 = varref (1, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[5] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*)UITAG(6);
    r0[2] = r1;
    r1 = varref (0, 3);
    r0[3] = r1;
    r1 = varref (2, 110);
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L851:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2fif_495; r1[2] = lenv;
  r0[114] = r1;
  // def node/fix_500
  goto L852;
  FUN_node_2ffix_500:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = varref (0, 0);
    r2 = varref (1, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (1, 1);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (2, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L853; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L853:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (0, 1);
    r1[3] = r2;
    r2 = varref (2, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L854; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L854:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    t = alloc_no_clear (UOTAG(10),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = varref (0, 2);
    r0[3] = r1;
    r1 = varref (2, 110);
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L852:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2ffix_500; r1[2] = lenv;
  r0[115] = r1;
  // def node/let_501
  goto L855;
  FUN_node_2flet_501:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = varref (0, 0);
    r2 = varref (1, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (1, 1);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (2, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L856; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L856:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (0, 1);
    r1[3] = r2;
    r2 = varref (2, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L857; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L857:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    t = alloc_no_clear (UOTAG(9),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = varref (0, 2);
    r0[3] = r1;
    r1 = varref (2, 110);
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L855:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2flet_501; r1[2] = lenv;
  r0[116] = r1;
  // def node/nvcase_502
  goto L858;
  FUN_node_2fnvcase_502:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 4);
    r2 = varref (1, 5);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = varref (0, 0);
    r2 = varref (1, 3);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 1);
    r2 = varref (1, 2);
    r3 = varref (1, 0);
    t = alloc_no_clear (UOTAG(4),3);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    r1 = t;
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[3] = r1;
    r1 = varref (2, 110);
    r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
  L858:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_node_2fnvcase_502; r1[2] = lenv;
  r0[117] = r1;
  // def unpack-fix_506
  goto L859;
  FUN_unpack_fix_506:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = (object *) constructed_37[0];
    r1[3] = r2;
    r2 = varref (2, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L860; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L860:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (UOTAG(1), 2);
        r1 = varref (0, 0);
        r0[1] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = (object *) constructed_37[0];
        r1[3] = r2;
        r2 = varref (3, 19);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L861; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
        L861:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_214;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_214_over;
    fatbar_214:
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_792;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_792;
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
    PXLL_RETURN(0);
    fatbar_214_over: ;
    PXLL_RETURN(0);
  L859:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unpack_fix_506; r1[2] = lenv;
  r0[118] = r1;
  // def literal->string_507
  goto L862;
  FUN_literal__3estring_507:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 6);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8706;
        r2[2] = r3;
        r3 = varref (3, 44);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L863; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L863:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8706;
        r2[2] = r3;
        r3 = varref (3, 44);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L864; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L864:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (1, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r1 = varref (0, 4);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 54);
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_374;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 7);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 8962;
        r2[2] = r3;
        r3 = varref (3, 44);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L865; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L865:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = (object *) 23554;
        r2[2] = r3;
        r3 = varref (3, 44);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L866; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L866:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (3, 44);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L867; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_char__3estring_358;
        L867:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r2 = (object*)TC_NIL;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = varref (0, 4);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r1 = varref (0, 5);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
      case (UITAG(3)): {
        r0 = (object*) &constructed_780;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 8);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (2, 0);
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r2 = varref (0, 0);
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
            r1[2] = r2;
            r2 = varref (1, 1);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (2, 1);
            r3 = UOBJ_GET(r3,0);
            r2[2] = r3;
            r2 = varref (0, 0);
            lenv = lenv[1];
            r2 = r2;
            r2=r2;
            r1[3] = r2;
            r2 = (object*)TC_NIL;
            r1[4] = r2;
            r2 = varref (0, 2);
            r3 = (object*) &constructed_783;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r2 = varref (0, 3);
            r3 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = varref (0, 4);
            r3 = (object*) &constructed_782;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = varref (0, 5);
            r3 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r1 = varref (0, 6);
            r2 = (object*) &constructed_781;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (2, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } break;
          default: {
            goto fatbar_213;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_213_over;
        fatbar_213:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 11);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 0);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (2, 0);
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = varref (0, 0);
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[2] = r2;
        r2 = varref (1, 1);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (2, 1);
        r3 = UOBJ_GET(r3,0);
        r2[2] = r3;
        r2 = varref (0, 0);
        lenv = lenv[1];
        r2 = r2;
        r2=r2;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (3, 117);
        r3[2] = r4;
        r4 = varref (1, 2);
        r3[3] = r4;
        r4 = varref (3, 30);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L868; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
        L868:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_788;
        r2[3] = r3;
        r3 = varref (3, 46);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L869; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L869:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r2 = (object*)TC_NIL;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = (object*) &constructed_787;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = varref (0, 4);
        r3 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r2 = varref (0, 5);
        r3 = (object*) &constructed_786;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[8] = r2;
        r2 = varref (0, 6);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[9] = r2;
        r2 = varref (0, 7);
        r3 = (object*) &constructed_785;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[10] = r2;
        r2 = varref (0, 8);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[11] = r2;
        r1 = varref (0, 9);
        r2 = (object*) &constructed_784;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_213_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (3, 117);
        r3[2] = r4;
        r4 = varref (1, 0);
        r3[3] = r4;
        r4 = varref (3, 30);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L870; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
        L870:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*) &constructed_791;
        r2[3] = r3;
        r3 = varref (3, 46);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L871; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_join_363;
        L871:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_790;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_789;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (2, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      } break;
    }
    PXLL_RETURN(0);
  L862:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_literal__3estring_507; r1[2] = lenv;
  r0[119] = r1;
  // def flags-repr_508
  goto L872;
  FUN_flags_repr_508:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2390
    goto L873;
    FUN_loop_2390:
      check_heap (0);
      r0 = (object *) 1;
      r1 = varref (0, 1);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (3, 52);
        r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object *) 3;
        r2 = varref (1, 1);
        r1 = box(unbox(r2)&unbox(r1));
        r0[2] = r1;
        r0 = (object *) 3;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = (object *) 3;
          r1 = varref (0, 1);
          r0 = box(unbox(r1)>>unbox(r0));
          r1 = varref (0, 0);
          r2 = (object *) 12546;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_2390;
        } else {
          r0 = (object *) 3;
          r1 = varref (0, 1);
          r0 = box(unbox(r1)>>unbox(r0));
          r1 = varref (0, 0);
          r2 = (object *) 12290;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_loop_2390;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L873:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2390; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_779[0];
    r0[2] = r1;
    r1 = varref (1, 0);
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2390;
  L872:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_flags_repr_508; r1[2] = lenv;
  r0[120] = r1;
  // def pp-node_510
  goto L874;
  FUN_pp_node_510:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def PP_2396
    goto L875;
    FUN__50_50_2396:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (1, 0);
      r3 = ((pxll_vector*)r3)->val[5];
      r2[2] = r3;
      r3 = varref (4, 131);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L876; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_apply_subst_533;
      L876:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r2 = varref (4, 99);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L877; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_repr_464;
      L877:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 11);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = varref (2, 0);
      r4 = ((pxll_vector*)r4)->val[1];
      r3[2] = r4;
      r4 = varref (5, 54);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L878; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L878:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = (object *) 13;
      r3[2] = r4;
      r4 = varref (0, 0);
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = varref (5, 56);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L879; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
      L879:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = varref (2, 0);
      r4 = ((pxll_vector*)r4)->val[2];
      r3[2] = r4;
      r4 = varref (5, 54);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L880; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L880:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[4] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = (object *) 11;
      r3[2] = r4;
      r4 = varref (0, 2);
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = varref (5, 56);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L881; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
      L881:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[5] = r3;
      r3 = varref (5, 181);
      r4 = (object *) 5;
      r3 = box(unbox(r4)+unbox(r3));
      r2[6] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = varref (2, 0);
      r4 = ((pxll_vector*)r4)->val[0];
      r3[2] = r4;
      r4 = varref (5, 118);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L882; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_flags_repr_508;
      L882:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[7] = r3;
      r3 = allocate (TC_TUPLE, 4);
      r4 = varref (0, 4);
      r3[2] = r4;
      r4 = varref (0, 5);
      r3[3] = r4;
      r4 = (object *) 262;
      r3[4] = r4;
      r4 = varref (5, 56);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L883; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_pad_377;
      L883:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[8] = r3;
      r3 = (object*)TC_NIL;
      r2[9] = r3;
      r3 = varref (0, 7);
      r4 = varref (0, 6);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[10] = r3;
      r3 = varref (0, 8);
      r4 = varref (0, 3);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[11] = r3;
      r2 = varref (0, 9);
      r3 = varref (0, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (4, 45);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L884; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L884:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = (object *) 2562;
      box(fputc (GET_CHAR(r0), stdout));
      r0 = varref (0, 1);
      r0 = box(((pxll_string*)(r0))->len);
      r1 = varref (0, 1);
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object *) 1;
      r1 = varref (1, 1);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) 262;
        r0=r0;
      } else {
        goto fatbar_212;
      }
      goto fatbar_212_over;
      fatbar_212:
      r0 = (object*) &constructed_778;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_778;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 3;
      r2 = varref (1, 1);
      r1 = box(unbox(r2)-unbox(r1));
      r0[2] = r1;
      r1 = varref (4, 84);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L885; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_indent_436;
      L885:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      fatbar_212_over: ;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_746;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = varref (0, 4);
          r3 = (object*) &constructed_745;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L886; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L886:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 1);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_748;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = varref (0, 4);
          r3 = (object*) &constructed_747;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L887; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L887:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 1);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(2)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (1, 0);
          r3[2] = r4;
          r4 = varref (7, 117);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L888; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_literal__3estring_507;
          L888:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_750;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = varref (0, 4);
          r3 = (object*) &constructed_749;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L889; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L889:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 1);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(3)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (1, 1);
          r3[2] = r4;
          r4 = varref (7, 99);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L890; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
          L890:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_753;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (1, 2);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = varref (0, 4);
          r4 = (object*) &constructed_752;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = varref (0, 5);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = varref (0, 6);
          r3 = (object*) &constructed_751;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L891; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L891:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = varref (0, 3);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 3);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(5)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = varref (0, 0);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = varref (0, 1);
          r3 = (object*) &constructed_754;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L892; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L892:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 0);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(6)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = varref (0, 0);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = varref (0, 1);
          r3 = (object*) &constructed_755;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L893; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L893:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 0);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(8)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = varref (0, 0);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = varref (0, 1);
          r3 = (object*) &constructed_756;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L894; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L894:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 0);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 9);
          r2[1] = lenv; lenv = r2;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = varref (7, 72);
          r4[2] = r5;
          r5 = varref (1, 1);
          r4[3] = r5;
          r5 = varref (7, 30);
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L895; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
          L895:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_760;
          r3[3] = r4;
          r4 = varref (7, 46);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L896; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L896:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = (object*) &constructed_759;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = varref (0, 4);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = varref (0, 5);
          r4 = (object*) &constructed_758;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = varref (0, 6);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r2 = varref (0, 7);
          r3 = (object*) &constructed_757;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L897; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L897:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = varref (0, 2);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 2);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = varref (7, 72);
          r4[2] = r5;
          r5 = varref (1, 0);
          r4[3] = r5;
          r5 = varref (7, 30);
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L898; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
          L898:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_763;
          r3[3] = r4;
          r4 = varref (7, 46);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L899; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L899:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_762;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = varref (0, 4);
          r3 = (object*) &constructed_761;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L900; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L900:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 1);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(4)): {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 12);
          r2[1] = lenv; lenv = r2;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = varref (7, 72);
          r4[2] = r5;
          r5 = varref (1, 1);
          r4[3] = r5;
          r5 = varref (7, 30);
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L901; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
          L901:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_769;
          r3[3] = r4;
          r4 = varref (7, 46);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L902; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L902:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = varref (7, 54);
          r4[2] = r5;
          r5 = varref (1, 2);
          r4[3] = r5;
          r5 = varref (7, 30);
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L903; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
          L903:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_768;
          r3[3] = r4;
          r4 = varref (7, 46);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L904; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L904:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r3 = (object*)TC_NIL;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = varref (0, 4);
          r4 = (object*) &constructed_767;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = varref (0, 5);
          r4 = varref (0, 2);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = varref (0, 6);
          r4 = (object*) &constructed_766;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r3 = varref (0, 7);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[10] = r3;
          r3 = varref (0, 8);
          r4 = (object*) &constructed_765;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[11] = r3;
          r3 = varref (0, 9);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[12] = r3;
          r2 = varref (0, 10);
          r3 = (object*) &constructed_764;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L905; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L905:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r0 = varref (0, 3);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 3);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(11)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 7);
          r2[1] = lenv; lenv = r2;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = varref (1, 1);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 1);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = (object*) &constructed_771;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = varref (0, 4);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r2 = varref (0, 5);
          r3 = (object*) &constructed_770;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L906; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L906:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = varref (0, 2);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 2);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(12)): {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 9);
          r2[1] = lenv; lenv = r2;
          r3 = varref (1, 0);
          r3 = allocate (TC_TUPLE, 2);
          r3[1] = lenv; lenv = r3;
          r4 = varref (2, 0);
          r4 = UOBJ_GET(r4,0);
          r3[2] = r4;
          r3 = varref (0, 0);
          lenv = lenv[1];
          r3 = r3;
          r3=r3;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (1, 1);
          r3[2] = r4;
          r4 = varref (7, 83);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L907; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_repr_435;
          L907:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = (object*) &constructed_774;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = varref (0, 4);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = varref (0, 5);
          r4 = (object*) &constructed_773;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r3 = varref (0, 6);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[9] = r3;
          r2 = varref (0, 7);
          r3 = (object*) &constructed_772;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L908; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L908:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r0 = varref (0, 2);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 2);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = varref (7, 72);
          r4[2] = r5;
          r5 = varref (1, 0);
          r4[3] = r5;
          r5 = varref (7, 30);
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L909; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
          L909:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_777;
          r3[3] = r4;
          r4 = varref (7, 46);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L910; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L910:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_776;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = varref (0, 4);
          r3 = (object*) &constructed_775;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L911; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L911:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          r0 = box(((pxll_string*)(r0))->len);
          r1 = varref (0, 1);
          r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
      }
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r1 = varref (2, 1);
      r2 = (object *) 3;
      r1 = box(unbox(r2)+unbox(r1));
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_14264_i1719
      goto L912;
      FUN_lambda_14264_i1719:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (4, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN__50_50_2396;
      L912:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_14264_i1719; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[3] = r1;
      r1 = varref (5, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L875:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__50_50_2396; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = (object *) 1;
    r0[3] = r1;
    r1 = varref (0, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L913; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN__50_50_2396;
    L913:
    ; lenv = k[2]; k = k[1];
    r0 = (object *) 2562;
    r0 = box(fputc (GET_CHAR(r0), stdout));
    PXLL_RETURN(0);
  L874:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_pp_node_510; r1[2] = lenv;
  r0[121] = r1;
  // def get-formals_511
  goto L914;
  FUN_get_formals_511:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def p_2424
    goto L915;
    FUN_p_2424:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (1, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_211;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_211_over;
      fatbar_211:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_744;
      r0[2] = r1;
      r1 = varref (2, 0);
      r0[3] = r1;
      r1 = varref (3, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      fatbar_211_over: ;
      PXLL_RETURN(0);
    L915:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_p_2424; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = (object *) constructed_743[0];
    r1[3] = r2;
    r2 = varref (2, 0);
    r1[4] = r2;
    r2 = varref (3, 35);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L916; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_fold_340;
    L916:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = (object *) constructed_37[0];
    r0[3] = r1;
    r1 = varref (3, 19);
    r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
  L914:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_get_formals_511; r1[2] = lenv;
  r0[122] = r1;
  // def unpack-bindings_512
  goto L917;
  FUN_unpack_bindings_512:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2429
    goto L918;
    FUN_loop_2429:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (UOTAG(0), 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (3, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L919; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L919:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[1] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 2);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (3, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L920; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L920:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = varref (5, 1);
                              r1 = varref (1, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r1;
                              t[2] = r0;
                              r0 = t;
                              r1 = varref (5, 2);
                              r2 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r2 = varref (4, 1);
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              lenv[2] = r2;
                              lenv[3] = r0;
                              lenv[4] = r1;
                              goto FUN_loop_2429;
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_210;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_210;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_210;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_210;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_210;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_210_over;
      fatbar_210:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_742;
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[3] = r1;
      r1 = varref (3, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      fatbar_210_over: ;
      PXLL_RETURN(0);
    L918:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2429; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = (object *) constructed_741[0];
    r0[3] = r1;
    r1 = (object *) constructed_740[0];
    r0[4] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2429;
  L917:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unpack_bindings_512; r1[2] = lenv;
  r0[123] = r1;
  // def parse-cexp-sig_513
  goto L921;
  FUN_parse_cexp_sig_513:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 183);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L922; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L922:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (0, 0);
    r1[3] = r2;
    r2 = varref (2, 103);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L923; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_parse_type_splat_469;
    L923:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = allocate (UOTAG(2), 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (0, 0);
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[7];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L924; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L924:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[1] = r1;
    r1 = varref (0, 1);
    r0[2] = r1;
    PXLL_RETURN(0);
  L921:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_parse_cexp_sig_513; r1[2] = lenv;
  r0[124] = r1;
  // def sort-fix-inits_514
  goto L925;
  FUN_sort_fix_inits_514:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_739[0];
    r0[2] = r1;
    r1 = (object *) constructed_738[0];
    r0[3] = r1;
    r1 = (object *) constructed_737[0];
    r0[4] = r1;
    r1 = (object *) constructed_736[0];
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L926; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L926:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 4);
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def $loop_2452
    goto L927;
    FUN__24loop_2452:
      check_heap (0);
      r0 = varref (2, 0);
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      } else {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (5, 0);
        r1[2] = r2;
        r2 = varref (1, 0);
        r1[3] = r2;
        r2 = varref (6, 25);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L928; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
        L928:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (5, 1);
        r1[2] = r2;
        r2 = varref (1, 0);
        r1[3] = r2;
        r2 = varref (6, 25);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L929; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
        L929:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (0, 1);
        r1 = ((pxll_vector*)r1)->val[4];
        r0[4] = r1;
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (UOTAG(7)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (5, 0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (4, 0, r0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (5, 2);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (4, 2, r0);
            r0=r0;
          } break;
          default: {
            goto fatbar_209;
          }
        }
        r0=r0;
        goto fatbar_209_over;
        fatbar_209:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 1);
        r0[2] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (4, 1, r0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 3);
        r0[2] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (4, 3, r0);
        r0=r0;
        fatbar_209_over: ;
        lenv = lenv[1];
        r0 = (object *) 3;
        r1 = varref (0, 0);
        r0 = box(unbox(r1)+unbox(r0));
        lenv[2] = r0;
        goto FUN__24loop_2452;
      }
      PXLL_RETURN(0);
    L927:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__24loop_2452; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = varref (0, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L930; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2452;
    L930:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = r0;
    lenv = lenv[1];
    r0 = allocate (UOTAG(3), 2);
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 0);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (3, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L931; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L931:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = varref (1, 1);
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 2);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (3, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L932; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L932:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 1);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (3, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L933; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L933:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (0, 3);
    r1[3] = r2;
    r2 = varref (3, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L934; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L934:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[1] = r1;
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 2);
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 0);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (3, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L935; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L935:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = varref (1, 3);
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 2);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (3, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L936; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L936:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 1);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (3, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L937; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L937:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (0, 3);
    r1[3] = r2;
    r2 = varref (3, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L938; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L938:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    PXLL_RETURN(0);
  L925:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_sort_fix_inits_514; r1[2] = lenv;
  r0[125] = r1;
  // def walk_515
  goto L939;
  FUN_walk_515:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_683[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_700[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_700[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_700[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(r1) {
          r1 = (object *) constructed_45[0];
          r1=r1;
        } else {
          r1 = (object *) constructed_42[0];
          r1=r1;
        }
        r0[3] = r1;
        r1 = varref (0, 1);
        r2 = (object *) constructed_722[0];
        r3 = (object *) constructed_47[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 2);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_700[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = (object*)UITAG(3);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_700[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        // def lambda_15029
        goto L940;
        FUN_lambda_15029:
          check_heap (0);
          r0 = varref (0, 0);
          r0 = allocate (TC_TUPLE, 8);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (0, 0);
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = varref (4, 124);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L941; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
          L941:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = (object*)TC_NIL;
          r0[6] = r1;
          r1 = varref (0, 4);
          r2 = varref (0, 3);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[7] = r1;
          r1 = varref (0, 5);
          r2 = varref (1, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[8] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 2);
          r2 = (object *) constructed_430[0];
          t = alloc_no_clear (UOTAG(12),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = varref (0, 6);
          r0[3] = r1;
          r1 = varref (4, 110);
          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
          PXLL_RETURN(0);
        L940:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_15029; r1[2] = lenv;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object *) 6;
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r3 = (object *) constructed_427[0];
        t = alloc_no_clear (UOTAG(12),2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = (object *) constructed_723[0];
        r1[3] = r2;
        r2 = varref (3, 110);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L942; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
        L942:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = varref (0, 0);
        r0[4] = r1;
        r1 = varref (2, 36);
        r0[1] = r1[2]; lenv = r0; goto FUN_foldr_341;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 7);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (0, 1);
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 124);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L943; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
        L943:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = (object*)TC_NIL;
        r0[6] = r1;
        r1 = varref (0, 4);
        r2 = varref (0, 3);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[7] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 2);
        r2 = (object *) constructed_424[0];
        t = alloc_no_clear (UOTAG(12),2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = varref (0, 5);
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        t = alloc_no_clear (UOTAG(7),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (2, 126);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L944; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
        L944:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_700[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 6);
        r3[1] = lenv; lenv = r3;
        r4 = varref (1, 0);
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = varref (2, 0);
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = varref (0, 0);
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[2] = r4;
        r4 = varref (1, 1);
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = varref (2, 1);
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = varref (0, 0);
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[3] = r4;
        r4 = (object*)TC_NIL;
        r3[4] = r4;
        r4 = varref (0, 2);
        r5 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[5] = r4;
        r4 = varref (0, 3);
        r5 = (object*) &constructed_724;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[6] = r4;
        r3 = varref (0, 4);
        r4 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r3 = varref (2, 45);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L945; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
        L945:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (2, 73);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L946; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
        L946:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 2);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = (object *) constructed_683[0];
        r0[3] = r1;
        r1 = varref (2, 110);
        r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = (object *) constructed_726[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 0);
                              switch (get_case (r0)) {
                                case (UOTAG(1)): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 0);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r0 = varref (1, 1);
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (2, 1);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = varref (2, 1);
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = varref (0, 0);
                                      switch (get_case (r0)) {
                                        case (UOTAG(1)): {
                                          r0 = allocate (TC_TUPLE, 2);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (1, 0);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r0 = varref (1, 1);
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = varref (5, 1);
                                              switch (get_case (r0)) {
                                                case (TC_PAIR): {
                                                  r0 = allocate (TC_TUPLE, 3);
                                                  r0[1] = lenv; lenv = r0;
                                                  r1 = varref (6, 1);
                                                  r1 = UOBJ_GET(r1,0);
                                                  r0[2] = r1;
                                                  r1 = varref (6, 1);
                                                  r1 = UOBJ_GET(r1,1);
                                                  r0[3] = r1;
                                                  r0 = varref (0, 1);
                                                  switch (get_case (r0)) {
                                                    case (TC_NIL): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = varref (1, 0);
                                                      r1[2] = r2;
                                                      r2 = varref (12, 124);
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L947; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                                      L947:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      r0[2] = r1;
                                                      r0 = allocate (TC_TUPLE, 3);
                                                      r1 = varref (2, 0);
                                                      r2 = varref (4, 0);
                                                      t = alloc_no_clear (UOTAG(11),2);
                                                      t[1] = r2;
                                                      t[2] = r1;
                                                      r1 = t;
                                                      r0[2] = r1;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = (object*)TC_NIL;
                                                      r1[2] = r2;
                                                      r1 = varref (0, 0);
                                                      r2 = varref (1, 0);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r2;
                                                      t[2] = r1;
                                                      r1 = t;
                                                      lenv = lenv[1];
                                                      r1 = r1;
                                                      r0[3] = r1;
                                                      r1 = varref (12, 110);
                                                      r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                                    } break;
                                                    default: {
                                                      lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                      goto fatbar_196;
                                                    }
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                                  goto fatbar_196;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_196;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_196;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_196;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_196;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_196;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_196;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_196;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_196;
                }
                PXLL_RETURN(0);
                goto fatbar_196_over;
                fatbar_196:
                r0 = (object *) constructed_728[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = varref (0, 0);
                          r1[2] = r2;
                          r2 = varref (6, 121);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L948; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_bindings_512;
                          L948:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case_noint (r0)) {
                            default: {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = varref (0, 0);
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = varref (7, 124);
                              r1[2] = r2;
                              r2 = varref (0, 1);
                              r1[3] = r2;
                              r2 = varref (7, 30);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L949; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                              L949:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = varref (8, 124);
                              r2[2] = r3;
                              r3 = varref (3, 1);
                              r2[3] = r3;
                              r3 = varref (8, 30);
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L950; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
                              L950:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = (object*)UITAG(5);
                              r1[2] = r2;
                              r2 = varref (0, 0);
                              r1[3] = r2;
                              r2 = varref (8, 110);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L951; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                              L951:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              lenv = lenv[1];
                              r1 = r1;
                              r0[4] = r1;
                              r1 = varref (7, 113);
                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffix_500;
                            } break;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_197;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_197;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_197;
                }
                PXLL_RETURN(0);
                goto fatbar_197_over;
                fatbar_197:
                r0 = (object *) constructed_535[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = varref (0, 0);
                          r1[2] = r2;
                          r2 = varref (6, 121);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L952; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_bindings_512;
                          L952:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case_noint (r0)) {
                            default: {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = varref (0, 0);
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = varref (7, 124);
                              r1[2] = r2;
                              r2 = varref (0, 1);
                              r1[3] = r2;
                              r2 = varref (7, 30);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L953; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                              L953:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = varref (8, 124);
                              r2[2] = r3;
                              r3 = varref (3, 1);
                              r2[3] = r3;
                              r3 = varref (8, 30);
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L954; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
                              L954:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r1 = allocate (TC_TUPLE, 3);
                              r2 = (object*)UITAG(5);
                              r1[2] = r2;
                              r2 = varref (0, 0);
                              r1[3] = r2;
                              r2 = varref (8, 110);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L955; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                              L955:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              lenv = lenv[1];
                              r1 = r1;
                              r0[4] = r1;
                              r1 = varref (7, 114);
                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2flet_501;
                            } break;
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_198;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_198;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_198;
                }
                PXLL_RETURN(0);
                goto fatbar_198_over;
                fatbar_198:
                r0 = (object *) constructed_612[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(0)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 0);
                              switch (get_case (r0)) {
                                case (UOTAG(0)): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 0);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = varref (2, 0);
                                  r2[2] = r3;
                                  r3 = varref (8, 120);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L956; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_get_formals_511;
                                  L956:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = varref (8, 124);
                                  r2[2] = r3;
                                  r3 = varref (0, 0);
                                  r2[3] = r3;
                                  r3 = varref (8, 30);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L957; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
                                  L957:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[3] = r2;
                                  r2 = varref (8, 123);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L958; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_sort_fix_inits_514;
                                  L958:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = varref (0, 1);
                                  switch (get_case_noint (r0)) {
                                    default: {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 1);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = varref (1, 1);
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = allocate (TC_TUPLE, 4);
                                      r1 = varref (0, 0);
                                      r0[2] = r1;
                                      r1 = varref (0, 1);
                                      r0[3] = r1;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = varref (10, 124);
                                      r2[2] = r3;
                                      r3 = varref (3, 1);
                                      r2[3] = r3;
                                      r3 = varref (10, 30);
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L959; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
                                      L959:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = (object*)UITAG(5);
                                      r1[2] = r2;
                                      r2 = varref (0, 0);
                                      r1[3] = r2;
                                      r2 = varref (10, 110);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L960; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                                      L960:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r0[4] = r1;
                                      r1 = varref (9, 113);
                                      r0[1] = r1[2]; lenv = r0; goto FUN_node_2ffix_500;
                                    } break;
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_199;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_199;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_199;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_199;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_199;
                }
                PXLL_RETURN(0);
                goto fatbar_199_over;
                fatbar_199:
                r0 = (object *) constructed_531[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 0);
                              switch (get_case (r0)) {
                                case (UOTAG(0)): {
                                  r0 = allocate (TC_TUPLE, 5);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 0);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (0, 0);
                                  r1[2] = r2;
                                  r2 = varref (8, 120);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L961; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_get_formals_511;
                                  L961:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (8, 124);
                                  r1[2] = r2;
                                  r2 = varref (1, 1);
                                  r1[3] = r2;
                                  r2 = varref (8, 30);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L962; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                                  L962:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object*)UITAG(5);
                                  r1[2] = r2;
                                  r2 = varref (0, 2);
                                  r1[3] = r2;
                                  r2 = varref (8, 110);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L963; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                                  L963:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[5] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (0, 1);
                                  r2 = varref (2, 0);
                                  t = alloc_no_clear (UOTAG(7),2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = (object*)TC_NIL;
                                  r1[2] = r2;
                                  r1 = varref (0, 0);
                                  r2 = varref (1, 3);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[3] = r1;
                                  r1 = varref (8, 110);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_200;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_200;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_200;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_200;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_200;
                }
                PXLL_RETURN(0);
                goto fatbar_200_over;
                fatbar_200:
                r0 = (object *) constructed_541[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = varref (0, 0);
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 0);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r0 = varref (1, 1);
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (2, 1);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = varref (2, 1);
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = varref (0, 0);
                                          switch (get_case (r0)) {
                                            case (UOTAG(0)): {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = varref (1, 0);
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r0 = varref (1, 1);
                                              switch (get_case (r0)) {
                                                case (TC_PAIR): {
                                                  r0 = allocate (TC_TUPLE, 3);
                                                  r0[1] = lenv; lenv = r0;
                                                  r1 = varref (2, 1);
                                                  r1 = UOBJ_GET(r1,0);
                                                  r0[2] = r1;
                                                  r1 = varref (2, 1);
                                                  r1 = UOBJ_GET(r1,1);
                                                  r0[3] = r1;
                                                  r0 = varref (0, 0);
                                                  switch (get_case (r0)) {
                                                    case (UOTAG(0)): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = varref (1, 0);
                                                      r1 = UOBJ_GET(r1,0);
                                                      r0[2] = r1;
                                                      r0 = varref (1, 1);
                                                      switch (get_case (r0)) {
                                                        case (TC_PAIR): {
                                                          r0 = allocate (TC_TUPLE, 3);
                                                          r0[1] = lenv; lenv = r0;
                                                          r1 = varref (2, 1);
                                                          r1 = UOBJ_GET(r1,0);
                                                          r0[2] = r1;
                                                          r1 = varref (2, 1);
                                                          r1 = UOBJ_GET(r1,1);
                                                          r0[3] = r1;
                                                          r0 = varref (0, 1);
                                                          switch (get_case (r0)) {
                                                            case (TC_NIL): {
                                                              r0 = allocate (TC_TUPLE, 7);
                                                              r1 = varref (8, 0);
                                                              r0[2] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = varref (14, 78);
                                                              r1[2] = r2;
                                                              r2 = varref (5, 0);
                                                              r1[3] = r2;
                                                              r2 = varref (14, 30);
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L964; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                                                              L964:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[3] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = varref (14, 79);
                                                              r1[2] = r2;
                                                              r2 = varref (3, 0);
                                                              r1[3] = r2;
                                                              r2 = varref (14, 30);
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L965; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                                                              L965:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[4] = r1;
                                                              r1 = allocate (TC_TUPLE, 2);
                                                              r2 = varref (7, 0);
                                                              r1[2] = r2;
                                                              r2 = varref (14, 124);
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L966; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                                              L966:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[5] = r1;
                                                              r1 = allocate (TC_TUPLE, 3);
                                                              r2 = varref (14, 124);
                                                              r1[2] = r2;
                                                              r2 = varref (1, 0);
                                                              r1[3] = r2;
                                                              r2 = varref (14, 30);
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L967; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                                                              L967:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[6] = r1;
                                                              r1 = allocate (TC_TUPLE, 2);
                                                              r2 = varref (0, 0);
                                                              r1[2] = r2;
                                                              r2 = varref (14, 124);
                                                              t = allocate (TC_SAVE, 4);
                                                              t[1] = k; t[2] = lenv; t[3] = &&L968; t[4] = r0; k = t;
                                                              r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                                              L968:
                                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                                              r1 = result;
                                                              r0[7] = r1;
                                                              r1 = varref (14, 115);
                                                              r0[1] = r1[2]; lenv = r0; goto FUN_node_2fnvcase_502;
                                                            } break;
                                                            default: {
                                                              lenv = ((object **********)lenv)[1][1][1][1][1][1][1][1][1][1];
                                                              goto fatbar_201;
                                                            }
                                                          }
                                                          PXLL_RETURN(0);
                                                        } break;
                                                        default: {
                                                          lenv = ((object *********)lenv)[1][1][1][1][1][1][1][1][1];
                                                          goto fatbar_201;
                                                        }
                                                      }
                                                      PXLL_RETURN(0);
                                                    } break;
                                                    default: {
                                                      lenv = ((object ********)lenv)[1][1][1][1][1][1][1][1];
                                                      goto fatbar_201;
                                                    }
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                  goto fatbar_201;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_201;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_201;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ****)lenv)[1][1][1][1];
                                      goto fatbar_201;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_201;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_201;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_201;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_201;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_201;
                }
                PXLL_RETURN(0);
                goto fatbar_201_over;
                fatbar_201:
                r0 = (object *) constructed_543[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (UOTAG(2)): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = varref (2, 0);
                              r1[2] = r2;
                              r2 = varref (7, 122);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L969; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_parse_cexp_sig_513;
                              L969:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case_noint (r0)) {
                                default: {
                                  r0 = allocate (TC_TUPLE, 4);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (8, 124);
                                  r1[2] = r2;
                                  r2 = varref (2, 1);
                                  r1[3] = r2;
                                  r2 = varref (8, 30);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L970; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                                  L970:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (0, 1);
                                  r2 = varref (1, 0);
                                  r3 = varref (0, 0);
                                  t = alloc_no_clear (UOTAG(3),3);
                                  t[1] = r3;
                                  t[2] = r1;
                                  t[3] = r2;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = varref (0, 2);
                                  r0[3] = r1;
                                  r1 = varref (8, 110);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                } break;
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_202;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_202;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_202;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_202;
                }
                PXLL_RETURN(0);
                goto fatbar_202_over;
                fatbar_202:
                r0 = (object *) constructed_525[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (2, 0);
                                  r1[2] = r2;
                                  r2 = varref (7, 124);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L971; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L971:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r2 = varref (7, 124);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L972; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L972:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (0, 0);
                                  r1[2] = r2;
                                  r2 = varref (7, 124);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L973; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L973:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = varref (7, 112);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_node_2fif_495;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_203;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_203;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_203;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_203;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_203;
                }
                PXLL_RETURN(0);
                goto fatbar_203_over;
                fatbar_203:
                r0 = (object *) constructed_730[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = varref (1, 0);
                          r1[2] = r2;
                          r2 = varref (6, 126);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L974; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
                          L974:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = varref (0, 0);
                          t = alloc_no_clear (UOTAG(2),1);
                          t[1] = r1;
                          r1 = t;
                          r0[2] = r1;
                          r1 = (object *) constructed_700[0];
                          r0[3] = r1;
                          r1 = varref (6, 110);
                          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_204;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_204;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_204;
                }
                PXLL_RETURN(0);
                goto fatbar_204_over;
                fatbar_204:
                r0 = (object *) constructed_732[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = varref (1, 0);
                          r1[2] = r2;
                          r2 = varref (6, 126);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L975; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
                          L975:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = varref (0, 0);
                          t = alloc_no_clear (UOTAG(2),1);
                          t[1] = r1;
                          r1 = t;
                          r0[2] = r1;
                          r1 = (object *) constructed_700[0];
                          r0[3] = r1;
                          r1 = varref (6, 110);
                          r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_205;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_205;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_205;
                }
                PXLL_RETURN(0);
                goto fatbar_205_over;
                fatbar_205:
                r0 = (object *) constructed_527[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (UOTAG(1)): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r0 = varref (1, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (2, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r2 = varref (8, 124);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L976; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                                  L976:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (2, 0);
                                  t = alloc_no_clear (UOTAG(1),1);
                                  t[1] = r1;
                                  r1 = t;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = (object*)TC_NIL;
                                  r1[2] = r2;
                                  r1 = varref (0, 0);
                                  r2 = varref (1, 0);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[3] = r1;
                                  r1 = varref (8, 110);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                                } break;
                                default: {
                                  lenv = ((object ***)lenv)[1][1][1];
                                  goto fatbar_206;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_206;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object *)lenv)[1];
                          goto fatbar_206;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      goto fatbar_206;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_206;
                }
                PXLL_RETURN(0);
                goto fatbar_206_over;
                fatbar_206:
                r0 = (object *) constructed_529[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 124);
                  r1[2] = r2;
                  r2 = varref (2, 1);
                  r1[3] = r2;
                  r2 = varref (5, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L977; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L977:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(5);
                  r0[2] = r1;
                  r1 = varref (0, 0);
                  r0[3] = r1;
                  r1 = varref (5, 110);
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_195;
                }
                PXLL_RETURN(0);
                fatbar_206_over: ;
                PXLL_RETURN(0);
                fatbar_205_over: ;
                PXLL_RETURN(0);
                fatbar_204_over: ;
                PXLL_RETURN(0);
                fatbar_203_over: ;
                PXLL_RETURN(0);
                fatbar_202_over: ;
                PXLL_RETURN(0);
                fatbar_201_over: ;
                PXLL_RETURN(0);
                fatbar_200_over: ;
                PXLL_RETURN(0);
                fatbar_199_over: ;
                PXLL_RETURN(0);
                fatbar_198_over: ;
                PXLL_RETURN(0);
                fatbar_197_over: ;
                PXLL_RETURN(0);
                fatbar_196_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_195;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_195_over;
            fatbar_195:
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (2, 0);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = varref (0, 0);
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
                r0[2] = r1;
                r1 = (object *) 1;
                r2 = varref (0, 0);
                range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
                r1 = (object *) 1;
                r2 = varref (0, 0);
                r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
                r0[3] = r1;
                r0 = (object *) 9474;
                r1 = varref (0, 1);
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = varref (1, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (2, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (5, 124);
                      r1[2] = r2;
                      r2 = varref (0, 1);
                      r1[3] = r2;
                      r2 = varref (5, 30);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L978; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                      L978:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = varref (0, 0);
                      r2 = varref (1, 0);
                      t = alloc_no_clear (UOTAG(12),2);
                      t[1] = r2;
                      t[2] = r1;
                      r1 = t;
                      r0[2] = r1;
                      r1 = varref (0, 2);
                      r0[3] = r1;
                      r1 = varref (5, 110);
                      r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                    } break;
                    default: {
                      goto fatbar_208;
                    }
                  }
                  PXLL_RETURN(0);
                  goto fatbar_208_over;
                  fatbar_208:
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*) &constructed_733;
                  r0[2] = r1;
                  r1 = varref (2, 0);
                  r0[3] = r1;
                  r1 = varref (4, 12);
                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                  fatbar_208_over: ;
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (2, 0);
                  r1[2] = r2;
                  r2 = varref (5, 124);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L979; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                  L979:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 124);
                  r1[2] = r2;
                  r2 = varref (2, 1);
                  r1[3] = r2;
                  r2 = varref (5, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L980; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L980:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = varref (0, 1);
                  r2 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(8);
                  r0[2] = r1;
                  r1 = varref (0, 2);
                  r0[3] = r1;
                  r1 = varref (5, 110);
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                }
                PXLL_RETURN(0);
              } break;
              case (UOTAG(9)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_50[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 9);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 1);
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (2, 1);
                  r1[2] = r2;
                  r2 = varref (5, 20);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L981; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                  L981:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = varref (0, 1);
                  t = alloc_no_clear (UOTAG(5),1);
                  t[1] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r1 = (object*)TC_NIL;
                  r0[5] = r1;
                  r1 = varref (0, 3);
                  r2 = varref (0, 2);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[6] = r1;
                  r1 = varref (0, 4);
                  r2 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[7] = r1;
                  r1 = varref (0, 5);
                  t = alloc_no_clear (UOTAG(0),1);
                  t[1] = r1;
                  r1 = t;
                  r0[8] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 124);
                  r1[2] = r2;
                  r2 = varref (2, 1);
                  r1[3] = r2;
                  r2 = varref (5, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L982; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L982:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[9] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = varref (0, 6);
                  r2 = (object *) constructed_435[0];
                  t = alloc_no_clear (UOTAG(12),2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[2] = r1;
                  r1 = varref (0, 7);
                  r0[3] = r1;
                  r1 = varref (5, 110);
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (2, 0);
                  r1[2] = r2;
                  r2 = varref (5, 124);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L983; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
                  L983:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 124);
                  r1[2] = r2;
                  r2 = varref (2, 1);
                  r1[3] = r2;
                  r2 = varref (5, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L984; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L984:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = varref (0, 1);
                  r2 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  r0[4] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = (object*)UITAG(8);
                  r0[2] = r1;
                  r1 = varref (0, 2);
                  r0[3] = r1;
                  r1 = varref (5, 110);
                  r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_207;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_207_over;
            fatbar_207:
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (4, 124);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L985; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
            L985:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 124);
            r1[2] = r2;
            r2 = varref (1, 1);
            r1[3] = r2;
            r2 = varref (4, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L986; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L986:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = varref (0, 1);
            r2 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*)UITAG(8);
            r0[2] = r1;
            r1 = varref (0, 2);
            r0[3] = r1;
            r1 = varref (4, 110);
            r0[1] = r1[2]; lenv = r0; goto FUN_make_node_488;
            fatbar_207_over: ;
            PXLL_RETURN(0);
            fatbar_195_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_194;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_194_over;
        fatbar_194:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_734;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (2, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        fatbar_194_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_193_over;
    fatbar_193:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_735;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_193_over: ;
    PXLL_RETURN(0);
  L939:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_walk_515; r1[2] = lenv;
  r0[126] = r1;
  // def build-list-literal_516
  goto L987;
  FUN_build_list_literal_516:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(9)): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 126);
            r1[2] = r2;
            r2 = varref (1, 1);
            r1[3] = r2;
            r2 = varref (3, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L988; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L988:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = varref (0, 1);
            r1 = varref (0, 2);
            r2 = varref (0, 0);
            t = alloc_no_clear (UOTAG(5),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_192;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_192_over;
        fatbar_192:
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = varref (3, 126);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L989; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_literal_517;
        L989:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (1, 1);
        r1[2] = r2;
        r2 = varref (3, 125);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L990; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_build_list_literal_516;
        L990:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = (object*)TC_NIL;
        r0[4] = r1;
        r1 = varref (0, 2);
        r2 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[5] = r1;
        r1 = varref (0, 3);
        r2 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[6] = r1;
        r0 = (object *) constructed_62[0];
        r1 = varref (0, 4);
        r2 = (object *) constructed_52[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_192_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object *) constructed_50[0];
        r1 = (object *) constructed_721[0];
        r2 = (object *) constructed_52[0];
        t = alloc_no_clear (UOTAG(5),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L987:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_list_literal_516; r1[2] = lenv;
  r0[127] = r1;
  // def build-literal_517
  goto L991;
  FUN_build_literal_517:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(2),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = (object*)UITAG(3);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 125);
        r0[1] = r1[2]; lenv = r0; goto FUN_build_list_literal_516;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 126);
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (2, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L992; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L992:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        t = alloc_no_clear (UOTAG(6),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_191;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_191_over;
    fatbar_191:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_720;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_191_over: ;
    PXLL_RETURN(0);
  L991:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_literal_517; r1[2] = lenv;
  r0[128] = r1;
  // def make-vardef_519
  goto L993;
  FUN_make_vardef_519:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 6);
    r3[1] = lenv; lenv = r3;
    r4 = varref (2, 0);
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = varref (3, 0);
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = varref (0, 0);
    lenv = lenv[1];
    r4 = r4;
    r4=r4;
    r3[2] = r4;
    r4 = allocate (TC_TUPLE, 2);
    r5 = varref (2, 1);
    r4[2] = r5;
    r5 = varref (3, 54);
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L994; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
    L994:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[3] = r4;
    r4 = (object*)TC_NIL;
    r3[4] = r4;
    r4 = varref (0, 2);
    r5 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[5] = r4;
    r4 = varref (0, 3);
    r5 = (object*) &constructed_719;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[6] = r4;
    r3 = varref (0, 4);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    lenv = lenv[1];
    r3 = r3;
    r2[2] = r3;
    r3 = varref (2, 45);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L995; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
    L995:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (2, 73);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L996; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
    L996:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (UOTAG(16), 5);
    r1 = (object *) constructed_718[0];
    r0[1] = r1;
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = (object *) constructed_717[0];
    r0[4] = r1;
    r1 = varref (1, 1);
    r0[5] = r1;
    PXLL_RETURN(0);
  L993:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_make_vardef_519; r1[2] = lenv;
  r0[129] = r1;
  // def k/free_524
  goto L997;
  FUN_k_2ffree_524:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_716;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_716;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L997:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_k_2ffree_524; r1[2] = lenv;
  r0[130] = r1;
  // def k/target_525
  goto L998;
  FUN_k_2ftarget_525:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_715;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_715;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L998:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_k_2ftarget_525; r1[2] = lenv;
  r0[131] = r1;
  // def unify_532
  goto L999;
  FUN_unify_532:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def type-error_3267
    goto L1000;
    FUN_type_error_3267:
      check_heap (0);
      r0 = (object *) 2562;
      box(fputc (GET_CHAR(r0), stdout));
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (2, 0);
      r0[2] = r1;
      r1 = varref (3, 119);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1001; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_510;
      L1001:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (4, 131);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1002; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_533;
      L1002:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 1);
      r1[2] = r2;
      r2 = varref (4, 131);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1003; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_533;
      L1003:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = varref (2, 0);
      r3[2] = r4;
      r4 = varref (6, 99);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1004; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
      L1004:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 2);
      r4 = varref (2, 1);
      r3[2] = r4;
      r4 = varref (6, 99);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1005; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_type_repr_464;
      L1005:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = varref (0, 2);
      r4 = (object*) &constructed_714;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = varref (0, 3);
      r4 = varref (0, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = varref (0, 4);
      r4 = (object*) &constructed_713;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = varref (0, 5);
      r4 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = varref (0, 6);
      r3 = (object*) &constructed_712;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (5, 45);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1006; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L1006:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      r0 = box(((pxll_string*)(r0))->len);
      r1 = varref (0, 0);
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      lenv = lenv[1];
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_711;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_711;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
    L1000:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_type_error_3267; r1[2] = lenv;
    r0[2] = r1;
    // def U_3268
    goto L1007;
    FUN__55_3268:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_20736
      goto L1008;
      FUN_lambda_20736:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r1[2] = r2;
        r2 = varref (5, 101);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1009; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
        L1009:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 1);
        r1[2] = r2;
        r2 = varref (5, 101);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1010; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
        L1010:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r2 = varref (1, 0);
        r1 = PXLL_TEST(r2==r1);
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = (object *) 14;
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (1, 1);
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = (object *) 14;
                  r0=r0;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (2, 1);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (2, 1);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = (object *) constructed_708[0];
                  r1 = varref (1, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = (object *) constructed_708[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = (object *) 14;
                      r0=r0;
                    } else {
                      goto fatbar_185;
                    }
                    r0=r0;
                    goto fatbar_185_over;
                    fatbar_185:
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = varref (1, 1);
                    r2[2] = r3;
                    r3 = varref (7, 17);
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1011; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
                    L1011:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = varref (2, 1);
                    r1[3] = r2;
                    r2 = varref (5, 1);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1012; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_3268;
                    L1012:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (3, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1013; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1013:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                    fatbar_185_over: ;
                    r0=r0;
                  } else {
                    goto fatbar_184;
                  }
                  r0=r0;
                  goto fatbar_184_over;
                  fatbar_184:
                  r0 = (object *) constructed_708[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = allocate (TC_TUPLE, 2);
                    r3 = varref (0, 1);
                    r2[2] = r3;
                    r3 = varref (7, 17);
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1014; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
                    L1014:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r2 = varref (2, 0);
                    r1[3] = r2;
                    r2 = varref (5, 1);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1015; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_3268;
                    L1015:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (3, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1016; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1016:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_186;
                  }
                  r0=r0;
                  goto fatbar_186_over;
                  fatbar_186:
                  r0 = (object *) constructed_710[0];
                  r1 = varref (1, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (2, 0);
                    r1[2] = r2;
                    r2 = varref (2, 1);
                    r1[3] = r2;
                    r2 = varref (5, 2);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1017; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3270;
                    L1017:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (3, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1018; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1018:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_187;
                  }
                  r0=r0;
                  goto fatbar_187_over;
                  fatbar_187:
                  r0 = (object *) constructed_710[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (2, 1);
                    r1[2] = r2;
                    r2 = varref (2, 0);
                    r1[3] = r2;
                    r2 = varref (5, 2);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1019; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3270;
                    L1019:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (3, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1020; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1020:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_188;
                  }
                  r0=r0;
                  goto fatbar_188_over;
                  fatbar_188:
                  r0 = (object *) constructed_491[0];
                  r1 = varref (1, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (2, 0);
                    r1[2] = r2;
                    r2 = varref (2, 1);
                    r1[3] = r2;
                    r2 = varref (5, 2);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1021; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3270;
                    L1021:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (3, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1022; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1022:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_189;
                  }
                  r0=r0;
                  goto fatbar_189_over;
                  fatbar_189:
                  r0 = (object *) constructed_491[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (2, 1);
                    r1[2] = r2;
                    r2 = varref (2, 0);
                    r1[3] = r2;
                    r2 = varref (5, 2);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1023; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN__55_row_3270;
                    L1023:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (3, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1024; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1024:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    goto fatbar_190;
                  }
                  r0=r0;
                  goto fatbar_190_over;
                  fatbar_190:
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r2 = varref (2, 0);
                  r1 = PXLL_TEST(r2==r1);
                  r0[2] = r1;
                  r0 = (object *) 6;
                  r1 = varref (0, 0);
                  r0 = PXLL_TEST(r1==r0);
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = (object *) 262;
                    r0=r0;
                  } else {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (2, 1);
                    r1[2] = r2;
                    r2 = varref (8, 20);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1025; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                    L1025:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 1);
                    r1[2] = r2;
                    r2 = varref (8, 20);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1026; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                    L1026:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = varref (0, 1);
                    r2 = varref (0, 0);
                    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                    r0[4] = r1;
                    r0 = (object *) 6;
                    r1 = varref (0, 2);
                    r0 = PXLL_TEST(r1==r0);
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  }
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = varref (4, 0);
                    r0[2] = r1;
                    r1 = varref (4, 1);
                    r0[3] = r1;
                    r1 = varref (5, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1027; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_type_error_3267;
                    L1027:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } else {
                    r0 = (object *) 14;
                    r0=r0;
                  }
                  r0=r0;
                  fatbar_190_over: ;
                  r0=r0;
                  fatbar_189_over: ;
                  r0=r0;
                  fatbar_188_over: ;
                  r0=r0;
                  fatbar_187_over: ;
                  r0=r0;
                  fatbar_186_over: ;
                  r0=r0;
                  fatbar_184_over: ;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
              }
              lenv = lenv[1];
              r0 = r0;
            } break;
          }
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (5, 102);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1028; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_type_union_468;
          L1028:
          ; lenv = k[2]; k = k[1];
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[2] = r1;
              r0 = varref (1, 1);
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (2, 1);
                  r1 = UOBJ_GET(r1,1);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = varref (5, 1);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r0[3] = r1;
                  r1 = varref (0, 0);
                  r0[4] = r1;
                  r1 = varref (7, 34);
                  r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_339;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_183;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_183;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_183_over;
          fatbar_183:
          r0 = (object *) 14;
          PXLL_RETURN(0);
          fatbar_183_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L1008:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_20736; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (3, 14);
      r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_307;
    L1007:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__55_3268; r1[2] = lenv;
    r0[3] = r1;
    // def U-row_3270
    goto L1029;
    FUN__55_row_3270:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_491[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = varref (2, 1);
                    switch (get_case (r0)) {
                      case (UOTAG(1)): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (3, 1);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (3, 1);
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = (object *) constructed_491[0];
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (2, 0);
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[3] = r1;
                                  r1 = varref (5, 1);
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                } break;
                                default: {
                                  lenv = ((object *)lenv)[1];
                                  goto fatbar_180;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              goto fatbar_180;
                            }
                          }
                          PXLL_RETURN(0);
                        } else {
                          goto fatbar_180;
                        }
                        PXLL_RETURN(0);
                        goto fatbar_180_over;
                        fatbar_180:
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = varref (1, 1);
                        r1[2] = r2;
                        r2 = varref (7, 20);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1030; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                        L1030:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = varref (0, 0);
                        r0[3] = r1;
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        // def $loop_3302
                        goto L1031;
                        FUN__24loop_3302:
                          check_heap (0);
                          r0 = varref (2, 1);
                          r1 = varref (0, 0);
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = varref (0, 1);
                            r0[2] = r1;
                            r1 = (object *) constructed_37[0];
                            r0[3] = r1;
                            r1 = varref (9, 19);
                            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                          } else {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (10, 97);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1032; t[4] = r0; k = t;
                            lenv = r1[2]; goto FUN_new_tvar_455;
                            L1032:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r0 = varref (1, 1);
                            r1 = varref (0, 0);
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            lenv = lenv[1];
                            r0 = r0;
                            r1 = (object *) 3;
                            r2 = varref (0, 0);
                            r1 = box(unbox(r2)+unbox(r1));
                            lenv[2] = r1;
                            lenv[3] = r0;
                            goto FUN__24loop_3302;
                          }
                          PXLL_RETURN(0);
                        L1031:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN__24loop_3302; r2[2] = lenv;
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object *) 1;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = varref (0, 0);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1033; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3302;
                        L1033:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[4] = r1;
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = varref (2, 0);
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = varref (1, 0);
                        r1[2] = r2;
                        r2 = varref (0, 2);
                        r1[3] = r2;
                        r2 = varref (7, 96);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1034; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                        L1034:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = varref (5, 1);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1035; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                        L1035:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        // def $loop_3307
                        goto L1036;
                        FUN__24loop_3307:
                          check_heap (0);
                          r0 = varref (2, 0);
                          r1 = varref (0, 0);
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = (object *) 14;
                            PXLL_RETURN(0);
                          } else {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = varref (4, 1);
                            r1[2] = r2;
                            r2 = varref (0, 0);
                            r1[3] = r2;
                            r2 = varref (10, 25);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1037; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                            L1037:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = allocate (TC_TUPLE, 3);
                            r3 = varref (4, 2);
                            r2[2] = r3;
                            r3 = varref (1, 0);
                            r2[3] = r3;
                            r3 = varref (11, 25);
                            t = allocate (TC_SAVE, 5);
                            t[1] = k; t[2] = lenv; t[3] = &&L1038; t[4] = r0; t[5] = r1; k = t;
                            r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                            L1038:
                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                            r2 = result;
                            r1[2] = r2;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = (object *) constructed_491[0];
                            r1[2] = r2;
                            r2 = allocate (TC_TUPLE, 2);
                            r2[1] = lenv; lenv = r2;
                            r3 = (object*)TC_NIL;
                            r2[2] = r3;
                            r2 = varref (0, 0);
                            r3 = varref (1, 0);
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r3;
                            t[2] = r2;
                            r2 = t;
                            lenv = lenv[1];
                            r2 = r2;
                            r1[3] = r2;
                            r2 = varref (11, 96);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1039; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                            L1039:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            lenv = lenv[1];
                            r1 = r1;
                            r0[3] = r1;
                            r1 = varref (8, 1);
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L1040; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                            L1040:
                            ; lenv = k[2]; k = k[1];
                            r0 = (object *) 3;
                            r1 = varref (0, 0);
                            r0 = box(unbox(r1)+unbox(r0));
                            lenv[2] = r0;
                            goto FUN__24loop_3307;
                          }
                          PXLL_RETURN(0);
                        L1036:
                        r1 = allocate (TC_CLOSURE, 2);
                        r1[1] = &&FUN__24loop_3307; r1[2] = lenv;
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = (object *) 1;
                        r0[2] = r1;
                        r1 = varref (0, 0);
                        r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3307;
                        fatbar_180_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_179;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_179;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_179;
              }
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_179;
          }
          PXLL_RETURN(0);
          goto fatbar_179_over;
          fatbar_179:
          r0 = (object *) constructed_710[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = varref (0, 1);
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 1);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (1, 1);
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = varref (0, 1);
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = varref (4, 1);
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (5, 1);
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = varref (5, 1);
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = (object *) constructed_710[0];
                                r1 = varref (0, 0);
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = varref (0, 1);
                                  switch (get_case (r0)) {
                                    case (TC_PAIR): {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 1);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = varref (1, 1);
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = varref (0, 1);
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (1, 1);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = varref (1, 1);
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = varref (0, 1);
                                          switch (get_case (r0)) {
                                            case (TC_PAIR): {
                                              r0 = allocate (TC_TUPLE, 3);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = varref (1, 1);
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r1 = varref (1, 1);
                                              r1 = UOBJ_GET(r1,1);
                                              r0[3] = r1;
                                              r0 = varref (0, 1);
                                              switch (get_case (r0)) {
                                                case (TC_NIL): {
                                                  r0 = varref (6, 0);
                                                  switch (get_case (r0)) {
                                                    case (UOTAG(1)): {
                                                      r0 = allocate (TC_TUPLE, 2);
                                                      r0[1] = lenv; lenv = r0;
                                                      r1 = varref (7, 0);
                                                      r1 = UOBJ_GET(r1,0);
                                                      r0[2] = r1;
                                                      r0 = varref (3, 0);
                                                      switch (get_case (r0)) {
                                                        case (UOTAG(1)): {
                                                          r0 = allocate (TC_TUPLE, 2);
                                                          r0[1] = lenv; lenv = r0;
                                                          r1 = varref (4, 0);
                                                          r1 = UOBJ_GET(r1,0);
                                                          r0[2] = r1;
                                                          r0 = varref (0, 0);
                                                          r1 = varref (1, 0);
                                                          r0 = PXLL_TEST(r1==r0);
                                                          lenv = lenv[1];
                                                          r0 = r0;
                                                          r0=r0;
                                                        } break;
                                                        default: {
                                                          lenv = ((object *)lenv)[1];
                                                          goto fatbar_182;
                                                        }
                                                      }
                                                      lenv = lenv[1];
                                                      r0 = r0;
                                                      r0=r0;
                                                    } break;
                                                    default: {
                                                      goto fatbar_182;
                                                    }
                                                  }
                                                  r0=r0;
                                                  goto fatbar_182_over;
                                                  fatbar_182:
                                                  r0 = (object *) 6;
                                                  r0=r0;
                                                  fatbar_182_over: ;
                                                  if PXLL_IS_TRUE(r0) {
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = varref (5, 0);
                                                    r0[2] = r1;
                                                    r1 = varref (1, 0);
                                                    r0[3] = r1;
                                                    r1 = varref (9, 1);
                                                    t = allocate (TC_SAVE, 3);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1041; ; k = t;
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                                    L1041:
                                                    ; lenv = k[2]; k = k[1];
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = varref (4, 0);
                                                    r0[2] = r1;
                                                    r1 = varref (0, 0);
                                                    r0[3] = r1;
                                                    r1 = varref (9, 1);
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                                  } else {
                                                    r0 = allocate (TC_TUPLE, 2);
                                                    r0[1] = lenv; lenv = r0;
                                                    r1 = varref (12, 97);
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1042; t[4] = r0; k = t;
                                                    lenv = r1[2]; goto FUN_new_tvar_455;
                                                    L1042:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[2] = r1;
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = varref (5, 0);
                                                    r0[2] = r1;
                                                    r1 = allocate (TC_TUPLE, 4);
                                                    r2 = varref (3, 0);
                                                    r1[2] = r2;
                                                    r2 = varref (2, 0);
                                                    r1[3] = r2;
                                                    r2 = varref (0, 0);
                                                    r1[4] = r2;
                                                    r2 = varref (12, 98);
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1043; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_460;
                                                    L1043:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[3] = r1;
                                                    r1 = varref (10, 1);
                                                    t = allocate (TC_SAVE, 3);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1044; ; k = t;
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                                    L1044:
                                                    ; lenv = k[2]; k = k[1];
                                                    r0 = allocate (TC_TUPLE, 3);
                                                    r1 = varref (1, 0);
                                                    r0[2] = r1;
                                                    r1 = allocate (TC_TUPLE, 4);
                                                    r2 = varref (7, 0);
                                                    r1[2] = r2;
                                                    r2 = varref (6, 0);
                                                    r1[3] = r2;
                                                    r2 = varref (0, 0);
                                                    r1[4] = r2;
                                                    r2 = varref (12, 98);
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1045; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_460;
                                                    L1045:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[3] = r1;
                                                    r1 = varref (10, 1);
                                                    r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                                  }
                                                  PXLL_RETURN(0);
                                                } break;
                                                default: {
                                                  lenv = ((object ***)lenv)[1][1][1];
                                                  goto fatbar_181;
                                                }
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_181;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_181;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      goto fatbar_181;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } else {
                                  goto fatbar_181;
                                }
                                PXLL_RETURN(0);
                                goto fatbar_181_over;
                                fatbar_181:
                                r0 = (object *) constructed_491[0];
                                r1 = varref (0, 0);
                                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (0, 1);
                                  r1[2] = r2;
                                  r2 = varref (8, 17);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1046; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
                                  L1046:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = varref (2, 0);
                                  r0[3] = r1;
                                  r1 = varref (6, 1);
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1047; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                  L1047:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (5, 1);
                                  r0[2] = r1;
                                  r1 = varref (1, 0);
                                  r0[3] = r1;
                                  r1 = varref (6, 1);
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                } else {
                                  r0 = allocate (TC_TUPLE, 6);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (1, 1);
                                  r1[2] = r2;
                                  r2 = varref (9, 20);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1048; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                                  L1048:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  // def $loop_3326
                                  goto L1049;
                                  FUN__24loop_3326:
                                    check_heap (0);
                                    r0 = varref (2, 1);
                                    r1 = varref (0, 0);
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = varref (0, 1);
                                      r0[2] = r1;
                                      r1 = (object *) constructed_37[0];
                                      r0[3] = r1;
                                      r1 = varref (11, 19);
                                      r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (12, 97);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1050; t[4] = r0; k = t;
                                      lenv = r1[2]; goto FUN_new_tvar_455;
                                      L1050:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r0 = varref (1, 1);
                                      r1 = varref (0, 0);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r1;
                                      t[2] = r0;
                                      r0 = t;
                                      lenv = lenv[1];
                                      r0 = r0;
                                      r1 = (object *) 3;
                                      r2 = varref (0, 0);
                                      r1 = box(unbox(r2)+unbox(r1));
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN__24loop_3326;
                                    }
                                    PXLL_RETURN(0);
                                  L1049:
                                  r2 = allocate (TC_CLOSURE, 2);
                                  r2[1] = &&FUN__24loop_3326; r2[2] = lenv;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object *) 1;
                                  r1[2] = r2;
                                  r2 = (object*)TC_NIL;
                                  r1[3] = r2;
                                  r2 = varref (0, 0);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1051; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3326;
                                  L1051:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[4] = r1;
                                  r1 = varref (0, 0);
                                  r0[5] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  // def $loop_3331
                                  goto L1052;
                                  FUN__24loop_3331:
                                    check_heap (0);
                                    r0 = varref (2, 3);
                                    r1 = varref (0, 0);
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = varref (0, 1);
                                      r0[2] = r1;
                                      r1 = (object *) constructed_37[0];
                                      r0[3] = r1;
                                      r1 = varref (11, 19);
                                      r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (12, 97);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1053; t[4] = r0; k = t;
                                      lenv = r1[2]; goto FUN_new_tvar_455;
                                      L1053:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r0 = varref (1, 1);
                                      r1 = varref (0, 0);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r1;
                                      t[2] = r0;
                                      r0 = t;
                                      lenv = lenv[1];
                                      r0 = r0;
                                      r1 = (object *) 3;
                                      r2 = varref (0, 0);
                                      r1 = box(unbox(r2)+unbox(r1));
                                      lenv[2] = r1;
                                      lenv[3] = r0;
                                      goto FUN__24loop_3331;
                                    }
                                    PXLL_RETURN(0);
                                  L1052:
                                  r2 = allocate (TC_CLOSURE, 2);
                                  r2[1] = &&FUN__24loop_3331; r2[2] = lenv;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = (object *) 1;
                                  r1[2] = r2;
                                  r2 = (object*)TC_NIL;
                                  r1[3] = r2;
                                  r2 = varref (0, 0);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1054; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3331;
                                  L1054:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r0[6] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r2 = varref (0, 2);
                                  r1[3] = r2;
                                  r2 = varref (9, 96);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1055; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1055:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = varref (3, 0);
                                  r0[3] = r1;
                                  r1 = varref (7, 1);
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1056; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                  L1056:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r2 = varref (0, 4);
                                  r1[3] = r2;
                                  r2 = varref (9, 96);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1057; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1057:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = varref (2, 0);
                                  r0[3] = r1;
                                  r1 = varref (7, 1);
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1058; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                  L1058:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 0);
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  // def $loop_3336
                                  goto L1059;
                                  FUN__24loop_3336:
                                    check_heap (0);
                                    r0 = varref (2, 0);
                                    r1 = varref (0, 0);
                                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                      r0 = (object *) 14;
                                      PXLL_RETURN(0);
                                    } else {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = varref (4, 1);
                                      r1[2] = r2;
                                      r2 = varref (0, 0);
                                      r1[3] = r2;
                                      r2 = varref (12, 25);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1060; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                                      L1060:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 4);
                                      r2 = varref (7, 0);
                                      r1[2] = r2;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = varref (3, 2);
                                      r2[2] = r3;
                                      r3 = varref (0, 0);
                                      r2[3] = r3;
                                      r3 = varref (12, 25);
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1061; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                                      L1061:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[3] = r2;
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = varref (3, 4);
                                      r2[2] = r3;
                                      r3 = varref (0, 0);
                                      r2[3] = r3;
                                      r3 = varref (12, 25);
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1062; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                                      L1062:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[4] = r2;
                                      r2 = varref (12, 98);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1063; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_rlabel_460;
                                      L1063:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = varref (10, 1);
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1064; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
                                      L1064:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = (object *) 3;
                                      r1 = varref (0, 0);
                                      r0 = box(unbox(r1)+unbox(r0));
                                      lenv[2] = r0;
                                      goto FUN__24loop_3336;
                                    }
                                    PXLL_RETURN(0);
                                  L1059:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN__24loop_3336; r1[2] = lenv;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = (object *) 1;
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3336;
                                }
                                PXLL_RETURN(0);
                                fatbar_181_over: ;
                                PXLL_RETURN(0);
                              } break;
                              default: {
                                lenv = ((object ****)lenv)[1][1][1][1];
                                goto fatbar_178;
                              }
                            }
                            PXLL_RETURN(0);
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_178;
                          }
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_178;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_178;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_178;
              }
            }
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_178;
          }
          PXLL_RETURN(0);
          fatbar_179_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_178;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_178_over;
      fatbar_178:
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (0, 1);
      r0[3] = r1;
      r1 = varref (1, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_type_error_3267;
      fatbar_178_over: ;
      PXLL_RETURN(0);
    L1029:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN__55_row_3270; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 1);
    r0[2] = r1;
    r1 = varref (1, 2);
    r0[3] = r1;
    r1 = varref (0, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN__55_3268;
  L999:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_unify_532; r1[2] = lenv;
  r0[132] = r1;
  // def apply-subst_533
  goto L1065;
  FUN_apply_subst_533:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def p_3339
    goto L1066;
    FUN_p_3339:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (4, 101);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1067; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type_find_467;
      L1067:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = varref (4, 100);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1068; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_type__3etrec_466;
      L1068:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = varref (0, 1);
      r0 = ((pxll_vector*)r0)->val[2];
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 97);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1069; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_new_tvar_455;
        L1069:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        r1 = varref (1, 1);
        ((pxll_vector*)r1)->val[0] = r0;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } else {
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = varref (0, 0);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_708[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            } else {
              goto fatbar_177;
            }
            PXLL_RETURN(0);
            goto fatbar_177_over;
            fatbar_177:
            r0 = (object *) 262;
            r1 = varref (1, 1);
            ((pxll_vector*)r1)->val[2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (4, 0);
            r2[2] = r3;
            r3 = varref (1, 1);
            r2[3] = r3;
            r3 = varref (6, 30);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1070; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
            L1070:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = varref (6, 96);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1071; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
            L1071:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = varref (2, 1);
            ((pxll_vector*)r1)->val[2] = r0;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 1);
            r1 = ((pxll_vector*)r1)->val[0];
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object *) constructed_708[0];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r1[1] = lenv; lenv = r1;
                r2 = (object*)TC_NIL;
                r1[2] = r2;
                r2 = varref (0, 0);
                r3 = varref (3, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[3] = r2;
                r1 = varref (0, 1);
                r2 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[3] = r1;
                r1 = varref (8, 96);
                r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
              } break;
              default: {
                r0 = varref (1, 0);
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
            fatbar_177_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1066:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_p_3339; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_p_3339;
  L1065:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_apply_subst_533; r1[2] = lenv;
  r0[133] = r1;
  // def build-dependency-graph_538
  goto L1072;
  FUN_build_dependency_graph_538:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 183);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1073; t[4] = r0; k = t;
    lenv = r1[2]; goto *r1[1];
    L1073:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def search_3749
    goto L1074;
    FUN_search_3749:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (2, 1);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (2, 1);
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (2, 1);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (2, 1);
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1075; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1075:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (2, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = varref (6, 17);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1076; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
          L1076:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[3] = r1;
          r1 = varref (3, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_search_3749;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (7, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1077; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L1077:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def $loop_3757
          goto L1078;
          FUN__24loop_3757:
            check_heap (0);
            r0 = varref (2, 0);
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (4, 0);
              r1[2] = r2;
              r2 = varref (1, 0);
              r1[3] = r2;
              r2 = varref (10, 25);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1079; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
              L1079:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (6, 0);
              r2 = ((pxll_vector*)r2)->val[3];
              r1[2] = r2;
              r2 = varref (1, 0);
              r1[3] = r2;
              r2 = varref (10, 25);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1080; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
              L1080:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = (object *) constructed_706[0];
              r1[2] = r2;
              r2 = varref (10, 182);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1081; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L1081:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r1 = varref (8, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (0, 2);
              r0[4] = r1;
              r1 = varref (8, 0);
              r1 = ((pxll_vector*)r1)->val[1];
              r1 = ((pxll_vector*)r1)->val[0];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1082; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1082:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (0, 1);
              r0[2] = r1;
              r1 = varref (0, 2);
              r0[3] = r1;
              r1 = varref (7, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1083; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_search_3749;
              L1083:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = (object *) 3;
              r1 = varref (0, 0);
              r0 = box(unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_3757;
            }
            PXLL_RETURN(0);
          L1078:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN__24loop_3757; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = varref (0, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1084; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3757;
          L1084:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (2, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (0, 0);
          r2[2] = r3;
          r3 = varref (6, 20);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1085; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
          L1085:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1086; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L1086:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[3] = r1;
          r1 = varref (3, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_search_3749;
        } break;
        default: {
          goto fatbar_176;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_176_over;
      fatbar_176:
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_24103
      goto L1087;
      FUN_lambda_24103:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 1);
        r0[3] = r1;
        r1 = varref (3, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_search_3749;
      L1087:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_24103; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (5, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      fatbar_176_over: ;
      PXLL_RETURN(0);
    L1074:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_search_3749; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_705[0];
    r1[2] = r2;
    r2 = varref (4, 182);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1088; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1088:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (2, 0);
    r0[2] = r1;
    r1 = (object *) constructed_448[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[4] = r1;
    r1 = varref (2, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1089; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1089:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (3, 0);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1090; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_search_3749;
    L1090:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = varref (1, 0);
    r1 = varref (2, 1);
    ((pxll_vector*)r1)->val[2] = r0;
    PXLL_RETURN(0);
  L1072:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_build_dependency_graph_538; r1[2] = lenv;
  r0[134] = r1;
  // def symbol-add-suffix_547
  goto L1091;
  FUN_symbol_add_suffix_547:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = varref (1, 0);
    r3 = allocate (TC_TUPLE, 2);
    r3[1] = lenv; lenv = r3;
    r4 = varref (2, 0);
    r4 = UOBJ_GET(r4,0);
    r3[2] = r4;
    r3 = varref (0, 0);
    lenv = lenv[1];
    r3 = r3;
    r3=r3;
    r2[2] = r3;
    r3 = (object*)TC_NIL;
    r2[3] = r3;
    r3 = varref (0, 1);
    r4 = varref (1, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = varref (0, 2);
    r3 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (1, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1092; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L1092:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (1, 73);
    r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_422;
  L1091:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_symbol_add_suffix_547; r1[2] = lenv;
  r0[135] = r1;
  // def do-simple-optimizations_550
  goto L1093;
  FUN_do_simple_optimizations_550:
    check_heap (0);
    r0 = (object *) 1;
    varset (1, 185, r0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4017
    goto L1094;
    FUN_loop_4017:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 5);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = varref (5, 185);
      r3[2] = r4;
      r4 = varref (5, 54);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L1095; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L1095:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = (object*)TC_NIL;
      r2[3] = r3;
      r3 = varref (0, 1);
      r4 = (object*) &constructed_704;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[4] = r3;
      r3 = varref (0, 2);
      r4 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r2 = varref (0, 3);
      r3 = (object*) &constructed_703;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (4, 45);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1096; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L1096:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      r0 = box(((pxll_string*)(r0))->len);
      r1 = varref (0, 0);
      r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (4, 185);
      r0[2] = r1;
      r0 = (object *) 1;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(unbox(r1)>unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 1;
        varset (3, 185, r0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (3, 135);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1097; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_simpleopt_551;
        L1097:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv[2] = r0;
        goto FUN_loop_4017;
      } else {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1094:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4017; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 135);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1098; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
    L1098:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4017;
  L1093:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_do_simple_optimizations_550; r1[2] = lenv;
  r0[136] = r1;
  // def simpleopt_551
  goto L1099;
  FUN_simpleopt_551:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_26633
    goto L1100;
    FUN_lambda_26633:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (3, 185);
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = (object *) 3;
      r0 = box(unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      varset (2, 185, r0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = varref (4, 0);
              r3 = ((pxll_vector*)r3)->val[3];
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (0, 0);
              r2[2] = r3;
              r3 = varref (5, 17);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1101; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
              L1101:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (4, 135);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1102; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
              L1102:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (2, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1103; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1103:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r0=r0;
            } break;
            default: {
              goto fatbar_169;
            }
          }
          r0=r0;
          goto fatbar_169_over;
          fatbar_169:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (4, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = varref (5, 116);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1104; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
          L1104:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[3];
              r0[5] = r1;
              r0 = varref (0, 2);
              switch (get_case (r0)) {
                case (UOTAG(10)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 2);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (1, 3);
                  r1[2] = r2;
                  r2 = varref (7, 116);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1105; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
                  L1105:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  switch (get_case_noint (r0)) {
                    default: {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = varref (4, 0);
                      r4[2] = r5;
                      r5 = (object *) constructed_37[0];
                      r4[3] = r5;
                      r5 = varref (8, 19);
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1106; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                      L1106:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = varref (1, 0);
                      r3[3] = r4;
                      r4 = varref (8, 19);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1107; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                      L1107:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = varref (2, 1);
                      r4[2] = r5;
                      r5 = (object *) constructed_37[0];
                      r4[3] = r5;
                      r5 = varref (8, 19);
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1108; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                      L1108:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = varref (0, 1);
                      r3[3] = r4;
                      r4 = varref (8, 19);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1109; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                      L1109:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = varref (0, 0);
                      r2[4] = r3;
                      r3 = varref (8, 113);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1110; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_node_2ffix_500;
                      L1110:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = varref (8, 135);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1111; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
                      L1111:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = varref (6, 0);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1112; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L1112:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_170;
                }
              }
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
          }
          r0=r0;
          goto fatbar_170_over;
          fatbar_170:
          r0 = (object *) 14;
          r0=r0;
          fatbar_170_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
          fatbar_169_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = varref (4, 0);
              r3 = ((pxll_vector*)r3)->val[3];
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (0, 0);
              r2[2] = r3;
              r3 = varref (5, 17);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1113; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
              L1113:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (4, 135);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1114; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
              L1114:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (2, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1115; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L1115:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r0=r0;
            } break;
            default: {
              goto fatbar_171;
            }
          }
          r0=r0;
          goto fatbar_171_over;
          fatbar_171:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (4, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = varref (5, 116);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1116; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
          L1116:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[3];
              r0[5] = r1;
              r0 = varref (0, 2);
              switch (get_case (r0)) {
                case (UOTAG(9)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 2);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (1, 3);
                  r1[2] = r2;
                  r2 = varref (7, 116);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1117; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
                  L1117:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  switch (get_case_noint (r0)) {
                    default: {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 4);
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = varref (4, 0);
                      r4[2] = r5;
                      r5 = (object *) constructed_37[0];
                      r4[3] = r5;
                      r5 = varref (8, 19);
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1118; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                      L1118:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = varref (1, 0);
                      r3[3] = r4;
                      r4 = varref (8, 19);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1119; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                      L1119:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = allocate (TC_TUPLE, 3);
                      r5 = varref (2, 1);
                      r4[2] = r5;
                      r5 = (object *) constructed_37[0];
                      r4[3] = r5;
                      r5 = varref (8, 19);
                      t = allocate (TC_SAVE, 7);
                      t[1] = k; t[2] = lenv; t[3] = &&L1120; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                      r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                      L1120:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                      r4 = result;
                      r3[2] = r4;
                      r4 = varref (0, 1);
                      r3[3] = r4;
                      r4 = varref (8, 19);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L1121; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                      L1121:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = varref (0, 0);
                      r2[4] = r3;
                      r3 = varref (8, 114);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1122; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_node_2flet_501;
                      L1122:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = varref (8, 135);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1123; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
                      L1123:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = varref (6, 0);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1124; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L1124:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_172;
                }
              }
              r0=r0;
              goto fatbar_172_over;
              fatbar_172:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 1);
              r1[2] = r2;
              r2 = varref (7, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1125; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L1125:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def $loop_4044
              goto L1126;
              FUN__24loop_4044:
                check_heap (0);
                r0 = varref (2, 0);
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                  r0 = (object *) 14;
                  PXLL_RETURN(0);
                } else {
                  r0 = allocate (TC_TUPLE, 4);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 1);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r1[3] = r2;
                  r2 = varref (11, 25);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1127; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                  L1127:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = varref (0, 0);
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[3] = r1;
                  r1 = varref (0, 0);
                  r1 = ((pxll_vector*)r1)->val[3];
                  r0[4] = r1;
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (UOTAG(9)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 2);
                      r1[2] = r2;
                      r2 = varref (12, 116);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1128; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
                      L1128:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case_noint (r0)) {
                        default: {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 4);
                          r3 = allocate (TC_TUPLE, 4);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = varref (10, 0);
                          r4[2] = r5;
                          r5 = (object *) 1;
                          r4[3] = r5;
                          r5 = varref (4, 0);
                          r4[4] = r5;
                          r5 = varref (14, 27);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1129; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_332;
                          L1129:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = allocate (TC_TUPLE, 3);
                          r6 = varref (0, 0);
                          r5[2] = r6;
                          r6 = (object *) constructed_37[0];
                          r5[3] = r6;
                          r6 = varref (14, 19);
                          t = allocate (TC_SAVE, 8);
                          t[1] = k; t[2] = lenv; t[3] = &&L1130; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                          r5[1] = r6[2]; lenv = r5; goto FUN_reverse_onto_320;
                          L1130:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                          r5 = result;
                          r4[2] = r5;
                          r5 = varref (2, 0);
                          r4[3] = r5;
                          r5 = varref (14, 19);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1131; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                          L1131:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = varref (10, 0);
                          r4[2] = r5;
                          r5 = varref (4, 0);
                          r4[3] = r5;
                          r5 = varref (7, 0);
                          r4[4] = r5;
                          r5 = varref (14, 27);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1132; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_332;
                          L1132:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r3 = allocate (TC_TUPLE, 3);
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = varref (0, 1);
                          r4[2] = r5;
                          r5 = (object *) constructed_37[0];
                          r4[3] = r5;
                          r5 = varref (14, 19);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1133; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                          L1133:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = varref (0, 2);
                          r3[3] = r4;
                          r4 = varref (14, 19);
                          t = allocate (TC_SAVE, 6);
                          t[1] = k; t[2] = lenv; t[3] = &&L1134; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                          L1134:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                          r3 = result;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = varref (8, 1);
                          r4[2] = r5;
                          r5 = (object *) 1;
                          r4[3] = r5;
                          r5 = varref (4, 0);
                          r4[4] = r5;
                          r5 = varref (14, 27);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1135; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_332;
                          L1135:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = allocate (TC_TUPLE, 3);
                          r6 = varref (0, 0);
                          r5[2] = r6;
                          r6 = (object *) constructed_37[0];
                          r5[3] = r6;
                          r6 = varref (14, 19);
                          t = allocate (TC_SAVE, 8);
                          t[1] = k; t[2] = lenv; t[3] = &&L1136; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                          r5[1] = r6[2]; lenv = r5; goto FUN_reverse_onto_320;
                          L1136:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                          r5 = result;
                          r4[2] = r5;
                          r5 = varref (1, 1);
                          r4[3] = r5;
                          r5 = varref (14, 19);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1137; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                          L1137:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 4);
                          r5 = varref (8, 1);
                          r4[2] = r5;
                          r5 = (object *) 3;
                          r6 = varref (4, 0);
                          r5 = box(unbox(r6)+unbox(r5));
                          r4[3] = r5;
                          r5 = varref (7, 0);
                          r4[4] = r5;
                          r5 = varref (14, 27);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1138; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_slice_332;
                          L1138:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = varref (0, 2);
                          r5 = varref (1, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = allocate (TC_TUPLE, 3);
                          r4 = allocate (TC_TUPLE, 3);
                          r5 = varref (0, 1);
                          r4[2] = r5;
                          r5 = (object *) constructed_37[0];
                          r4[3] = r5;
                          r5 = varref (14, 19);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L1139; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                          L1139:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = varref (0, 3);
                          r3[3] = r4;
                          r4 = varref (14, 19);
                          t = allocate (TC_SAVE, 6);
                          t[1] = k; t[2] = lenv; t[3] = &&L1140; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                          r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                          L1140:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                          r3 = result;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[3] = r3;
                          r3 = varref (7, 0);
                          r2[4] = r3;
                          r3 = varref (13, 114);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L1141; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_node_2flet_501;
                          L1141:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (13, 135);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1142; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
                          L1142:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = varref (11, 0);
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1143; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          L1143:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = r0;
                          r0=r0;
                        } break;
                      }
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                    default: {
                      goto fatbar_173;
                    }
                  }
                  r0=r0;
                  goto fatbar_173_over;
                  fatbar_173:
                  r0 = (object *) 14;
                  r0=r0;
                  fatbar_173_over: ;
                  lenv = lenv[1];
                  r0 = (object *) 3;
                  r1 = varref (0, 0);
                  r0 = box(unbox(r1)+unbox(r0));
                  lenv[2] = r0;
                  goto FUN__24loop_4044;
                }
                PXLL_RETURN(0);
              L1126:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN__24loop_4044; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r1 = (object *) 1;
              r0[2] = r1;
              r1 = varref (0, 0);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1144; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4044;
              L1144:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = r0;
              lenv = lenv[1];
              r0 = (object *) 14;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
              fatbar_172_over: ;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
          }
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
          fatbar_171_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(6)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 0);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[4] = r1;
              r0 = varref (0, 2);
              switch (get_case (r0)) {
                case (UOTAG(2)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 2);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(5)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = (object *) constructed_47[0];
                      r1 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = varref (2, 1);
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (3, 1);
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = varref (3, 1);
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = varref (0, 1);
                            switch (get_case (r0)) {
                              case (TC_PAIR): {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (1, 1);
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = varref (1, 1);
                                r1 = UOBJ_GET(r1,1);
                                r0[3] = r1;
                                r0 = varref (0, 1);
                                switch (get_case (r0)) {
                                  case (TC_NIL): {
                                    r0 = (object *) constructed_45[0];
                                    r1 = varref (2, 1);
                                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = varref (1, 0);
                                      r1[2] = r2;
                                      r2 = varref (9, 135);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1145; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
                                      L1145:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = varref (7, 0);
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1146; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                      L1146:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = result;
                                      r0=r0;
                                    } else {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r1 = allocate (TC_TUPLE, 2);
                                      r2 = varref (0, 0);
                                      r1[2] = r2;
                                      r2 = varref (9, 135);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1147; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
                                      L1147:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[2] = r1;
                                      r1 = varref (7, 0);
                                      t = allocate (TC_SAVE, 3);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1148; ; k = t;
                                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                      L1148:
                                      ; lenv = k[2]; k = k[1];
                                      r0 = result;
                                      r0=r0;
                                    }
                                    r0=r0;
                                  } break;
                                  default: {
                                    lenv = ((object *****)lenv)[1][1][1][1][1];
                                    goto fatbar_174;
                                  }
                                }
                                lenv = lenv[1];
                                r0 = r0;
                                r0=r0;
                              } break;
                              default: {
                                lenv = ((object ****)lenv)[1][1][1][1];
                                goto fatbar_174;
                              }
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            lenv = ((object ***)lenv)[1][1][1];
                            goto fatbar_174;
                          }
                        }
                        r0=r0;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_174;
                      }
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_174;
                    }
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_174;
                }
              }
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            default: {
              goto fatbar_174;
            }
          }
          r0=r0;
          goto fatbar_174_over;
          fatbar_174:
          r0 = (object *) 14;
          r0=r0;
          fatbar_174_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UITAG(5)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (3, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = varref (4, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1149; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L1149:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = (object *) 3;
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (2, 0);
            r3 = ((pxll_vector*)r3)->val[3];
            r2[2] = r3;
            r3 = (object *) 1;
            r2[3] = r3;
            r3 = varref (3, 25);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1150; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
            L1150:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (3, 135);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1151; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
            L1151:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = varref (1, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1152; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L1152:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 0);
            r1 = ((pxll_vector*)r1)->val[3];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (4, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1153; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L1153:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_4067
            goto L1154;
            FUN__24loop_4067:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (4, 0);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (8, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1155; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1155:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (0, 0);
                r1 = ((pxll_vector*)r1)->val[4];
                r0[3] = r1;
                r1 = varref (0, 0);
                r1 = ((pxll_vector*)r1)->val[3];
                r0[4] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (UITAG(5)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = allocate (TC_TUPLE, 5);
                    r2[1] = lenv; lenv = r2;
                    r3 = allocate (TC_TUPLE, 4);
                    r4 = varref (5, 0);
                    r3[2] = r4;
                    r4 = (object *) 1;
                    r3[3] = r4;
                    r4 = varref (2, 0);
                    r3[4] = r4;
                    r4 = varref (9, 27);
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1156; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_slice_332;
                    L1156:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[2] = r3;
                    r3 = allocate (TC_TUPLE, 3);
                    r4 = allocate (TC_TUPLE, 3);
                    r5 = varref (0, 0);
                    r4[2] = r5;
                    r5 = (object *) constructed_37[0];
                    r4[3] = r5;
                    r5 = varref (9, 19);
                    t = allocate (TC_SAVE, 7);
                    t[1] = k; t[2] = lenv; t[3] = &&L1157; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                    r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                    L1157:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                    r4 = result;
                    r3[2] = r4;
                    r4 = varref (1, 2);
                    r3[3] = r4;
                    r4 = varref (9, 19);
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1158; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                    L1158:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[3] = r3;
                    r3 = allocate (TC_TUPLE, 4);
                    r4 = varref (5, 0);
                    r3[2] = r4;
                    r4 = varref (2, 0);
                    r5 = (object *) 3;
                    r4 = box(unbox(r5)+unbox(r4));
                    r3[3] = r4;
                    r4 = varref (5, 1);
                    r3[4] = r4;
                    r4 = varref (9, 27);
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1159; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_slice_332;
                    L1159:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[4] = r3;
                    r3 = allocate (TC_TUPLE, 3);
                    r4 = allocate (TC_TUPLE, 3);
                    r5 = varref (0, 1);
                    r4[2] = r5;
                    r5 = (object *) constructed_37[0];
                    r4[3] = r5;
                    r5 = varref (9, 19);
                    t = allocate (TC_SAVE, 7);
                    t[1] = k; t[2] = lenv; t[3] = &&L1160; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                    r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
                    L1160:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                    r4 = result;
                    r3[2] = r4;
                    r4 = varref (0, 2);
                    r3[3] = r4;
                    r4 = varref (9, 19);
                    t = allocate (TC_SAVE, 6);
                    t[1] = k; t[2] = lenv; t[3] = &&L1161; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                    r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                    L1161:
                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                    r3 = result;
                    r2[5] = r3;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = (object*)UITAG(5);
                    r2[2] = r3;
                    r3 = varref (0, 3);
                    r2[3] = r3;
                    r3 = varref (9, 110);
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1162; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_make_node_488;
                    L1162:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    lenv = lenv[1];
                    r2 = r2;
                    r1[2] = r2;
                    r2 = varref (8, 135);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1163; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_simpleopt_551;
                    L1163:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (6, 0);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1164; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto *r1[1];
                    L1164:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                    r0=r0;
                  } break;
                  default: {
                    goto fatbar_175;
                  }
                }
                r0=r0;
                goto fatbar_175_over;
                fatbar_175:
                r0 = (object *) 14;
                r0=r0;
                fatbar_175_over: ;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4067;
              }
              PXLL_RETURN(0);
            L1154:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_4067; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1165; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4067;
            L1165:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = (object *) 14;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          }
          r0=r0;
        } break;
        default: {
          goto fatbar_168;
        }
      }
      r0=r0;
      goto fatbar_168_over;
      fatbar_168:
      r0 = (object *) 14;
      r0=r0;
      fatbar_168_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (3, 185);
      r0[2] = r1;
      r0 = (object *) 3;
      r1 = varref (0, 0);
      r0 = box(unbox(r1)-unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      varset (2, 185, r0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (3, 135);
      r1[2] = r2;
      r2 = varref (2, 0);
      r2 = ((pxll_vector*)r2)->val[3];
      r1[3] = r2;
      r2 = varref (3, 30);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1166; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
      L1166:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = varref (2, 0);
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = varref (2, 0);
      PXLL_RETURN(0);
    L1100:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_26633; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (1, 14);
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_307;
  L1099:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_simpleopt_551; r1[2] = lenv;
  r0[137] = r1;
  // def do-one-round_554
  goto L1167;
  FUN_do_one_round_554:
    check_heap (0);
    r0 = (object*)UITAG(2);
    r1 = varref (0, 1);
    ((pxll_vector*)r1)->val[14] = r0;
    r0 = (object*)UITAG(2);
    r1 = varref (0, 1);
    ((pxll_vector*)r1)->val[3] = r0;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[3] = r1;
    r1 = varref (1, 6);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1168; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_260;
    L1168:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_448[0];
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[3] = r1;
    r1 = varref (1, 5);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1169; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_add_var_259;
    L1169:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def walk_3827_i2918_i2921
    goto L1170;
    FUN_walk_3827_i2918_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(8)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (2, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = varref (5, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1171; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L1171:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (5, 1);
              r1[2] = r2;
              r2 = varref (0, 0);
              r1[3] = r2;
              r2 = varref (6, 3);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1172; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
              L1172:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (0, 0);
              r0[2] = r1;
              r1 = varref (3, 1);
              r0[3] = r1;
              r1 = varref (6, 23);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1173; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_328;
              L1173:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = ((pxll_vector*)r1)->val[1];
                r0[2] = r1;
                r0 = varref (7, 142);
                r1 = varref (0, 0);
                r0 = box(unbox(r1)|(1<<unbox(r0)));
                lenv = lenv[1];
                r0 = r0;
                r1 = varref (0, 1);
                ((pxll_vector*)r1)->val[1] = r0;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (4, 0);
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = varref (7, 179);
                r1 = varref (0, 0);
                r0 = box(unbox(r1)|(1<<unbox(r0)));
                lenv = lenv[1];
                r0 = r0;
                r1 = varref (3, 0);
                ((pxll_vector*)r1)->val[0] = r0;
              } else {
                r0 = (object *) 14;
              }
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = ((pxll_vector*)r1)->val[0];
              r0[2] = r1;
              r0 = varref (0, 0);
              r1 = (object *) 3;
              r0 = box(unbox(r1)+unbox(r0));
              lenv = lenv[1];
              r0 = r0;
              r1 = varref (0, 1);
              ((pxll_vector*)r1)->val[0] = r0;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            default: {
              goto fatbar_167;
            }
          }
          r0=r0;
          goto fatbar_167_over;
          fatbar_167:
          r0 = (object *) 14;
          r0=r0;
          fatbar_167_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
          r0 = allocate (TC_TUPLE, 5);
          r1 = varref (4, 1);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = varref (5, 74);
          r0[3] = r1;
          r1 = varref (0, 0);
          r0[4] = r1;
          r1 = varref (2, 0);
          r0[5] = r1;
          r1 = varref (5, 69);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1174; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
          L1174:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          r1 = varref (4, 1);
          ((pxll_vector*)r1)->val[3] = r0;
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (4, 1);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (5, 144);
          r0[4] = r1;
          r1 = varref (5, 4);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1175; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
          L1175:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_166;
        }
      }
      r0=r0;
      goto fatbar_166_over;
      fatbar_166:
      r0 = (object *) 14;
      r0=r0;
      fatbar_166_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_24778_i2918_i2921
      goto L1176;
      FUN_lambda_24778_i2918_i2921:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (2, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_walk_3827_i2918_i2921;
      L1176:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_24778_i2918_i2921; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (0, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (3, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L1170:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3827_i2918_i2921; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = (object *) constructed_702[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1177; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3827_i2918_i2921;
    L1177:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def add-ref_3844_i2919_i2921
    goto L1178;
    FUN_add_ref_3844_i2919_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (3, 1);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (4, 3);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1179; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
      L1179:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = (object *) 3;
      r0 = box(unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      r1 = varref (0, 0);
      ((pxll_vector*)r1)->val[3] = r0;
      PXLL_RETURN(0);
    L1178:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_ref_3844_i2919_i2921; r1[2] = lenv;
    r0[2] = r1;
    // def add-set_3845_i2919_i2921
    goto L1180;
    FUN_add_set_3845_i2919_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (3, 1);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (4, 3);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1181; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
      L1181:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = (object *) 3;
      r0 = box(unbox(r1)+unbox(r0));
      lenv = lenv[1];
      r0 = r0;
      r1 = varref (0, 0);
      ((pxll_vector*)r1)->val[4] = r0;
      PXLL_RETURN(0);
    L1180:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_add_set_3845_i2919_i2921; r1[2] = lenv;
    r0[3] = r1;
    // def walk_3846_i2919_i2921
    goto L1182;
    FUN_walk_3846_i2919_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (4, 1);
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 3);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1183; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
          L1183:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = (object *) 3;
          r0 = box(unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (0, 1);
          ((pxll_vector*)r1)->val[3] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (4, 1);
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 3);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1184; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
          L1184:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = ((pxll_vector*)r1)->val[4];
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = (object *) 3;
          r0 = box(unbox(r1)+unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (0, 1);
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_165;
        }
      }
      r0=r0;
      goto fatbar_165_over;
      fatbar_165:
      r0 = (object *) 14;
      r0=r0;
      fatbar_165_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (1, 2);
      r0[2] = r1;
      r1 = varref (0, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (3, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L1182:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3846_i2919_i2921; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 2);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1185; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3846_i2919_i2921;
    L1185:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_701[0];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    // def find-escaping-functions_3989_i2920_i2921
    goto L1186;
    FUN_find_escaping_functions_3989_i2920_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (2, 1);
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (UOTAG(10)): {
              r0 = (object *) 14;
              r0=r0;
            } break;
            default: {
              goto fatbar_163;
            }
          }
          r0=r0;
          goto fatbar_163_over;
          fatbar_163:
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (5, 1);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (6, 143);
          r0[4] = r1;
          r1 = varref (6, 4);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1187; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
          L1187:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 0);
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (4, 0, r0);
          r0=r0;
          fatbar_163_over: ;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 1);
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (7, 3);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1188; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
          L1188:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[1];
          r0[3] = r1;
          r0 = varref (7, 144);
          r1 = varref (0, 1);
          r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 1);
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UITAG(8)): {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = varref (4, 1);
                r1 = ((pxll_vector*)r1)->val[3];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (0, 0);
                r1[2] = r2;
                r2 = varref (8, 17);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1189; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
                L1189:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = varref (4, 0);
                r2 = varref (0, 1);
                r1 = PXLL_TEST(r2==r1);
                r0[4] = r1;
                r0 = (object *) 6;
                r1 = varref (0, 2);
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = varref (6, 1);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r0[3] = r1;
                  r1 = varref (7, 143);
                  r0[4] = r1;
                  r1 = varref (7, 4);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1190; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
                  L1190:
                  ; lenv = k[2]; k = k[1];
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (6, 0);
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  r1 = varref (2, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  varset (5, 0, r0);
                  r0=r0;
                } else {
                  r0 = (object *) 14;
                  r0=r0;
                }
                r0=r0;
              } break;
              default: {
                goto fatbar_164;
              }
            }
            r0=r0;
            goto fatbar_164_over;
            fatbar_164:
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (6, 1);
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (7, 143);
            r0[4] = r1;
            r1 = varref (7, 4);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1191; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
            L1191:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 0);
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (2, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (5, 0, r0);
            r0=r0;
            fatbar_164_over: ;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } else {
            r0 = (object *) 14;
            r0=r0;
          }
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_162;
        }
      }
      r0=r0;
      goto fatbar_162_over;
      fatbar_162:
      r0 = (object *) 14;
      r0=r0;
      fatbar_162_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_25967_i2920_i2921
      goto L1192;
      FUN_lambda_25967_i2920_i2921:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r0[3] = r1;
        r1 = varref (2, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_functions_3989_i2920_i2921;
      L1192:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_25967_i2920_i2921; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (0, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (4, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L1186:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_escaping_functions_3989_i2920_i2921; r1[2] = lenv;
    r0[2] = r1;
    // def maybe-var-escapes_3990_i2920_i2921
    goto L1193;
    FUN_maybe_var_escapes_3990_i2920_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (1, 1);
      r1[3] = r2;
      r2 = varref (5, 23);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1194; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_328;
      L1194:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 6;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (3, 1);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (4, 143);
        r0[4] = r1;
        r1 = varref (4, 4);
        r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
      } else {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1193:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_maybe_var_escapes_3990_i2920_i2921; r1[2] = lenv;
    r0[3] = r1;
    // def find-escaping-variables_3991_i2920_i2921
    goto L1195;
    FUN_find_escaping_variables_3991_i2920_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (7, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1196; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1196:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (7, 19);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1197; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          L1197:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (7, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1198; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1198:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (7, 19);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1199; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          L1199:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (7, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1200; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1200:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (7, 19);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1201; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          L1201:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1202; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_maybe_var_escapes_3990_i2920_i2921;
          L1202:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1203; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_maybe_var_escapes_3990_i2920_i2921;
          L1203:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_161;
        }
      }
      r0=r0;
      goto fatbar_161_over;
      fatbar_161:
      r0 = (object *) 14;
      r0=r0;
      fatbar_161_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_26052_i2920_i2921
      goto L1204;
      FUN_lambda_26052_i2920_i2921:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (2, 2);
        r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_variables_3991_i2920_i2921;
      L1204:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_26052_i2920_i2921; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (0, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (4, 33);
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L1195:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_escaping_variables_3991_i2920_i2921; r1[2] = lenv;
    r0[4] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (2, 0);
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = (object *) 1;
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (0, 0);
    t = alloc_no_clear (UOTAG(2),1);
    t[1] = r2;
    r2 = t;
    r1[2] = r2;
    r2 = (object *) constructed_700[0];
    r1[3] = r2;
    r2 = varref (4, 110);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1205; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
    L1205:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = varref (0, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1206; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_functions_3989_i2920_i2921;
    L1206:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_26096_i2920_i2921
    goto L1207;
    FUN_lambda_26096_i2920_i2921:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 4);
      r2 = varref (4, 1);
      r2 = ((pxll_vector*)r2)->val[3];
      r1[2] = r2;
      r2 = varref (5, 74);
      r1[3] = r2;
      r2 = varref (1, 0);
      r1[4] = r2;
      r2 = varref (5, 70);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1208; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
      L1208:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (0, 0);
      switch (get_case (r1)) {
        case (UOTAG(0)): {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_699;
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1209; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1209:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
        } break;
      }
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (0, 1);
      r0[2] = r1;
      r1 = (object *) constructed_698[0];
      r0[3] = r1;
      r1 = varref (2, 2);
      r0[1] = r1[2]; lenv = r0; goto FUN_find_escaping_variables_3991_i2920_i2921;
    L1207:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_26096_i2920_i2921; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (1, 0);
    r0[3] = r1;
    r1 = varref (3, 33);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1210; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L1210:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    lenv = lenv[1];
    r0 = r0;
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[3] = r1;
    r1 = varref (1, 132);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1211; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_build_dependency_graph_538;
    L1211:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 5);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 3);
    r3[1] = lenv; lenv = r3;
    r4 = varref (2, 1);
    r4 = ((pxll_vector*)r4)->val[2];
    r3[2] = r4;
    r4 = allocate (TC_TUPLE, 2);
    r5 = (object *) constructed_697[0];
    r4[2] = r5;
    r5 = varref (3, 182);
    t = allocate (TC_SAVE, 7);
    t[1] = k; t[2] = lenv; t[3] = &&L1212; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
    r4[1] = r5[2]; lenv = r4; goto *r5[1];
    L1212:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
    r4 = result;
    r3[3] = r4;
    r3 = allocate (TC_TUPLE, 3);
    r3[1] = lenv; lenv = r3;
    // def walk_4077_i2923
    goto L1213;
    FUN_walk_4077_i2923:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (3, 0);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (3, 0);
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1214; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1214:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (4, 1);
          r0[2] = r1;
          r1 = varref (2, 0);
          r0[3] = r1;
          r1 = varref (4, 1);
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1215; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1215:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_26674_i2923
          goto L1216;
          FUN_lambda_26674_i2923:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (6, 1);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (6, 1);
            r2 = ((pxll_vector*)r2)->val[1];
            r2 = ((pxll_vector*)r2)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1217; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L1217:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r1 = varref (0, 0);
              r0[2] = r1;
              r1 = varref (4, 0);
              r0[1] = r1[2]; lenv = r0; goto FUN_walk_4077_i2923;
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          L1216:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_26674_i2923; r1[2] = lenv;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (0, 0);
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,49)];
          r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1218; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1218:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = varref (7, 33);
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        } break;
      }
      PXLL_RETURN(0);
    L1213:
    r4 = allocate (TC_CLOSURE, 2);
    r4[1] = &&FUN_walk_4077_i2923; r4[2] = lenv;
    r3[2] = r4;
    // def trim_4078_i2923
    goto L1219;
    FUN_trim_4078_i2923:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r1 = varref (0, 0);
      switch (get_case (r1)) {
        case (UOTAG(10)): {
          r1 = allocate (TC_TUPLE, 5);
          r1[1] = lenv; lenv = r1;
          r2 = varref (1, 0);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (0, 0);
          r2[2] = r3;
          r3 = varref (7, 20);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1220; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
          L1220:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (2, 0);
          r2 = ((pxll_vector*)r2)->val[3];
          r1[4] = r2;
          r2 = (object *) constructed_696[0];
          r1[5] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (1, 1);
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def $loop_4090_i2923
          goto L1221;
          FUN__24loop_4090_i2923:
            check_heap (0);
            r0 = varref (2, 0);
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (8, 1);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (4, 0);
              r2[2] = r3;
              r3 = varref (1, 0);
              r2[3] = r3;
              r3 = varref (11, 25);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1222; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
              L1222:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = varref (8, 1);
              r2 = ((pxll_vector*)r2)->val[1];
              r2 = ((pxll_vector*)r2)->val[2];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1223; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L1223:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = (object *) 6;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (4, 3);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (3, 3, r0);
              } else {
                r0 = (object *) 14;
              }
              r0 = (object *) 3;
              r1 = varref (0, 0);
              r0 = box(unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_4090_i2923;
            }
            PXLL_RETURN(0);
          L1221:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN__24loop_4090_i2923; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = varref (0, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1224; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4090_i2923;
          L1224:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          lenv = lenv[1];
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (1, 3);
          r1[2] = r2;
          r1 = varref (0, 0);
          switch (get_case (r1)) {
            case (TC_NIL): {
              r1 = (object *) 262;
              r1=r1;
            } break;
            default: {
              goto fatbar_160;
            }
          }
          r1=r1;
          goto fatbar_160_over;
          fatbar_160:
          r1 = (object *) 6;
          r1=r1;
          fatbar_160_over: ;
          lenv = lenv[1];
          r1 = r1;
          if PXLL_IS_TRUE(r1) {
            r1 = varref (2, 0);
            r1=r1;
          } else {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = (object *) constructed_695[0];
            r1[2] = r2;
            r2 = (object *) constructed_694[0];
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 3);
            // def lambda_26755_i2923
            goto L1225;
            FUN_lambda_26755_i2923:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (2, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (9, 25);
              r0[1] = r1[2]; lenv = r0; goto FUN_nth_330;
            L1225:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN_lambda_26755_i2923; r3[2] = lenv;
            r2[2] = r3;
            r3 = varref (1, 3);
            r2[3] = r3;
            r3 = varref (8, 30);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1226; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
            L1226:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 1);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4097_i2923
            goto L1227;
            FUN__24loop_4097_i2923:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (1, 0);
                r1[2] = r2;
                r2 = varref (5, 3);
                r1[3] = r2;
                r2 = varref (12, 23);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1228; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_328;
                L1228:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = (object *) 6;
                r1 = varref (0, 0);
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 0);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r1[3] = r2;
                  r2 = varref (12, 25);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1229; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                  L1229:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = varref (4, 0);
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  r1 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  varset (3, 0, r0);
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (5, 2);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r1[3] = r2;
                  r2 = varref (12, 25);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1230; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                  L1230:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = varref (4, 1);
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  r1 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  varset (3, 1, r0);
                } else {
                  r0 = (object *) 14;
                }
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4097_i2923;
              }
              PXLL_RETURN(0);
            L1227:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4097_i2923; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = varref (0, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1231; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4097_i2923;
            L1231:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 4);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 0);
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (9, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1232; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L1232:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 1);
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (9, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1233; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L1233:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 21);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1234; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_last_326;
            L1234:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r2 = varref (8, 113);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1235; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_node_2ffix_500;
            L1235:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          }
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
        default: {
          goto fatbar_159;
        }
      }
      r1=r1;
      goto fatbar_159_over;
      fatbar_159:
      r1 = varref (1, 0);
      r1=r1;
      fatbar_159_over: ;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (2, 1);
      r0[2] = r1;
      r1 = varref (0, 1);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (6, 30);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1236; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_map_335;
      L1236:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = varref (0, 1);
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = varref (0, 1);
      PXLL_RETURN(0);
    L1219:
    r4 = allocate (TC_CLOSURE, 2);
    r4[1] = &&FUN_trim_4078_i2923; r4[2] = lenv;
    r3[3] = r4;
    r3 = allocate (TC_TUPLE, 2);
    r4 = (object *) constructed_448[0];
    r3[2] = r4;
    r4 = varref (0, 0);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1237; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_walk_4077_i2923;
    L1237:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (3, 0);
    r3[2] = r4;
    r4 = varref (0, 1);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1238; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_trim_4078_i2923;
    L1238:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    lenv = lenv[1];
    r3 = r3;
    lenv = lenv[1];
    r3 = r3;
    r2[2] = r3;
    r3 = varref (2, 134);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1239; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_do_simple_optimizations_550;
    L1239:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = (object *) 1;
    r2[2] = r3;
    r3 = varref (2, 105);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1240; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
    L1240:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = allocate (TC_TUPLE, 2);
    r3 = (object *) 1;
    r2[2] = r3;
    r3 = varref (2, 105);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1241; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
    L1241:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[4] = r2;
    r2 = (object*)UITAG(0);
    r1[5] = r2;
    r1 = allocate (TC_TUPLE, 7);
    r1[1] = lenv; lenv = r1;
    // def set-multiplier_3862_i2922
    goto L1242;
    FUN_set_multiplier_3862_i2922:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (4, 1);
      r1 = ((pxll_vector*)r1)->val[2];
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (0, 0);
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1243; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1243:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          // def lambda_24960_i2922
          goto L1244;
          FUN_lambda_24960_i2922:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (6, 3);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (8, 64);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1245; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L1245:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (7, 3);
                r0[2] = r1;
                r0 = varref (5, 1);
                r1 = varref (0, 0);
                r2 = varref (2, 0);
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (6, 3, r0);
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L1244:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_24960_i2922; r1[2] = lenv;
          r0[3] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,49)];
          r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,30)];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1242:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_set_multiplier_3862_i2922; r2[2] = lenv;
    r1[2] = r2;
    // def follow-aliases_3863_i2922
    goto L1246;
    FUN_follow_aliases_3863_i2922:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (1, 0);
      r1[2] = r2;
      r2 = varref (1, 1);
      r1[3] = r2;
      r2 = varref (5, 64);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1247; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L1247:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (3, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (4, 1);
              r0[1] = r1[2]; lenv = r0; goto FUN_follow_aliases_3863_i2922;
            } break;
            default: {
              goto fatbar_158;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_158_over;
          fatbar_158:
          r0 = varref (0, 0);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
          fatbar_158_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1246:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_follow_aliases_3863_i2922; r2[2] = lenv;
    r1[3] = r2;
    // def get-fun-calls_3864_i2922
    goto L1248;
    FUN_get_fun_calls_3864_i2922:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (3, 3);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (5, 64);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1249; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
      L1249:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (2, 1);
          r1 = varref (0, 0);
          r0 = box(unbox(r1)*unbox(r0));
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = varref (1, 1);
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1248:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_get_fun_calls_3864_i2922; r2[2] = lenv;
    r1[4] = r2;
    // def inline_3865_i2922
    goto L1250;
    FUN_inline_3865_i2922:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_25242_i2922
      goto L1251;
      FUN_lambda_25242_i2922:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[4];
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (7, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1252; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L1252:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_3893_i2922
            goto L1253;
            FUN__24loop_3893_i2922:
              check_heap (0);
              r0 = varref (2, 1);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (3, 0);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (10, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1254; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1254:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (6, 0);
                r2 = ((pxll_vector*)r2)->val[3];
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (10, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1255; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1255:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = varref (6, 1);
                r0[4] = r1;
                r0 = varref (0, 1);
                r1 = varref (0, 2);
                r2 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (5, 1, r0);
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_3893_i2922;
              }
              PXLL_RETURN(0);
            L1253:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_3893_i2922; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1256; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3893_i2922;
            L1256:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UITAG(8)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 0);
            r1 = ((pxll_vector*)r1)->val[3];
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = (object*) &constructed_69;
                r0 = box(((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_69;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_68;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_68;
                r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                r0=r0;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r1 = varref (0, 0);
                r1 = ((pxll_vector*)r1)->val[4];
                r0[4] = r1;
                r0 = varref (0, 2);
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 2);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (5, 1);
                    r1[2] = r2;
                    r2 = varref (0, 0);
                    r1[3] = r2;
                    r2 = varref (6, 1);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1257; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_follow_aliases_3863_i2922;
                    L1257:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r0 = varref (0, 1);
                    switch (get_case (r0)) {
                      case (UITAG(1)): {
                        r0 = (object *) 14;
                        r0=r0;
                      } break;
                      default: {
                        r0 = allocate (TC_TUPLE, 8);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 1);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = varref (9, 1);
                        r1[2] = r2;
                        r2 = varref (1, 0);
                        r1[3] = r2;
                        r2 = varref (10, 3);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1258; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
                        L1258:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[3] = r1;
                        r1 = varref (0, 1);
                        r1 = ((pxll_vector*)r1)->val[1];
                        r0[4] = r1;
                        r1 = varref (10, 143);
                        r2 = varref (0, 2);
                        r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                        r0[5] = r1;
                        r1 = varref (0, 1);
                        r1 = ((pxll_vector*)r1)->val[1];
                        r0[6] = r1;
                        r1 = varref (10, 142);
                        r2 = varref (0, 4);
                        r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                        r0[7] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = varref (1, 0);
                        r1[2] = r2;
                        r2 = varref (0, 1);
                        r2 = ((pxll_vector*)r2)->val[0];
                        r1[3] = r2;
                        r2 = varref (7, 2);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1259; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_fun_calls_3864_i2922;
                        L1259:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[8] = r1;
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,67)];
                        r0[2] = r1;
                        r0 = varref (0, 0);
                        switch (get_case (r0)) {
                          case (UOTAG(7)): {
                            r0 = (object *) 262;
                            r0=r0;
                          } break;
                          default: {
                            goto fatbar_157;
                          }
                        }
                        r0=r0;
                        goto fatbar_157_over;
                        fatbar_157:
                        r0 = (object *) 6;
                        r0=r0;
                        fatbar_157_over: ;
                        lenv = lenv[1];
                        r0 = r0;
                        if PXLL_IS_TRUE(r0) {
                          r0 = allocate (TC_TUPLE, 4);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 0);
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (3, 0);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = varref (0, 0);
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                          r0[2] = r1;
                          r1 = (object *) 1;
                          r2 = varref (0, 0);
                          range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
                          r1 = (object *) 1;
                          r2 = varref (0, 0);
                          r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
                          r0[3] = r1;
                          r1 = (object *) 24066;
                          r2 = varref (0, 1);
                          r1 = PXLL_TEST(r2==r1);
                          r0[4] = r1;
                          r0 = (object *) 6;
                          r1 = varref (0, 2);
                          r0 = PXLL_TEST(r1==r0);
                          lenv = lenv[1];
                          r0 = r0;
                          if PXLL_IS_TRUE(r0) {
                            r0 = (object *) 1;
                            r1 = varref (0, 6);
                            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,65)];
                              r0[2] = r1;
                              r0 = varref (11, 184);
                              r1 = varref (0, 0);
                              r0 = PXLL_TEST(unbox(r1)<=unbox(r0));
                              lenv = lenv[1];
                              r0 = r0;
                              if PXLL_IS_TRUE(r0) {
                                r0 = (object *) 262;
                                r0=r0;
                              } else {
                                r0 = (object *) 3;
                                r1 = varref (0, 6);
                                if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                                  r0 = (object *) 6;
                                  r1 = varref (0, 3);
                                  r0 = PXLL_TEST(r1==r0);
                                  r0=r0;
                                } else {
                                  r0 = (object *) 6;
                                  r0=r0;
                                }
                                r0=r0;
                              }
                              if PXLL_IS_TRUE(r0) {
                                r0 = (object *) 6;
                                r1 = varref (0, 5);
                                r0 = PXLL_TEST(r1==r0);
                                r0=r0;
                              } else {
                                r0 = (object *) 6;
                                r0=r0;
                              }
                              r0=r0;
                            } else {
                              r0 = (object *) 6;
                              r0=r0;
                            }
                            r0=r0;
                          } else {
                            r0 = (object *) 6;
                            r0=r0;
                          }
                          r0=r0;
                        } else {
                          r0 = (object *) 6;
                          r0=r0;
                        }
                        if PXLL_IS_TRUE(r0) {
                          r0 = (object *) 3;
                          r1 = varref (0, 6);
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                            r0 = allocate (TC_TUPLE, 3);
                            r1 = varref (1, 0);
                            r0[2] = r1;
                            r1 = varref (0, 6);
                            r0[3] = r1;
                            r1 = varref (7, 0);
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L1260; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto FUN_set_multiplier_3862_i2922;
                            L1260:
                            ; lenv = k[2]; k = k[1];
                            r0 = result;
                          } else {
                            r0 = (object *) 14;
                          }
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (1, 0);
                          r1[2] = r2;
                          r2 = varref (3, 1);
                          r1[3] = r2;
                          r2 = varref (8, 4);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1261; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_inline_application_3868_i2922;
                          L1261:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 3);
                          r1 = varref (0, 0);
                          r0[2] = r1;
                          r1 = varref (10, 1);
                          r0[3] = r1;
                          r1 = varref (11, 6);
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1262; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_add_vars_260;
                          L1262:
                          ; lenv = k[2]; k = k[1];
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (0, 0);
                          r1[2] = r2;
                          r2 = varref (7, 1);
                          r1[3] = r2;
                          r2 = varref (8, 3);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1263; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_inline_3865_i2922;
                          L1263:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = varref (6, 0);
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1264; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          L1264:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = r0;
                          r0=r0;
                        } else {
                          r0 = (object *) 14;
                          r0=r0;
                        }
                        lenv = lenv[1];
                        r0 = r0;
                        r0=r0;
                      } break;
                    }
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_156;
                  }
                }
                lenv = lenv[1];
                r0 = r0;
                r0=r0;
              } break;
            }
            r0=r0;
            goto fatbar_156_over;
            fatbar_156:
            r0 = (object *) 14;
            r0=r0;
            fatbar_156_over: ;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          default: {
            goto fatbar_155;
          }
        }
        r0=r0;
        goto fatbar_155_over;
        fatbar_155:
        r0 = (object *) 14;
        r0=r0;
        fatbar_155_over: ;
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_25234_i2922
        goto L1265;
        FUN_lambda_25234_i2922:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[3] = r1;
          r1 = varref (3, 3);
          r0[1] = r1[2]; lenv = r0; goto FUN_inline_3865_i2922;
        L1265:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_25234_i2922; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,66)];
        r0[3] = r1;
        r1 = varref (5, 30);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1266; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_map_335;
        L1266:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = varref (1, 0);
        ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,66)] = r0;
        r0 = varref (1, 0);
        PXLL_RETURN(0);
      L1251:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_25242_i2922; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (4, 14);
      r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_307;
    L1250:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_inline_3865_i2922; r2[2] = lenv;
    r1[5] = r2;
    // def inline-application_3868_i2922
    goto L1267;
    FUN_inline_application_3868_i2922:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 5);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_693[0];
      r0[2] = r1;
      r1 = (object *) constructed_692[0];
      r0[3] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (1, 1);
      r1[2] = r2;
      r2 = varref (5, 20);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1268; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
      L1268:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[4] = r1;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[5] = r1;
      r0 = varref (0, 3);
      switch (get_case (r0)) {
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 3);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 3);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 1);
          r1[2] = r2;
          r2 = varref (7, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1269; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L1269:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r2 = varref (2, 2);
          r1 = PXLL_TEST(unbox(r2)==unbox(r1));
          r0[3] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 1);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_682;
            r0[2] = r1;
            r1 = varref (2, 0);
            r0[3] = r1;
            r1 = varref (6, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 2);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_3948_i2922
            goto L1270;
            FUN__24loop_3948_i2922:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (4, 1);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (10, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1271; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1271:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (9, 1);
                r1[2] = r2;
                r2 = varref (0, 0);
                r1[3] = r2;
                r2 = varref (10, 3);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1272; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
                L1272:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (6, 1);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (10, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1273; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1273:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = ((pxll_vector*)r1)->val[4];
                r0[2] = r1;
                r0 = (object *) 1;
                r1 = varref (0, 0);
                r0 = PXLL_TEST(unbox(r1)>unbox(r0));
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (6, 1);
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  r1 = varref (2, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  varset (5, 1, r0);
                  r0=r0;
                } else {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 2);
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(2)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (7, 0);
                      r0[2] = r1;
                      r0 = varref (0, 0);
                      r1 = varref (3, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r1;
                      t[2] = r0;
                      r0 = t;
                      lenv = lenv[1];
                      r0 = r0;
                      varset (6, 0, r0);
                      r0=r0;
                    } break;
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (11, 1);
                      r1[2] = r2;
                      r2 = varref (0, 0);
                      r1[3] = r2;
                      r2 = varref (12, 3);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1274; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
                      L1274:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = ((pxll_vector*)r1)->val[4];
                      r0[2] = r1;
                      r0 = (object *) 1;
                      r1 = varref (0, 0);
                      r0 = PXLL_TEST(unbox(r1)>unbox(r0));
                      lenv = lenv[1];
                      r0 = r0;
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (8, 1);
                        r0[2] = r1;
                        r0 = varref (0, 0);
                        r1 = varref (4, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        varset (7, 1, r0);
                        r0=r0;
                      } else {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (8, 0);
                        r0[2] = r1;
                        r0 = varref (0, 0);
                        r1 = varref (4, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        varset (7, 0, r0);
                        r0=r0;
                      }
                      lenv = lenv[1];
                      r0 = r0;
                      r0=r0;
                    } break;
                    default: {
                      goto fatbar_153;
                    }
                  }
                  r0=r0;
                  goto fatbar_153_over;
                  fatbar_153:
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (2, 1);
                  r1 = ((pxll_vector*)r1)->val[3];
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  r1 = (object *) 3;
                  r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = varref (7, 1);
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 4);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (8, 1);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (0, 0);
                        r1 = ((pxll_vector*)r1)->val[4];
                        r0[3] = r1;
                        r1 = varref (0, 0);
                        r1 = ((pxll_vector*)r1)->val[3];
                        r0[4] = r1;
                        r0 = varref (0, 1);
                        switch (get_case (r0)) {
                          case (UOTAG(12)): {
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (1, 1);
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r0 = (object *) constructed_258[0];
                            r1 = varref (0, 0);
                            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                              r0 = varref (1, 2);
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (2, 2);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r1 = ((pxll_vector*)r1)->val[4];
                                  r0[3] = r1;
                                  r0 = varref (0, 1);
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 4);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 1);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = varref (14, 1);
                                      r1[2] = r2;
                                      r2 = varref (0, 0);
                                      r1[3] = r2;
                                      r2 = varref (15, 3);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1275; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
                                      L1275:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[3] = r1;
                                      r1 = varref (0, 1);
                                      r1 = ((pxll_vector*)r1)->val[4];
                                      r0[4] = r1;
                                      r0 = varref (0, 2);
                                      r1 = (object *) 1;
                                      r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                                      lenv = lenv[1];
                                      r0 = r0;
                                      r0=r0;
                                    } break;
                                    default: {
                                      lenv = ((object ***)lenv)[1][1][1];
                                      goto fatbar_154;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r0 = r0;
                                  r0=r0;
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_154;
                                }
                              }
                              r0=r0;
                            } else {
                              lenv = ((object **)lenv)[1][1];
                              goto fatbar_154;
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            lenv = ((object *)lenv)[1];
                            goto fatbar_154;
                          }
                        }
                        lenv = lenv[1];
                        r0 = r0;
                        r0=r0;
                      } break;
                      default: {
                        goto fatbar_154;
                      }
                    }
                    r0=r0;
                    goto fatbar_154_over;
                    fatbar_154:
                    r0 = (object *) 6;
                    r0=r0;
                    fatbar_154_over: ;
                    r0=r0;
                  } else {
                    r0 = (object *) 6;
                    r0=r0;
                  }
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (7, 0);
                    r0[2] = r1;
                    r0 = varref (0, 0);
                    r1 = varref (3, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    varset (6, 0, r0);
                    r0=r0;
                  } else {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (7, 1);
                    r0[2] = r1;
                    r0 = varref (0, 0);
                    r1 = varref (3, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    varset (6, 1, r0);
                    r0=r0;
                  }
                  r0=r0;
                  fatbar_153_over: ;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                }
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_3948_i2922;
              }
              PXLL_RETURN(0);
            L1270:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_3948_i2922; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1276; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3948_i2922;
            L1276:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_690[0];
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 4);
            r2[1] = lenv; lenv = r2;
            r3 = allocate (TC_TUPLE, 2);
            r4 = varref (6, 1);
            r4 = ((pxll_vector*)r4)->val[1];
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L1277; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            lenv = r4[2]; goto *r4[1];
            L1277:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = varref (8, 54);
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L1278; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
            L1278:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = varref (0, 1);
            r4 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[4] = r3;
            r2 = varref (0, 2);
            r3 = (object*) &constructed_689;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = varref (7, 45);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1279; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
            L1279:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 0);
            r2 = ((pxll_vector*)r2)->val[3];
            r1[2] = r2;
            r2 = (object *) 1;
            r1[3] = r2;
            r2 = varref (7, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1280; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1280:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            // def append-suffix_3912_i2837_i2922
            goto L1281;
            FUN_append_suffix_3912_i2837_i2922:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = varref (1, 0);
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = varref (2, 0);
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = varref (0, 0);
              lenv = lenv[1];
              r3 = r3;
              r3=r3;
              r2[2] = r3;
              r3 = (object*)TC_NIL;
              r2[3] = r3;
              r3 = varref (0, 1);
              r4 = varref (3, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = varref (0, 2);
              r3 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (9, 45);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1282; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L1282:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (9, 73);
              r0[1] = r1[2]; lenv = r0; goto FUN_string__3esymbol_422;
            L1281:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_append_suffix_3912_i2837_i2922; r2[2] = lenv;
            r1[2] = r2;
            // def rename_3913_i2837_i2922
            goto L1283;
            FUN_rename_3913_i2837_i2922:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def get-new-name_3917_i2837_i2922
              goto L1284;
              FUN_get_new_name_3917_i2837_i2922:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (1, 0);
                r1[2] = r2;
                r2 = varref (4, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1285; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_3912_i2837_i2922;
                L1285:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (6, 0);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (5, 0, r0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (4, 1);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (2, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (3, 1, r0);
                r0 = varref (0, 0);
                PXLL_RETURN(0);
              L1284:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_get_new_name_3917_i2837_i2922; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (2, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (UOTAG(2)): {
                  r0 = varref (0, 0);
                  r0=r0;
                } break;
                default: {
                  goto fatbar_152;
                }
              }
              r0=r0;
              goto fatbar_152_over;
              fatbar_152:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (1, 0);
              r2 = ((pxll_vector*)r2)->val[4];
              r1[2] = r2;
              r2 = varref (1, 0);
              r2 = ((pxll_vector*)r2)->val[3];
              r1[3] = r2;
              r2 = varref (12, 110);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1286; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
              L1286:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (1, 0);
              r0 = ((pxll_vector*)r0)->val[0];
              r1 = varref (0, 0);
              ((pxll_vector*)r1)->val[0] = r0;
              r0 = varref (1, 0);
              r0 = ((pxll_vector*)r0)->val[5];
              r1 = varref (0, 0);
              ((pxll_vector*)r1)->val[5] = r0;
              r0 = varref (0, 0);
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
              fatbar_152_over: ;
              lenv = lenv[1];
              r0 = r0;
              varset (1, 0, r0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (2, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(9)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (3, 0);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r1[3] = r2;
                  r2 = varref (13, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1287; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L1287:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  t = alloc_no_clear (UOTAG(9),1);
                  t[1] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  r1 = varref (3, 0);
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(10)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (3, 0);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r1[3] = r2;
                  r2 = varref (13, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1288; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L1288:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  t = alloc_no_clear (UOTAG(10),1);
                  t[1] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  r1 = varref (3, 0);
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(7)): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (1, 0);
                  r1[2] = r2;
                  r2 = varref (3, 0);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1289; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_get_new_name_3917_i2837_i2922;
                  L1289:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (3, 0);
                  r1[2] = r2;
                  r2 = varref (1, 1);
                  r1[3] = r2;
                  r2 = varref (13, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1290; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L1290:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r0 = varref (0, 1);
                  r1 = varref (0, 0);
                  t = alloc_no_clear (UOTAG(7),2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  r1 = varref (3, 0);
                  ((pxll_vector*)r1)->val[4] = r0;
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = varref (0, 0);
                  r0[2] = r1;
                  r1 = varref (3, 1);
                  r0[3] = r1;
                  r1 = varref (12, 23);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1291; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_328;
                  L1291:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (5, 0);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1292; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_3912_i2837_i2922;
                    L1292:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r0 = varref (0, 0);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = varref (3, 0);
                    ((pxll_vector*)r1)->val[4] = r0;
                    r0=r0;
                  } else {
                    r0 = (object *) 14;
                    r0=r0;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = varref (0, 0);
                  r0[2] = r1;
                  r1 = varref (3, 1);
                  r0[3] = r1;
                  r1 = varref (12, 23);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1293; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_328;
                  L1293:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (5, 0);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1294; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_append_suffix_3912_i2837_i2922;
                    L1294:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r0 = varref (0, 0);
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = varref (3, 0);
                    ((pxll_vector*)r1)->val[4] = r0;
                    r0=r0;
                  } else {
                    r0 = (object *) 14;
                    r0=r0;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_151;
                }
              }
              r0=r0;
              goto fatbar_151_over;
              fatbar_151:
              r0 = (object *) 14;
              r0=r0;
              fatbar_151_over: ;
              lenv = lenv[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_25405_i2837_i2922
              goto L1295;
              FUN_lambda_25405_i2837_i2922:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (0, 0);
                r0[2] = r1;
                r1 = varref (2, 1);
                r0[3] = r1;
                r1 = varref (3, 1);
                r0[1] = r1[2]; lenv = r0; goto FUN_rename_3913_i2837_i2922;
              L1295:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_25405_i2837_i2922; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = ((pxll_vector*)r1)->val[3];
              r0[3] = r1;
              r1 = varref (10, 30);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1296; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_map_335;
              L1296:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              r1 = varref (1, 0);
              ((pxll_vector*)r1)->val[3] = r0;
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            L1283:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_rename_3913_i2837_i2922; r2[2] = lenv;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 2);
            r1[2] = r2;
            r2 = (object *) constructed_688[0];
            r1[3] = r2;
            r2 = varref (0, 1);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1297; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_rename_3913_i2837_i2922;
            L1297:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (3, 0);
            r1[2] = r2;
            r2 = varref (0, 0);
            switch (get_case (r2)) {
              case (TC_NIL): {
                r2 = (object *) 262;
                r2=r2;
              } break;
              default: {
                goto fatbar_150;
              }
            }
            r2=r2;
            goto fatbar_150_over;
            fatbar_150:
            r2 = (object *) 6;
            r2=r2;
            fatbar_150_over: ;
            r1[3] = r2;
            r1 = (object *) 6;
            r2 = varref (0, 1);
            r1 = PXLL_TEST(r2==r1);
            lenv = lenv[1];
            r1 = r1;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 3);
              // def lambda_25638_i2922
              goto L1298;
              FUN_lambda_25638_i2922:
                check_heap (0);
                r0 = allocate (UOTAG(0), 2);
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (2, 1);
                r1[2] = r2;
                r2 = varref (0, 0);
                r1[3] = r2;
                r2 = varref (8, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1299; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1299:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[1] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (4, 1);
                r1[2] = r2;
                r2 = varref (0, 0);
                r1[3] = r2;
                r2 = varref (8, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1300; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1300:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                PXLL_RETURN(0);
              L1298:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_25638_i2922; r2[2] = lenv;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (7, 30);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1301; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
              L1301:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) constructed_687[0];
              r1=r1;
            }
            r0[6] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (3, 1);
            r0[2] = r1;
            r1 = (object*)TC_NIL;
            r0[3] = r1;
            r0 = varref (0, 1);
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (0, 3);
              r0[2] = r1;
              r1 = varref (0, 4);
              r0[3] = r1;
              r1 = varref (4, 5);
              r0[1] = r1[2]; lenv = r0; goto FUN_substitute_3869_i2922;
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = (object *) constructed_686[0];
              r0[2] = r1;
              r1 = (object *) constructed_685[0];
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (3, 1);
              r1[2] = r2;
              r2 = varref (8, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1302; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L1302:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_25707_i2922
              goto L1303;
              FUN_lambda_25707_i2922:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (4, 1);
                r2[2] = r3;
                r3 = varref (1, 0);
                r2[3] = r3;
                r3 = varref (10, 25);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1304; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                L1304:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 4);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (9, 2);
                r5 = ((pxll_vector*)r5)->val[1];
                t = allocate (TC_SAVE, 8);
                t[1] = k; t[2] = lenv; t[3] = &&L1305; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                lenv = r5[2]; goto *r5[1];
                L1305:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                r5 = result;
                r4[2] = r5;
                r5 = varref (11, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L1306; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L1306:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = varref (0, 1);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r3 = varref (0, 2);
                r4 = (object*) &constructed_684;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (10, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1307; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L1307:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = varref (10, 133);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1308; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_symbol_add_suffix_547;
                L1308:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (3, 0);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (2, 0, r0);
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (7, 1);
                r1[2] = r2;
                r2 = varref (2, 0);
                r1[3] = r2;
                r2 = varref (11, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1309; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1309:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (3, 1);
                r0[3] = r1;
                r0 = varref (0, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (2, 1, r0);
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (UOTAG(0), 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (5, 1);
                r2[2] = r3;
                r3 = varref (2, 0);
                r2[3] = r3;
                r3 = varref (11, 25);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1310; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                L1310:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[1] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (1, 0);
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r3;
                r3 = t;
                r2[2] = r3;
                r3 = (object *) constructed_683[0];
                r2[3] = r3;
                r3 = varref (11, 110);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1311; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_make_node_488;
                L1311:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r0[2] = r1;
                r1 = varref (4, 4);
                r0[3] = r1;
                r0 = varref (0, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (3, 4, r0);
                PXLL_RETURN(0);
              L1303:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_25707_i2922; r1[2] = lenv;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (4, 1);
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (0, 0);
              r1[2] = r2;
              r2 = (object *) constructed_37[0];
              r1[3] = r2;
              r2 = varref (9, 19);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1312; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
              L1312:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[3] = r1;
              r1 = varref (8, 33);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1313; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
              L1313:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (2, 3);
              r1[2] = r2;
              r2 = varref (2, 4);
              r1[3] = r2;
              r2 = varref (6, 5);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1314; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_substitute_3869_i2922;
              L1314:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (2, 0);
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (0, 0);
              r1[2] = r2;
              r2 = (object *) constructed_37[0];
              r1[3] = r2;
              r2 = varref (10, 19);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1315; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
              L1315:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (2, 1);
              r1[2] = r2;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (0, 0);
              r1[2] = r2;
              r2 = (object *) constructed_37[0];
              r1[3] = r2;
              r2 = varref (10, 19);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1316; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
              L1316:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              lenv = lenv[1];
              r1 = r1;
              r0[3] = r1;
              r1 = varref (0, 0);
              r0[4] = r1;
              r1 = varref (9, 114);
              r0[1] = r1[2]; lenv = r0; goto FUN_node_2flet_501;
            }
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_149;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_149_over;
      fatbar_149:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_691;
      r0[2] = r1;
      r1 = varref (1, 0);
      r0[3] = r1;
      r1 = varref (5, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      fatbar_149_over: ;
      PXLL_RETURN(0);
    L1267:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_inline_application_3868_i2922; r2[2] = lenv;
    r1[6] = r2;
    // def substitute_3869_i2922
    goto L1317;
    FUN_substitute_3869_i2922:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      // def lookup_3967_i2922
      goto L1318;
      FUN_lookup_3967_i2922:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_3970_i2922
        goto L1319;
        FUN_loop_3970_i2922:
          check_heap (0);
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*)UITAG(1);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 0);
              switch (get_case_noint (r0)) {
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 0);
                  r1 = varref (4, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = varref (0, 1);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } else {
                    r0 = varref (1, 1);
                    lenv = ((object **)lenv)[1][1];
                    lenv[2] = r0;
                    goto FUN_loop_3970_i2922;
                  }
                  PXLL_RETURN(0);
                } break;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L1319:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_3970_i2922; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (3, 1);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_3970_i2922;
      L1318:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lookup_3967_i2922; r1[2] = lenv;
      r0[2] = r1;
      // def walk_3968_i2922
      goto L1320;
      FUN_walk_3968_i2922:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = ((pxll_vector*)r1)->val[4];
        r0[2] = r1;
        r1 = varref (0, 0);
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = varref (3, 0);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1321; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_lookup_3967_i2922;
            L1321:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = varref (0, 1);
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (1, 1);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = varref (0, 0);
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                r1 = varref (2, 0);
                r1=r1;
              } break;
            }
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = varref (3, 0);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1322; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_lookup_3967_i2922;
            L1322:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = varref (0, 1);
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = allocate (TC_TUPLE, 4);
                r1[1] = lenv; lenv = r1;
                r2 = varref (1, 1);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (0, 0);
                r3 = ((pxll_vector*)r3)->val[4];
                r2[2] = r3;
                r3 = varref (9, 111);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1323; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_varref__3ename_491;
                L1323:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[3] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (3, 0);
                r3 = ((pxll_vector*)r3)->val[3];
                r2[2] = r3;
                r3 = varref (9, 17);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1324; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
                L1324:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[4] = r2;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (0, 1);
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r2;
                r2 = t;
                r1[2] = r2;
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = (object*)TC_NIL;
                r2[2] = r3;
                r2 = varref (0, 0);
                r3 = varref (1, 2);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[3] = r2;
                r2 = varref (9, 110);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1325; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_make_node_488;
                L1325:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                r1 = varref (2, 0);
                r1=r1;
              } break;
            }
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            goto fatbar_148;
          }
        }
        r1=r1;
        goto fatbar_148_over;
        fatbar_148:
        r1 = varref (1, 0);
        r1=r1;
        fatbar_148_over: ;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (2, 1);
        r0[2] = r1;
        r1 = varref (0, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = varref (7, 30);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1326; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_map_335;
        L1326:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = varref (0, 1);
        ((pxll_vector*)r1)->val[3] = r0;
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      L1320:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_walk_3968_i2922; r1[2] = lenv;
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (1, 0);
      r0[2] = r1;
      r1 = varref (0, 1);
      r0[1] = r1[2]; lenv = r0; goto FUN_walk_3968_i2922;
    L1317:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_substitute_3869_i2922; r2[2] = lenv;
    r1[7] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = (object*)UITAG(0);
    r1[3] = r2;
    r2 = varref (0, 3);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1327; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_inline_3865_i2922;
    L1327:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = varref (1, 134);
    r0[1] = r1[2]; lenv = r0; goto FUN_do_simple_optimizations_550;
  L1167:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_do_one_round_554; r1[2] = lenv;
  r0[138] = r1;
  // def encode-immediate_557
  goto L1328;
  FUN_encode_immediate_557:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = (object *) 3;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)<<unbox(r1));
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = (object *) 3;
        r0 = box(unbox(r1)|unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r1 = box(GET_CHAR(r1));
        r0[3] = r1;
        r1 = (object *) 17;
        r2 = varref (0, 1);
        r1 = box(unbox(r2)<<unbox(r1));
        r0[4] = r1;
        r0 = varref (0, 2);
        r1 = (object *) 5;
        r0 = box(unbox(r1)|unbox(r0));
        PXLL_RETURN(0);
      } break;
      case (UITAG(3)): {
        r0 = (object *) 29;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_47[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_42[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 13;
            PXLL_RETURN(0);
          } else {
            goto fatbar_147;
          }
          PXLL_RETURN(0);
          goto fatbar_147_over;
          fatbar_147:
          r0 = (object *) constructed_45[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 525;
            PXLL_RETURN(0);
          } else {
            lenv = ((object *)lenv)[1];
            goto fatbar_146;
          }
          PXLL_RETURN(0);
          fatbar_147_over: ;
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_146;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_146;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_146_over;
    fatbar_146:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_681;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (1, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_146_over: ;
    PXLL_RETURN(0);
  L1328:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_encode_immediate_557; r1[2] = lenv;
  r0[139] = r1;
  // def wrap-in_558
  goto L1329;
  FUN_wrap_in_558:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def wrap_4135
    goto L1330;
    FUN_wrap_4135:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (1, 1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = (object *) constructed_453[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_84[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_NIL): {
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = allocate (TC_TUPLE, 4);
                          r1[1] = lenv; lenv = r1;
                          r2 = (object*)TC_NIL;
                          r1[2] = r2;
                          r2 = varref (0, 0);
                          r3 = (object*) &constructed_667;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r3;
                          t[2] = r2;
                          r2 = t;
                          r1[3] = r2;
                          r2 = varref (0, 1);
                          r3 = varref (4, 1);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r3;
                          t[2] = r2;
                          r2 = t;
                          r1[4] = r2;
                          r1 = varref (0, 2);
                          r2 = (object*) &constructed_666;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r2;
                          t[2] = r1;
                          r1 = t;
                          lenv = lenv[1];
                          r1 = r1;
                          r0[2] = r1;
                          r1 = varref (6, 45);
                          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_136;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_136;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_136;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_136;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_136_over;
            fatbar_136:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_668;
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (4, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            fatbar_136_over: ;
            PXLL_RETURN(0);
          } else {
            goto fatbar_135;
          }
          PXLL_RETURN(0);
          goto fatbar_135_over;
          fatbar_135:
          r0 = (object *) constructed_670[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 1);
            PXLL_RETURN(0);
          } else {
            goto fatbar_137;
          }
          PXLL_RETURN(0);
          goto fatbar_137_over;
          fatbar_137:
          r0 = (object *) constructed_635[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 1);
            PXLL_RETURN(0);
          } else {
            goto fatbar_138;
          }
          PXLL_RETURN(0);
          goto fatbar_138_over;
          fatbar_138:
          r0 = (object *) constructed_59[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 1);
            PXLL_RETURN(0);
          } else {
            goto fatbar_139;
          }
          PXLL_RETURN(0);
          goto fatbar_139_over;
          fatbar_139:
          r0 = (object *) constructed_413[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 1);
            PXLL_RETURN(0);
          } else {
            goto fatbar_140;
          }
          PXLL_RETURN(0);
          goto fatbar_140_over;
          fatbar_140:
          r0 = (object *) constructed_95[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (1, 1);
            PXLL_RETURN(0);
          } else {
            goto fatbar_141;
          }
          PXLL_RETURN(0);
          goto fatbar_141_over;
          fatbar_141:
          r0 = (object *) constructed_674[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = (object*)TC_NIL;
            r1[2] = r2;
            r2 = varref (0, 0);
            r3 = (object*) &constructed_672;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r2 = varref (0, 1);
            r3 = varref (2, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[4] = r2;
            r1 = varref (0, 2);
            r2 = (object*) &constructed_671;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (4, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } else {
            goto fatbar_142;
          }
          PXLL_RETURN(0);
          goto fatbar_142_over;
          fatbar_142:
          r0 = (object *) constructed_661[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = (object*)TC_NIL;
            r1[2] = r2;
            r2 = varref (0, 0);
            r3 = varref (2, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r1 = varref (0, 1);
            r2 = (object*) &constructed_675;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (4, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } else {
            goto fatbar_143;
          }
          PXLL_RETURN(0);
          goto fatbar_143_over;
          fatbar_143:
          r0 = (object *) constructed_84[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = (object*)TC_NIL;
            r1[2] = r2;
            r2 = varref (0, 0);
            r3 = (object*) &constructed_677;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r2 = varref (0, 1);
            r3 = varref (2, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[4] = r2;
            r1 = varref (0, 2);
            r2 = (object*) &constructed_676;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (4, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } else {
            goto fatbar_144;
          }
          PXLL_RETURN(0);
          goto fatbar_144_over;
          fatbar_144:
          r0 = (object *) constructed_633[0];
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = (object*)TC_NIL;
            r1[2] = r2;
            r2 = varref (0, 0);
            r3 = (object*) &constructed_679;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r2 = varref (0, 1);
            r3 = varref (2, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[4] = r2;
            r1 = varref (0, 2);
            r2 = (object*) &constructed_678;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (4, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } else {
            goto fatbar_145;
          }
          PXLL_RETURN(0);
          goto fatbar_145_over;
          fatbar_145:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_680;
          r0[2] = r1;
          r1 = varref (1, 0);
          r0[3] = r1;
          r1 = varref (4, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
          fatbar_145_over: ;
          PXLL_RETURN(0);
          fatbar_144_over: ;
          PXLL_RETURN(0);
          fatbar_143_over: ;
          PXLL_RETURN(0);
          fatbar_142_over: ;
          PXLL_RETURN(0);
          fatbar_141_over: ;
          PXLL_RETURN(0);
          fatbar_140_over: ;
          PXLL_RETURN(0);
          fatbar_139_over: ;
          PXLL_RETURN(0);
          fatbar_138_over: ;
          PXLL_RETURN(0);
          fatbar_137_over: ;
          PXLL_RETURN(0);
          fatbar_135_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1330:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_wrap_4135; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (1, 0);
    r0[3] = r1;
    r1 = varref (1, 1);
    r0[4] = r1;
    r1 = varref (2, 31);
    r0[1] = r1[2]; lenv = r0; goto FUN_map2_336;
  L1329:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_wrap_in_558; r1[2] = lenv;
  r0[140] = r1;
  // def wrap-out_559
  goto L1331;
  FUN_wrap_out_559:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = (object *) constructed_661[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = varref (0, 0);
          r3 = varref (2, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r1 = varref (0, 1);
          r2 = (object*) &constructed_659;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = varref (2, 45);
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_133;
        }
        PXLL_RETURN(0);
        goto fatbar_133_over;
        fatbar_133:
        r0 = (object *) constructed_47[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = varref (0, 0);
          r3 = (object*) &constructed_663;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = varref (0, 1);
          r3 = varref (2, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = varref (0, 2);
          r2 = (object*) &constructed_662;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = varref (2, 45);
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          goto fatbar_134;
        }
        PXLL_RETURN(0);
        goto fatbar_134_over;
        fatbar_134:
        r0 = (object *) constructed_633[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = varref (0, 0);
          r3 = (object*) &constructed_665;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = varref (0, 1);
          r3 = varref (2, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = varref (0, 2);
          r2 = (object*) &constructed_664;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[2] = r1;
          r1 = varref (2, 45);
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_132;
        }
        PXLL_RETURN(0);
        fatbar_134_over: ;
        PXLL_RETURN(0);
        fatbar_133_over: ;
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_132;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_132_over;
    fatbar_132:
    r0 = varref (0, 1);
    PXLL_RETURN(0);
    fatbar_132_over: ;
    PXLL_RETURN(0);
  L1331:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_wrap_out_559; r1[2] = lenv;
  r0[141] = r1;
  // def cexp-subst_560
  goto L1332;
  FUN_cexp_subst_560:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = (object *) 9474;
    r1[3] = r2;
    r2 = varref (2, 47);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1333; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_split_364;
    L1333:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4150
    goto L1334;
    FUN_loop_4150:
      check_heap (0);
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (4, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1335; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1335:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (4, 45);
          r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = (object*) &constructed_657;
          r1[3] = r2;
          r2 = varref (6, 48);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1336; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
          L1336:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_655;
                r0[2] = r1;
                r1 = varref (4, 0);
                r0[3] = r1;
                r1 = varref (5, 12);
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (3, 0);
                r2 = (object*) &constructed_656;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = varref (0, 1);
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_4150;
              } break;
            }
            PXLL_RETURN(0);
          } else {
            goto fatbar_131;
          }
          PXLL_RETURN(0);
          goto fatbar_131_over;
          fatbar_131:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 155);
          r1[2] = r2;
          r2 = (object *) 1;
          r3 = varref (1, 0);
          range_check (((pxll_string *)(((pxll_string*)(r3))))->len, unbox(r2));
          r2 = (object *) 1;
          r3 = varref (1, 0);
          r2 = TO_CHAR(((unsigned char *)((pxll_string*)(r3))->data)[unbox(r2)]);
          r1[3] = r2;
          r2 = varref (6, 64);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1337; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
          L1337:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UITAG(1)): {
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_658;
              r0[2] = r1;
              r1 = varref (5, 0);
              r0[3] = r1;
              r1 = varref (6, 12);
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 4);
              r2 = varref (3, 0);
              r1[2] = r2;
              r2 = (object *) 3;
              r1[3] = r2;
              r2 = varref (3, 0);
              r2 = box(((pxll_string*)(r2))->len);
              r1[4] = r2;
              r2 = varref (8, 43);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1338; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_substring_355;
              L1338:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (7, 1);
              r1[2] = r2;
              r2 = varref (1, 0);
              r1[3] = r2;
              r2 = varref (8, 25);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1339; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
              L1339:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = varref (4, 0);
              r2 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[4] = r1;
              r0 = varref (0, 2);
              r1 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = varref (2, 1);
              lenv = ((object ***)lenv)[1][1][1];
              lenv[2] = r0;
              lenv[3] = r1;
              goto FUN_loop_4150;
            } break;
          }
          PXLL_RETURN(0);
          fatbar_131_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1334:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4150; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = allocate (TC_TUPLE, 3);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = varref (2, 0);
    r2[2] = r3;
    r3 = varref (4, 17);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1340; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
    L1340:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r1 = varref (0, 1);
    r2 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (3, 18);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1341; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
    L1341:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4150;
  L1332:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_cexp_subst_560; r1[2] = lenv;
  r0[142] = r1;
  // def getenv-or_570
  goto L1342;
  FUN_getenv_or_570:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (2, 51);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1343; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_zero_terminate_370;
    L1343:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1 = (object*)getenv (((pxll_string*)(r1))->data);
    r0[2] = r1;
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST((char*)r1==NULL)) {
      r1 = (object*) &constructed_654;
      r1=r1;
    } else {
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = varref (2, 58);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1344; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_copy_cstring_382;
      L1344:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r1=r1;
    }
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 1);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = varref (0, 0);
    r1 = (object *) 1;
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = varref (1, 1);
      PXLL_RETURN(0);
    } else {
      r0 = varref (0, 1);
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1342:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_getenv_or_570; r1[2] = lenv;
  r0[143] = r1;
  r1 = (object *) 1;
  r0[144] = r1;
  r1 = (object *) 3;
  r0[145] = r1;
  r1 = (object *) 5;
  r0[146] = r1;
  r1 = (object *) 7;
  r0[147] = r1;
  r1 = (object *) 11;
  r0[148] = r1;
  r1 = (object *) constructed_653[0];
  r0[149] = r1;
  r1 = box(O_RDONLY);
  r0[150] = r1;
  r1 = box(O_WRONLY);
  r0[151] = r1;
  r1 = box(O_CREAT);
  r0[152] = r1;
  r1 = box(O_TRUNC);
  r0[153] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = box(argc);
  r1[2] = r2;
  r2 = varref (0, 0);
  ensure_heap (2, unbox(r2));
  r2 = (object*) &constructed_652;
  r3 = varref (0, 0);
  if (unbox(r3) == 0) { r2 = (object *) TC_EMPTY_VECTOR; } else {
    t = alloc_no_clear (TC_VECTOR, unbox(r3));
    for (i=0; i<unbox(r3); i++) { t[i+1] = r2; }
    r2 = t;
  }
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  // def loop_4640
  goto L1345;
  FUN_loop_4640:
    check_heap (0);
    r0 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(unbox(r0)==0)) {
      r0 = varref (2, 1);
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) 3;
      r2 = varref (1, 0);
      r1 = box(unbox(r2)-unbox(r1));
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 0);
      r1 = (object*)argv[unbox(r1)];
      r0[2] = r1;
      r1 = varref (4, 58);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1346; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_copy_cstring_382;
      L1346:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      r1 = (object *) 3;
      r2 = varref (0, 0);
      r1 = box(unbox(r2)-unbox(r1));
      r2 = varref (2, 1);
      range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
      ((pxll_vector*)r2)->val[unbox(r1)] = r0;
      r0 = (object *) 3;
      r1 = varref (0, 0);
      r0 = box(unbox(r1)-unbox(r0));
      lenv[2] = r0;
      goto FUN_loop_4640;
    }
    PXLL_RETURN(0);
  L1345:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_loop_4640; r3[2] = lenv;
  r2[2] = r3;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (1, 0);
  r2[2] = r3;
  r3 = varref (0, 0);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1347; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_loop_4640;
  L1347:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  lenv = lenv[1];
  r2 = r2;
  r1[4] = r2;
  r1 = allocate (UOTAG(15), 2);
  r2 = varref (0, 0);
  r1[1] = r2;
  r2 = varref (0, 2);
  r1[2] = r2;
  lenv = lenv[1];
  r1 = r1;
  r0[154] = r1;
  r1 = (object*)UITAG(2);
  r0[155] = r1;
  r1 = (object *) constructed_651[0];
  r0[156] = r1;
  r1 = (object *) constructed_650[0];
  r0[157] = r1;
  r1 = (object *) constructed_649[0];
  r0[158] = r1;
  r1 = (object *) constructed_648[0];
  r0[159] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_647;
  r1[2] = r2;
  r2 = varref (0, 53);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1348; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_372;
  L1348:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[160] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_646;
  r1[2] = r2;
  r2 = varref (0, 53);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1349; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_372;
  L1349:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[161] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = allocate (TC_TUPLE, 3);
  r3 = varref (0, 157);
  r2[2] = r3;
  r3 = (object *) constructed_37[0];
  r2[3] = r3;
  r3 = varref (0, 19);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1350; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
  L1350:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = varref (0, 158);
  r1[3] = r2;
  r2 = varref (0, 19);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1351; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
  L1351:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[162] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_645;
  r1[2] = r2;
  r2 = varref (0, 53);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1352; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string__3elist_372;
  L1352:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[163] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) constructed_644[0];
  r1[2] = r2;
  r2 = varref (0, 75);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1353; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1353:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[164] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (0, 160);
  r1[2] = r2;
  r2 = varref (0, 75);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1354; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1354:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[165] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (0, 161);
  r1[2] = r2;
  r2 = varref (0, 75);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1355; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1355:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[166] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  r3 = allocate (TC_TUPLE, 3);
  r4 = allocate (TC_TUPLE, 3);
  r5 = varref (1, 159);
  r4[2] = r5;
  r5 = (object *) constructed_37[0];
  r4[3] = r5;
  r5 = varref (1, 19);
  t = allocate (TC_SAVE, 7);
  t[1] = k; t[2] = lenv; t[3] = &&L1356; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
  r4[1] = r5[2]; lenv = r4; goto FUN_reverse_onto_320;
  L1356:
  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
  r4 = result;
  r3[2] = r4;
  r4 = varref (1, 161);
  r3[3] = r4;
  r4 = varref (1, 19);
  t = allocate (TC_SAVE, 6);
  t[1] = k; t[2] = lenv; t[3] = &&L1357; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
  r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
  L1357:
  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
  r3 = result;
  r2[2] = r3;
  r2 = varref (0, 0);
  r3 = (object *) 11522;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[2] = r2;
  r2 = varref (0, 75);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1358; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1358:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[167] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = varref (0, 105);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1359; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1359:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[168] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_633[0];
  r1[2] = r2;
  r2 = (object *) constructed_643[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1360; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1360:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[169] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_635[0];
  r1[2] = r2;
  r2 = (object *) constructed_642[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1361; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1361:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[170] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_84[0];
  r1[2] = r2;
  r2 = (object *) constructed_641[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1362; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1362:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[171] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_637[0];
  r1[2] = r2;
  r2 = (object *) constructed_640[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1363; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1363:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[172] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_47[0];
  r1[2] = r2;
  r2 = (object *) constructed_639[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1364; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1364:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[173] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_59[0];
  r1[2] = r2;
  r2 = (object *) constructed_638[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1365; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1365:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[174] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = varref (1, 172);
  r3 = varref (0, 0);
  r4 = (object *) constructed_59[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[3] = r2;
  r2 = varref (1, 170);
  r3 = varref (0, 1);
  r4 = (object *) constructed_637[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[4] = r2;
  r2 = varref (1, 169);
  r3 = varref (0, 2);
  r4 = (object *) constructed_84[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[5] = r2;
  r2 = varref (1, 168);
  r3 = varref (0, 3);
  r4 = (object *) constructed_635[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  r1[6] = r2;
  r1 = varref (1, 167);
  r2 = varref (0, 4);
  r3 = (object *) constructed_633[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r3;
  t[2] = r1;
  t[3] = r2;
  r1 = t;
  lenv = lenv[1];
  r1 = r1;
  r0[175] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) constructed_442[0];
  t = alloc_no_clear (UOTAG(1),1);
  t[1] = r2;
  r2 = t;
  r1[2] = r2;
  r2 = (object *) 6;
  t = alloc_no_clear (UOTAG(4),1);
  t[1] = r2;
  r2 = t;
  r1[3] = r2;
  r2 = (object*)TC_NIL;
  r1[4] = r2;
  r2 = varref (0, 2);
  r3 = varref (0, 1);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[5] = r2;
  r2 = varref (0, 3);
  r3 = varref (0, 0);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[6] = r2;
  r1 = varref (0, 4);
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  lenv = lenv[1];
  r1 = r1;
  r0[176] = r1;
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = (object *) constructed_440[0];
  t = alloc_no_clear (UOTAG(1),1);
  t[1] = r2;
  r2 = t;
  r1[2] = r2;
  r2 = (object *) 6;
  t = alloc_no_clear (UOTAG(4),1);
  t[1] = r2;
  r2 = t;
  r1[3] = r2;
  r2 = (object*)TC_NIL;
  r1[4] = r2;
  r2 = varref (0, 2);
  r3 = varref (0, 1);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[5] = r2;
  r2 = varref (0, 3);
  r3 = varref (0, 0);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  r1[6] = r2;
  r1 = varref (0, 4);
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  lenv = lenv[1];
  r1 = r1;
  r0[177] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = varref (0, 105);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1366; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1366:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[178] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = varref (0, 105);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1367; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1367:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[179] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object *) constructed_631[0];
  r1[2] = r2;
  r2 = (object *) constructed_629[0];
  r1[3] = r2;
  r2 = varref (0, 96);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1368; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
  L1368:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[180] = r1;
  r1 = (object *) 1;
  r0[181] = r1;
  r1 = (object *) 5;
  r0[182] = r1;
  r1 = (object *) 7;
  r0[183] = r1;
  r1 = allocate (TC_TUPLE, 5);
  r1[1] = lenv; lenv = r1;
  // def in_3668_i4320
  goto L1369;
  FUN_in_3668_i4320:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3674_i4320
    goto L1370;
    FUN_loop_3674_i4320:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 6;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (3, 1);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object *) 262;
            PXLL_RETURN(0);
          } else {
            r0 = varref (0, 1);
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_loop_3674_i4320;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1370:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3674_i4320; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3674_i4320;
  L1369:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_in_3668_i4320; r2[2] = lenv;
  r1[2] = r2;
  // def add_3669_i4320
  goto L1371;
  FUN_add_3669_i4320:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[3] = r1;
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[2];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1372; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1372:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[0];
      r0[2] = r1;
      r0 = varref (0, 0);
      r1 = varref (1, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      lenv = lenv[1];
      r0 = r0;
      r1 = varref (0, 0);
      ((pxll_vector*)r1)->val[0] = r0;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1371:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3669_i4320; r2[2] = lenv;
  r1[3] = r2;
  // def get_3670_i4320
  goto L1373;
  FUN_get_3670_i4320:
    r0 = varref (0, 0);
    r0 = ((pxll_vector*)r0)->val[0];
    PXLL_RETURN(0);
  L1373:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_3670_i4320; r2[2] = lenv;
  r1[4] = r2;
  // def iterate_3671_i4320
  goto L1374;
  FUN_iterate_3671_i4320:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3683_i4320
    goto L1375;
    FUN_loop_3683_i4320:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1376; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1376:
          ; lenv = k[2]; k = k[1];
          r0 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_3683_i4320;
        } break;
      }
      PXLL_RETURN(0);
    L1375:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3683_i4320; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3683_i4320;
  L1374:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3671_i4320; r2[2] = lenv;
  r1[5] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(14), 4);
  r3 = varref (1, 1);
  r2[1] = r3;
  r3 = varref (1, 2);
  r2[2] = r3;
  r3 = varref (1, 0);
  r2[3] = r3;
  r3 = varref (1, 3);
  r2[4] = r3;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def new_3688_i4320
  goto L1377;
  FUN_new_3688_i4320:
    r0 = allocate (UOTAG(13), 2);
    r1 = varref (0, 0);
    r0[1] = r1;
    r1 = varref (2, 0);
    r0[2] = r1;
    PXLL_RETURN(0);
  L1377:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_new_3688_i4320; r2[2] = lenv;
  r1[2] = r2;
  r1 = varref (0, 0);
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[184] = r1;
  r1 = allocate (TC_TUPLE, 9);
  r1[1] = lenv; lenv = r1;
  // def add_3690_i4321
  goto L1378;
  FUN_add_3690_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r0 = varref (1, 2);
    r1 = varref (0, 0);
    r2 = varref (1, 1);
    t = alloc_no_clear (UOTAG(1),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    lenv = lenv[1];
    r0 = r0;
    r1 = varref (0, 0);
    ((pxll_vector*)r1)->val[0] = r0;
    PXLL_RETURN(0);
  L1378:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_3690_i4321; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_3691_i4321
  goto L1379;
  FUN_lookup_3691_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3703_i4321
    goto L1380;
    FUN_loop_3703_i4321:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = varref (0, 0);
          r1 = varref (3, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = varref (0, 1);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } else {
            r0 = varref (0, 2);
            lenv = ((object *)lenv)[1];
            lenv[2] = r0;
            goto FUN_loop_3703_i4321;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1380:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3703_i4321; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3703_i4321;
  L1379:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_3691_i4321; r2[2] = lenv;
  r1[3] = r2;
  // def lookup*_3692_i4321
  goto L1381;
  FUN_lookup_splat_3692_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (1, 1);
    r1[3] = r2;
    r2 = varref (2, 1);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1382; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_lookup_3691_i4321;
    L1382:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = varref (1, 2);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1381:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_splat_3692_i4321; r2[2] = lenv;
  r1[4] = r2;
  // def get-error_3693_i4321
  goto L1383;
  FUN_get_error_3693_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (1, 1);
    r1[3] = r2;
    r2 = varref (2, 1);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1384; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_lookup_3691_i4321;
    L1384:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (1, 2);
        r0[2] = r1;
        r1 = varref (1, 1);
        r0[3] = r1;
        r1 = varref (3, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1383:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_error_3693_i4321; r2[2] = lenv;
  r1[5] = r2;
  // def iterate_3694_i4321
  goto L1385;
  FUN_iterate_3694_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3720_i4321
    goto L1386;
    FUN_loop_3720_i4321:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (3, 1);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1387; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1387:
          ; lenv = k[2]; k = k[1];
          r0 = varref (0, 2);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          goto FUN_loop_3720_i4321;
        } break;
      }
      PXLL_RETURN(0);
    L1386:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3720_i4321; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3720_i4321;
  L1385:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_iterate_3694_i4321; r2[2] = lenv;
  r1[6] = r2;
  // def map_3695_i4321
  goto L1388;
  FUN_map_3695_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3727_i4321
    goto L1389;
    FUN_loop_3727_i4321:
      check_heap (0);
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (4, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 4);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,2);
          r0[4] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (1, 1);
          r1[3] = r2;
          r2 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1390; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1390:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (2, 0);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (0, 2);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3727_i4321;
        } break;
      }
      PXLL_RETURN(0);
    L1389:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3727_i4321; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_628[0];
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3727_i4321;
  L1388:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_map_3695_i4321; r2[2] = lenv;
  r1[7] = r2;
  // def keys_3696_i4321
  goto L1391;
  FUN_keys_3696_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3734_i4321
    goto L1392;
    FUN_loop_3734_i4321:
      check_heap (0);
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (4, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,2);
          r0[3] = r1;
          r0 = varref (1, 0);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3734_i4321;
        } break;
      }
      PXLL_RETURN(0);
    L1392:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3734_i4321; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_627[0];
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3734_i4321;
  L1391:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_keys_3696_i4321; r2[2] = lenv;
  r1[8] = r2;
  // def values_3697_i4321
  goto L1393;
  FUN_values_3697_i4321:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3740_i4321
    goto L1394;
    FUN_loop_3740_i4321:
      check_heap (0);
      r0 = varref (0, 1);
      switch (get_case (r0)) {
        case (UITAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (4, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r1 = varref (1, 1);
          r1 = UOBJ_GET(r1,2);
          r0[3] = r1;
          r0 = varref (1, 0);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r0;
          lenv[3] = r1;
          goto FUN_loop_3740_i4321;
        } break;
      }
      PXLL_RETURN(0);
    L1394:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3740_i4321; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object *) constructed_626[0];
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3740_i4321;
  L1393:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_values_3697_i4321; r2[2] = lenv;
  r1[9] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (UOTAG(12), 8);
  r3 = varref (1, 0);
  r2[1] = r3;
  r3 = varref (1, 1);
  r2[2] = r3;
  r3 = varref (1, 2);
  r2[3] = r3;
  r3 = varref (1, 3);
  r2[4] = r3;
  r3 = varref (1, 4);
  r2[5] = r3;
  r3 = varref (1, 6);
  r2[6] = r3;
  r3 = varref (1, 5);
  r2[7] = r3;
  r3 = varref (1, 7);
  r2[8] = r3;
  r1[2] = r2;
  // def lambda_23984_i4321
  goto L1395;
  FUN_lambda_23984_i4321:
    r0 = allocate (UOTAG(11), 2);
    r1 = (object*)UITAG(0);
    r0[1] = r1;
    r1 = varref (0, 0);
    r0[2] = r1;
    PXLL_RETURN(0);
  L1395:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_23984_i4321; r1[2] = lenv;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[185] = r1;
  r1 = (object *) 27;
  r0[186] = r1;
  r1 = (object *) 1;
  r0[187] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) 1;
  r2[2] = r3;
  r3 = varref (1, 105);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1396; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
  L1396:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  // def lambda_27113
  goto L1397;
  FUN_lambda_27113:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 4);
    r1[1] = lenv; lenv = r1;
    r2 = allocate (TC_TUPLE, 2);
    r3 = varref (1, 0);
    r3 = ((pxll_vector*)r3)->val[1];
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1398; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    lenv = r3[2]; goto *r3[1];
    L1398:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = varref (2, 54);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1399; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
    L1399:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = varref (0, 1);
    r3 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r1[4] = r2;
    r1 = varref (0, 2);
    r2 = (object*) &constructed_625;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = varref (1, 45);
    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
  L1397:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_27113; r1[2] = lenv;
  lenv = lenv[1];
  r1 = r1;
  r0[188] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object*) &constructed_624;
  r2[2] = r3;
  r3 = varref (0, 53);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1400; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string__3elist_372;
  L1400:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = varref (0, 75);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1401; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_char_class_425;
  L1401:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[189] = r1;
  r1 = (object*) &constructed_623;
  r0[190] = r1;
  r1 = (object*) &constructed_622;
  r0[191] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = (object *) pxll_internal_symbols;
  r0[2] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  // def loop_1287_i4325
  goto L1402;
  FUN_loop_1287_i4325:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (3, 0);
    r1 = box((r1 == (object*) TC_EMPTY_VECTOR) ? 0 : GET_TUPLE_LENGTH(*r1));
    r0[2] = r1;
    r0 = varref (0, 0);
    r1 = varref (1, 0);
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    } else {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r2 = varref (3, 0);
      range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
      r1 = ((pxll_vector*)r2)->val[unbox(r1)];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 5);
      r1 = varref (4, 153);
      r0[2] = r1;
      r1 = varref (4, 50);
      r0[3] = r1;
      r1 = varref (0, 0);
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = varref (1, 0);
      r2 = UOBJ_GET(r2,0);
      r1[2] = r2;
      r1 = varref (0, 0);
      lenv = lenv[1];
      r1 = r1;
      r1=r1;
      r0[4] = r1;
      r1 = varref (0, 0);
      r0[5] = r1;
      r1 = varref (4, 69);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1403; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
      L1403:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      varset (4, 153, r0);
      r0 = varref (0, 0);
      lenv = lenv[1];
      r0 = (object *) 3;
      r1 = varref (0, 0);
      r0 = box(unbox(r1)+unbox(r0));
      lenv[2] = r0;
      goto FUN_loop_1287_i4325;
    }
    PXLL_RETURN(0);
  L1402:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_loop_1287_i4325; r1[2] = lenv;
  r0[2] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r1 = (object *) 1;
  r0[2] = r1;
  r1 = varref (0, 0);
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L1404; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_loop_1287_i4325;
  L1404:
  ; lenv = k[2]; k = k[1];
  r0 = result;
  lenv = lenv[1];
  r0 = r0;
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = varref (1, 152);
  r1 = ((pxll_vector*)r1)->val[0];
  r0[2] = r1;
  r0 = (object *) 5;
  r1 = varref (0, 0);
  r0 = PXLL_TEST(unbox(r1)<unbox(r0));
  lenv = lenv[1];
  r0 = r0;
  if PXLL_IS_TRUE(r0) {
    r0 = (object*) &constructed_69;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_69;
    (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    r0 = (object*) &constructed_621;
    dump_object (r0, 0); fprintf (stdout, "\n");
    r0 = (object*) &constructed_621;
    r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
  } else {
    r0 = (object *) 14;
  }
  r0 = allocate (TC_TUPLE, 35);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (UOTAG(9), 15);
  r2 = (object *) constructed_620[0];
  r1[1] = r2;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = varref (1, 183);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1405; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto *r2[1];
  L1405:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = (object*)UITAG(2);
  r1[4] = r2;
  r2 = (object *) constructed_619[0];
  r1[5] = r2;
  r2 = (object*)UITAG(2);
  r1[6] = r2;
  r2 = (object *) constructed_618[0];
  r1[7] = r2;
  r2 = (object*)UITAG(0);
  r1[8] = r2;
  r2 = (object *) constructed_617[0];
  r1[9] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r2[1] = lenv; lenv = r2;
  r3 = (object *) -1;
  r2[2] = r3;
  r2 = allocate (TC_TUPLE, 3);
  r2[1] = lenv; lenv = r2;
  // def allocate_2655_i3_i4235_i4326
  goto L1406;
  FUN_allocate_2655_i3_i4235_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2658_i3_i4235_i4326
    goto L1407;
    FUN_loop_2658_i3_i4235_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 4);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (2, 0);
      r0[3] = r1;
      r1 = varref (6, 8);
      r0[4] = r1;
      r1 = varref (6, 22);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1408; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_member_question_327;
      L1408:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      if PXLL_IS_TRUE(r0) {
        r0 = (object *) 3;
        r1 = varref (0, 0);
        r0 = box(unbox(r1)+unbox(r0));
        lenv[2] = r0;
        goto FUN_loop_2658_i3_i4235_i4326;
      } else {
        r0 = varref (4, 0);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
          r0 = varref (0, 0);
          r0=r0;
        } else {
          r0 = varref (4, 0);
          r0=r0;
        }
        varset (4, 0, r0);
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1407:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2658_i3_i4235_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2658_i3_i4235_i4326;
  L1406:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_allocate_2655_i3_i4235_i4326; r3[2] = lenv;
  r2[2] = r3;
  // def get-max_2656_i3_i4235_i4326
  goto L1409;
  FUN_get_max_2656_i3_i4235_i4326:
    r0 = varref (1, 0);
    PXLL_RETURN(0);
  L1409:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_get_max_2656_i3_i4235_i4326; r3[2] = lenv;
  r2[3] = r3;
  r2 = allocate (UOTAG(10), 2);
  r3 = varref (0, 0);
  r2[1] = r3;
  r3 = varref (0, 1);
  r2[2] = r3;
  lenv = lenv[1];
  r2 = r2;
  lenv = lenv[1];
  r2 = r2;
  r1[10] = r2;
  r2 = (object *) constructed_616[0];
  r1[11] = r2;
  r2 = (object*) &constructed_615;
  r1[12] = r2;
  r2 = (object*)UITAG(0);
  r1[13] = r2;
  r2 = (object*)UITAG(0);
  r1[14] = r2;
  r2 = (object*)UITAG(2);
  r1[15] = r2;
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 27);
  r1[1] = lenv; lenv = r1;
  // def go_1996_i4236_i4326
  goto L1410;
  FUN_go_1996_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    switch (get_case (r1)) {
      case (UOTAG(0)): {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (2, 0);
        r2 = UOBJ_GET(r2,0);
        r1[2] = r2;
        r1 = varref (0, 0);
        switch (get_case (r1)) {
          case (TC_NIL): {
            r1 = (object *) constructed_613[0];
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (1, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = varref (0, 1);
            switch (get_case (r1)) {
              case (TC_NIL): {
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (0, 0);
                r1[2] = r2;
                r2 = varref (4, 6);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1411; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                L1411:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_130;
              }
            }
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r1=r1;
        goto fatbar_130_over;
        fatbar_130:
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (4, 3);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1412; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_find_declarations_2001_i4236_i4326;
        L1412:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (4, 2);
        r1[3] = r2;
        r2 = varref (4, 4);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1413; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2002_i4236_i4326;
        L1413:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
        fatbar_130_over: ;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      } break;
      default: {
        goto fatbar_129;
      }
    }
    r1=r1;
    goto fatbar_129_over;
    fatbar_129:
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_614;
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (4, 12);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1414; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
    L1414:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
    fatbar_129_over: ;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (2, 18);
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_with_constructors_2019_i4236_i4326;
  L1410:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_go_1996_i4236_i4326; r2[2] = lenv;
  r1[2] = r2;
  // def wrap-fix_1997_i4236_i4326
  goto L1415;
  FUN_wrap_fix_1997_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (4, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1416; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L1416:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)>unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 9);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_612[0];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[2] = r1;
      r1 = varref (1, 0);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[3] = r1;
      r1 = varref (1, 1);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[4] = r1;
      r1 = (object*)TC_NIL;
      r0[5] = r1;
      r1 = varref (0, 3);
      r2 = varref (1, 2);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[6] = r1;
      r1 = varref (0, 4);
      r2 = varref (0, 2);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[7] = r1;
      r1 = varref (0, 5);
      r2 = varref (0, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[8] = r1;
      r1 = varref (0, 6);
      r2 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[9] = r1;
      r0 = varref (0, 7);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r0;
      r0 = t;
      PXLL_RETURN(0);
    } else {
      r0 = varref (0, 2);
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1415:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_fix_1997_i4236_i4326; r2[2] = lenv;
  r1[3] = r2;
  // def wrap-definitions_1999_i4236_i4326
  goto L1417;
  FUN_wrap_definitions_1999_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_610[0];
    r0[2] = r1;
    r1 = (object *) constructed_609[0];
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_11305_i4236_i4326
    goto L1418;
    FUN_lambda_11305_i4236_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = varref (3, 0);
          r0[3] = r1;
          r0 = varref (0, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 0, r0);
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 1);
          r1[2] = r2;
          r2 = varref (5, 6);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1419; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
          L1419:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (3, 1);
          r0[3] = r1;
          r0 = varref (0, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 1, r0);
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1418:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_11305_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (1, 0);
    r0[3] = r1;
    r1 = varref (4, 33);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1420; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L1420:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 4);
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 0);
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = (object *) constructed_37[0];
    r1[3] = r2;
    r2 = varref (5, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1421; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L1421:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 1);
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = (object *) constructed_37[0];
    r1[3] = r2;
    r2 = varref (5, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1422; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L1422:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 3);
    r2[1] = lenv; lenv = r2;
    r3 = (object *) constructed_529[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r3;
    r3 = t;
    r2[2] = r3;
    r3 = varref (2, 1);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r2 = varref (0, 1);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (2, 6);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1423; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
    L1423:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = varref (2, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_fix_1997_i4236_i4326;
  L1417:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_definitions_1999_i4236_i4326; r2[2] = lenv;
  r1[4] = r2;
  // def find-declarations_2001_i4236_i4326
  goto L1424;
  FUN_find_declarations_2001_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_2051_i4236_i4326
    goto L1425;
    FUN_recur_2051_i4236_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 1);
          r0[2] = r1;
          r1 = (object *) constructed_37[0];
          r0[3] = r1;
          r1 = varref (5, 19);
          r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_602[0];
                      r1 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = varref (1, 1);
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (2, 1);
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = varref (2, 1);
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = varref (0, 0);
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 4);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (1, 0);
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                // def loop_2207_i1206_i4236_i4326
                                goto L1426;
                                FUN_loop_2207_i1206_i4236_i4326:
                                  check_heap (0);
                                  r0 = varref (0, 0);
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = (object *) constructed_598[0];
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      r0 = allocate (TC_TUPLE, 3);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 0);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r1 = varref (1, 0);
                                      r1 = UOBJ_GET(r1,1);
                                      r0[3] = r1;
                                      r0 = varref (0, 1);
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (1, 1);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = varref (1, 1);
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = varref (0, 0);
                                          switch (get_case (r0)) {
                                            case (UOTAG(1)): {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = varref (1, 0);
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r0 = (object *) constructed_587[0];
                                              r1 = varref (0, 0);
                                              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                                r0 = varref (1, 1);
                                                switch (get_case (r0)) {
                                                  case (TC_PAIR): {
                                                    r0 = allocate (TC_TUPLE, 5);
                                                    r0[1] = lenv; lenv = r0;
                                                    r1 = varref (2, 1);
                                                    r1 = UOBJ_GET(r1,0);
                                                    r0[2] = r1;
                                                    r1 = varref (2, 1);
                                                    r1 = UOBJ_GET(r1,1);
                                                    r0[3] = r1;
                                                    r1 = allocate (UOTAG(0), 2);
                                                    r2 = varref (3, 0);
                                                    r1[1] = r2;
                                                    r2 = varref (0, 0);
                                                    r1[2] = r2;
                                                    r0[4] = r1;
                                                    r1 = allocate (TC_TUPLE, 2);
                                                    r2 = varref (0, 1);
                                                    r1[2] = r2;
                                                    r2 = varref (5, 0);
                                                    t = allocate (TC_SAVE, 4);
                                                    t[1] = k; t[2] = lenv; t[3] = &&L1427; t[4] = r0; k = t;
                                                    r1[1] = r2[2]; lenv = r1; goto FUN_loop_2207_i1206_i4236_i4326;
                                                    L1427:
                                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                                    r1 = result;
                                                    r0[5] = r1;
                                                    r0 = varref (0, 3);
                                                    r1 = varref (0, 2);
                                                    t = alloc_no_clear (TC_PAIR,2);
                                                    t[1] = r1;
                                                    t[2] = r0;
                                                    r0 = t;
                                                    PXLL_RETURN(0);
                                                  } break;
                                                  default: {
                                                    lenv = ((object ***)lenv)[1][1][1];
                                                    goto fatbar_126;
                                                  }
                                                }
                                                PXLL_RETURN(0);
                                              } else {
                                                lenv = ((object ***)lenv)[1][1][1];
                                                goto fatbar_126;
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_126;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_126;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                  }
                                  PXLL_RETURN(0);
                                  goto fatbar_126_over;
                                  fatbar_126:
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = (object*) &constructed_599;
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[3] = r1;
                                  r1 = varref (13, 12);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                                  fatbar_126_over: ;
                                  PXLL_RETURN(0);
                                L1426:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_loop_2207_i1206_i4236_i4326; r2[2] = lenv;
                                r1[2] = r2;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = varref (2, 1);
                                r1[2] = r2;
                                r2 = varref (0, 0);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1428; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_loop_2207_i1206_i4236_i4326;
                                L1428:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                lenv = lenv[1];
                                r1 = r1;
                                r0[3] = r1;
                                r1 = allocate (TC_TUPLE, 3);
                                r1[1] = lenv; lenv = r1;
                                // def apply_1594_i1207_i4236_i4326
                                goto L1429;
                                FUN_apply_1594_i1207_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  // def loop_1597_i1207_i4236_i4326
                                  goto L1430;
                                  FUN_loop_1597_i1207_i4236_i4326:
                                    check_heap (0);
                                    r0 = varref (0, 0);
                                    switch (get_case (r0)) {
                                      case (TC_PAIR): {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r0[1] = lenv; lenv = r0;
                                        r1 = varref (1, 0);
                                        r1 = UOBJ_GET(r1,0);
                                        r0[2] = r1;
                                        r1 = varref (1, 0);
                                        r1 = UOBJ_GET(r1,1);
                                        r0[3] = r1;
                                        r0 = varref (0, 0);
                                        switch (get_case_noint (r0)) {
                                          default: {
                                            r0 = allocate (TC_TUPLE, 3);
                                            r0[1] = lenv; lenv = r0;
                                            r1 = varref (1, 0);
                                            r1 = UOBJ_GET(r1,0);
                                            r0[2] = r1;
                                            r1 = varref (1, 0);
                                            r1 = UOBJ_GET(r1,1);
                                            r0[3] = r1;
                                            r0 = allocate (TC_TUPLE, 3);
                                            r1 = varref (0, 0);
                                            r0[2] = r1;
                                            r1 = varref (4, 0);
                                            r0[3] = r1;
                                            r1 = varref (17, 89);
                                            t = allocate (TC_SAVE, 3);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1431; ; k = t;
                                            r0[1] = r1[2]; lenv = r0; goto FUN_matches_pattern_question_443;
                                            L1431:
                                            ; lenv = k[2]; k = k[1];
                                            r0 = result;
                                            if PXLL_IS_TRUE(r0) {
                                              r0 = allocate (TC_TUPLE, 2);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = allocate (TC_TUPLE, 3);
                                              r2 = varref (1, 1);
                                              r1[2] = r2;
                                              r2 = allocate (TC_TUPLE, 3);
                                              r3 = varref (1, 0);
                                              r2[2] = r3;
                                              r3 = varref (5, 0);
                                              r2[3] = r3;
                                              r3 = varref (18, 93);
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1432; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_get_bindings_447;
                                              L1432:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[3] = r2;
                                              r2 = varref (18, 94);
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1433; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_pattern_449;
                                              L1433:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[2] = r1;
                                              r0 = varref (0, 0);
                                              PXLL_RETURN(0);
                                            } else {
                                              r0 = varref (1, 1);
                                              lenv = ((object **)lenv)[1][1];
                                              lenv[2] = r0;
                                              goto FUN_loop_1597_i1207_i4236_i4326;
                                            }
                                            PXLL_RETURN(0);
                                          } break;
                                        }
                                        PXLL_RETURN(0);
                                      } break;
                                      default: {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object*) &constructed_597;
                                        r0[2] = r1;
                                        r1 = allocate (TC_TUPLE, 2);
                                        r2 = varref (2, 0);
                                        r1[2] = r2;
                                        r2 = varref (15, 83);
                                        t = allocate (TC_SAVE, 4);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1434; t[4] = r0; k = t;
                                        r1[1] = r2[2]; lenv = r1; goto FUN_repr_435;
                                        L1434:
                                        r0 = k[4]; lenv = k[2]; k = k[1];
                                        r1 = result;
                                        r0[3] = r1;
                                        r1 = varref (15, 12);
                                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                                      } break;
                                    }
                                    PXLL_RETURN(0);
                                  L1430:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN_loop_1597_i1207_i4236_i4326; r1[2] = lenv;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 2);
                                  r1 = varref (3, 1);
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_loop_1597_i1207_i4236_i4326;
                                L1429:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_apply_1594_i1207_i4236_i4326; r2[2] = lenv;
                                r1[2] = r2;
                                // def unread-macro_1595_i1207_i4236_i4326
                                goto L1435;
                                FUN_unread_macro_1595_i1207_i4236_i4326:
                                  check_heap (0);
                                  r0 = (object*) &constructed_596;
                                  r0 = box(((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_596;
                                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  r0 = varref (1, 0);
                                  dump_object (r0, 0);
                                  r0 = (object*) &constructed_595;
                                  r0 = box(((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_595;
                                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  r0 = allocate (TC_TUPLE, 3);
                                  // def lambda_8104_i1207_i4236_i4326
                                  goto L1436;
                                  FUN_lambda_8104_i1207_i4236_i4326:
                                    check_heap (0);
                                    r0 = varref (0, 0);
                                    switch (get_case_noint (r0)) {
                                      default: {
                                        r0 = allocate (TC_TUPLE, 3);
                                        r0[1] = lenv; lenv = r0;
                                        r1 = varref (1, 0);
                                        r1 = UOBJ_GET(r1,0);
                                        r0[2] = r1;
                                        r1 = varref (1, 0);
                                        r1 = UOBJ_GET(r1,1);
                                        r0[3] = r1;
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object *) 1;
                                        r0[2] = r1;
                                        r1 = varref (0, 0);
                                        r0[3] = r1;
                                        r1 = varref (14, 87);
                                        t = allocate (TC_SAVE, 3);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1437; ; k = t;
                                        r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
                                        L1437:
                                        ; lenv = k[2]; k = k[1];
                                        r0 = (object*) &constructed_594;
                                        r0 = box(((pxll_string*)(r0))->len);
                                        r1 = (object*) &constructed_594;
                                        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                        r0 = allocate (TC_TUPLE, 3);
                                        r1 = (object *) 1;
                                        r0[2] = r1;
                                        r1 = varref (0, 1);
                                        r0[3] = r1;
                                        r1 = varref (14, 87);
                                        t = allocate (TC_SAVE, 3);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1438; ; k = t;
                                        r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
                                        L1438:
                                        ; lenv = k[2]; k = k[1];
                                        r0 = (object*) &constructed_593;
                                        r0 = box(((pxll_string*)(r0))->len);
                                        r1 = (object*) &constructed_593;
                                        r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                        PXLL_RETURN(0);
                                      } break;
                                    }
                                    PXLL_RETURN(0);
                                  L1436:
                                  r1 = allocate (TC_CLOSURE, 2);
                                  r1[1] = &&FUN_lambda_8104_i1207_i4236_i4326; r1[2] = lenv;
                                  r0[2] = r1;
                                  r1 = varref (1, 1);
                                  r0[3] = r1;
                                  r1 = varref (12, 33);
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1439; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
                                  L1439:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = (object*) &constructed_592;
                                  r0 = box(((pxll_string*)(r0))->len);
                                  r1 = (object*) &constructed_592;
                                  r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                                  PXLL_RETURN(0);
                                L1435:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_unread_macro_1595_i1207_i4236_i4326; r2[2] = lenv;
                                r1[3] = r2;
                                r1 = allocate (UOTAG(7), 4);
                                r2 = varref (0, 0);
                                r1[1] = r2;
                                r2 = varref (1, 0);
                                r1[2] = r2;
                                r2 = varref (1, 1);
                                r1[3] = r2;
                                r2 = varref (0, 1);
                                r1[4] = r2;
                                lenv = lenv[1];
                                r1 = r1;
                                r0[4] = r1;
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (11, 0);
                                r1 = ((pxll_vector*)r1)->val[7];
                                r0[2] = r1;
                                r0 = varref (1, 2);
                                r1 = varref (0, 0);
                                r2 = varref (1, 0);
                                t = alloc_no_clear (UOTAG(1),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                lenv = lenv[1];
                                r0 = r0;
                                r1 = varref (10, 0);
                                ((pxll_vector*)r1)->val[7] = r0;
                                lenv = lenv[1];
                                r0 = r0;
                                r0=r0;
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_125;
                              }
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            goto fatbar_125;
                          }
                        }
                        goto fatbar_125_over;
                        fatbar_125:
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_600;
                        r0[2] = r1;
                        r1 = varref (1, 1);
                        r0[3] = r1;
                        r1 = varref (9, 12);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1440; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                        L1440:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        fatbar_125_over: ;
                        r0 = varref (4, 1);
                        r1 = varref (3, 1);
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r1;
                        lenv[3] = r0;
                        goto FUN_recur_2051_i4236_i4326;
                      } else {
                        goto fatbar_124;
                      }
                      PXLL_RETURN(0);
                      goto fatbar_124_over;
                      fatbar_124:
                      r0 = (object *) constructed_608[0];
                      r1 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = varref (1, 1);
                        switch (get_case (r0)) {
                          case (TC_PAIR): {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (2, 1);
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = varref (2, 1);
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = varref (0, 0);
                            switch (get_case (r0)) {
                              case (UOTAG(1)): {
                                r0 = allocate (TC_TUPLE, 6);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (1, 0);
                                r1 = UOBJ_GET(r1,0);
                                r0[2] = r1;
                                r1 = varref (11, 183);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1441; t[4] = r0; k = t;
                                lenv = r1[2]; goto *r1[1];
                                L1441:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r1 = varref (11, 183);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1442; t[4] = r0; k = t;
                                lenv = r1[2]; goto *r1[1];
                                L1442:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[4] = r1;
                                r1 = (object *) 1;
                                r0[5] = r1;
                                r1 = allocate (TC_TUPLE, 8);
                                r1[1] = lenv; lenv = r1;
                                // def get_2221_i1213_i4236_i4326
                                goto L1443;
                                FUN_get_2221_i1213_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = varref (2, 2);
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[3] = r1;
                                  r1 = (object*) &constructed_605;
                                  r0[4] = r1;
                                  r1 = varref (2, 2);
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[3];
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L1443:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_2221_i1213_i4236_i4326; r2[2] = lenv;
                                r1[2] = r2;
                                // def add_2222_i1213_i4236_i4326
                                goto L1444;
                                FUN_add_2222_i1213_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 4);
                                  r1 = varref (2, 2);
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r1 = ((pxll_vector*)r1)->val[2];
                                  r0[3] = r1;
                                  r1 = varref (0, 0);
                                  r0[4] = r1;
                                  r1 = varref (2, 2);
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[0];
                                  t = allocate (TC_SAVE, 3);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1445; ; k = t;
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                  L1445:
                                  ; lenv = k[2]; k = k[1];
                                  r0 = varref (2, 3);
                                  r1 = varref (0, 0);
                                  ((pxll_vector*)r1)->val[1] = r0;
                                  r0 = varref (2, 3);
                                  r1 = (object *) 3;
                                  r0 = box(unbox(r1)+unbox(r0));
                                  varset (2, 3, r0);
                                  PXLL_RETURN(0);
                                L1444:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_add_2222_i1213_i4236_i4326; r2[2] = lenv;
                                r1[3] = r2;
                                // def iterate_2223_i1213_i4236_i4326
                                goto L1446;
                                FUN_iterate_2223_i1213_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (2, 2);
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[3] = r1;
                                  r1 = varref (2, 2);
                                  r1 = ((pxll_vector*)r1)->val[1];
                                  r1 = ((pxll_vector*)r1)->val[4];
                                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                L1446:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_iterate_2223_i1213_i4236_i4326; r2[2] = lenv;
                                r1[4] = r2;
                                // def get-nalts_2224_i1213_i4236_i4326
                                goto L1447;
                                FUN_get_nalts_2224_i1213_i4236_i4326:
                                  r0 = varref (1, 3);
                                  PXLL_RETURN(0);
                                L1447:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_nalts_2224_i1213_i4236_i4326; r2[2] = lenv;
                                r1[5] = r2;
                                // def get-scheme_2225_i1213_i4236_i4326
                                goto L1448;
                                FUN_get_scheme_2225_i1213_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (2, 1);
                                  r1[2] = r2;
                                  r2 = varref (2, 1);
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1449; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1449:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (0, 0);
                                  r1[2] = r2;
                                  r2 = (object *) constructed_37[0];
                                  r1[3] = r2;
                                  r2 = varref (13, 19);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1450; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                  L1450:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r0 = allocate (UOTAG(2), 2);
                                  r1 = varref (0, 1);
                                  r0[1] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (2, 0);
                                  r1[2] = r2;
                                  r2 = varref (0, 1);
                                  r1[3] = r2;
                                  r2 = varref (13, 96);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1451; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1451:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  PXLL_RETURN(0);
                                L1448:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_scheme_2225_i1213_i4236_i4326; r2[2] = lenv;
                                r1[6] = r2;
                                // def get-tvars_2226_i1213_i4236_i4326
                                goto L1452;
                                FUN_get_tvars_2226_i1213_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (2, 1);
                                  r1[2] = r2;
                                  r2 = varref (2, 1);
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1453; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1453:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = varref (0, 0);
                                  r0[2] = r1;
                                  r1 = (object *) constructed_37[0];
                                  r0[3] = r1;
                                  r1 = varref (13, 19);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
                                L1452:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_tvars_2226_i1213_i4236_i4326; r2[2] = lenv;
                                r1[7] = r2;
                                // def get-alt-scheme_2227_i1213_i4236_i4326
                                goto L1454;
                                FUN_get_alt_scheme_2227_i1213_i4236_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 6);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (TC_TUPLE, 4);
                                  r2 = varref (3, 2);
                                  r1[2] = r2;
                                  r2 = varref (1, 0);
                                  r1[3] = r2;
                                  r2 = (object*) &constructed_604;
                                  r1[4] = r2;
                                  r2 = varref (3, 2);
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[3];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1455; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1455:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[2] = r1;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r2 = varref (3, 1);
                                  r1[2] = r2;
                                  r2 = varref (3, 1);
                                  r2 = ((pxll_vector*)r2)->val[1];
                                  r2 = ((pxll_vector*)r2)->val[7];
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1456; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                  L1456:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[3] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (0, 1);
                                  r1[2] = r2;
                                  r2 = (object *) constructed_37[0];
                                  r1[3] = r2;
                                  r2 = varref (14, 19);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1457; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                  L1457:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[4] = r1;
                                  r1 = allocate (TC_TUPLE, 3);
                                  r2 = varref (3, 0);
                                  r1[2] = r2;
                                  r2 = varref (0, 2);
                                  r1[3] = r2;
                                  r2 = varref (14, 96);
                                  t = allocate (TC_SAVE, 4);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1458; t[4] = r0; k = t;
                                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                                  L1458:
                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                  r1 = result;
                                  r0[5] = r1;
                                  r1 = allocate (UOTAG(2), 2);
                                  r2 = varref (0, 2);
                                  r1[1] = r2;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r2[1] = lenv; lenv = r2;
                                  r3 = varref (1, 0);
                                  r3 = ((pxll_vector*)r3)->val[3];
                                  r2[2] = r3;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = (object *) constructed_95[0];
                                  r2[2] = r3;
                                  r3 = varref (0, 0);
                                  r4 = varref (1, 3);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r4;
                                  t[2] = r3;
                                  r3 = t;
                                  r2[3] = r3;
                                  r3 = varref (15, 96);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1459; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                  L1459:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  lenv = lenv[1];
                                  r2 = r2;
                                  r1[2] = r2;
                                  r0[6] = r1;
                                  r0 = varref (0, 4);
                                  PXLL_RETURN(0);
                                L1454:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_get_alt_scheme_2227_i1213_i4236_i4326; r2[2] = lenv;
                                r1[8] = r2;
                                r1 = allocate (UOTAG(8), 8);
                                r2 = varref (0, 1);
                                r1[1] = r2;
                                r2 = varref (0, 0);
                                r1[2] = r2;
                                r2 = varref (0, 6);
                                r1[3] = r2;
                                r2 = varref (0, 3);
                                r1[4] = r2;
                                r2 = varref (0, 4);
                                r1[5] = r2;
                                r2 = varref (0, 5);
                                r1[6] = r2;
                                r2 = varref (0, 2);
                                r1[7] = r2;
                                r2 = varref (1, 0);
                                r1[8] = r2;
                                lenv = lenv[1];
                                r1 = r1;
                                r0[6] = r1;
                                r0 = allocate (TC_TUPLE, 3);
                                // def lambda_13137_i1212_i4236_i4326
                                goto L1460;
                                FUN_lambda_13137_i1212_i4236_i4326:
                                  check_heap (0);
                                  r0 = varref (0, 0);
                                  switch (get_case (r0)) {
                                    case (UOTAG(0)): {
                                      r0 = allocate (TC_TUPLE, 2);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = varref (1, 0);
                                      r1 = UOBJ_GET(r1,0);
                                      r0[2] = r1;
                                      r0 = varref (0, 0);
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (1, 0);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = varref (1, 0);
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = varref (0, 0);
                                          switch (get_case (r0)) {
                                            case (UOTAG(9)): {
                                              r0 = allocate (TC_TUPLE, 3);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = varref (1, 0);
                                              r1 = UOBJ_GET(r1,0);
                                              r0[2] = r1;
                                              r1 = varref (1, 0);
                                              r1 = UOBJ_GET(r1,1);
                                              r0[3] = r1;
                                              r0 = (object *) constructed_50[0];
                                              r1 = varref (0, 0);
                                              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                                                r0 = allocate (TC_TUPLE, 2);
                                                r1 = allocate (TC_TUPLE, 4);
                                                r2 = varref (4, 1);
                                                r1[2] = r2;
                                                r2 = varref (0, 1);
                                                r1[3] = r2;
                                                r2 = varref (1, 1);
                                                r1[4] = r2;
                                                r2 = varref (13, 20);
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1461; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_make_alt_2021_i4236_i4326;
                                                L1461:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r0[2] = r1;
                                                r1 = varref (4, 4);
                                                r1 = ((pxll_vector*)r1)->val[0];
                                                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                                              } else {
                                                lenv = ((object ***)lenv)[1][1][1];
                                                goto fatbar_128;
                                              }
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object **)lenv)[1][1];
                                              goto fatbar_128;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *)lenv)[1];
                                          goto fatbar_128;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      goto fatbar_128;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                  goto fatbar_128_over;
                                  fatbar_128:
                                  r0 = allocate (TC_TUPLE, 3);
                                  r1 = (object*) &constructed_603;
                                  r0[2] = r1;
                                  r1 = varref (0, 0);
                                  r0[3] = r1;
                                  r1 = varref (12, 12);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                                  fatbar_128_over: ;
                                  PXLL_RETURN(0);
                                L1460:
                                r1 = allocate (TC_CLOSURE, 2);
                                r1[1] = &&FUN_lambda_13137_i1212_i4236_i4326; r1[2] = lenv;
                                r0[2] = r1;
                                r1 = varref (1, 1);
                                r0[3] = r1;
                                r1 = varref (11, 33);
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L1462; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
                                L1462:
                                ; lenv = k[2]; k = k[1];
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (11, 0);
                                r1 = ((pxll_vector*)r1)->val[1];
                                r0[2] = r1;
                                r0 = varref (1, 4);
                                r1 = varref (0, 0);
                                r2 = varref (1, 0);
                                t = alloc_no_clear (UOTAG(1),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                lenv = lenv[1];
                                r0 = r0;
                                r1 = varref (10, 0);
                                ((pxll_vector*)r1)->val[1] = r0;
                                lenv = lenv[1];
                                r0 = r0;
                                r0=r0;
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_127;
                              }
                            }
                            lenv = lenv[1];
                            r0 = r0;
                            r0=r0;
                          } break;
                          default: {
                            goto fatbar_127;
                          }
                        }
                        goto fatbar_127_over;
                        fatbar_127:
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_606;
                        r0[2] = r1;
                        r1 = varref (1, 1);
                        r0[3] = r1;
                        r1 = varref (9, 12);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1463; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                        L1463:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                        fatbar_127_over: ;
                        r0 = varref (4, 1);
                        r1 = varref (3, 1);
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r1;
                        lenv[3] = r0;
                        goto FUN_recur_2051_i4236_i4326;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_123;
                      }
                      PXLL_RETURN(0);
                      fatbar_124_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_123;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_123;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_123;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_123_over;
          fatbar_123:
          r0 = varref (1, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = varref (0, 1);
          lenv = ((object *)lenv)[1];
          lenv[2] = r1;
          lenv[3] = r0;
          goto FUN_recur_2051_i4236_i4326;
          fatbar_123_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1425:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_2051_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = (object *) constructed_591[0];
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_2051_i4236_i4326;
  L1424:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_find_declarations_2001_i4236_i4326; r2[2] = lenv;
  r1[5] = r2;
  // def find-definitions_2002_i4236_i4326
  goto L1464;
  FUN_find_definitions_2002_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def recur_2062_i4236_i4326
    goto L1465;
    FUN_recur_2062_i4236_i4326:
      check_heap (0);
      r0 = varref (0, 2);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 3);
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (5, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1466; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1466:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (5, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1467; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1467:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = varref (2, 1);
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_590[0];
                      r1 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (2, 1);
                        switch (get_case (r1)) {
                          case (TC_PAIR): {
                            r1 = allocate (TC_TUPLE, 3);
                            r1[1] = lenv; lenv = r1;
                            r2 = varref (3, 1);
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r2 = varref (3, 1);
                            r2 = UOBJ_GET(r2,1);
                            r1[3] = r2;
                            r1 = varref (0, 0);
                            switch (get_case (r1)) {
                              case (UOTAG(1)): {
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                r2 = varref (1, 0);
                                r2 = UOBJ_GET(r2,0);
                                r1[2] = r2;
                                r1 = allocate (TC_TUPLE, 4);
                                r2 = (object *) constructed_587[0];
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r2;
                                r2 = t;
                                r1[2] = r2;
                                r2 = varref (1, 1);
                                r1[3] = r2;
                                r2 = varref (12, 81);
                                r1[4] = r2;
                                r2 = varref (12, 22);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L1468; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_member_question_327;
                                L1468:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                if PXLL_IS_TRUE(r1) {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 5);
                                  r3 = varref (12, 0);
                                  r2[2] = r3;
                                  r3 = varref (11, 6);
                                  r2[3] = r3;
                                  r3 = (object *) constructed_584[0];
                                  r2[4] = r3;
                                  r3 = varref (2, 1);
                                  r2[5] = r3;
                                  r3 = varref (13, 108);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1469; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_compile_pattern_480;
                                  L1469:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = varref (0, 0);
                                  switch (get_case_noint (r1)) {
                                    default: {
                                      r1 = allocate (TC_TUPLE, 3);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = varref (1, 0);
                                      r2 = UOBJ_GET(r2,0);
                                      r1[2] = r2;
                                      r2 = varref (1, 0);
                                      r2 = UOBJ_GET(r2,1);
                                      r1[3] = r2;
                                      r1 = allocate (UOTAG(0), 2);
                                      r2 = varref (2, 0);
                                      r1[1] = r2;
                                      r2 = allocate (TC_TUPLE, 11);
                                      r2[1] = lenv; lenv = r2;
                                      r3 = (object *) constructed_531[0];
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[2] = r3;
                                      r3 = varref (3, 0);
                                      t = alloc_no_clear (UOTAG(1),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[3] = r3;
                                      r3 = allocate (TC_TUPLE, 3);
                                      r4 = varref (15, 1);
                                      r3[2] = r4;
                                      r4 = varref (1, 0);
                                      r3[3] = r4;
                                      r4 = varref (15, 30);
                                      t = allocate (TC_SAVE, 6);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1470; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                      r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
                                      L1470:
                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                      r3 = result;
                                      r2[4] = r3;
                                      r3 = varref (0, 2);
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r3;
                                      r3 = t;
                                      r2[5] = r3;
                                      r3 = allocate (TC_TUPLE, 2);
                                      r4 = varref (1, 1);
                                      r3[2] = r4;
                                      r4 = varref (13, 6);
                                      t = allocate (TC_SAVE, 6);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1471; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                      r3[1] = r4[2]; lenv = r3; goto FUN_expand_2004_i4236_i4326;
                                      L1471:
                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                      r3 = result;
                                      r2[6] = r3;
                                      r3 = (object*)TC_NIL;
                                      r2[7] = r3;
                                      r3 = varref (0, 5);
                                      r4 = varref (0, 4);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[8] = r3;
                                      r3 = varref (0, 6);
                                      r4 = varref (0, 3);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[9] = r3;
                                      r3 = varref (0, 7);
                                      r4 = varref (0, 1);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[10] = r3;
                                      r3 = varref (0, 8);
                                      r4 = varref (0, 0);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r4;
                                      t[2] = r3;
                                      r3 = t;
                                      r2[11] = r3;
                                      r2 = varref (0, 9);
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r2;
                                      r2 = t;
                                      lenv = lenv[1];
                                      r2 = r2;
                                      r1[2] = r2;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r1=r1;
                                    } break;
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } else {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = varref (2, 1);
                                  r2[2] = r3;
                                  r3 = varref (13, 20);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1472; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
                                  L1472:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = varref (0, 0);
                                  r3 = (object *) 3;
                                  r2 = PXLL_TEST(unbox(r3)==unbox(r2));
                                  r1[3] = r2;
                                  r1 = (object *) 6;
                                  r2 = varref (0, 1);
                                  r1 = PXLL_TEST(r2==r1);
                                  lenv = lenv[1];
                                  r1 = r1;
                                  if PXLL_IS_TRUE(r1) {
                                    r1 = allocate (TC_TUPLE, 3);
                                    r2 = (object*) &constructed_585;
                                    r1[2] = r2;
                                    r2 = varref (0, 0);
                                    r1[3] = r2;
                                    r2 = varref (12, 12);
                                    t = allocate (TC_SAVE, 4);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1473; t[4] = r0; k = t;
                                    r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                                    L1473:
                                    r0 = k[4]; lenv = k[2]; k = k[1];
                                    r1 = result;
                                    r1=r1;
                                  } else {
                                    r1 = allocate (UOTAG(0), 2);
                                    r2 = varref (0, 0);
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 2);
                                    r3 = varref (1, 1);
                                    r2[2] = r3;
                                    r3 = varref (12, 17);
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1474; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
                                    L1474:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    r1[2] = r2;
                                    r1=r1;
                                  }
                                  r1=r1;
                                }
                                lenv = lenv[1];
                                r1 = r1;
                                r1=r1;
                              } break;
                              case (UOTAG(0)): {
                                r1 = allocate (TC_TUPLE, 2);
                                r1[1] = lenv; lenv = r1;
                                r2 = varref (1, 0);
                                r2 = UOBJ_GET(r2,0);
                                r1[2] = r2;
                                r1 = varref (0, 0);
                                switch (get_case (r1)) {
                                  case (TC_PAIR): {
                                    r1 = allocate (TC_TUPLE, 3);
                                    r1[1] = lenv; lenv = r1;
                                    r2 = varref (1, 0);
                                    r2 = UOBJ_GET(r2,0);
                                    r1[2] = r2;
                                    r2 = varref (1, 0);
                                    r2 = UOBJ_GET(r2,1);
                                    r1[3] = r2;
                                    r1 = varref (0, 0);
                                    switch (get_case (r1)) {
                                      case (UOTAG(1)): {
                                        r1 = allocate (TC_TUPLE, 2);
                                        r1[1] = lenv; lenv = r1;
                                        r2 = varref (1, 0);
                                        r2 = UOBJ_GET(r2,0);
                                        r1[2] = r2;
                                        r1 = allocate (UOTAG(0), 2);
                                        r2 = varref (0, 0);
                                        r1[1] = r2;
                                        r2 = allocate (TC_TUPLE, 10);
                                        r2[1] = lenv; lenv = r2;
                                        r3 = (object *) constructed_531[0];
                                        t = alloc_no_clear (UOTAG(1),1);
                                        t[1] = r3;
                                        r3 = t;
                                        r2[2] = r3;
                                        r3 = varref (1, 0);
                                        t = alloc_no_clear (UOTAG(1),1);
                                        t[1] = r3;
                                        r3 = t;
                                        r2[3] = r3;
                                        r3 = varref (2, 1);
                                        t = alloc_no_clear (UOTAG(0),1);
                                        t[1] = r3;
                                        r3 = t;
                                        r2[4] = r3;
                                        r3 = allocate (TC_TUPLE, 3);
                                        r4 = varref (4, 1);
                                        r3[2] = r4;
                                        r4 = varref (13, 2);
                                        r3[3] = r4;
                                        r4 = varref (13, 4);
                                        t = allocate (TC_SAVE, 6);
                                        t[1] = k; t[2] = lenv; t[3] = &&L1475; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                        r3[1] = r4[2]; lenv = r3; goto FUN_find_definitions_2002_i4236_i4326;
                                        L1475:
                                        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                        r3 = result;
                                        r2[5] = r3;
                                        r3 = (object*)TC_NIL;
                                        r2[6] = r3;
                                        r3 = varref (0, 4);
                                        r4 = varref (0, 3);
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[7] = r3;
                                        r3 = varref (0, 5);
                                        r4 = varref (0, 2);
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[8] = r3;
                                        r3 = varref (0, 6);
                                        r4 = varref (0, 1);
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[9] = r3;
                                        r3 = varref (0, 7);
                                        r4 = varref (0, 0);
                                        t = alloc_no_clear (TC_PAIR,2);
                                        t[1] = r4;
                                        t[2] = r3;
                                        r3 = t;
                                        r2[10] = r3;
                                        r2 = varref (0, 8);
                                        t = alloc_no_clear (UOTAG(0),1);
                                        t[1] = r2;
                                        r2 = t;
                                        lenv = lenv[1];
                                        r2 = r2;
                                        r1[2] = r2;
                                        lenv = lenv[1];
                                        r1 = r1;
                                        r1=r1;
                                      } break;
                                      default: {
                                        lenv = ((object ***)lenv)[1][1][1];
                                        goto fatbar_122;
                                      }
                                    }
                                    lenv = lenv[1];
                                    r1 = r1;
                                    r1=r1;
                                  } break;
                                  default: {
                                    lenv = ((object **)lenv)[1][1];
                                    goto fatbar_122;
                                  }
                                }
                                lenv = lenv[1];
                                r1 = r1;
                                r1=r1;
                              } break;
                              default: {
                                lenv = ((object *)lenv)[1];
                                goto fatbar_122;
                              }
                            }
                            lenv = lenv[1];
                            r1 = r1;
                            r1=r1;
                          } break;
                          default: {
                            goto fatbar_122;
                          }
                        }
                        r1=r1;
                        goto fatbar_122_over;
                        fatbar_122:
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = (object*) &constructed_588;
                        r1[2] = r2;
                        r2 = varref (2, 1);
                        r1[3] = r2;
                        r2 = varref (10, 12);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1476; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                        L1476:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                        fatbar_122_over: ;
                        r0[2] = r1;
                        r0 = varref (5, 0);
                        r1 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        r1 = varref (4, 1);
                        r2 = varref (3, 1);
                        lenv = ((object ****)lenv)[1][1][1][1];
                        lenv[2] = r0;
                        lenv[3] = r1;
                        lenv[4] = r2;
                        goto FUN_recur_2062_i4236_i4326;
                      } else {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_121;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_121;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_121;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_121;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_121_over;
          fatbar_121:
          r0 = varref (1, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          r1 = varref (0, 1);
          r2 = varref (1, 0);
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_recur_2062_i4236_i4326;
          fatbar_121_over: ;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1465:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_recur_2062_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) constructed_583[0];
    r0[2] = r1;
    r1 = (object *) constructed_582[0];
    r0[3] = r1;
    r1 = varref (1, 0);
    r0[4] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_recur_2062_i4236_i4326;
  L1464:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_find_definitions_2002_i4236_i4326; r2[2] = lenv;
  r1[6] = r2;
  // def expand-field_2003_i4236_i4326
  goto L1477;
  FUN_expand_field_2003_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,0);
    r0[2] = r1;
    r1 = varref (1, 0);
    r1 = UOBJ_GET(r1,1);
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 1);
    r1[2] = r2;
    r2 = varref (2, 6);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1478; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
    L1478:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r0 = varref (0, 2);
    r1 = varref (0, 0);
    t = alloc_no_clear (UOTAG(0),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    PXLL_RETURN(0);
  L1477:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_field_2003_i4236_i4326; r2[2] = lenv;
  r1[7] = r2;
  // def expand_2004_i4236_i4326
  goto L1479;
  FUN_expand_2004_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 7);
        r0[1] = r1[2]; lenv = r0; goto FUN_maybe_expand_2005_i4236_i4326;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 6);
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (4, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1480; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1480:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        t = alloc_no_clear (UOTAG(7),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(8)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (2, 5);
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (4, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1481; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1481:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        t = alloc_no_clear (UOTAG(8),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 6);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1482; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
        L1482:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 2);
        t = alloc_no_clear (UOTAG(10),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1479:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_2004_i4236_i4326; r2[2] = lenv;
  r1[8] = r2;
  // def maybe-expand_2005_i4236_i4326
  goto L1483;
  FUN_maybe_expand_2005_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) constructed_577[0];
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 25);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (5, 64);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1484; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L1484:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (2, 1);
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (5, 0);
                r2 = ((pxll_vector*)r2)->val[7];
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (6, 64);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1485; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                L1485:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(0)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (4, 0);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r2;
                    r2 = t;
                    r1[2] = r2;
                    r2 = varref (0, 0);
                    r2 = ((pxll_vector*)r2)->val[0];
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1486; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L1486:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (5, 6);
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_2004_i4236_i4326;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (5, 6);
                    r1[2] = r2;
                    r2 = varref (3, 1);
                    r1[3] = r2;
                    r2 = varref (7, 30);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1487; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                    L1487:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (0, 0);
                    r2 = varref (3, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[3] = r1;
                    r0 = varref (0, 1);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_581[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (UOTAG(1)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r0 = varref (1, 1);
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (2, 1);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = varref (2, 1);
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = varref (0, 1);
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = allocate (TC_TUPLE, 8);
                                      r0[1] = lenv; lenv = r0;
                                      r1 = (object *) constructed_579[0];
                                      r2 = varref (1, 0);
                                      t = alloc_no_clear (UOTAG(10),2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[2] = r1;
                                      r1 = varref (2, 0);
                                      r2 = varref (0, 0);
                                      t = alloc_no_clear (UOTAG(10),2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[3] = r1;
                                      r1 = (object*)TC_NIL;
                                      r0[4] = r1;
                                      r1 = varref (0, 2);
                                      r2 = varref (1, 0);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[5] = r1;
                                      r1 = varref (0, 3);
                                      r2 = varref (0, 1);
                                      t = alloc_no_clear (TC_PAIR,2);
                                      t[1] = r2;
                                      t[2] = r1;
                                      r1 = t;
                                      r0[6] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = varref (9, 6);
                                      r1[2] = r2;
                                      r2 = varref (7, 1);
                                      r1[3] = r2;
                                      r2 = varref (11, 30);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1488; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                                      L1488:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[7] = r1;
                                      r1 = allocate (TC_TUPLE, 3);
                                      r2 = allocate (TC_TUPLE, 3);
                                      r3 = varref (0, 4);
                                      r2[2] = r3;
                                      r3 = (object *) constructed_37[0];
                                      r2[3] = r3;
                                      r3 = varref (11, 19);
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1489; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                                      L1489:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r2 = varref (0, 5);
                                      r1[3] = r2;
                                      r2 = varref (11, 19);
                                      t = allocate (TC_SAVE, 4);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1490; t[4] = r0; k = t;
                                      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                                      L1490:
                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                      r1 = result;
                                      r0[8] = r1;
                                      r0 = varref (0, 6);
                                      t = alloc_no_clear (UOTAG(0),1);
                                      t[1] = r0;
                                      r0 = t;
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                      goto fatbar_120;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_120;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_120;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_120;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_120;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_120;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_120;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_120;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_120_over;
        fatbar_120:
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (3, 6);
        r1[2] = r2;
        r2 = varref (2, 0);
        r1[3] = r2;
        r2 = varref (5, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1491; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1491:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_120_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1483:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_maybe_expand_2005_i4236_i4326; r2[2] = lenv;
  r1[9] = r2;
  // def expand-if_2006_i4236_i4326
  goto L1492;
  FUN_expand_if_2006_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 10);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (2, 0);
                r1[2] = r2;
                r2 = varref (4, 6);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1493; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                L1493:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (1, 0);
                r1[2] = r2;
                r2 = varref (4, 6);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1494; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                L1494:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = (object*)UITAG(6);
                r0[4] = r1;
                r1 = (object*)TC_NIL;
                r0[5] = r1;
                r1 = varref (0, 3);
                r2 = varref (0, 2);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[6] = r1;
                r1 = varref (0, 4);
                r2 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[7] = r1;
                r1 = varref (0, 5);
                r2 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[8] = r1;
                r1 = (object *) constructed_525[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[9] = r1;
                r1 = varref (0, 6);
                r2 = varref (0, 7);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[10] = r1;
                r0 = varref (0, 8);
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 10);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (3, 0);
                    r1[2] = r2;
                    r2 = varref (5, 6);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1495; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                    L1495:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (2, 0);
                    r1[2] = r2;
                    r2 = varref (5, 6);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1496; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                    L1496:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (5, 6);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1497; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                    L1497:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r1 = (object*)TC_NIL;
                    r0[5] = r1;
                    r1 = varref (0, 3);
                    r2 = varref (0, 2);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = varref (0, 4);
                    r2 = varref (0, 1);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = varref (0, 5);
                    r2 = varref (0, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r1 = (object *) constructed_525[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[9] = r1;
                    r1 = varref (0, 6);
                    r2 = varref (0, 7);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[10] = r1;
                    r0 = varref (0, 8);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_119;
                  }
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_119;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_119;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_119_over;
    fatbar_119:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_576;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_119_over: ;
    PXLL_RETURN(0);
  L1492:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_if_2006_i4236_i4326; r2[2] = lenv;
  r1[10] = r2;
  // def expand-set!_2007_i4236_i4326
  goto L1498;
  FUN_expand_set_bang_2007_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(10)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (1, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (2, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (2, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 10);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (2, 1);
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (2, 0);
                    r1[2] = r2;
                    r2 = varref (5, 6);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1499; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                    L1499:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (5, 6);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1500; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                    L1500:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r1 = (object*)TC_NIL;
                    r0[5] = r1;
                    r1 = varref (0, 3);
                    r2 = varref (0, 2);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = varref (0, 4);
                    r2 = varref (0, 1);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = varref (0, 5);
                    r2 = varref (0, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r1 = (object *) constructed_422[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[9] = r1;
                    r1 = varref (0, 6);
                    r2 = varref (0, 7);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[10] = r1;
                    r0 = varref (0, 8);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_118;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_118;
              }
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = (object *) constructed_239[0];
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_PAIR): {
                                  r0 = allocate (TC_TUPLE, 3);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,0);
                                  r0[2] = r1;
                                  r1 = varref (1, 1);
                                  r1 = UOBJ_GET(r1,1);
                                  r0[3] = r1;
                                  r0 = varref (0, 1);
                                  switch (get_case (r0)) {
                                    case (TC_NIL): {
                                      r0 = varref (6, 1);
                                      switch (get_case (r0)) {
                                        case (TC_PAIR): {
                                          r0 = allocate (TC_TUPLE, 3);
                                          r0[1] = lenv; lenv = r0;
                                          r1 = varref (7, 1);
                                          r1 = UOBJ_GET(r1,0);
                                          r0[2] = r1;
                                          r1 = varref (7, 1);
                                          r1 = UOBJ_GET(r1,1);
                                          r0[3] = r1;
                                          r0 = varref (0, 1);
                                          switch (get_case (r0)) {
                                            case (TC_NIL): {
                                              r0 = allocate (TC_TUPLE, 11);
                                              r0[1] = lenv; lenv = r0;
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = varref (3, 0);
                                              r1[2] = r2;
                                              r2 = varref (10, 6);
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1501; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                                              L1501:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[2] = r1;
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = varref (2, 0);
                                              r1[2] = r2;
                                              r2 = varref (10, 6);
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1502; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                                              L1502:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[3] = r1;
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = varref (1, 0);
                                              r1[2] = r2;
                                              r2 = varref (10, 6);
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1503; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                                              L1503:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r0[4] = r1;
                                              r1 = (object*)TC_NIL;
                                              r0[5] = r1;
                                              r1 = varref (0, 3);
                                              r2 = varref (0, 2);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[6] = r1;
                                              r1 = varref (0, 4);
                                              r2 = varref (0, 1);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[7] = r1;
                                              r1 = varref (0, 5);
                                              r2 = varref (0, 0);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[8] = r1;
                                              r1 = varref (0, 6);
                                              r2 = varref (4, 0);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[9] = r1;
                                              r1 = (object *) constructed_230[0];
                                              t = alloc_no_clear (UOTAG(1),1);
                                              t[1] = r1;
                                              r1 = t;
                                              r0[10] = r1;
                                              r1 = varref (0, 7);
                                              r2 = varref (0, 8);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r2;
                                              t[2] = r1;
                                              r1 = t;
                                              r0[11] = r1;
                                              r0 = varref (0, 9);
                                              t = alloc_no_clear (UOTAG(0),1);
                                              t[1] = r0;
                                              r0 = t;
                                              PXLL_RETURN(0);
                                            } break;
                                            default: {
                                              lenv = ((object ********)lenv)[1][1][1][1][1][1][1][1];
                                              goto fatbar_118;
                                            }
                                          }
                                          PXLL_RETURN(0);
                                        } break;
                                        default: {
                                          lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                          goto fatbar_118;
                                        }
                                      }
                                      PXLL_RETURN(0);
                                    } break;
                                    default: {
                                      lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                      goto fatbar_118;
                                    }
                                  }
                                  PXLL_RETURN(0);
                                } break;
                                default: {
                                  lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                  goto fatbar_118;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_118;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_118;
                        }
                      }
                      PXLL_RETURN(0);
                    } else {
                      lenv = ((object ****)lenv)[1][1][1][1];
                      goto fatbar_118;
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_118;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_118;
              }
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (1, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (2, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (2, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 8);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (2, 0);
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (5, 6);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1504; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                    L1504:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = (object*)TC_NIL;
                    r0[4] = r1;
                    r1 = varref (0, 2);
                    r2 = varref (0, 1);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[5] = r1;
                    r1 = varref (0, 3);
                    r2 = varref (0, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = (object *) constructed_527[0];
                    t = alloc_no_clear (UOTAG(1),1);
                    t[1] = r1;
                    r1 = t;
                    r0[7] = r1;
                    r1 = varref (0, 4);
                    r2 = varref (0, 5);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[8] = r1;
                    r0 = varref (0, 6);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object ***)lenv)[1][1][1];
                    goto fatbar_118;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_118;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_118;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_118;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_118_over;
    fatbar_118:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_575;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_118_over: ;
    PXLL_RETURN(0);
  L1498:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_set_bang_2007_i4236_i4326; r2[2] = lenv;
  r1[11] = r2;
  // def expand-begin_2008_i4236_i4326
  goto L1505;
  FUN_expand_begin_2008_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_574;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_574;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (2, 6);
            r0[1] = r1[2]; lenv = r0; goto FUN_expand_2004_i4236_i4326;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_117;
          }
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
    goto fatbar_117_over;
    fatbar_117:
    r0 = allocate (TC_TUPLE, 4);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (2, 6);
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (4, 30);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1506; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
    L1506:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = (object *) constructed_529[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = varref (0, 0);
    r2 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r0 = varref (0, 2);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_117_over: ;
    PXLL_RETURN(0);
  L1505:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_begin_2008_i4236_i4326; r2[2] = lenv;
  r1[12] = r2;
  // def expand-let-splat_2009_i4236_i4326
  goto L1507;
  FUN_expand_let_splat_2009_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_12095_i4236_i4326
            goto L1508;
            FUN_lambda_12095_i4236_i4326:
              check_heap (0);
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = allocate (TC_TUPLE, 5);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = varref (1, 0);
                              r1[2] = r2;
                              r2 = varref (8, 6);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1509; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                              L1509:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = (object*)TC_NIL;
                              r0[3] = r1;
                              r1 = varref (0, 1);
                              r2 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r0[4] = r1;
                              r1 = varref (0, 2);
                              r2 = varref (2, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r0[5] = r1;
                              r0 = varref (0, 3);
                              t = alloc_no_clear (UOTAG(0),1);
                              t[1] = r0;
                              r0 = t;
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_116;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_116;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_116;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_116;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_116_over;
              fatbar_116:
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_572;
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (6, 12);
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
              fatbar_116_over: ;
              PXLL_RETURN(0);
            L1508:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_12095_i4236_i4326; r2[2] = lenv;
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (5, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1510; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L1510:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = varref (0, 1);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 1);
            r1[2] = r2;
            r2 = varref (3, 2);
            r1[3] = r2;
            r2 = varref (3, 4);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1511; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2002_i4236_i4326;
            L1511:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = (object*)TC_NIL;
            r0[6] = r1;
            r1 = varref (0, 4);
            r2 = varref (0, 3);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = varref (0, 5);
            r2 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = (object *) constructed_535[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = varref (0, 6);
            r2 = varref (0, 7);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[10] = r1;
            r0 = varref (0, 8);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_115;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_115;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_115_over;
    fatbar_115:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_573;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_115_over: ;
    PXLL_RETURN(0);
  L1507:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_let_splat_2009_i4236_i4326; r2[2] = lenv;
  r1[13] = r2;
  // def expand-lambda_2010_i4236_i4326
  goto L1512;
  FUN_expand_lambda_2010_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = (object *) constructed_517[0];
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (2, 2);
        r1[3] = r2;
        r2 = varref (2, 4);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1513; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2002_i4236_i4326;
        L1513:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (2, 14);
        r0[1] = r1[2]; lenv = r0; goto FUN_exp_function_2012_i4236_i4326;
      } break;
      default: {
        goto fatbar_114;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_114_over;
    fatbar_114:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_571;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_114_over: ;
    PXLL_RETURN(0);
  L1512:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_lambda_2010_i4236_i4326; r2[2] = lenv;
  r1[14] = r2;
  // def expand-function_2011_i4236_i4326
  goto L1514;
  FUN_expand_function_2011_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (3, 2);
            r1[3] = r2;
            r2 = varref (3, 4);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1515; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_find_definitions_2002_i4236_i4326;
            L1515:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = varref (3, 14);
            r0[1] = r1[2]; lenv = r0; goto FUN_exp_function_2012_i4236_i4326;
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_113;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_113;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_113_over;
    fatbar_113:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_570;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_113_over: ;
    PXLL_RETURN(0);
  L1514:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_function_2011_i4236_i4326; r2[2] = lenv;
  r1[15] = r2;
  // def exp-function_2012_i4236_i4326
  goto L1516;
  FUN_exp_function_2012_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 7);
    r0[1] = lenv; lenv = r0;
    r1 = (object*)TC_NIL;
    r0[2] = r1;
    r1 = varref (0, 0);
    r2 = varref (1, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = varref (0, 1);
    r2 = varref (1, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = varref (0, 2);
    r2 = varref (1, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[5] = r1;
    r1 = (object *) constructed_531[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[6] = r1;
    r1 = varref (0, 3);
    r2 = varref (0, 4);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[7] = r1;
    r0 = varref (0, 5);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1516:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_exp_function_2012_i4236_i4326; r2[2] = lenv;
  r1[16] = r2;
  // def make-nvget_2014_i4236_i4326
  goto L1517;
  FUN_make_nvget_2014_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 15);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_258[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = varref (1, 1);
    r2 = varref (1, 0);
    t = alloc_no_clear (UOTAG(9),2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r1 = varref (1, 2);
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = varref (1, 3);
    t = alloc_no_clear (UOTAG(5),1);
    t[1] = r1;
    r1 = t;
    r0[5] = r1;
    r1 = (object*)TC_NIL;
    r0[6] = r1;
    r1 = varref (0, 4);
    r2 = varref (0, 3);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = varref (0, 5);
    r2 = varref (0, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[8] = r1;
    r1 = varref (0, 6);
    r2 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[9] = r1;
    r1 = varref (0, 7);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[10] = r1;
    r1 = varref (1, 4);
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[11] = r1;
    r1 = (object*)TC_NIL;
    r0[12] = r1;
    r1 = varref (0, 10);
    r2 = varref (0, 9);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[13] = r1;
    r1 = varref (0, 11);
    r2 = varref (0, 8);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[14] = r1;
    r1 = varref (0, 12);
    r2 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[15] = r1;
    r0 = varref (0, 13);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1517:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_nvget_2014_i4236_i4326; r2[2] = lenv;
  r1[17] = r2;
  // def expand-vcase_2015_i4236_i4326
  goto L1518;
  FUN_expand_vcase_2015_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (1, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (2, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (2, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 0);
                switch (get_case (r0)) {
                  case (UOTAG(1)): {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    r1 = varref (2, 0);
                    r0[2] = r1;
                    r1 = varref (0, 0);
                    r0[3] = r1;
                    r1 = varref (1, 1);
                    r0[4] = r1;
                    r1 = varref (5, 17);
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_vcase_splat_2016_i4236_i4326;
                  } break;
                  default: {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_112;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_112;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_112_over;
            fatbar_112:
            r0 = allocate (TC_TUPLE, 4);
            r1 = (object *) constructed_50[0];
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (1, 1);
            r0[4] = r1;
            r1 = varref (3, 17);
            r0[1] = r1[2]; lenv = r0; goto FUN_expand_vcase_splat_2016_i4236_i4326;
            fatbar_112_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_111;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_111;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_111_over;
    fatbar_111:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_569;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_111_over: ;
    PXLL_RETURN(0);
  L1518:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_vcase_2015_i4236_i4326; r2[2] = lenv;
  r1[18] = r2;
  // def expand-vcase*_2016_i4236_i4326
  goto L1519;
  FUN_expand_vcase_splat_2016_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def lambda_12661_i4236_i4326
    goto L1520;
    FUN_lambda_12661_i4236_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_568[0];
      r0[2] = r1;
      r1 = (object *) constructed_567[0];
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (2, 2);
      r1[2] = r2;
      r2 = varref (7, 20);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1521; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
      L1521:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_2191_i4236_i4326
      goto L1522;
      FUN__24loop_2191_i4236_i4326:
        check_heap (0);
        r0 = varref (2, 0);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (5, 1);
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (10, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1523; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L1523:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (10, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1524; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L1524:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (5, 0);
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (10, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1525; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L1525:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          // def loop_2196_i4236_i4326
          goto L1526;
          FUN_loop_2196_i4236_i4326:
            check_heap (0);
            r0 = varref (2, 1);
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (0, 1);
              r0[2] = r1;
              r1 = (object *) constructed_37[0];
              r0[3] = r1;
              r1 = varref (12, 19);
              r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (3, 0);
              r1[2] = r2;
              r2 = varref (1, 0);
              r1[3] = r2;
              r2 = varref (13, 25);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1527; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
              L1527:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(1)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = (object *) constructed_566[0];
                  r1 = varref (0, 0);
                  if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                    r0 = (object *) 3;
                    r1 = varref (2, 0);
                    r0 = box(unbox(r1)+unbox(r0));
                    r1 = varref (2, 1);
                    lenv = ((object **)lenv)[1][1];
                    lenv[2] = r0;
                    lenv[3] = r1;
                    goto FUN_loop_2196_i4236_i4326;
                  } else {
                    lenv = ((object *)lenv)[1];
                    goto fatbar_110;
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_110;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_110_over;
              fatbar_110:
              r0 = allocate (TC_TUPLE, 6);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 6);
              r2 = varref (11, 0);
              r1[2] = r2;
              r2 = varref (4, 2);
              r1[3] = r2;
              r2 = varref (2, 0);
              r1[4] = r2;
              r2 = varref (4, 1);
              r1[5] = r2;
              r2 = varref (11, 1);
              r1[6] = r2;
              r2 = varref (12, 15);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1528; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_make_nvget_2014_i4236_i4326;
              L1528:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = (object*)TC_NIL;
              r0[3] = r1;
              r1 = varref (0, 1);
              r2 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[4] = r1;
              r1 = varref (0, 2);
              r2 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              r0[5] = r1;
              r1 = varref (0, 3);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              r0[6] = r1;
              r0 = varref (2, 1);
              r1 = varref (0, 4);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              r1 = (object *) 3;
              r2 = varref (1, 0);
              r1 = box(unbox(r2)+unbox(r1));
              lenv = ((object *)lenv)[1];
              lenv[2] = r1;
              lenv[3] = r0;
              goto FUN_loop_2196_i4236_i4326;
              fatbar_110_over: ;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          L1526:
          r2 = allocate (TC_CLOSURE, 2);
          r2[1] = &&FUN_loop_2196_i4236_i4326; r2[2] = lenv;
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object *) 1;
          r1[2] = r2;
          r2 = (object *) constructed_564[0];
          r1[3] = r2;
          r2 = varref (0, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1529; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_loop_2196_i4236_i4326;
          L1529:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 0);
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (4, 0, r0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 3);
          switch (get_case (r1)) {
            case (TC_NIL): {
              r1 = (object *) 262;
              r1=r1;
            } break;
            default: {
              goto fatbar_109;
            }
          }
          r1=r1;
          goto fatbar_109_over;
          fatbar_109:
          r1 = (object *) 6;
          r1=r1;
          fatbar_109_over: ;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 12);
            r0[1] = lenv; lenv = r0;
            r1 = (object *) constructed_549[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[2] = r1;
            r1 = varref (1, 3);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[3] = r1;
            r1 = (object*)TC_NIL;
            r0[4] = r1;
            r1 = varref (0, 2);
            r2 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[5] = r1;
            r1 = varref (0, 3);
            r2 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (6, 2);
            r1[2] = r2;
            r2 = varref (2, 0);
            r1[3] = r2;
            r2 = varref (11, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1530; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1530:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r1 = (object*)TC_NIL;
            r0[8] = r1;
            r1 = varref (0, 6);
            r2 = varref (0, 5);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[9] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 4);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (11, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1531; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L1531:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (0, 7);
            r1[3] = r2;
            r2 = varref (11, 19);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1532; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
            L1532:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[10] = r1;
            r1 = varref (0, 8);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r1;
            r1 = t;
            r0[11] = r1;
            r1 = varref (5, 1);
            r0[12] = r1;
            r0 = varref (0, 10);
            r1 = varref (0, 9);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (4, 1, r0);
            r0=r0;
          } else {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (6, 2);
            r1[2] = r2;
            r2 = varref (2, 0);
            r1[3] = r2;
            r2 = varref (11, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1533; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1533:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = varref (5, 1);
            r0[3] = r1;
            r0 = varref (0, 1);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (4, 1, r0);
            r0=r0;
          }
          lenv = lenv[1];
          r0 = (object *) 3;
          r1 = varref (0, 0);
          r0 = box(unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_2191_i4236_i4326;
        }
        PXLL_RETURN(0);
      L1522:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_2191_i4236_i4326; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = varref (0, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1534; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2191_i4236_i4326;
      L1534:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 19);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_541[0];
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[2] = r1;
      r1 = varref (4, 0);
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[3] = r1;
      r1 = varref (4, 1);
      t = alloc_no_clear (UOTAG(1),1);
      t[1] = r1;
      r1 = t;
      r0[4] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (7, 1);
      r1[2] = r2;
      r2 = varref (2, 0);
      r1[3] = r2;
      r2 = varref (7, 30);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1535; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
      L1535:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[5] = r1;
      r1 = varref (0, 3);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[6] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (7, 2);
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (2, 0);
      r2[2] = r3;
      r2 = allocate (TC_TUPLE, 3);
      r3 = varref (0, 0);
      r2[2] = r3;
      r3 = (object *) constructed_37[0];
      r2[3] = r3;
      r3 = varref (8, 19);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L1536; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
      L1536:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      lenv = lenv[1];
      r2 = r2;
      r1[3] = r2;
      r2 = varref (7, 30);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1537; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
      L1537:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[7] = r1;
      r1 = varref (0, 5);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[8] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (5, 6);
      r1[2] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r2[1] = lenv; lenv = r2;
      r3 = varref (2, 1);
      r2[2] = r3;
      r2 = allocate (TC_TUPLE, 3);
      r3 = varref (0, 0);
      r2[2] = r3;
      r3 = (object *) constructed_37[0];
      r2[3] = r3;
      r3 = varref (8, 19);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L1538; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
      L1538:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      lenv = lenv[1];
      r2 = r2;
      r1[3] = r2;
      r2 = varref (7, 30);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1539; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
      L1539:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[9] = r1;
      r1 = varref (0, 7);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r1;
      r1 = t;
      r0[10] = r1;
      r1 = varref (2, 3);
      switch (get_case (r1)) {
        case (UITAG(1)): {
          r1 = varref (7, 174);
          r1=r1;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (3, 3);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = varref (6, 6);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1540; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
          L1540:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      r0[11] = r1;
      r1 = (object*)TC_NIL;
      r0[12] = r1;
      r1 = varref (0, 10);
      r2 = varref (0, 9);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[13] = r1;
      r1 = varref (0, 11);
      r2 = varref (0, 8);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[14] = r1;
      r1 = varref (0, 12);
      r2 = varref (0, 6);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[15] = r1;
      r1 = varref (0, 13);
      r2 = varref (0, 4);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[16] = r1;
      r1 = varref (0, 14);
      r2 = varref (0, 2);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[17] = r1;
      r1 = varref (0, 15);
      r2 = varref (0, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[18] = r1;
      r1 = varref (0, 16);
      r2 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r2;
      t[2] = r1;
      r1 = t;
      r0[19] = r1;
      r0 = varref (0, 17);
      t = alloc_no_clear (UOTAG(0),1);
      t[1] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L1520:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_12661_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2154_i1340_i4236_i4326
    goto L1541;
    FUN_loop_2154_i1340_i4236_i4326:
      check_heap (0);
      r0 = varref (0, 3);
      switch (get_case (r0)) {
        case (TC_NIL): {
          r0 = allocate (TC_TUPLE, 5);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (0, 2);
          r0[4] = r1;
          r1 = (object*)UITAG(1);
          r0[5] = r1;
          r1 = varref (2, 0);
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 3);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 3);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(0)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = varref (0, 0);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (1, 0);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (UOTAG(9)): {
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 0);
                              r1 = UOBJ_GET(r1,1);
                              r0[2] = r1;
                              r0 = allocate (TC_TUPLE, 2);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 3);
                              r2[1] = lenv; lenv = r2;
                              r3 = (object *) constructed_529[0];
                              t = alloc_no_clear (UOTAG(1),1);
                              t[1] = r3;
                              r3 = t;
                              r2[2] = r3;
                              r3 = varref (5, 1);
                              r4 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              r2[3] = r3;
                              r2 = varref (0, 1);
                              t = alloc_no_clear (UOTAG(0),1);
                              t[1] = r2;
                              r2 = t;
                              lenv = lenv[1];
                              r2 = r2;
                              r1[2] = r2;
                              r2 = varref (11, 6);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1542; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_expand_2004_i4236_i4326;
                              L1542:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r0 = varref (7, 2);
                              r1 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r1;
                              t[2] = r0;
                              r0 = t;
                              lenv = lenv[1];
                              r0 = r0;
                              r1 = varref (6, 1);
                              r2 = varref (1, 1);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r2;
                              t[2] = r1;
                              r1 = t;
                              r2 = varref (6, 0);
                              r3 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r3;
                              t[2] = r2;
                              r2 = t;
                              r3 = varref (5, 1);
                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                              lenv[2] = r2;
                              lenv[3] = r1;
                              lenv[4] = r0;
                              lenv[5] = r3;
                              goto FUN_loop_2154_i1340_i4236_i4326;
                            } break;
                            default: {
                              lenv = ((object *****)lenv)[1][1][1][1][1];
                              goto fatbar_108;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ****)lenv)[1][1][1][1];
                          goto fatbar_108;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = (object *) constructed_562[0];
                      r1 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = varref (3, 1);
                        switch (get_case (r0)) {
                          case (TC_NIL): {
                            r0 = allocate (TC_TUPLE, 5);
                            r1 = varref (4, 0);
                            r0[2] = r1;
                            r1 = varref (4, 1);
                            r0[3] = r1;
                            r1 = varref (4, 2);
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = allocate (TC_TUPLE, 2);
                            r3 = allocate (TC_TUPLE, 3);
                            r3[1] = lenv; lenv = r3;
                            r4 = (object *) constructed_529[0];
                            t = alloc_no_clear (UOTAG(1),1);
                            t[1] = r4;
                            r4 = t;
                            r3[2] = r4;
                            r4 = varref (3, 1);
                            r5 = varref (0, 0);
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r5;
                            t[2] = r4;
                            r4 = t;
                            r3[3] = r4;
                            r3 = varref (0, 1);
                            t = alloc_no_clear (UOTAG(0),1);
                            t[1] = r3;
                            r3 = t;
                            lenv = lenv[1];
                            r3 = r3;
                            r2[2] = r3;
                            r3 = varref (9, 6);
                            t = allocate (TC_SAVE, 5);
                            t[1] = k; t[2] = lenv; t[3] = &&L1543; t[4] = r0; t[5] = r1; k = t;
                            r2[1] = r3[2]; lenv = r2; goto FUN_expand_2004_i4236_i4326;
                            L1543:
                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                            r2 = result;
                            r1[2] = r2;
                            r1 = varref (0, 0);
                            t = alloc_no_clear (UOTAG(0),1);
                            t[1] = r1;
                            r1 = t;
                            lenv = lenv[1];
                            r1 = r1;
                            r0[5] = r1;
                            r1 = varref (6, 0);
                            r0[1] = r1[2]; lenv = r0; goto *r1[1];
                          } break;
                          default: {
                            lenv = ((object ****)lenv)[1][1][1][1];
                            goto fatbar_108;
                          }
                        }
                        PXLL_RETURN(0);
                      } else {
                        lenv = ((object ****)lenv)[1][1][1][1];
                        goto fatbar_108;
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object ***)lenv)[1][1][1];
                      goto fatbar_108;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_108;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_108;
            }
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
      goto fatbar_108_over;
      fatbar_108:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 3);
      r1[2] = r2;
      r2 = varref (6, 17);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1544; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
      L1544:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = varref (6, 87);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1545; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_pp_439;
      L1545:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_563;
      r0[2] = r1;
      r1 = varref (0, 3);
      r0[3] = r1;
      r1 = varref (6, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      fatbar_108_over: ;
      PXLL_RETURN(0);
    L1541:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2154_i1340_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r1 = (object *) constructed_560[0];
    r0[2] = r1;
    r1 = (object *) constructed_559[0];
    r0[3] = r1;
    r1 = (object *) constructed_558[0];
    r0[4] = r1;
    r1 = varref (2, 2);
    r0[5] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2154_i1340_i4236_i4326;
  L1519:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_vcase_splat_2016_i4236_i4326; r2[2] = lenv;
  r1[19] = r2;
  // def wrap-with-constructors_2019_i4236_i4326
  goto L1546;
  FUN_wrap_with_constructors_2019_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_557[0];
    r0[2] = r1;
    r1 = (object *) constructed_556[0];
    r0[3] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_12926_i4236_i4326
    goto L1547;
    FUN_lambda_12926_i4236_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      // def lambda_12923_i4236_i4326
      goto L1548;
      FUN_lambda_12923_i4236_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 7);
        r3[1] = lenv; lenv = r3;
        r4 = varref (3, 1);
        r4 = ((pxll_vector*)r4)->val[7];
        r3[2] = r4;
        r4 = varref (0, 0);
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = varref (1, 0);
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = varref (0, 0);
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[3] = r4;
        r4 = varref (2, 0);
        r4 = allocate (TC_TUPLE, 2);
        r4[1] = lenv; lenv = r4;
        r5 = varref (3, 0);
        r5 = UOBJ_GET(r5,0);
        r4[2] = r5;
        r4 = varref (0, 0);
        lenv = lenv[1];
        r4 = r4;
        r4=r4;
        r3[4] = r4;
        r4 = (object*)TC_NIL;
        r3[5] = r4;
        r4 = varref (0, 3);
        r5 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[6] = r4;
        r4 = varref (0, 4);
        r5 = (object*) &constructed_555;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[7] = r4;
        r3 = varref (0, 5);
        r4 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r3 = varref (7, 45);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1549; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
        L1549:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (7, 73);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1550; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
        L1550:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (3, 0);
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (2, 0, r0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (2, 1);
        r2 = ((pxll_vector*)r2)->val[7];
        r1[2] = r2;
        r2 = varref (1, 0);
        r1[3] = r2;
        r2 = varref (1, 1);
        r2 = ((pxll_vector*)r2)->val[0];
        r1[4] = r2;
        r2 = varref (5, 19);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1551; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_make_constructor_2020_i4236_i4326;
        L1551:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (3, 1);
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (2, 1, r0);
        PXLL_RETURN(0);
      L1548:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_12923_i4236_i4326; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (0, 1);
      r1 = ((pxll_vector*)r1)->val[6];
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1547:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_12926_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (3, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r0[3] = r1;
    r1 = varref (4, 66);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1552; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
    L1552:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 4);
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (4, 1);
    r1[2] = r2;
    r2 = varref (0, 0);
    r1[3] = r2;
    r2 = varref (4, 30);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1553; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
    L1553:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (0, 1);
    r0[3] = r1;
    r1 = varref (1, 0);
    r0[4] = r1;
    r1 = varref (2, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN_wrap_fix_1997_i4236_i4326;
  L1546:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_wrap_with_constructors_2019_i4236_i4326; r2[2] = lenv;
  r1[20] = r2;
  // def make-constructor_2020_i4236_i4326
  goto L1554;
  FUN_make_constructor_2020_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 19);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 2);
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def $loop_2248_i4236_i4326
    goto L1555;
    FUN__24loop_2248_i4236_i4326:
      check_heap (0);
      r0 = varref (2, 0);
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = (object *) constructed_37[0];
        r0[3] = r1;
        r1 = varref (6, 19);
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
      } else {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r3 = allocate (TC_TUPLE, 4);
        r3[1] = lenv; lenv = r3;
        r4 = allocate (TC_TUPLE, 2);
        r5 = varref (2, 0);
        r4[2] = r5;
        r5 = varref (8, 54);
        t = allocate (TC_SAVE, 7);
        t[1] = k; t[2] = lenv; t[3] = &&L1556; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
        L1556:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
        r4 = result;
        r3[2] = r4;
        r4 = (object*)TC_NIL;
        r3[3] = r4;
        r4 = varref (0, 1);
        r5 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r5;
        t[2] = r4;
        r4 = t;
        r3[4] = r4;
        r3 = varref (0, 2);
        r4 = (object*) &constructed_554;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r3 = varref (7, 45);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1557; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
        L1557:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (7, 73);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1558; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
        L1558:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(1),1);
        t[1] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = varref (1, 1);
        r1 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 3;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)+unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN__24loop_2248_i4236_i4326;
      }
      PXLL_RETURN(0);
    L1555:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN__24loop_2248_i4236_i4326; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = varref (0, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1559; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2248_i4236_i4326;
    L1559:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = (object *) constructed_531[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 2);
    r3 = allocate (TC_TUPLE, 6);
    r3[1] = lenv; lenv = r3;
    r4 = varref (2, 0);
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = varref (3, 0);
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = varref (0, 0);
    lenv = lenv[1];
    r4 = r4;
    r4=r4;
    r3[2] = r4;
    r4 = varref (2, 1);
    r4 = allocate (TC_TUPLE, 2);
    r4[1] = lenv; lenv = r4;
    r5 = varref (3, 1);
    r5 = UOBJ_GET(r5,0);
    r4[2] = r5;
    r4 = varref (0, 0);
    lenv = lenv[1];
    r4 = r4;
    r4=r4;
    r3[3] = r4;
    r4 = (object*)TC_NIL;
    r3[4] = r4;
    r4 = varref (0, 2);
    r5 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[5] = r4;
    r4 = varref (0, 3);
    r5 = (object*) &constructed_553;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r5;
    t[2] = r4;
    r4 = t;
    r3[6] = r4;
    r3 = varref (0, 4);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    lenv = lenv[1];
    r3 = r3;
    r2[2] = r3;
    r3 = varref (4, 45);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1560; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
    L1560:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (4, 73);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1561; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
    L1561:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = varref (0, 3);
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[6] = r1;
    r1 = varref (0, 1);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[7] = r1;
    r1 = (object *) constructed_272[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[8] = r1;
    r1 = varref (1, 1);
    r2 = varref (1, 0);
    t = alloc_no_clear (UOTAG(9),2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[9] = r1;
    r1 = (object*)TC_NIL;
    r0[10] = r1;
    r1 = varref (0, 8);
    r2 = varref (0, 7);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[11] = r1;
    r1 = varref (0, 9);
    r2 = varref (0, 6);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[12] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 10);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (4, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1562; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L1562:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[2] = r2;
    r2 = varref (0, 1);
    r1[3] = r2;
    r2 = varref (4, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1563; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L1563:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[13] = r1;
    r1 = varref (0, 11);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r1;
    r1 = t;
    r0[14] = r1;
    r1 = (object*)TC_NIL;
    r0[15] = r1;
    r1 = varref (0, 13);
    r2 = varref (0, 12);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[16] = r1;
    r1 = varref (0, 14);
    r2 = varref (0, 5);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[17] = r1;
    r1 = varref (0, 15);
    r2 = varref (0, 4);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[18] = r1;
    r1 = varref (0, 16);
    r2 = varref (0, 2);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[19] = r1;
    r0 = varref (0, 17);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1554:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_constructor_2020_i4236_i4326; r2[2] = lenv;
  r1[21] = r2;
  // def make-alt_2021_i4236_i4326
  goto L1564;
  FUN_make_alt_2021_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    // def lambda_13055_i4236_i4326
    goto L1565;
    FUN_lambda_13055_i4236_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (2, 0);
      r0[3] = r1;
      r1 = varref (5, 103);
      r0[1] = r1[2]; lenv = r0; goto FUN_parse_type_splat_469;
    L1565:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_13055_i4236_i4326; r2[2] = lenv;
    r1[2] = r2;
    r2 = varref (1, 2);
    r1[3] = r2;
    r2 = varref (4, 30);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1566; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
    L1566:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (4, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1567; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L1567:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = allocate (UOTAG(6), 4);
    r1 = varref (0, 1);
    r0[1] = r1;
    r1 = (object *) 1;
    r0[2] = r1;
    r1 = varref (1, 1);
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[4] = r1;
    PXLL_RETURN(0);
  L1564:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_make_alt_2021_i4236_i4326; r2[2] = lenv;
  r1[22] = r2;
  // def expand-match_2027_i4236_i4326
  goto L1568;
  FUN_expand_match_2027_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_2289_i4236_i4326
    goto L1569;
    FUN_loop_2289_i4236_i4326:
      check_heap (0);
      r0 = varref (0, 2);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 2);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = (object *) constructed_551[0];
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 5);
                r2 = varref (7, 0);
                r1[2] = r2;
                r2 = varref (6, 6);
                r1[3] = r2;
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (3, 0);
                r2[2] = r3;
                r3 = (object *) constructed_37[0];
                r2[3] = r3;
                r3 = varref (8, 19);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1570; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                L1570:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[4] = r2;
                r2 = varref (2, 1);
                r1[5] = r2;
                r2 = varref (8, 108);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1571; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_compile_pattern_480;
                L1571:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (0, 0);
                switch (get_case_noint (r0)) {
                  default: {
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 0);
                    r1 = UOBJ_GET(r1,1);
                    r0[2] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = varref (4, 1);
                    switch (get_case (r1)) {
                      case (TC_NIL): {
                        r1 = (object *) 262;
                        r1=r1;
                      } break;
                      default: {
                        goto fatbar_107;
                      }
                    }
                    r1=r1;
                    goto fatbar_107_over;
                    fatbar_107:
                    r1 = (object *) 6;
                    r1=r1;
                    fatbar_107_over: ;
                    if PXLL_IS_TRUE(r1) {
                      r1 = varref (0, 0);
                      r1=r1;
                    } else {
                      r1 = allocate (TC_TUPLE, 7);
                      r1[1] = lenv; lenv = r1;
                      r2 = (object *) constructed_549[0];
                      t = alloc_no_clear (UOTAG(1),1);
                      t[1] = r2;
                      r2 = t;
                      r1[2] = r2;
                      r2 = varref (5, 1);
                      t = alloc_no_clear (UOTAG(0),1);
                      t[1] = r2;
                      r2 = t;
                      r1[3] = r2;
                      r2 = (object*)TC_NIL;
                      r1[4] = r2;
                      r2 = varref (0, 2);
                      r3 = varref (1, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[5] = r2;
                      r2 = varref (0, 3);
                      r3 = varref (0, 1);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[6] = r2;
                      r2 = varref (0, 4);
                      r3 = varref (0, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      r1[7] = r2;
                      r1 = varref (0, 5);
                      t = alloc_no_clear (UOTAG(0),1);
                      t[1] = r1;
                      r1 = t;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    }
                    r0[2] = r1;
                    r1 = varref (7, 6);
                    r0[1] = r1[2]; lenv = r0; goto FUN_expand_2004_i4236_i4326;
                  } break;
                }
                PXLL_RETURN(0);
              } else {
                goto fatbar_106;
              }
              PXLL_RETURN(0);
              goto fatbar_106_over;
              fatbar_106:
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              r1 = varref (2, 1);
              r2 = varref (1, 1);
              lenv = ((object **)lenv)[1][1];
              lenv[2] = r0;
              lenv[3] = r1;
              lenv[4] = r2;
              goto FUN_loop_2289_i4236_i4326;
              fatbar_106_over: ;
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_105;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_105_over;
          fatbar_105:
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (7, 106);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1572; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_match_var_478;
          L1572:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r1;
          r1 = t;
          r0[2] = r1;
          r1 = (object*)TC_NIL;
          r0[3] = r1;
          r1 = varref (0, 1);
          r2 = varref (2, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[4] = r1;
          r1 = varref (0, 2);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r1 = varref (0, 3);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = varref (3, 1);
          r1 = varref (0, 4);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (2, 0);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r2 = varref (1, 1);
          lenv = ((object **)lenv)[1][1];
          lenv[2] = r1;
          lenv[3] = r0;
          lenv[4] = r2;
          goto FUN_loop_2289_i4236_i4326;
          fatbar_105_over: ;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_104;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_104_over;
      fatbar_104:
      r0 = allocate (TC_TUPLE, 3);
      r1 = (object*) &constructed_552;
      r0[2] = r1;
      r1 = varref (2, 0);
      r0[3] = r1;
      r1 = varref (5, 12);
      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      fatbar_104_over: ;
      PXLL_RETURN(0);
    L1569:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_2289_i4236_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = (object *) constructed_547[0];
    r0[2] = r1;
    r1 = (object *) constructed_546[0];
    r0[3] = r1;
    r1 = varref (1, 0);
    r0[4] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_2289_i4236_i4326;
  L1568:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_match_2027_i4236_i4326; r2[2] = lenv;
  r1[23] = r2;
  // def expand-cinclude_2028_i4236_i4326
  goto L1573;
  FUN_expand_cinclude_2028_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(2)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = varref (1, 1);
            switch (get_case (r0)) {
              case (TC_NIL): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (5, 0);
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = varref (4, 0);
                ((pxll_vector*)r1)->val[0] = r0;
                r0 = allocate (TC_TUPLE, 4);
                r0[1] = lenv; lenv = r0;
                r1 = (object *) constructed_529[0];
                t = alloc_no_clear (UOTAG(1),1);
                t[1] = r1;
                r1 = t;
                r0[2] = r1;
                r1 = (object*)TC_NIL;
                r0[3] = r1;
                r1 = varref (0, 1);
                r2 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[4] = r1;
                r0 = varref (0, 2);
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object **)lenv)[1][1];
                goto fatbar_103;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_103;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_103;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_103_over;
    fatbar_103:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_545;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_103_over: ;
    PXLL_RETURN(0);
  L1573:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand_cinclude_2028_i4236_i4326; r2[2] = lenv;
  r1[24] = r2;
  // def expand-%nvcase_2029_i4236_i4326
  goto L1574;
  FUN_expand__percentnvcase_2029_i4236_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = (object *) constructed_541[0];
    t = alloc_no_clear (UOTAG(1),1);
    t[1] = r1;
    r1 = t;
    r0[2] = r1;
    r1 = varref (1, 0);
    r2 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r2;
    t[2] = r1;
    r1 = t;
    r0[3] = r1;
    r0 = varref (0, 1);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L1574:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand__percentnvcase_2029_i4236_i4326; r2[2] = lenv;
  r1[25] = r2;
  // def expand-%%cexp_2030_i4236_i4326
  goto L1575;
  FUN_expand__percent_percentcexp_2030_i4236_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_PAIR): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = (object *) constructed_543[0];
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r1;
            r1 = t;
            r0[4] = r1;
            r1 = (object*)TC_NIL;
            r0[5] = r1;
            r1 = varref (0, 3);
            r2 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[6] = r1;
            r1 = varref (0, 4);
            r2 = varref (1, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[7] = r1;
            r1 = varref (0, 5);
            r2 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            r0[8] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 6);
            r1[2] = r2;
            r2 = varref (0, 1);
            r1[3] = r2;
            r2 = varref (5, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1576; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L1576:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[9] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 6);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (5, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1577; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L1577:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (0, 7);
            r1[3] = r2;
            r2 = varref (5, 19);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1578; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
            L1578:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[10] = r1;
            r0 = varref (0, 8);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            lenv = ((object *)lenv)[1];
            goto fatbar_102;
          }
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_102;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_102_over;
    fatbar_102:
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_544;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (3, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_102_over: ;
    PXLL_RETURN(0);
  L1575:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_expand__percent_percentcexp_2030_i4236_i4326; r2[2] = lenv;
  r1[26] = r2;
  r2 = allocate (TC_TUPLE, 12);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)UITAG(0);
  r2[2] = r3;
  r3 = varref (1, 24);
  r4 = varref (0, 0);
  r5 = (object *) constructed_543[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[3] = r3;
  r3 = varref (1, 23);
  r4 = varref (0, 1);
  r5 = (object *) constructed_541[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[4] = r3;
  r3 = varref (1, 22);
  r4 = varref (0, 2);
  r5 = (object *) constructed_539[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[5] = r3;
  r3 = varref (1, 21);
  r4 = varref (0, 3);
  r5 = (object *) constructed_537[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[6] = r3;
  r3 = varref (1, 11);
  r4 = varref (0, 4);
  r5 = (object *) constructed_535[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[7] = r3;
  r3 = varref (1, 16);
  r4 = varref (0, 5);
  r5 = (object *) constructed_533[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[8] = r3;
  r3 = varref (1, 13);
  r4 = varref (0, 6);
  r5 = (object *) constructed_531[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[9] = r3;
  r3 = varref (1, 12);
  r4 = varref (0, 7);
  r5 = (object *) constructed_517[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[10] = r3;
  r3 = varref (1, 10);
  r4 = varref (0, 8);
  r5 = (object *) constructed_529[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[11] = r3;
  r3 = varref (1, 9);
  r4 = varref (0, 9);
  r5 = (object *) constructed_527[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r5;
  t[2] = r3;
  t[3] = r4;
  r3 = t;
  r2[12] = r3;
  r2 = varref (1, 8);
  r3 = varref (0, 10);
  r4 = (object *) constructed_525[0];
  t = alloc_no_clear (UOTAG(1),3);
  t[1] = r4;
  t[2] = r2;
  t[3] = r3;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[27] = r2;
  r1 = varref (0, 0);
  lenv = lenv[1];
  r1 = r1;
  r0[3] = r1;
  r1 = varref (1, 152);
  r1 = ((pxll_vector*)r1)->val[1];
  r2 = (object *) 3;
  range_check (GET_TUPLE_LENGTH(*(object*)r1), unbox(r2));
  r1 = ((pxll_vector*)r1)->val[unbox(r2)];
  r0[4] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (0, 2);
  r1[2] = r2;
  r2 = (object *) 11778;
  r1[3] = r2;
  r2 = varref (1, 47);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1579; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_split_364;
  L1579:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[5] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (0, 3);
  r1[2] = r2;
  r2 = (object *) constructed_37[0];
  r1[3] = r2;
  r2 = varref (1, 19);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1580; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
  L1580:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[6] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (1, 4);
  r2[2] = r3;
  r3 = varref (2, 17);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1581; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
  L1581:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = varref (0, 0);
  r2[2] = r3;
  r3 = (object*) &constructed_523;
  r2[3] = r3;
  r3 = varref (2, 48);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1582; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
  L1582:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = (object *) 1;
  r3 = varref (0, 1);
  r2 = PXLL_TEST(unbox(r3)==unbox(r2));
  r1[4] = r2;
  r1 = (object *) 6;
  r2 = varref (0, 2);
  r1 = PXLL_TEST(r2==r1);
  lenv = lenv[1];
  r1 = r1;
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_521;
    r1[2] = r2;
    r2 = varref (0, 2);
    r1[3] = r2;
    r2 = varref (1, 12);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1583; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
    L1583:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  } else {
    r1 = allocate (TC_TUPLE, 3);
    r2 = allocate (TC_TUPLE, 2);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (1, 4);
    r3[2] = r4;
    r4 = varref (2, 18);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L1584; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_cdr_319;
    L1584:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 0);
    r2[2] = r3;
    r3 = (object *) constructed_37[0];
    r2[3] = r3;
    r3 = varref (2, 19);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1585; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
    L1585:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = (object*) &constructed_522;
    r1[3] = r2;
    r2 = varref (1, 46);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1586; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_join_363;
    L1586:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  }
  r0[7] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 3);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)TC_NIL;
  r2[2] = r3;
  r3 = varref (0, 0);
  r4 = (object*) &constructed_520;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[3] = r3;
  r2 = varref (0, 1);
  r3 = varref (1, 5);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[2] = r2;
  r2 = varref (1, 45);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1587; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
  L1587:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[8] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (0, 2);
  r1[2] = r2;
  r2 = varref (1, 77);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1588; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_read_file_427;
  L1588:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[9] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r2 = varref (1, 0);
  r1[2] = r2;
  r2 = varref (0, 7);
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (0, 0);
  r3 = ((pxll_vector*)r3)->val[11];
  r2[2] = r3;
  r3 = varref (1, 77);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1589; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_read_file_427;
  L1589:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = varref (1, 36);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1590; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_foldr_341;
  L1590:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[10] = r1;
  r1 = varref (0, 8);
  t = alloc_no_clear (UOTAG(0),1);
  t[1] = r1;
  r1 = t;
  r0[11] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (0, 9);
  r1[2] = r2;
  r2 = varref (0, 1);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1591; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1591:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[12] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (0, 10);
  r1[2] = r2;
  r2 = varref (1, 124);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1592; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_walk_515;
  L1592:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[13] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  // def shadow_2631_i4243_i4326
  goto L1593;
  FUN_shadow_2631_i4243_i4326:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*)TC_NIL;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 0);
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = varref (2, 0);
        r1[3] = r2;
        r2 = varref (5, 23);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1594; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_328;
        L1594:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 6;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (2, 0);
          r1[2] = r2;
          r2 = varref (1, 1);
          r1[3] = r2;
          r2 = varref (3, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1595; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_shadow_2631_i4243_i4326;
          L1595:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (2, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2631_i4243_i4326;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1593:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_shadow_2631_i4243_i4326; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_2632_i4243_i4326
  goto L1596;
  FUN_lookup_2632_i4243_i4326:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = varref (0, 0);
        r1 = varref (2, 0);
        r0 = PXLL_TEST(r1==r0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = varref (0, 0);
          r0 = ((pxll_vector*)r0)->val[1];
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (1, 0);
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (2, 1);
          r0[1] = r1[2]; lenv = r0; goto FUN_lookup_2632_i4243_i4326;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1596:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_2632_i4243_i4326; r2[2] = lenv;
  r1[3] = r2;
  // def walk_2633_i4243_i4326
  goto L1597;
  FUN_walk_2633_i4243_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_16629_i4243_i4326
    goto L1598;
    FUN_lambda_16629_i4243_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(10)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (3, 1);
          r0[3] = r1;
          r1 = varref (4, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1599; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2631_i4243_i4326;
          L1599:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (3, 1, r0);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(9)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (3, 1);
          r0[3] = r1;
          r1 = varref (4, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1600; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2631_i4243_i4326;
          L1600:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (3, 1, r0);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(7)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (3, 1);
          r0[3] = r1;
          r1 = varref (4, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1601; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_shadow_2631_i4243_i4326;
          L1601:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          varset (3, 1, r0);
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(11)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(5), 2);
          r2 = varref (1, 0);
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (1, 1);
          r2[2] = r3;
          r3 = varref (4, 1);
          r2[3] = r3;
          r3 = varref (5, 1);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1602; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_lookup_2632_i4243_i4326;
          L1602:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r0[2] = r1;
          r1 = varref (4, 1);
          r0[3] = r1;
          r0 = varref (0, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (3, 1, r0);
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 3);
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (3, 0);
          r3 = ((pxll_vector*)r3)->val[3];
          r2[2] = r3;
          r3 = varref (6, 17);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1603; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
          L1603:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = varref (3, 1);
          r1[3] = r2;
          r2 = varref (4, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1604; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_2633_i4243_i4326;
          L1604:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (2, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1605; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L1605:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (4, 1);
          r1[3] = r2;
          r2 = varref (5, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1606; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2632_i4243_i4326;
          L1606:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (3, 0);
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (4, 1);
          r1[3] = r2;
          r2 = varref (5, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1607; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2632_i4243_i4326;
          L1607:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          t = alloc_no_clear (UOTAG(1),1);
          t[1] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (3, 0);
          ((pxll_vector*)r1)->val[4] = r0;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
        } break;
        default: {
          goto fatbar_101;
        }
      }
      r0=r0;
      goto fatbar_101_over;
      fatbar_101:
      r0 = (object *) 14;
      r0=r0;
      fatbar_101_over: ;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_16621_i4243_i4326
      goto L1608;
      FUN_lambda_16621_i4243_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 1);
        r0[3] = r1;
        r1 = varref (3, 2);
        r0[1] = r1[2]; lenv = r0; goto FUN_walk_2633_i4243_i4326;
      L1608:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_16621_i4243_i4326; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[3];
      r0[3] = r1;
      r1 = varref (4, 30);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1609; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_map_335;
      L1609:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      r1 = varref (1, 0);
      ((pxll_vector*)r1)->val[3] = r0;
      r0 = varref (1, 0);
      PXLL_RETURN(0);
    L1598:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_16629_i4243_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (3, 14);
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_307;
  L1597:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_walk_2633_i4243_i4326; r2[2] = lenv;
  r1[4] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (1, 11);
  r1[2] = r2;
  r2 = (object *) constructed_519[0];
  r1[3] = r2;
  r2 = varref (0, 2);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1610; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_walk_2633_i4243_i4326;
  L1610:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[14] = r1;
  r1 = (object*)UITAG(2);
  r0[15] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) 1;
  r1[2] = r2;
  r2 = varref (1, 105);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1611; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_make_counter_474;
  L1611:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[16] = r1;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  // def add_2578_i1828_i4244_i4326
  goto L1612;
  FUN_add_2578_i1828_i4244_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (3, 14);
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L1613; t[4] = r0; t[5] = r1; k = t;
    lenv = r2[2]; goto *r2[1];
    L1613:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r2 = varref (4, 127);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1614; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_make_vardef_519;
    L1614:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 5);
    r1 = varref (3, 13);
    r0[2] = r1;
    r1 = varref (4, 74);
    r0[3] = r1;
    r1 = varref (1, 0);
    r0[4] = r1;
    r1 = varref (0, 0);
    r0[5] = r1;
    r1 = varref (4, 69);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1615; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
    L1615:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    varset (3, 13, r0);
    r0 = varref (0, 0);
    PXLL_RETURN(0);
  L1612:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_2578_i1828_i4244_i4326; r2[2] = lenv;
  r1[2] = r2;
  // def lookup_2579_i1828_i4244_i4326
  goto L1616;
  FUN_lookup_2579_i1828_i4244_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (2, 13);
    r0[2] = r1;
    r1 = varref (3, 74);
    r0[3] = r1;
    r1 = varref (0, 0);
    r0[4] = r1;
    r1 = varref (3, 70);
    r0[1] = r1[2]; lenv = r0; goto FUN_tree_2fmember_415;
  L1616:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lookup_2579_i1828_i4244_i4326; r2[2] = lenv;
  r1[3] = r2;
  // def get_2580_i1828_i4244_i4326
  goto L1617;
  FUN_get_2580_i1828_i4244_i4326:
    r0 = varref (1, 13);
    PXLL_RETURN(0);
  L1617:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_2580_i1828_i4244_i4326; r2[2] = lenv;
  r1[4] = r2;
  r1 = allocate (UOTAG(4), 3);
  r2 = varref (0, 0);
  r1[1] = r2;
  r2 = varref (0, 2);
  r1[2] = r2;
  r2 = varref (0, 1);
  r1[3] = r2;
  lenv = lenv[1];
  r1 = r1;
  r0[17] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def rename_2587_i4244_i4326
  goto L1618;
  FUN_rename_2587_i4244_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def lookup_2593_i4244_i4326
    goto L1619;
    FUN_lookup_2593_i4244_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def loop0_2595_i4244_i4326
      goto L1620;
      FUN_loop0_2595_i4244_i4326:
        check_heap (0);
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object*)UITAG(1);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def loop1_2599_i4244_i4326
            goto L1621;
            FUN_loop1_2599_i4244_i4326:
              check_heap (0);
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = varref (2, 1);
                  lenv = ((object ***)lenv)[1][1][1];
                  lenv[2] = r0;
                  goto FUN_loop0_2595_i4244_i4326;
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,21)];
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  r1 = varref (7, 0);
                  r0 = PXLL_TEST(r1==r0);
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = varref (0, 0);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } else {
                    r0 = varref (0, 1);
                    lenv = ((object *)lenv)[1];
                    lenv[2] = r0;
                    goto FUN_loop1_2599_i4244_i4326;
                  }
                  PXLL_RETURN(0);
                } break;
              }
              PXLL_RETURN(0);
            L1621:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_loop1_2599_i4244_i4326; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN_loop1_2599_i4244_i4326;
          } break;
        }
        PXLL_RETURN(0);
      L1620:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_loop0_2595_i4244_i4326; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (3, 1);
      r0[2] = r1;
      r1 = varref (0, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_loop0_2595_i4244_i4326;
    L1619:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lookup_2593_i4244_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 0);
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (5, 15);
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = varref (0, 1);
        r1[3] = r2;
        r2 = varref (6, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1622; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1622:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1623; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2593_i4244_i4326;
        L1623:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = varref (0, 3);
        switch (get_case (r1)) {
          case (UITAG(1)): {
            r1 = (object *) constructed_517[0];
            r2 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (4, 0);
              r5 = ((pxll_vector*)r5)->val[1];
              r4[2] = r5;
              r5 = varref (7, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1624; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L1624:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = varref (0, 2);
              r4 = (object*) &constructed_515;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (6, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1625; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L1625:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (6, 73);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1626; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string__3esymbol_422;
              L1626:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = varref (0, 0);
              r1=r1;
            }
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 3);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = varref (0, 0);
            r1 = ((pxll_vector*)r1)->val[2];
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_16229_i4244_i4326
        goto L1627;
        FUN_lambda_16229_i4244_i4326:
          r0 = varref (0, 0);
          r0 = ((pxll_vector*)r0)->val[2];
          PXLL_RETURN(0);
        L1627:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_16229_i4244_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (1, 2);
        r1[3] = r2;
        r2 = varref (7, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1628; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1628:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 4);
        t = alloc_no_clear (UOTAG(7),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = varref (3, 0);
        ((pxll_vector*)r1)->val[4] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (4, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = varref (4, 1);
        r2 = varref (1, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16114_i1837_i4244_i4326
        goto L1629;
        FUN_lambda_16114_i1837_i4244_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (1, 1);
          r0[3] = r1;
          r1 = varref (6, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2587_i4244_i4326;
        L1629:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16114_i1837_i4244_i4326; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (7, 33);
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (5, 15);
        r2 = ((pxll_vector*)r2)->val[0];
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (6, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1630; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1630:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_16262_i4244_i4326
        goto L1631;
        FUN_lambda_16262_i4244_i4326:
          r0 = varref (0, 0);
          r0 = ((pxll_vector*)r0)->val[2];
          PXLL_RETURN(0);
        L1631:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_16262_i4244_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (7, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1632; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1632:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        t = alloc_no_clear (UOTAG(10),1);
        t[1] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = varref (3, 0);
        ((pxll_vector*)r1)->val[4] = r0;
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (4, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = varref (4, 1);
        r2 = varref (1, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16114_i1840_i4244_i4326
        goto L1633;
        FUN_lambda_16114_i1840_i4244_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (1, 1);
          r0[3] = r1;
          r1 = varref (6, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2587_i4244_i4326;
        L1633:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16114_i1840_i4244_i4326; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (7, 33);
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (3, 0);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = varref (6, 116);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1634; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_unpack_fix_506;
        L1634:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = (object *) constructed_518[0];
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (7, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1635; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L1635:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 3);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def $loop_2621_i4244_i4326
            goto L1636;
            FUN__24loop_2621_i4244_i4326:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 3);
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (3, 1);
                r1[2] = r2;
                r2 = varref (0, 0);
                r1[3] = r2;
                r2 = varref (10, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1637; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L1637:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (4, 2);
                r1[2] = r2;
                r1 = varref (8, 1);
                r2 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[3] = r1;
                r1 = varref (8, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L1638; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_rename_2587_i4244_i4326;
                L1638:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 3);
                r3 = varref (5, 0);
                r2[2] = r3;
                r3 = varref (1, 0);
                r2[3] = r3;
                r3 = varref (11, 25);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L1639; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                L1639:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (10, 15);
                r2 = ((pxll_vector*)r2)->val[0];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1640; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L1640:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (4, 2);
                r0[3] = r1;
                r0 = varref (0, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (3, 2, r0);
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_2621_i4244_i4326;
              }
              PXLL_RETURN(0);
            L1636:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN__24loop_2621_i4244_i4326; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = (object *) 1;
            r0[2] = r1;
            r1 = varref (0, 0);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1641; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN__24loop_2621_i4244_i4326;
            L1641:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            lenv = lenv[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_16346_i4244_i4326
            goto L1642;
            FUN_lambda_16346_i4244_i4326:
              r0 = varref (0, 0);
              r0 = ((pxll_vector*)r0)->val[2];
              PXLL_RETURN(0);
            L1642:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_16346_i4244_i4326; r2[2] = lenv;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (2, 2);
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = (object *) constructed_37[0];
            r2[3] = r3;
            r3 = varref (9, 19);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1643; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
            L1643:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r2 = varref (8, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1644; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L1644:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(9),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = varref (4, 0);
            ((pxll_vector*)r1)->val[4] = r0;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 2);
            r1[2] = r2;
            r1 = varref (5, 1);
            r2 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[3] = r1;
            r1 = varref (5, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN_rename_2587_i4244_i4326;
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1645; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2593_i4244_i4326;
        L1645:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = ((pxll_vector*)r1)->val[2];
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(0),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = varref (4, 0);
            ((pxll_vector*)r1)->val[4] = r0;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = varref (3, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1646; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lookup_2593_i4244_i4326;
        L1646:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = (object *) 14;
            r0=r0;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = ((pxll_vector*)r1)->val[2];
            r0[2] = r1;
            r0 = varref (0, 0);
            t = alloc_no_clear (UOTAG(1),1);
            t[1] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = varref (5, 0);
            ((pxll_vector*)r1)->val[4] = r0;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
        }
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (4, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_16114_i1851_i4244_i4326
        goto L1647;
        FUN_lambda_16114_i1851_i4244_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (5, 1);
          r0[3] = r1;
          r1 = varref (6, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_rename_2587_i4244_i4326;
        L1647:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_16114_i1851_i4244_i4326; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (7, 33);
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      } break;
      default: {
        goto fatbar_100;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_100_over;
    fatbar_100:
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (3, 0);
    r1 = ((pxll_vector*)r1)->val[3];
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_16114_i1852_i4244_i4326
    goto L1648;
    FUN_lambda_16114_i1852_i4244_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (4, 1);
      r0[3] = r1;
      r1 = varref (5, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_rename_2587_i4244_i4326;
    L1648:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_16114_i1852_i4244_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (6, 33);
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    fatbar_100_over: ;
    PXLL_RETURN(0);
  L1618:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_rename_2587_i4244_i4326; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (1, 12);
  r1[2] = r2;
  r2 = (object *) constructed_514[0];
  r1[3] = r2;
  r2 = varref (0, 0);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1649; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_rename_2587_i4244_i4326;
  L1649:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[18] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (0, 12);
  r1[2] = r2;
  r2 = varref (0, 0);
  r1[3] = r2;
  r2 = varref (1, 136);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1650; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_do_one_round_554;
  L1650:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[19] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (0, 17);
  r1[2] = r2;
  r2 = varref (0, 0);
  r1[3] = r2;
  r2 = varref (1, 136);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1651; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_do_one_round_554;
  L1651:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[20] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def search_3838_i4245_i4326
  goto L1652;
  FUN_search_3838_i4245_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[3];
    r0[3] = r1;
    r1 = varref (3, 38);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1653; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_every_question_343;
    L1653:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 0);
      r1 = ((pxll_vector*)r1)->val[4];
      r0[2] = r1;
      r1 = varref (0, 0);
      switch (get_case (r1)) {
        case (UITAG(8)): {
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = varref (2, 0);
          r2 = ((pxll_vector*)r2)->val[0];
          r1[2] = r2;
          r1 = varref (5, 179);
          r2 = varref (0, 0);
          r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
        default: {
          goto fatbar_99;
        }
      }
      r1=r1;
      goto fatbar_99_over;
      fatbar_99:
      r1 = (object *) 262;
      r1=r1;
      fatbar_99_over: ;
      r0[3] = r1;
      r0 = varref (0, 1);
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = varref (5, 180);
        r1 = varref (0, 0);
        r0 = box(unbox(r1)|(1<<unbox(r0)));
        lenv = lenv[1];
        r0 = r0;
        r1 = varref (1, 0);
        ((pxll_vector*)r1)->val[0] = r0;
      } else {
        r0 = (object *) 14;
      }
      r0 = varref (0, 1);
      PXLL_RETURN(0);
    } else {
      r0 = (object *) 6;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1652:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_search_3838_i4245_i4326; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (1, 18);
  r1[2] = r2;
  r2 = varref (0, 0);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1654; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_search_3838_i4245_i4326;
  L1654:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[21] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (0, 18);
  r1[2] = r2;
  r2 = varref (0, 0);
  r1[3] = r2;
  r2 = varref (1, 132);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1655; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_build_dependency_graph_538;
  L1655:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[22] = r1;
  r1 = (object*) &constructed_513;
  r1 = box(((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_513;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[23] = r1;
  r1 = varref (0, 0);
  r1 = ((pxll_vector*)r1)->val[2];
  r0[24] = r1;
  r1 = (object *) constructed_512[0];
  r0[25] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object *) constructed_511[0];
  r1[2] = r2;
  r2 = varref (1, 182);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1656; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1656:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[26] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def visit0_3779_i4247_i4326
  goto L1657;
  FUN_visit0_3779_i4247_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (2, 24);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (2, 24);
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1658; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1658:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (3, 22);
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (3, 22);
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1659; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1659:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = (object *) 14;
        r0=r0;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        // def lambda_24285_i4247_i4326
        goto L1660;
        FUN_lambda_24285_i4247_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 24);
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (6, 24);
          r2 = ((pxll_vector*)r2)->val[1];
          r2 = ((pxll_vector*)r2)->val[2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1661; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1661:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (4, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN_visit0_3779_i4247_i4326;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L1660:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_24285_i4247_i4326; r1[2] = lenv;
        r0[3] = r1;
        r1 = varref (0, 0);
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,49)];
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,30)];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1662; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1662:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        r0 = r0;
        r0=r0;
      } break;
    }
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (3, 23);
    r0[2] = r1;
    r0 = varref (0, 0);
    r1 = varref (1, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    lenv = lenv[1];
    r0 = r0;
    varset (2, 23, r0);
    PXLL_RETURN(0);
  L1657:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_visit0_3779_i4247_i4326; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (1, 22);
  r1[2] = r2;
  // def lambda_24320_i4247_i4326
  goto L1663;
  FUN_lambda_24320_i4247_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (3, 24);
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (3, 24);
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[2];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1664; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1664:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = (object *) 6;
    r1 = varref (0, 0);
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (1, 0);
      r0[1] = r1[2]; lenv = r0; goto FUN_visit0_3779_i4247_i4326;
    } else {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1663:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lambda_24320_i4247_i4326; r2[2] = lenv;
  r1[3] = r2;
  r2 = varref (1, 22);
  r2 = ((pxll_vector*)r2)->val[1];
  r2 = ((pxll_vector*)r2)->val[4];
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1665; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto *r2[1];
  L1665:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = allocate (TC_TUPLE, 6);
  r1[1] = lenv; lenv = r1;
  r2 = varref (3, 183);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1666; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto *r2[1];
  L1666:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = varref (2, 22);
  r2[2] = r3;
  // def lambda_24155_i2741_i4247_i4326
  goto L1667;
  FUN_lambda_24155_i2741_i4247_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_510[0];
    r1[2] = r2;
    r2 = varref (4, 182);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1668; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1668:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L1667:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_lambda_24155_i2741_i4247_i4326; r3[2] = lenv;
  r2[3] = r3;
  r3 = varref (2, 22);
  r3 = ((pxll_vector*)r3)->val[1];
  r3 = ((pxll_vector*)r3)->val[4];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1669; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1669:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = allocate (TC_TUPLE, 3);
  r3 = varref (2, 22);
  r2[2] = r3;
  // def lambda_24206_i2741_i4247_i4326
  goto L1670;
  FUN_lambda_24206_i2741_i4247_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_24198_i2741_i4247_i4326
    goto L1671;
    FUN_lambda_24198_i2741_i4247_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (3, 0);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (3, 0);
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[1];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1672; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1672:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UITAG(1)): {
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (3, 0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (3, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (6, 182);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1673; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1673:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = varref (3, 0);
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = varref (3, 0);
          r0[3] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[1];
          r1 = ((pxll_vector*)r1)->val[0];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
      }
      PXLL_RETURN(0);
    L1671:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_24198_i2741_i4247_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 1);
    r1[2] = r2;
    r2 = varref (0, 1);
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,49)];
    r2 = ((pxll_vector*)r2)->val[lookup_field((GET_TYPECODE(*r2)-TC_USEROBJ)>>2,16)];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1674; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1674:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (4, 33);
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
  L1670:
  r3 = allocate (TC_CLOSURE, 2);
  r3[1] = &&FUN_lambda_24206_i2741_i4247_i4326; r3[2] = lenv;
  r2[3] = r3;
  r3 = varref (2, 22);
  r3 = ((pxll_vector*)r3)->val[1];
  r3 = ((pxll_vector*)r3)->val[4];
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1675; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1675:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = varref (0, 0);
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) constructed_509[0];
  r2[2] = r3;
  r3 = varref (3, 182);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1676; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1676:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = (object *) constructed_508[0];
  r1[5] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) constructed_507[0];
  r2[2] = r3;
  r3 = varref (3, 182);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1677; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto *r3[1];
  L1677:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[6] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def visit1_3790_i4247_i4326
  goto L1678;
  FUN_visit1_3790_i4247_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (2, 2);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (2, 2);
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1679; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L1679:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (3, 1);
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (3, 1);
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1680; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1680:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = (object *) 14;
        r0=r0;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 0);
        r0[2] = r1;
        // def lambda_24366_i4247_i4326
        goto L1681;
        FUN_lambda_24366_i4247_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 2);
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (6, 2);
          r2 = ((pxll_vector*)r2)->val[1];
          r2 = ((pxll_vector*)r2)->val[2];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1682; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto *r2[1];
          L1682:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (4, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN_visit1_3790_i4247_i4326;
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        L1681:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_24366_i4247_i4326; r1[2] = lenv;
        r0[3] = r1;
        r1 = varref (0, 0);
        r1 = ((pxll_vector*)r1)->val[1];
        r1 = ((pxll_vector*)r1)->val[3];
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1683; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1683:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        r0 = r0;
        r0=r0;
      } break;
    }
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (2, 4);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[3] = r1;
    r1 = varref (2, 4);
    r1 = ((pxll_vector*)r1)->val[1];
    r1 = ((pxll_vector*)r1)->val[0];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L1678:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_visit1_3790_i4247_i4326; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def $loop_3795_i4247_i4326
  goto L1684;
  FUN__24loop_3795_i4247_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (5, 23);
    r0[2] = r1;
    r1 = varref (0, 0);
    switch (get_case (r1)) {
      case (TC_NIL): {
        r1 = (object *) 262;
        r1=r1;
      } break;
      default: {
        goto fatbar_98;
      }
    }
    r1=r1;
    goto fatbar_98_over;
    fatbar_98:
    r1 = (object *) 6;
    r1=r1;
    fatbar_98_over: ;
    r0[3] = r1;
    r0 = (object *) 6;
    r1 = varref (0, 1);
    r0 = PXLL_TEST(r1==r0);
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (5, 23);
      switch (get_case (r1)) {
        case (TC_NIL): {
          r1 = (object*) &constructed_69;
          r1 = box(((pxll_string*)(r1))->len);
          r2 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
          r1 = (object*) &constructed_506;
          dump_object (r1, 0); fprintf (stdout, "\n");
          r1 = (object*) &constructed_506;
          r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
          r1=r1;
        } break;
        default: {
          r1 = allocate (TC_TUPLE, 3);
          r1[1] = lenv; lenv = r1;
          r2 = varref (6, 23);
          r2 = UOBJ_GET(r2,0);
          r1[2] = r2;
          r2 = varref (6, 23);
          r2 = UOBJ_GET(r2,1);
          r1[3] = r2;
          r1 = varref (0, 1);
          varset (6, 23, r1);
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = r1;
          r1=r1;
        } break;
      }
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (4, 2);
      r1[2] = r2;
      r2 = varref (1, 0);
      r1[3] = r2;
      r2 = varref (4, 2);
      r2 = ((pxll_vector*)r2)->val[1];
      r2 = ((pxll_vector*)r2)->val[2];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1685; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto *r2[1];
      L1685:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r0 = (object *) 6;
      r1 = varref (0, 0);
      r0 = PXLL_TEST(r1==r0);
      lenv = lenv[1];
      r0 = r0;
      if PXLL_IS_TRUE(r0) {
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) constructed_505[0];
        r0[2] = r1;
        r1 = varref (6, 182);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1686; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
        L1686:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        varset (3, 4, r0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1687; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_visit1_3790_i4247_i4326;
        L1687:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (4, 4);
        r1[2] = r2;
        r2 = varref (4, 4);
        r2 = ((pxll_vector*)r2)->val[1];
        r2 = ((pxll_vector*)r2)->val[1];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1688; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L1688:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (4, 3);
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (3, 3, r0);
        r0=r0;
      } else {
        r0 = (object *) 14;
        r0=r0;
      }
      lenv = lenv[1];
      goto FUN__24loop_3795_i4247_i4326;
    } else {
      r0 = (object *) 14;
      PXLL_RETURN(0);
    }
    PXLL_RETURN(0);
  L1684:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN__24loop_3795_i4247_i4326; r2[2] = lenv;
  r1[2] = r2;
  r1 = varref (0, 0);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1689; t[4] = r0; k = t;
  lenv = r1[2]; goto FUN__24loop_3795_i4247_i4326;
  L1689:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = varref (1, 3);
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[27] = r1;
  r1 = varref (0, 25);
  r2 = varref (0, 0);
  ((pxll_vector*)r2)->val[10] = r1;
  r0[28] = r1;
  r1 = (object*) &constructed_504;
  r1 = box(((pxll_string*)(r1))->len);
  r2 = (object*) &constructed_504;
  r1 = (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
  r0[29] = r1;
  r1 = allocate (TC_TUPLE, 14);
  r1[1] = lenv; lenv = r1;
  // def instantiate-type-scheme_3354_i4249_i4326
  goto L1690;
  FUN_instantiate_type_scheme_3354_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    // def lambda_21338_i4249_i4326
    goto L1691;
    FUN_lambda_21338_i4249_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (6, 97);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1692; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_455;
          L1692:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          r1 = varref (1, 1);
          r2 = varref (0, 0);
          t = alloc_no_clear (UOTAG(1),3);
          t[1] = r2;
          t[2] = r0;
          t[3] = r1;
          r0 = t;
          PXLL_RETURN(0);
        } break;
        default: {
          goto fatbar_97;
        }
      }
      PXLL_RETURN(0);
      goto fatbar_97_over;
      fatbar_97:
      r0 = (object*) &constructed_69;
      r0 = box(((pxll_string*)(r0))->len);
      r1 = (object*) &constructed_69;
      (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
      r0 = (object*) &constructed_503;
      dump_object (r0, 0); fprintf (stdout, "\n");
      r0 = (object*) &constructed_503;
      r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
      PXLL_RETURN(0);
      fatbar_97_over: ;
      PXLL_RETURN(0);
    L1691:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_21338_i4249_i4326; r2[2] = lenv;
    r1[2] = r2;
    r2 = (object*)UITAG(0);
    r1[3] = r2;
    r2 = varref (1, 0);
    r1[4] = r2;
    r2 = varref (4, 36);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1693; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_foldr_341;
    L1693:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def walk_3391_i4249_i4326
    goto L1694;
    FUN_walk_3391_i4249_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(1)): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (0, 0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (2, 0);
          r1[2] = r2;
          r2 = varref (0, 1);
          r1[3] = r2;
          r2 = varref (7, 30);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1695; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
          L1695:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r1 = varref (7, 96);
          r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (3, 0);
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (7, 64);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1696; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
          L1696:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[3] = r1;
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = varref (1, 0);
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L1694:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_walk_3391_i4249_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (2, 1);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_walk_3391_i4249_i4326;
  L1690:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_instantiate_type_scheme_3354_i4249_i4326; r2[2] = lenv;
  r1[2] = r2;
  // def occurs-in-type_3355_i4249_i4326
  goto L1697;
  FUN_occurs_in_type_3355_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_21426_i4249_i4326
    goto L1698;
    FUN_lambda_21426_i4249_i4326:
      check_heap (0);
      r0 = varref (1, 1);
      r1 = varref (1, 0);
      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
        r0 = (object *) 262;
        PXLL_RETURN(0);
      } else {
        r0 = varref (1, 1);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = (object *) 6;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (2, 1);
            r1 = UOBJ_GET(r1,1);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_21414_i4249_i4326
            goto L1699;
            FUN_lambda_21414_i4249_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (3, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (4, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1700; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_occurs_in_type_3355_i4249_i4326;
              L1700:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 262;
                r0[2] = r1;
                r1 = varref (2, 0);
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            L1699:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_21414_i4249_i4326; r1[2] = lenv;
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (5, 33);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1701; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
            L1701:
            ; lenv = k[2]; k = k[1];
            r0 = (object *) 6;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L1698:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_21426_i4249_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (3, 14);
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_307;
  L1697:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_occurs_in_type_3355_i4249_i4326; r2[2] = lenv;
  r1[3] = r2;
  // def occurs-free-in-tenv_3356_i4249_i4326
  goto L1702;
  FUN_occurs_free_in_tenv_3356_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    // def lambda_21467_i4249_i4326
    goto L1703;
    FUN_lambda_21467_i4249_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_21461_i4249_i4326
      goto L1704;
      FUN_lambda_21461_i4249_i4326:
        check_heap (0);
        r0 = varref (0, 1);
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 0);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (7, 23);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1705; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_member_eq_question_328;
            L1705:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r1 = varref (3, 0);
              r0[2] = r1;
              r1 = varref (0, 1);
              r0[3] = r1;
              r1 = varref (4, 1);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1706; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_occurs_in_type_3355_i4249_i4326;
              L1706:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) 262;
                r0[2] = r1;
                r1 = varref (2, 0);
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } else {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L1704:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_21461_i4249_i4326; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (1, 1);
      r0[3] = r1;
      r1 = varref (4, 66);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1707; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
      L1707:
      ; lenv = k[2]; k = k[1];
      r0 = (object *) 6;
      PXLL_RETURN(0);
    L1703:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_21467_i4249_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (3, 14);
    r0[1] = r1[2]; lenv = r0; goto FUN__5ecall_2fcc_307;
  L1702:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_occurs_free_in_tenv_3356_i4249_i4326; r2[2] = lenv;
  r1[4] = r2;
  // def build-type-scheme_3357_i4249_i4326
  goto L1708;
  FUN_build_type_scheme_3357_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) constructed_502[0];
    r1[2] = r2;
    r2 = varref (4, 182);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1709; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1709:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def find-generic-tvars_3413_i4249_i4326
    goto L1710;
    FUN_find_generic_tvars_3413_i4249_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (UOTAG(0)): {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (4, 1);
          r1[3] = r2;
          r2 = varref (5, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1711; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_occurs_free_in_tenv_3356_i4249_i4326;
          L1711:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (2, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (2, 0);
            r1 = ((pxll_vector*)r1)->val[1];
            r1 = ((pxll_vector*)r1)->val[0];
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
          } else {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (2, 0);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (7, 33);
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        } break;
      }
      PXLL_RETURN(0);
    L1710:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_find_generic_tvars_3413_i4249_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (3, 0);
    r1[2] = r2;
    r2 = varref (6, 131);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1712; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_533;
    L1712:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (1, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1713; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_find_generic_tvars_3413_i4249_i4326;
    L1713:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (UOTAG(2), 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (2, 0);
    r1[2] = r2;
    r2 = varref (2, 0);
    r2 = ((pxll_vector*)r2)->val[1];
    r2 = ((pxll_vector*)r2)->val[1];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1714; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1714:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[1] = r1;
    r1 = varref (0, 0);
    r0[2] = r1;
    PXLL_RETURN(0);
  L1708:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_build_type_scheme_3357_i4249_i4326; r2[2] = lenv;
  r1[5] = r2;
  // def type-of*_3358_i4249_i4326
  goto L1715;
  FUN_type_of_splat_3358_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (0, 0);
        r0[2] = r1;
        r1 = varref (2, 0);
        r0[3] = r1;
        r1 = varref (2, 1);
        r0[4] = r1;
        r1 = varref (3, 5);
        r0[1] = r1[2]; lenv = r0; goto FUN_type_of_literal_3360_i4249_i4326;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (0, 1);
        r1[3] = r2;
        r2 = varref (3, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1716; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3354_i4249_i4326;
        L1716:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (UOTAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 2);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = (object *) constructed_95[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = allocate (TC_TUPLE, 5);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 1);
              r1[2] = r2;
              r2 = varref (7, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1717; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L1717:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = (object *) 3;
              r2 = varref (0, 0);
              r1 = box(unbox(r2)-unbox(r1));
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (4, 0);
              r2 = ((pxll_vector*)r2)->val[3];
              r1[2] = r2;
              r2 = varref (7, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1718; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L1718:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[4] = r1;
              r1 = varref (0, 2);
              r2 = varref (0, 1);
              r1 = PXLL_TEST(unbox(r2)==unbox(r1));
              r0[5] = r1;
              r0 = (object *) 6;
              r1 = varref (0, 3);
              r0 = PXLL_TEST(r1==r0);
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = (object*) &constructed_456;
                r0[2] = r1;
                r1 = varref (3, 0);
                r0[3] = r1;
                r1 = varref (6, 12);
                r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
              } else {
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 3);
                    r1 = (object*) &constructed_457;
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r0[3] = r1;
                    r1 = varref (6, 12);
                    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 4);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    // def lambda_21921_i2259_i4249_i4326
                    goto L1719;
                    FUN_lambda_21921_i2259_i4249_i4326:
                      check_heap (0);
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (1, 0);
                      r1[2] = r2;
                      r2 = varref (6, 1);
                      r1[3] = r2;
                      r2 = varref (7, 4);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1720; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
                      L1720:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = varref (0, 0);
                      r1 = varref (1, 0);
                      ((pxll_vector*)r1)->val[5] = r0;
                      r0 = varref (0, 0);
                      PXLL_RETURN(0);
                    L1719:
                    r2 = allocate (TC_CLOSURE, 2);
                    r2[1] = &&FUN_lambda_21921_i2259_i4249_i4326; r2[2] = lenv;
                    r1[2] = r2;
                    r2 = varref (4, 0);
                    r2 = ((pxll_vector*)r2)->val[3];
                    r1[3] = r2;
                    r2 = varref (7, 30);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1721; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                    L1721:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[4] = r1;
                    r0 = allocate (TC_TUPLE, 4);
                    // def lambda_21934_i2259_i4249_i4326
                    goto L1722;
                    FUN_lambda_21934_i2259_i4249_i4326:
                      check_heap (0);
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = varref (5, 0);
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (0, 0);
                      r1[2] = r2;
                      r2 = varref (6, 6);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1723; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_unraw_3361_i4249_i4326;
                      L1723:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = varref (0, 1);
                      r0[4] = r1;
                      r1 = varref (8, 130);
                      r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                    L1722:
                    r1 = allocate (TC_CLOSURE, 2);
                    r1[1] = &&FUN_lambda_21934_i2259_i4249_i4326; r1[2] = lenv;
                    r0[2] = r1;
                    r1 = varref (0, 1);
                    r0[3] = r1;
                    r1 = varref (0, 2);
                    r0[4] = r1;
                    r1 = varref (7, 34);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1724; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_for_each2_339;
                    L1724:
                    ; lenv = k[2]; k = k[1];
                    r0 = varref (0, 0);
                    PXLL_RETURN(0);
                  } break;
                }
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } else {
              lenv = ((object *)lenv)[1];
              goto fatbar_68;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_68;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_68_over;
        fatbar_68:
        r0 = varref (0, 2);
        PXLL_RETURN(0);
        fatbar_68_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_21968_i2265_i4249_i4326
        goto L1725;
        FUN_lambda_21968_i2265_i4249_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (4, 1);
          r1[3] = r2;
          r2 = varref (5, 4);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1726; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
          L1726:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        L1725:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_21968_i2265_i4249_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (2, 0);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = varref (5, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1727; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1727:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = varref (0, 1);
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 4);
                        r1 = varref (5, 0);
                        r0[2] = r1;
                        r1 = varref (2, 0);
                        r0[3] = r1;
                        r1 = varref (8, 171);
                        r0[4] = r1;
                        r1 = varref (8, 130);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1728; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                        L1728:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 4);
                        r1 = varref (5, 0);
                        r0[2] = r1;
                        r1 = varref (1, 0);
                        r0[3] = r1;
                        r1 = varref (0, 0);
                        r0[4] = r1;
                        r1 = varref (8, 130);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1729; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                        L1729:
                        ; lenv = k[2]; k = k[1];
                        r0 = varref (0, 0);
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_69;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_69;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_69;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_69;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_69_over;
        fatbar_69:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_458;
        r0[2] = r1;
        r1 = varref (2, 0);
        r0[3] = r1;
        r1 = varref (5, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        fatbar_69_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(5)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def loop_3489_i2267_i4249_i4326
        goto L1730;
        FUN_loop_3489_i2267_i4249_i4326:
          check_heap (0);
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_NIL): {
              r0 = (object*) &constructed_69;
              r0 = box(((pxll_string*)(r0))->len);
              r1 = (object*) &constructed_69;
              (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
              r0 = (object*) &constructed_459;
              dump_object (r0, 0); fprintf (stdout, "\n");
              r0 = (object*) &constructed_459;
              r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
              PXLL_RETURN(0);
            } break;
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (1, 0);
                  r1[2] = r2;
                  r2 = varref (6, 1);
                  r1[3] = r2;
                  r2 = varref (7, 4);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1731; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
                  L1731:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = varref (0, 0);
                  r1 = varref (1, 0);
                  ((pxll_vector*)r1)->val[5] = r0;
                  r0 = varref (0, 0);
                  PXLL_RETURN(0);
                } break;
                default: {
                  goto fatbar_70;
                }
              }
              PXLL_RETURN(0);
              goto fatbar_70_over;
              fatbar_70:
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (1, 0);
              r1[2] = r2;
              r2 = varref (6, 1);
              r1[3] = r2;
              r2 = varref (7, 4);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1732; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
              L1732:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (0, 0);
              r1 = varref (1, 0);
              ((pxll_vector*)r1)->val[5] = r0;
              r0 = varref (0, 0);
              lenv = lenv[1];
              r0 = varref (0, 1);
              lenv = ((object *)lenv)[1];
              lenv[2] = r0;
              goto FUN_loop_3489_i2267_i4249_i4326;
              fatbar_70_over: ;
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L1730:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_loop_3489_i2267_i4249_i4326; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[1] = r1[2]; lenv = r0; goto FUN_loop_3489_i2267_i4249_i4326;
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1733; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L1733:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (2, 1);
        r0[4] = r1;
        r1 = (object *) constructed_461[0];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_22093_i2271_i4249_i4326
        goto L1734;
        FUN_lambda_22093_i2271_i4249_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (7, 97);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1735; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_455;
          L1735:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (2, 3);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          varset (2, 3, r0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_460[0];
          r1[1] = r2;
          r2 = varref (1, 0);
          r1[2] = r2;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (3, 2);
          r2 = varref (2, 0);
          t = alloc_no_clear (UOTAG(1),3);
          t[1] = r2;
          t[2] = r0;
          t[3] = r1;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 2, r0);
          PXLL_RETURN(0);
        L1734:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_22093_i2271_i4249_i4326; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (5, 33);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1736; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        L1736:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 1);
        r1[2] = r2;
        r2 = varref (1, 2);
        r1[3] = r2;
        r2 = varref (4, 4);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1737; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
        L1737:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (0, 0);
        r2 = varref (1, 1);
        ((pxll_vector*)r2)->val[5] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 3);
        r1[2] = r2;
        r2 = (object *) constructed_37[0];
        r1[3] = r2;
        r2 = varref (6, 19);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1738; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
        L1738:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_95[0];
        r0[2] = r1;
        r1 = varref (0, 2);
        r2 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        r0[3] = r1;
        r1 = varref (6, 96);
        r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 1);
        r1[3] = r2;
        r2 = varref (3, 7);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1739; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_apply_tenv_3367_i4249_i4326;
        L1739:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1740; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L1740:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (2, 1);
        r1[3] = r2;
        r2 = varref (3, 7);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1741; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_apply_tenv_3367_i4249_i4326;
        L1741:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (2, 1);
        r1[3] = r2;
        r2 = varref (3, 4);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1742; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
        L1742:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = varref (0, 3);
        r2 = varref (0, 1);
        ((pxll_vector*)r2)->val[5] = r1;
        r1 = varref (0, 3);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (2, 0);
        r0[2] = r1;
        r1 = varref (0, 2);
        r0[3] = r1;
        r1 = varref (0, 4);
        r0[4] = r1;
        r1 = varref (5, 130);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1743; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
        L1743:
        ; lenv = k[2]; k = k[1];
        r0 = varref (5, 170);
        PXLL_RETURN(0);
      } break;
      case (UITAG(8)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_22182_i2281_i4249_i4326
        goto L1744;
        FUN_lambda_22182_i2281_i4249_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (4, 1);
          r1[3] = r2;
          r2 = varref (5, 4);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1745; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
          L1745:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          ((pxll_vector*)r1)->val[5] = r0;
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        L1744:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_22182_i2281_i4249_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (2, 0);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[3] = r2;
        r2 = varref (5, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1746; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L1746:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = varref (6, 97);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1747; t[4] = r0; k = t;
            lenv = r1[2]; goto FUN_new_tvar_455;
            L1747:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (3, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = (object *) constructed_95[0];
            r1[2] = r2;
            r2 = varref (0, 1);
            r3 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[3] = r2;
            r2 = varref (6, 96);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1748; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
            L1748:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = varref (6, 130);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1749; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
            L1749:
            ; lenv = k[2]; k = k[1];
            r0 = varref (0, 2);
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_69;
            r0 = box(((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_462;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_462;
            r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 17);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (2, 1);
        r0[3] = r1;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = varref (4, 0);
        r1 = ((pxll_vector*)r1)->val[10];
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (5, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1750; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L1750:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[6] = r1;
        r1 = varref (5, 183);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1751; t[4] = r0; k = t;
        lenv = r1[2]; goto *r1[1];
        L1751:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[7] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 4);
        r1[2] = r2;
        r2 = varref (5, 28);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1752; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_range_333;
        L1752:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[8] = r1;
        r1 = (object *) constructed_470[0];
        r0[9] = r1;
        r1 = (object *) constructed_469[0];
        r0[10] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = varref (1, 4);
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_3807_i2287_i4249_i4326
        goto L1753;
        FUN__24loop_3807_i2287_i4249_i4326:
          check_heap (0);
          r0 = varref (2, 0);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (3, 5);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 0);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (8, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1754; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1754:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (UOTAG(3), 2);
            r2 = (object *) 6;
            r1[1] = r2;
            r2 = varref (0, 0);
            r1[2] = r2;
            r0[4] = r1;
            r1 = varref (3, 5);
            r1 = ((pxll_vector*)r1)->val[1];
            r1 = ((pxll_vector*)r1)->val[0];
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1755; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto *r1[1];
            L1755:
            ; lenv = k[2]; k = k[1];
            r0 = (object *) 3;
            r1 = varref (0, 0);
            r0 = box(unbox(r1)+unbox(r0));
            lenv[2] = r0;
            goto FUN__24loop_3807_i2287_i4249_i4326;
          }
          PXLL_RETURN(0);
        L1753:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_3807_i2287_i4249_i4326; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 2);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1756; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_3807_i2287_i4249_i4326;
        L1756:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        lenv = lenv[1];
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_24570_i2287_i4249_i4326
        goto L1757;
        FUN_lambda_24570_i2287_i4249_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (2, 8);
          r1[2] = r2;
          r2 = varref (7, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1758; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L1758:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(unbox(r1)>unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (1, 7);
            r1 = varref (1, 8);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            varset (1, 7, r0);
            r0 = (object *) constructed_468[0];
            varset (1, 8, r0);
          } else {
            r0 = (object *) 14;
          }
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_24565_i2287_i4249_i4326
          goto L1759;
          FUN_lambda_24565_i2287_i4249_i4326:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 5);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (3, 5);
            r2 = ((pxll_vector*)r2)->val[1];
            r2 = ((pxll_vector*)r2)->val[1];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1760; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L1760:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UITAG(1)): {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = ((pxll_vector*)r1)->val[0];
                r0[2] = r1;
                r0 = (object *) 6;
                r1 = varref (0, 0);
                r0 = PXLL_TEST(r1==r0);
                lenv = lenv[1];
                r0 = r0;
                if PXLL_IS_TRUE(r0) {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = ((pxll_vector*)r1)->val[1];
                  r0[2] = r1;
                  r0 = varref (5, 8);
                  r1 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r1;
                  t[2] = r0;
                  r0 = t;
                  lenv = lenv[1];
                  r0 = r0;
                  varset (4, 8, r0);
                  r0 = (object *) 262;
                  r1 = varref (0, 0);
                  ((pxll_vector*)r1)->val[0] = r0;
                  r0 = allocate (TC_TUPLE, 3);
                  r1 = varref (0, 0);
                  r1 = ((pxll_vector*)r1)->val[1];
                  r0[2] = r1;
                  r1 = varref (4, 6);
                  r0[3] = r1;
                  r1 = varref (9, 24);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1761; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_remove_eq_329;
                  L1761:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  varset (4, 6, r0);
                  PXLL_RETURN(0);
                } else {
                  r0 = (object *) 14;
                  PXLL_RETURN(0);
                }
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L1759:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_24565_i2287_i4249_i4326; r1[2] = lenv;
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (6, 33);
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        L1757:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_24570_i2287_i4249_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (0, 3);
        r1[3] = r2;
        r2 = varref (5, 33);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1762; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_for_each_338;
        L1762:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 8);
        r2[2] = r3;
        r3 = varref (6, 20);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1763; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
        L1763:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 1;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(unbox(r2)>unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (0, 7);
          r2 = varref (0, 8);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          varset (0, 7, r1);
        } else {
          r1 = (object *) 14;
        }
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 6);
        r2[2] = r3;
        r3 = varref (6, 20);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1764; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
        L1764:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = (object *) 1;
        r2 = varref (0, 0);
        r1 = PXLL_TEST(unbox(r2)>unbox(r1));
        lenv = lenv[1];
        r1 = r1;
        if PXLL_IS_TRUE(r1) {
          r1 = varref (0, 7);
          r2 = varref (0, 6);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          varset (0, 7, r1);
        } else {
          r1 = (object *) 14;
        }
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 7);
        r1[2] = r2;
        r2 = (object *) constructed_37[0];
        r1[3] = r2;
        r2 = varref (5, 19);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1765; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
        L1765:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[11] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (5, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1766; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L1766:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[12] = r1;
        r1 = (object *) constructed_467[0];
        r0[13] = r1;
        r1 = (object *) constructed_466[0];
        r0[14] = r1;
        r1 = (object *) constructed_465[0];
        r0[15] = r1;
        r1 = (object *) 1;
        r0[16] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_24663_i2286_i4249_i4326
        goto L1767;
        FUN_lambda_24663_i2286_i4249_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_464[0];
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_24649_i2286_i4249_i4326
          goto L1768;
          FUN_lambda_24649_i2286_i4249_i4326:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 0);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (9, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1769; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1769:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (4, 11);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (3, 11, r0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 2);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (9, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1770; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1770:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (4, 12);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (3, 12, r0);
            r0 = varref (1, 0);
            r1 = varref (3, 14);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            varset (1, 0, r0);
            r0 = (object *) 3;
            r1 = varref (3, 14);
            r0 = box(unbox(r1)+unbox(r0));
            varset (3, 14, r0);
            PXLL_RETURN(0);
          L1768:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_24649_i2286_i4249_i4326; r1[2] = lenv;
          r0[2] = r1;
          r1 = varref (1, 0);
          r0[3] = r1;
          r1 = varref (7, 33);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1771; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
          L1771:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (8, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1772; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L1772:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (3, 13);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          varset (2, 13, r0);
          PXLL_RETURN(0);
        L1767:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_24663_i2286_i4249_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (0, 9);
        r1[3] = r2;
        r2 = varref (5, 33);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1773; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_for_each_338;
        L1773:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = allocate (UOTAG(5), 4);
        r2 = allocate (TC_TUPLE, 3);
        r3 = varref (0, 11);
        r2[2] = r3;
        r3 = (object *) constructed_37[0];
        r2[3] = r3;
        r3 = varref (5, 19);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1774; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
        L1774:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[1] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = varref (0, 12);
        r2[2] = r3;
        r3 = (object *) constructed_37[0];
        r2[3] = r3;
        r3 = varref (5, 19);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1775; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
        L1775:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = varref (0, 2);
        r2[2] = r3;
        r3 = varref (0, 10);
        r2[3] = r3;
        r3 = varref (5, 25);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1776; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
        L1776:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = varref (0, 13);
        r2[2] = r3;
        r3 = (object *) constructed_37[0];
        r2[3] = r3;
        r3 = varref (5, 19);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1777; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
        L1777:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[4] = r2;
        r0[17] = r1;
        r0 = varref (0, 15);
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 10);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 15);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 15);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = varref (1, 15);
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r1 = varref (1, 15);
            r1 = UOBJ_GET(r1,3);
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (6, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1778; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L1778:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (6, 41);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1779; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_348;
            L1779:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (6, 41);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1780; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_348;
            L1780:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[8] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            r3 = varref (1, 4);
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_3535_i2285_i4249_i4326
            goto L1781;
            FUN__24loop_3535_i2285_i4249_i4326:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (0, 1);
                r0[2] = r1;
                r1 = (object *) constructed_37[0];
                r0[3] = r1;
                r1 = varref (9, 19);
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (10, 97);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1782; t[4] = r0; k = t;
                lenv = r1[2]; goto FUN_new_tvar_455;
                L1782:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (1, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = (object *) 3;
                r2 = varref (0, 0);
                r1 = box(unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_3535_i2285_i4249_i4326;
              }
              PXLL_RETURN(0);
            L1781:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_3535_i2285_i4249_i4326; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = varref (0, 0);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1783; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_3535_i2285_i4249_i4326;
            L1783:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = varref (6, 41);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1784; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_list__3evector_348;
            L1784:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[9] = r1;
            r1 = varref (0, 4);
            ensure_heap (1, unbox(r1));
            r1 = varref (6, 178);
            r2 = varref (0, 4);
            if (unbox(r2) == 0) { r1 = (object *) TC_EMPTY_VECTOR; } else {
              t = alloc_no_clear (TC_VECTOR, unbox(r2));
              for (i=0; i<unbox(r2); i++) { t[i+1] = r1; }
              r1 = t;
            }
            r0[10] = r1;
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_22354_i2285_i4249_i4326
            goto L1785;
            FUN_lambda_22354_i2285_i4249_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 4);
              // def lambda_22294_i2285_i4249_i4326
              goto L1786;
              FUN_lambda_22294_i2285_i4249_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r2 = varref (4, 5);
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r1 = allocate (UOTAG(2), 2);
                r2 = (object *) constructed_463[0];
                r1[1] = r2;
                r2 = varref (1, 0);
                r3 = varref (4, 7);
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r0[3] = r1;
                r0 = varref (0, 1);
                r1 = varref (1, 1);
                r2 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                PXLL_RETURN(0);
              L1786:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_22294_i2285_i4249_i4326; r2[2] = lenv;
              r1[2] = r2;
              r2 = varref (3, 1);
              r1[3] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (1, 0);
              r2[2] = r3;
              r3 = (object *) constructed_37[0];
              r2[3] = r3;
              r3 = varref (8, 19);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1787; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
              L1787:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[4] = r2;
              r2 = varref (8, 36);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L1788; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_foldr_341;
              L1788:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_22326_i2285_i4249_i4326
              goto L1789;
              FUN_lambda_22326_i2285_i4249_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 6);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r2 = varref (4, 6);
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (0, 0);
                r1[2] = r2;
                r2 = varref (2, 0);
                r1[3] = r2;
                r2 = varref (8, 4);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1790; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
                L1790:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = varref (0, 1);
                r2 = varref (0, 0);
                ((pxll_vector*)r2)->val[5] = r1;
                r1 = varref (0, 1);
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 4);
                r2 = varref (1, 0);
                r3 = varref (4, 6);
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r2 = varref (0, 2);
                r1[3] = r2;
                r2 = varref (1, 0);
                r3 = varref (4, 7);
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[4] = r2;
                r2 = varref (10, 130);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1791; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_unify_532;
                L1791:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (0, 2);
                r1[2] = r2;
                r2 = varref (10, 131);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1792; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_533;
                L1792:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[6] = r1;
                r0 = varref (1, 0);
                r1 = varref (0, 4);
                r2 = varref (4, 8);
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r0));
                ((pxll_vector*)r2)->val[unbox(r0)] = r1;
                PXLL_RETURN(0);
              L1789:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_22326_i2285_i4249_i4326; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (1, 0);
              r0[3] = r1;
              r1 = varref (8, 33);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L1793; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
              L1793:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_22347_i2285_i4249_i4326
              goto L1794;
              FUN_lambda_22347_i2285_i4249_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (1, 0);
                r3 = varref (4, 8);
                range_check (GET_TUPLE_LENGTH(*(object*)r3), unbox(r2));
                r2 = ((pxll_vector*)r3)->val[unbox(r2)];
                r1[2] = r2;
                r2 = varref (5, 1);
                r1[3] = r2;
                r2 = varref (8, 3);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1795; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_build_type_scheme_3357_i4249_i4326;
                L1795:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (2, 0);
                r2 = varref (5, 5);
                range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                r0[2] = r1;
                r0 = varref (1, 0);
                r1 = varref (6, 1);
                r2 = varref (0, 0);
                t = alloc_no_clear (UOTAG(1),3);
                t[1] = r2;
                t[2] = r0;
                t[3] = r1;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (5, 1, r0);
                PXLL_RETURN(0);
              L1794:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_22347_i2285_i4249_i4326; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (1, 0);
              r0[3] = r1;
              r1 = varref (8, 33);
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
            L1785:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_22354_i2285_i4249_i4326; r1[2] = lenv;
            r0[2] = r1;
            r1 = varref (0, 3);
            r0[3] = r1;
            r1 = varref (6, 33);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1796; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
            L1796:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 2);
            r1[2] = r2;
            r2 = varref (2, 1);
            r1[3] = r2;
            r2 = varref (5, 4);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1797; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
            L1797:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (1, 2);
            ((pxll_vector*)r1)->val[5] = r0;
            r0 = varref (0, 0);
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (2, 1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (5, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1798; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L1798:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        // def $loop_3556_i2319_i4249_i4326
        goto L1799;
        FUN__24loop_3556_i2319_i4249_i4326:
          check_heap (0);
          r0 = varref (2, 0);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 3);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (9, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1800; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1800:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (4, 0);
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (9, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1801; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L1801:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (4, 1);
            r1[3] = r2;
            r2 = varref (7, 4);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1802; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
            L1802:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = varref (0, 2);
            r2 = varref (0, 0);
            ((pxll_vector*)r2)->val[5] = r1;
            r1 = varref (0, 2);
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (UOTAG(2), 2);
            r2 = (object *) constructed_471[0];
            r1[1] = r2;
            r2 = varref (1, 3);
            r1[2] = r2;
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = varref (5, 1);
            r2 = varref (1, 1);
            t = alloc_no_clear (UOTAG(1),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (4, 1, r0);
            lenv = lenv[1];
            r0 = (object *) 3;
            r1 = varref (0, 0);
            r0 = box(unbox(r1)+unbox(r0));
            lenv[2] = r0;
            goto FUN__24loop_3556_i2319_i4249_i4326;
          }
          PXLL_RETURN(0);
        L1799:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN__24loop_3556_i2319_i4249_i4326; r1[2] = lenv;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = (object *) 1;
        r0[2] = r1;
        r1 = varref (0, 0);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1803; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3556_i2319_i4249_i4326;
        L1803:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        lenv = lenv[1];
        r0 = r0;
        lenv = lenv[1];
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 3);
        r1[2] = r2;
        r2 = varref (1, 2);
        r1[3] = r2;
        r2 = varref (6, 25);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1804; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
        L1804:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (1, 1);
        r1[3] = r2;
        r2 = varref (4, 4);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1805; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
        L1805:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        ((pxll_vector*)r1)->val[5] = r0;
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (2, 0);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = (object *) constructed_258[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = varref (0, 0);
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (1, 0);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = varref (0, 0);
                  switch (get_case (r1)) {
                    case (UOTAG(9)): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = varref (1, 1);
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (2, 1);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = varref (2, 1);
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = varref (0, 0);
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = varref (1, 0);
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = varref (1, 1);
                              switch (get_case (r1)) {
                                case (TC_PAIR): {
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = varref (2, 1);
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r2 = varref (2, 1);
                                  r2 = UOBJ_GET(r2,1);
                                  r1[3] = r2;
                                  r1 = varref (0, 0);
                                  switch (get_case (r1)) {
                                    case (UOTAG(5)): {
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = varref (1, 0);
                                      r2 = UOBJ_GET(r2,0);
                                      r1[2] = r2;
                                      r1 = varref (1, 1);
                                      switch (get_case (r1)) {
                                        case (TC_NIL): {
                                          r1 = (object *) constructed_50[0];
                                          r2 = varref (4, 0);
                                          if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                            r1 = allocate (TC_TUPLE, 6);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = allocate (TC_TUPLE, 2);
                                            r3 = varref (1, 0);
                                            r2[2] = r3;
                                            r3 = varref (11, 8);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1806; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_n_tvars_3377_i4249_i4326;
                                            L1806:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[2] = r2;
                                            r2 = varref (13, 97);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1807; t[4] = r0; t[5] = r1; k = t;
                                            lenv = r2[2]; goto FUN_new_tvar_455;
                                            L1807:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[3] = r2;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = varref (5, 1);
                                            r2[2] = r3;
                                            r3 = (object *) constructed_480[0];
                                            r2[3] = r3;
                                            r3 = varref (13, 96);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1808; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                            L1808:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[4] = r2;
                                            r2 = allocate (TC_TUPLE, 4);
                                            r3 = varref (0, 2);
                                            r2[2] = r3;
                                            r3 = allocate (TC_TUPLE, 2);
                                            r3[1] = lenv; lenv = r3;
                                            r4 = (object *) 3;
                                            r5 = varref (2, 0);
                                            if PXLL_IS_TRUE(PXLL_TEST(unbox(r5)>unbox(r4))) {
                                              r4 = allocate (TC_TUPLE, 3);
                                              r5 = (object *) constructed_479[0];
                                              r4[2] = r5;
                                              r5 = varref (1, 0);
                                              r4[3] = r5;
                                              r5 = varref (14, 96);
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1809; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                              L1809:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r4=r4;
                                            } else {
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = varref (1, 0);
                                              r4[2] = r5;
                                              r5 = varref (14, 17);
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L1810; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_car_318;
                                              L1810:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r4=r4;
                                            }
                                            r3[2] = r4;
                                            r3 = allocate (TC_TUPLE, 3);
                                            r4 = (object *) constructed_477[0];
                                            r3[2] = r4;
                                            r4 = allocate (TC_TUPLE, 2);
                                            r4[1] = lenv; lenv = r4;
                                            r5 = (object*)TC_NIL;
                                            r4[2] = r5;
                                            r4 = varref (0, 0);
                                            r5 = varref (1, 0);
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r5;
                                            t[2] = r4;
                                            r4 = t;
                                            lenv = lenv[1];
                                            r4 = r4;
                                            r3[3] = r4;
                                            r4 = varref (14, 96);
                                            t = allocate (TC_SAVE, 6);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1811; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                            r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                            L1811:
                                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                            r3 = result;
                                            lenv = lenv[1];
                                            r3 = r3;
                                            r2[3] = r3;
                                            r3 = varref (0, 1);
                                            r2[4] = r3;
                                            r3 = varref (13, 98);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1812; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_rlabel_460;
                                            L1812:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[5] = r2;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = (object *) constructed_475[0];
                                            r2[2] = r3;
                                            r3 = allocate (TC_TUPLE, 2);
                                            r3[1] = lenv; lenv = r3;
                                            r4 = (object*)TC_NIL;
                                            r3[2] = r4;
                                            r3 = varref (0, 0);
                                            r4 = varref (1, 3);
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            lenv = lenv[1];
                                            r3 = r3;
                                            r2[3] = r3;
                                            r3 = varref (13, 96);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1813; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                            L1813:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[6] = r2;
                                            r1 = allocate (UOTAG(2), 2);
                                            r2 = varref (0, 0);
                                            r3 = varref (0, 1);
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r3;
                                            t[2] = r2;
                                            r2 = t;
                                            r1[1] = r2;
                                            r2 = allocate (TC_TUPLE, 4);
                                            r2[1] = lenv; lenv = r2;
                                            r3 = allocate (TC_TUPLE, 3);
                                            r4 = varref (1, 0);
                                            r3[2] = r4;
                                            r4 = varref (4, 0);
                                            r3[3] = r4;
                                            r4 = varref (14, 25);
                                            t = allocate (TC_SAVE, 6);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1814; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                            r3[1] = r4[2]; lenv = r3; goto FUN_nth_330;
                                            L1814:
                                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                            r3 = result;
                                            r2[2] = r3;
                                            r3 = (object*)TC_NIL;
                                            r2[3] = r3;
                                            r3 = varref (0, 1);
                                            r4 = varref (1, 4);
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            r2[4] = r3;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = (object *) constructed_95[0];
                                            r2[2] = r3;
                                            r3 = varref (0, 2);
                                            r4 = varref (0, 0);
                                            t = alloc_no_clear (TC_PAIR,2);
                                            t[1] = r4;
                                            t[2] = r3;
                                            r3 = t;
                                            r2[3] = r3;
                                            r3 = varref (14, 96);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1815; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                            L1815:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            lenv = lenv[1];
                                            r2 = r2;
                                            r1[2] = r2;
                                            lenv = lenv[1];
                                            r1 = r1;
                                            r1=r1;
                                          } else {
                                            r1 = allocate (TC_TUPLE, 2);
                                            r1[1] = lenv; lenv = r1;
                                            r2 = allocate (TC_TUPLE, 3);
                                            r3 = varref (12, 0);
                                            r3 = ((pxll_vector*)r3)->val[1];
                                            r2[2] = r3;
                                            r3 = varref (5, 0);
                                            r2[3] = r3;
                                            r3 = varref (13, 64);
                                            t = allocate (TC_SAVE, 5);
                                            t[1] = k; t[2] = lenv; t[3] = &&L1816; t[4] = r0; t[5] = r1; k = t;
                                            r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
                                            L1816:
                                            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                            r2 = result;
                                            r1[2] = r2;
                                            r1 = varref (0, 0);
                                            switch (get_case (r1)) {
                                              case (UITAG(1)): {
                                                r1 = allocate (TC_TUPLE, 3);
                                                r2 = (object*) &constructed_481;
                                                r1[2] = r2;
                                                r2 = varref (5, 0);
                                                r1[3] = r2;
                                                r2 = varref (13, 12);
                                                t = allocate (TC_SAVE, 4);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1817; t[4] = r0; k = t;
                                                r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                                                L1817:
                                                r0 = k[4]; lenv = k[2]; k = k[1];
                                                r1 = result;
                                                r1=r1;
                                              } break;
                                              default: {
                                                r1 = allocate (TC_TUPLE, 5);
                                                r1[1] = lenv; lenv = r1;
                                                r2 = varref (1, 0);
                                                r2 = UOBJ_GET(r2,0);
                                                r1[2] = r2;
                                                r2 = allocate (TC_TUPLE, 2);
                                                r3 = varref (6, 1);
                                                r2[2] = r3;
                                                r3 = varref (0, 0);
                                                r3 = ((pxll_vector*)r3)->val[1];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1818; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto *r3[1];
                                                L1818:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[3] = r2;
                                                r2 = varref (0, 0);
                                                r2 = ((pxll_vector*)r2)->val[5];
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1819; t[4] = r0; t[5] = r1; k = t;
                                                lenv = r2[2]; goto *r2[1];
                                                L1819:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[4] = r2;
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = varref (6, 0);
                                                r2[2] = r3;
                                                r3 = varref (0, 2);
                                                r2[3] = r3;
                                                r3 = varref (14, 96);
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1820; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                                L1820:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                r1[5] = r2;
                                                r1 = allocate (UOTAG(2), 2);
                                                r2 = varref (0, 2);
                                                r1[1] = r2;
                                                r2 = allocate (TC_TUPLE, 4);
                                                r2[1] = lenv; lenv = r2;
                                                r3 = allocate (TC_TUPLE, 3);
                                                r4 = varref (1, 1);
                                                r4 = ((pxll_vector*)r4)->val[3];
                                                r3[2] = r4;
                                                r4 = varref (5, 0);
                                                r3[3] = r4;
                                                r4 = varref (15, 25);
                                                t = allocate (TC_SAVE, 6);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1821; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                                r3[1] = r4[2]; lenv = r3; goto FUN_nth_330;
                                                L1821:
                                                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                                r3 = result;
                                                r2[2] = r3;
                                                r3 = (object*)TC_NIL;
                                                r2[3] = r3;
                                                r3 = varref (0, 1);
                                                r4 = varref (1, 3);
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[4] = r3;
                                                r2 = allocate (TC_TUPLE, 3);
                                                r3 = (object *) constructed_95[0];
                                                r2[2] = r3;
                                                r3 = varref (0, 2);
                                                r4 = varref (0, 0);
                                                t = alloc_no_clear (TC_PAIR,2);
                                                t[1] = r4;
                                                t[2] = r3;
                                                r3 = t;
                                                r2[3] = r3;
                                                r3 = varref (15, 96);
                                                t = allocate (TC_SAVE, 5);
                                                t[1] = k; t[2] = lenv; t[3] = &&L1822; t[4] = r0; t[5] = r1; k = t;
                                                r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                                L1822:
                                                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                r2 = result;
                                                lenv = lenv[1];
                                                r2 = r2;
                                                r1[2] = r2;
                                                lenv = lenv[1];
                                                r1 = r1;
                                                r1=r1;
                                              } break;
                                            }
                                            lenv = lenv[1];
                                            r1 = r1;
                                            r1=r1;
                                          }
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                          goto fatbar_73;
                                        }
                                      }
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                      goto fatbar_73;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_73;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_73;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_73;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_73;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_73;
                }
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_73;
            }
          }
          r1=r1;
          goto fatbar_73_over;
          fatbar_73:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_482;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1823; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1823:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_73_over: ;
          r1=r1;
        } else {
          goto fatbar_72;
        }
        r1=r1;
        goto fatbar_72_over;
        fatbar_72:
        r1 = (object *) constructed_435[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case (UOTAG(0)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = varref (0, 0);
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (1, 0);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (1, 0);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = varref (0, 0);
                  switch (get_case (r1)) {
                    case (UOTAG(1)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = varref (1, 1);
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (2, 1);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = varref (2, 1);
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = varref (0, 0);
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = varref (1, 0);
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = varref (1, 1);
                              switch (get_case (r1)) {
                                case (TC_NIL): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = varref (3, 0);
                                  r2[2] = r3;
                                  r3 = (object *) constructed_480[0];
                                  r2[3] = r3;
                                  r3 = varref (11, 96);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1824; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                  L1824:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = varref (11, 0);
                                  r3 = ((pxll_vector*)r3)->val[13];
                                  r2[2] = r3;
                                  r3 = varref (4, 0);
                                  r2[3] = r3;
                                  r3 = varref (12, 64);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1825; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
                                  L1825:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r1 = varref (0, 0);
                                  switch (get_case (r1)) {
                                    case (UOTAG(0)): {
                                      r1 = (object *) 14;
                                      r1=r1;
                                    } break;
                                    default: {
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = allocate (TC_TUPLE, 2);
                                      r3 = varref (12, 0);
                                      r3 = ((pxll_vector*)r3)->val[13];
                                      r2[2] = r3;
                                      r3 = varref (13, 68);
                                      t = allocate (TC_SAVE, 5);
                                      t[1] = k; t[2] = lenv; t[3] = &&L1826; t[4] = r0; t[5] = r1; k = t;
                                      r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flength_412;
                                      L1826:
                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                      r2 = result;
                                      r1[2] = r2;
                                      r1 = allocate (TC_TUPLE, 2);
                                      r1[1] = lenv; lenv = r1;
                                      r2 = varref (13, 0);
                                      r2 = ((pxll_vector*)r2)->val[13];
                                      r1[2] = r2;
                                      r1 = varref (1, 0);
                                      r2 = varref (0, 0);
                                      r3 = varref (6, 0);
                                      t = alloc_no_clear (UOTAG(1),3);
                                      t[1] = r3;
                                      t[2] = r1;
                                      t[3] = r2;
                                      r1 = t;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r2 = varref (12, 0);
                                      ((pxll_vector*)r2)->val[13] = r1;
                                      lenv = lenv[1];
                                      r1 = r1;
                                      r1=r1;
                                    } break;
                                  }
                                  lenv = lenv[1];
                                  r1 = (object *) 3;
                                  r2 = varref (1, 0);
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = allocate (UOTAG(2), 2);
                                    r2 = allocate (TC_TUPLE, 3);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = (object*)TC_NIL;
                                    r2[2] = r3;
                                    r3 = varref (0, 0);
                                    r4 = varref (10, 11);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r2 = varref (0, 1);
                                    r3 = varref (10, 10);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r3;
                                    t[2] = r2;
                                    r2 = t;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 5);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = allocate (TC_TUPLE, 4);
                                    r4 = varref (1, 0);
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 3);
                                    r5 = (object *) constructed_477[0];
                                    r4[2] = r5;
                                    r5 = allocate (TC_TUPLE, 2);
                                    r5[1] = lenv; lenv = r5;
                                    r6 = (object*)TC_NIL;
                                    r5[2] = r6;
                                    r5 = varref (0, 0);
                                    r6 = varref (11, 10);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r6;
                                    t[2] = r5;
                                    r5 = t;
                                    lenv = lenv[1];
                                    r5 = r5;
                                    r4[3] = r5;
                                    r5 = varref (12, 96);
                                    t = allocate (TC_SAVE, 7);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1827; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                    r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                    L1827:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                    r4 = result;
                                    r3[3] = r4;
                                    r4 = varref (10, 11);
                                    r3[4] = r4;
                                    r4 = varref (12, 98);
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1828; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
                                    L1828:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[2] = r3;
                                    r3 = allocate (TC_TUPLE, 3);
                                    r4 = (object *) constructed_475[0];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = (object*)TC_NIL;
                                    r4[2] = r5;
                                    r4 = varref (0, 0);
                                    r5 = varref (1, 0);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r5;
                                    t[2] = r4;
                                    r4 = t;
                                    lenv = lenv[1];
                                    r4 = r4;
                                    r3[3] = r4;
                                    r4 = varref (12, 96);
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1829; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                    L1829:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[3] = r3;
                                    r3 = (object*)TC_NIL;
                                    r2[4] = r3;
                                    r3 = varref (0, 2);
                                    r4 = varref (10, 10);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[5] = r3;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r3 = (object *) constructed_95[0];
                                    r2[2] = r3;
                                    r3 = varref (0, 3);
                                    r4 = varref (0, 1);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r3 = varref (12, 96);
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1830; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                    L1830:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[2] = r2;
                                    r1=r1;
                                  } else {
                                    goto fatbar_76;
                                  }
                                  r1=r1;
                                  goto fatbar_76_over;
                                  fatbar_76:
                                  r1 = (object *) 1;
                                  r2 = varref (1, 0);
                                  if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                                    r1 = allocate (UOTAG(2), 2);
                                    r2 = allocate (TC_TUPLE, 2);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = (object*)TC_NIL;
                                    r2[2] = r3;
                                    r2 = varref (0, 0);
                                    r3 = varref (10, 10);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r3;
                                    t[2] = r2;
                                    r2 = t;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[1] = r2;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r2[1] = lenv; lenv = r2;
                                    r3 = allocate (TC_TUPLE, 4);
                                    r4 = varref (1, 0);
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = allocate (TC_TUPLE, 3);
                                    r6 = (object *) constructed_479[0];
                                    r5[2] = r6;
                                    r6 = (object *) constructed_484[0];
                                    r5[3] = r6;
                                    r6 = varref (13, 96);
                                    t = allocate (TC_SAVE, 8);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1831; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                    r5[1] = r6[2]; lenv = r5; goto FUN_pred_453;
                                    L1831:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                    r5 = result;
                                    r4[2] = r5;
                                    r4 = allocate (TC_TUPLE, 3);
                                    r5 = (object *) constructed_477[0];
                                    r4[2] = r5;
                                    r5 = allocate (TC_TUPLE, 2);
                                    r5[1] = lenv; lenv = r5;
                                    r6 = (object*)TC_NIL;
                                    r5[2] = r6;
                                    r5 = varref (0, 0);
                                    r6 = varref (1, 0);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r6;
                                    t[2] = r5;
                                    r5 = t;
                                    lenv = lenv[1];
                                    r5 = r5;
                                    r4[3] = r5;
                                    r5 = varref (13, 96);
                                    t = allocate (TC_SAVE, 7);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1832; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                    r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                    L1832:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                    r4 = result;
                                    lenv = lenv[1];
                                    r4 = r4;
                                    r3[3] = r4;
                                    r4 = varref (10, 10);
                                    r3[4] = r4;
                                    r4 = varref (12, 98);
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1833; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
                                    L1833:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[2] = r3;
                                    r3 = allocate (TC_TUPLE, 3);
                                    r4 = (object *) constructed_475[0];
                                    r3[2] = r4;
                                    r4 = allocate (TC_TUPLE, 2);
                                    r4[1] = lenv; lenv = r4;
                                    r5 = (object*)TC_NIL;
                                    r4[2] = r5;
                                    r4 = varref (0, 0);
                                    r5 = varref (1, 0);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r5;
                                    t[2] = r4;
                                    r4 = t;
                                    lenv = lenv[1];
                                    r4 = r4;
                                    r3[3] = r4;
                                    r4 = varref (12, 96);
                                    t = allocate (TC_SAVE, 6);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1834; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                    r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                    L1834:
                                    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                    r3 = result;
                                    r2[3] = r3;
                                    r2 = allocate (TC_TUPLE, 3);
                                    r3 = (object *) constructed_95[0];
                                    r2[2] = r3;
                                    r3 = (object *) constructed_483[0];
                                    r4 = varref (0, 1);
                                    t = alloc_no_clear (TC_PAIR,2);
                                    t[1] = r4;
                                    t[2] = r3;
                                    r3 = t;
                                    r2[3] = r3;
                                    r3 = varref (12, 96);
                                    t = allocate (TC_SAVE, 5);
                                    t[1] = k; t[2] = lenv; t[3] = &&L1835; t[4] = r0; t[5] = r1; k = t;
                                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                    L1835:
                                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                    r2 = result;
                                    lenv = lenv[1];
                                    r2 = r2;
                                    r1[2] = r2;
                                    r1=r1;
                                  } else {
                                    goto fatbar_77;
                                  }
                                  r1=r1;
                                  goto fatbar_77_over;
                                  fatbar_77:
                                  r1 = allocate (TC_TUPLE, 3);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = varref (12, 97);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1836; t[4] = r0; t[5] = r1; k = t;
                                  lenv = r2[2]; goto FUN_new_tvar_455;
                                  L1836:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[2] = r2;
                                  r2 = allocate (TC_TUPLE, 2);
                                  r3 = varref (2, 0);
                                  r2[2] = r3;
                                  r3 = varref (10, 8);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1837; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_n_tvars_3377_i4249_i4326;
                                  L1837:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  r1[3] = r2;
                                  r1 = allocate (UOTAG(2), 2);
                                  r2 = varref (0, 1);
                                  r3 = varref (0, 0);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r3;
                                  t[2] = r2;
                                  r2 = t;
                                  r1[1] = r2;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r2[1] = lenv; lenv = r2;
                                  r3 = allocate (TC_TUPLE, 4);
                                  r4 = varref (2, 0);
                                  r3[2] = r4;
                                  r4 = allocate (TC_TUPLE, 2);
                                  r4[1] = lenv; lenv = r4;
                                  r5 = allocate (TC_TUPLE, 3);
                                  r6 = (object *) constructed_479[0];
                                  r5[2] = r6;
                                  r6 = varref (2, 1);
                                  r5[3] = r6;
                                  r6 = varref (14, 96);
                                  t = allocate (TC_SAVE, 8);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1838; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                  r5[1] = r6[2]; lenv = r5; goto FUN_pred_453;
                                  L1838:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                  r5 = result;
                                  r4[2] = r5;
                                  r4 = allocate (TC_TUPLE, 3);
                                  r5 = (object *) constructed_477[0];
                                  r4[2] = r5;
                                  r5 = allocate (TC_TUPLE, 2);
                                  r5[1] = lenv; lenv = r5;
                                  r6 = (object*)TC_NIL;
                                  r5[2] = r6;
                                  r5 = varref (0, 0);
                                  r6 = varref (1, 0);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r6;
                                  t[2] = r5;
                                  r5 = t;
                                  lenv = lenv[1];
                                  r5 = r5;
                                  r4[3] = r5;
                                  r5 = varref (14, 96);
                                  t = allocate (TC_SAVE, 7);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1839; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                  r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
                                  L1839:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                  r4 = result;
                                  lenv = lenv[1];
                                  r4 = r4;
                                  r3[3] = r4;
                                  r4 = varref (1, 0);
                                  r3[4] = r4;
                                  r4 = varref (13, 98);
                                  t = allocate (TC_SAVE, 6);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1840; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                  r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
                                  L1840:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                  r3 = result;
                                  r2[2] = r3;
                                  r3 = allocate (TC_TUPLE, 3);
                                  r4 = (object *) constructed_475[0];
                                  r3[2] = r4;
                                  r4 = allocate (TC_TUPLE, 2);
                                  r4[1] = lenv; lenv = r4;
                                  r5 = (object*)TC_NIL;
                                  r4[2] = r5;
                                  r4 = varref (0, 0);
                                  r5 = varref (1, 0);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r5;
                                  t[2] = r4;
                                  r4 = t;
                                  lenv = lenv[1];
                                  r4 = r4;
                                  r3[3] = r4;
                                  r4 = varref (13, 96);
                                  t = allocate (TC_SAVE, 6);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1841; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                                  r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
                                  L1841:
                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                                  r3 = result;
                                  r2[3] = r3;
                                  r2 = allocate (TC_TUPLE, 3);
                                  r3 = (object *) constructed_95[0];
                                  r2[2] = r3;
                                  r3 = varref (1, 1);
                                  r4 = varref (0, 1);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r4;
                                  t[2] = r3;
                                  r3 = t;
                                  r2[3] = r3;
                                  r3 = varref (13, 96);
                                  t = allocate (TC_SAVE, 5);
                                  t[1] = k; t[2] = lenv; t[3] = &&L1842; t[4] = r0; t[5] = r1; k = t;
                                  r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                                  L1842:
                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                  r2 = result;
                                  lenv = lenv[1];
                                  r2 = r2;
                                  r1[2] = r2;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                  fatbar_77_over: ;
                                  r1=r1;
                                  fatbar_76_over: ;
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  goto fatbar_75;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_75;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_75;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_75;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_75;
                }
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_75;
            }
          }
          r1=r1;
          goto fatbar_75_over;
          fatbar_75:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_482;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1843; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1843:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_75_over: ;
          r1=r1;
        } else {
          goto fatbar_74;
        }
        r1=r1;
        goto fatbar_74_over;
        fatbar_74:
        r1 = (object *) constructed_272[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case (UOTAG(9)): {
              r1 = allocate (TC_TUPLE, 4);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,1);
              r1[3] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (5, 0);
              r3 = ((pxll_vector*)r3)->val[1];
              r2[2] = r3;
              r3 = varref (0, 0);
              r2[3] = r3;
              r3 = varref (6, 64);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1844; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
              L1844:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[4] = r2;
              r1 = varref (0, 2);
              switch (get_case (r1)) {
                case (UITAG(1)): {
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object*) &constructed_485;
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  r1[3] = r2;
                  r2 = varref (6, 12);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1845; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                  L1845:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                } break;
                default: {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (1, 2);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (1, 1);
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  r2 = ((pxll_vector*)r2)->val[2];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1846; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L1846:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_79;
            }
          }
          r1=r1;
          goto fatbar_79_over;
          fatbar_79:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_482;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1847; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1847:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_79_over: ;
          r1=r1;
        } else {
          goto fatbar_78;
        }
        r1=r1;
        goto fatbar_78_over;
        fatbar_78:
        r1 = (object *) constructed_422[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 3);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = varref (0, 0);
              r4 = varref (5, 11);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r2 = varref (0, 1);
              r3 = varref (5, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 6);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = allocate (TC_TUPLE, 3);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = (object *) constructed_480[0];
              r4[3] = r5;
              r5 = varref (7, 96);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1848; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1848:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_477[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = varref (0, 0);
              r6 = varref (6, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r5 = r5;
              r4[3] = r5;
              r5 = varref (7, 96);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1849; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1849:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = varref (5, 11);
              r3[4] = r4;
              r4 = varref (7, 98);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1850; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L1850:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_487[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = varref (0, 0);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = varref (7, 96);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1851; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L1851:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = varref (0, 2);
              r4 = varref (5, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r3 = varref (0, 3);
              r4 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_95[0];
              r2[2] = r3;
              r3 = varref (0, 4);
              r4 = varref (7, 170);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = varref (7, 96);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1852; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L1852:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_81;
            }
          }
          r1=r1;
          goto fatbar_81_over;
          fatbar_81:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_482;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1853; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1853:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_81_over: ;
          r1=r1;
        } else {
          goto fatbar_80;
        }
        r1=r1;
        goto fatbar_80_over;
        fatbar_80:
        r1 = (object *) constructed_424[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 3);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = varref (0, 0);
              r4 = varref (5, 11);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r2 = varref (0, 1);
              r3 = varref (5, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 5);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = allocate (TC_TUPLE, 3);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = (object *) constructed_480[0];
              r4[3] = r5;
              r5 = varref (7, 96);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1854; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1854:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_477[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = varref (0, 0);
              r6 = varref (6, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r5 = r5;
              r4[3] = r5;
              r5 = varref (7, 96);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1855; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1855:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = varref (5, 11);
              r3[4] = r4;
              r4 = varref (7, 98);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1856; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L1856:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_487[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = varref (0, 0);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = varref (7, 96);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1857; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L1857:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = varref (0, 2);
              r4 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_95[0];
              r2[2] = r3;
              r3 = varref (0, 3);
              r4 = varref (5, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = varref (7, 96);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1858; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L1858:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_83;
            }
          }
          r1=r1;
          goto fatbar_83_over;
          fatbar_83:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_482;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1859; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1859:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_83_over: ;
          r1=r1;
        } else {
          goto fatbar_82;
        }
        r1=r1;
        goto fatbar_82_over;
        fatbar_82:
        r1 = (object *) constructed_430[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = varref (0, 1);
          switch (get_case (r1)) {
            case (UOTAG(1)): {
              r1 = allocate (TC_TUPLE, 3);
              r1[1] = lenv; lenv = r1;
              r2 = varref (1, 1);
              r2 = UOBJ_GET(r2,0);
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (0, 0);
              r2[2] = r3;
              r3 = (object *) constructed_480[0];
              r2[3] = r3;
              r3 = varref (6, 96);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1860; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L1860:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r1 = allocate (UOTAG(2), 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = (object*)TC_NIL;
              r2[2] = r3;
              r3 = varref (0, 0);
              r4 = varref (5, 12);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = varref (0, 1);
              r4 = varref (5, 11);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = varref (0, 2);
              r3 = varref (5, 10);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[1] = r2;
              r2 = allocate (TC_TUPLE, 8);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 4);
              r4 = varref (1, 1);
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 3);
              r5 = (object *) constructed_477[0];
              r4[2] = r5;
              r5 = allocate (TC_TUPLE, 2);
              r5[1] = lenv; lenv = r5;
              r6 = (object*)TC_NIL;
              r5[2] = r6;
              r5 = varref (0, 0);
              r6 = varref (6, 12);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r6;
              t[2] = r5;
              r5 = t;
              lenv = lenv[1];
              r5 = r5;
              r4[3] = r5;
              r5 = varref (7, 96);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L1861; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_pred_453;
              L1861:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = varref (5, 11);
              r3[4] = r4;
              r4 = varref (7, 98);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1862; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L1862:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_487[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = varref (0, 0);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = varref (7, 96);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1863; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L1863:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 4);
              r4 = varref (1, 1);
              r3[2] = r4;
              r4 = varref (5, 10);
              r3[3] = r4;
              r4 = varref (5, 11);
              r3[4] = r4;
              r4 = varref (7, 98);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1864; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_rlabel_460;
              L1864:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_487[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = (object*)TC_NIL;
              r4[2] = r5;
              r4 = varref (0, 0);
              r5 = varref (1, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              lenv = lenv[1];
              r4 = r4;
              r3[3] = r4;
              r4 = varref (7, 96);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L1865; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
              L1865:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = varref (0, 4);
              r4 = varref (5, 12);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = varref (0, 5);
              r4 = varref (0, 3);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = (object *) constructed_95[0];
              r2[2] = r3;
              r3 = varref (0, 6);
              r4 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[3] = r3;
              r3 = varref (7, 96);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L1866; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
              L1866:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } break;
            default: {
              goto fatbar_85;
            }
          }
          r1=r1;
          goto fatbar_85_over;
          fatbar_85:
          r1 = allocate (TC_TUPLE, 3);
          r2 = (object*) &constructed_482;
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 12);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1867; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
          L1867:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r1=r1;
          fatbar_85_over: ;
          r1=r1;
        } else {
          goto fatbar_84;
        }
        r1=r1;
        goto fatbar_84_over;
        fatbar_84:
        r1 = (object *) constructed_198[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_488[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = varref (0, 0);
          r4 = varref (6, 167);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = varref (0, 1);
          r4 = varref (6, 170);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (6, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1868; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1868:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_86;
        }
        r1=r1;
        goto fatbar_86_over;
        fatbar_86:
        r1 = (object *) constructed_427[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = (object *) constructed_495[0];
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_494[0];
          r3[2] = r4;
          r4 = (object *) constructed_492[0];
          r3[3] = r4;
          r4 = varref (6, 96);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1869; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1869:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_491[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = varref (0, 0);
          r5 = varref (1, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = varref (6, 96);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1870; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1870:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_487[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = varref (0, 0);
          r5 = varref (1, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = varref (6, 96);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1871; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1871:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = (object *) constructed_489[0];
          r4 = varref (0, 2);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (6, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1872; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1872:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_87;
        }
        r1=r1;
        goto fatbar_87_over;
        fatbar_87:
        r1 = (object *) constructed_230[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 6);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_413[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = varref (0, 0);
          r5 = varref (5, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = varref (6, 96);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1873; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1873:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (6, 167);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = varref (0, 4);
          r4 = varref (6, 170);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (6, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1874; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1874:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_88;
        }
        r1=r1;
        goto fatbar_88_over;
        fatbar_88:
        r1 = (object *) constructed_239[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_413[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = varref (0, 0);
          r5 = varref (5, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = varref (6, 96);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1875; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1875:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (6, 167);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = varref (0, 3);
          r4 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (6, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1876; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1876:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_89;
        }
        r1=r1;
        goto fatbar_89_over;
        fatbar_89:
        r1 = (object *) constructed_252[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 3);
          r4 = (object *) constructed_413[0];
          r3[2] = r4;
          r4 = allocate (TC_TUPLE, 2);
          r4[1] = lenv; lenv = r4;
          r5 = (object*)TC_NIL;
          r4[2] = r5;
          r4 = varref (0, 0);
          r5 = varref (5, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r5;
          t[2] = r4;
          r4 = t;
          lenv = lenv[1];
          r4 = r4;
          r3[3] = r4;
          r4 = varref (6, 96);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L1877; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_pred_453;
          L1877:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (6, 167);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (6, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1878; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1878:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_90;
        }
        r1=r1;
        goto fatbar_90_over;
        fatbar_90:
        r1 = (object *) constructed_442[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = (object *) constructed_496[0];
          r4 = varref (3, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (5, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1879; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1879:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_91;
        }
        r1=r1;
        goto fatbar_91_over;
        fatbar_91:
        r1 = (object *) constructed_440[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = (object *) constructed_497[0];
          r4 = varref (3, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (5, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1880; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1880:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_92;
        }
        r1=r1;
        goto fatbar_92_over;
        fatbar_92:
        r1 = (object *) constructed_437[0];
        r2 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
          r1 = allocate (UOTAG(2), 2);
          r2 = allocate (TC_TUPLE, 2);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r2 = varref (0, 0);
          r3 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[1] = r2;
          r2 = allocate (TC_TUPLE, 4);
          r2[1] = lenv; lenv = r2;
          r3 = (object*)TC_NIL;
          r2[2] = r3;
          r3 = varref (0, 0);
          r4 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r2 = allocate (TC_TUPLE, 3);
          r3 = (object *) constructed_95[0];
          r2[2] = r3;
          r3 = varref (0, 2);
          r4 = varref (4, 10);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[3] = r3;
          r3 = varref (6, 96);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1881; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
          L1881:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r1=r1;
        } else {
          goto fatbar_93;
        }
        r1=r1;
        goto fatbar_93_over;
        fatbar_93:
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object*) &constructed_498;
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (5, 12);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1882; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
        L1882:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r1=r1;
        fatbar_93_over: ;
        r1=r1;
        fatbar_92_over: ;
        r1=r1;
        fatbar_91_over: ;
        r1=r1;
        fatbar_90_over: ;
        r1=r1;
        fatbar_89_over: ;
        r1=r1;
        fatbar_88_over: ;
        r1=r1;
        fatbar_87_over: ;
        r1=r1;
        fatbar_86_over: ;
        r1=r1;
        fatbar_84_over: ;
        r1=r1;
        fatbar_82_over: ;
        r1=r1;
        fatbar_80_over: ;
        r1=r1;
        fatbar_78_over: ;
        r1=r1;
        fatbar_74_over: ;
        r1=r1;
        fatbar_72_over: ;
        r0[5] = r1;
        r0 = varref (0, 3);
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 3);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 3);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (0, 1);
            r1[3] = r2;
            r2 = varref (4, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1883; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3354_i4249_i4326;
            L1883:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = varref (0, 2);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 2);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 2);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_95[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 4);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 1);
                      r1[2] = r2;
                      r2 = varref (9, 20);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1884; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                      L1884:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (4, 2);
                      r1[2] = r2;
                      r2 = varref (9, 20);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1885; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                      L1885:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = varref (0, 1);
                      r2 = varref (0, 0);
                      r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                      r0[4] = r1;
                      r0 = (object *) 6;
                      r1 = varref (0, 2);
                      r0 = PXLL_TEST(r1==r0);
                      lenv = lenv[1];
                      r0 = r0;
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = (object*) &constructed_472;
                        r0[2] = r1;
                        r1 = varref (3, 2);
                        r0[3] = r1;
                        r1 = varref (8, 12);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L1886; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                        L1886:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      } else {
                        r0 = (object *) 14;
                      }
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 1);
                      r1[2] = r2;
                      r2 = varref (9, 20);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1887; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                      L1887:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      // def $loop_3661_i2325_i4249_i4326
                      goto L1888;
                      FUN__24loop_3661_i2325_i4249_i4326:
                        check_heap (0);
                        r0 = varref (2, 0);
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = (object *) 14;
                          PXLL_RETURN(0);
                        } else {
                          r0 = allocate (TC_TUPLE, 5);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (7, 2);
                          r1[2] = r2;
                          r2 = varref (1, 0);
                          r1[3] = r2;
                          r2 = varref (12, 25);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1889; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                          L1889:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (0, 0);
                          r1[2] = r2;
                          r2 = varref (9, 1);
                          r1[3] = r2;
                          r2 = varref (10, 4);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1890; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
                          L1890:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r1 = varref (0, 1);
                          r2 = varref (0, 0);
                          ((pxll_vector*)r2)->val[5] = r1;
                          r1 = varref (0, 1);
                          r0[4] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (4, 1);
                          r1[2] = r2;
                          r2 = varref (1, 0);
                          r1[3] = r2;
                          r2 = varref (12, 25);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1891; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                          L1891:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[5] = r1;
                          r0 = allocate (TC_TUPLE, 4);
                          r1 = varref (0, 0);
                          r0[2] = r1;
                          r1 = varref (0, 2);
                          r0[3] = r1;
                          r1 = varref (0, 3);
                          r0[4] = r1;
                          r1 = varref (12, 130);
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1892; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                          L1892:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = (object *) 3;
                          r1 = varref (0, 0);
                          r0 = box(unbox(r1)+unbox(r0));
                          lenv[2] = r0;
                          goto FUN__24loop_3661_i2325_i4249_i4326;
                        }
                        PXLL_RETURN(0);
                      L1888:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN__24loop_3661_i2325_i4249_i4326; r1[2] = lenv;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object *) 1;
                      r0[2] = r1;
                      r1 = varref (0, 0);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1893; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3661_i2325_i4249_i4326;
                      L1893:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      lenv = lenv[1];
                      r0 = varref (0, 0);
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_71;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_71;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_71;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_71_over;
            fatbar_71:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_473;
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (6, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            fatbar_71_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = (object *) constructed_50[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 0);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 7);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r1 = varref (8, 97);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1894; t[4] = r0; k = t;
                  lenv = r1[2]; goto FUN_new_tvar_455;
                  L1894:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[4] = r1;
                  r1 = varref (0, 0);
                  r1 = ((pxll_vector*)r1)->val[4];
                  r0[5] = r1;
                  r1 = varref (0, 3);
                  switch (get_case (r1)) {
                    case (UOTAG(12)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 3);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = (object *) constructed_442[0];
                      r2 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                        r1 = (object *) 6;
                        r1=r1;
                      } else {
                        lenv = ((object *)lenv)[1];
                        goto fatbar_95;
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      goto fatbar_95;
                    }
                  }
                  r1=r1;
                  goto fatbar_95_over;
                  fatbar_95:
                  r1 = (object *) 262;
                  r1=r1;
                  fatbar_95_over: ;
                  r0[6] = r1;
                  r1 = varref (0, 4);
                  if PXLL_IS_TRUE(r1) {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = (object *) constructed_494[0];
                    r2[2] = r3;
                    r3 = (object *) constructed_492[0];
                    r2[3] = r3;
                    r3 = varref (9, 96);
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1895; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                    L1895:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = (object *) constructed_491[0];
                    r1[2] = r2;
                    r2 = allocate (TC_TUPLE, 2);
                    r2[1] = lenv; lenv = r2;
                    r3 = (object*)TC_NIL;
                    r2[2] = r3;
                    r2 = varref (0, 0);
                    r3 = varref (1, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r3;
                    t[2] = r2;
                    r2 = t;
                    lenv = lenv[1];
                    r2 = r2;
                    r1[3] = r2;
                    r2 = varref (9, 96);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1896; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                    L1896:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    lenv = lenv[1];
                    r1 = r1;
                    r1=r1;
                  } else {
                    r1 = varref (8, 97);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L1897; t[4] = r0; k = t;
                    lenv = r1[2]; goto FUN_new_tvar_455;
                    L1897:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r1=r1;
                  }
                  r0[7] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (4, 1);
                  r1[2] = r2;
                  r2 = varref (9, 20);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1898; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                  L1898:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  // def $loop_3597_i2464_i4249_i4326
                  goto L1899;
                  FUN__24loop_3597_i2464_i4249_i4326:
                    check_heap (0);
                    r0 = varref (2, 0);
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                      r0 = (object *) 14;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 5);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (4, 1);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r1[3] = r2;
                      r2 = varref (12, 25);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1900; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                      L1900:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (7, 1);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r1[3] = r2;
                      r2 = varref (12, 25);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1901; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                      L1901:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (7, 2);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r1[3] = r2;
                      r2 = varref (12, 25);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1902; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                      L1902:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (0, 2);
                      r1[2] = r2;
                      r2 = varref (10, 8);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1903; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_n_tvars_3377_i4249_i4326;
                      L1903:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[5] = r1;
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (0, 1);
                      r1[2] = r2;
                      r2 = (object *) constructed_480[0];
                      r1[3] = r2;
                      r2 = varref (12, 96);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1904; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                      L1904:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = (object *) 3;
                      r3 = varref (1, 2);
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = varref (1, 3);
                        r2[2] = r3;
                        r3 = varref (13, 17);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L1905; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
                        L1905:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r2=r2;
                      } else {
                        r2 = allocate (TC_TUPLE, 3);
                        r3 = (object *) constructed_479[0];
                        r2[2] = r3;
                        r3 = varref (1, 3);
                        r2[3] = r3;
                        r3 = varref (13, 96);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L1906; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_pred_453;
                        L1906:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r2=r2;
                      }
                      r1[2] = r2;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object *) constructed_477[0];
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      r3 = (object*)TC_NIL;
                      r2[2] = r3;
                      r2 = varref (0, 0);
                      r3 = varref (1, 0);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r2 = r2;
                      r1[3] = r2;
                      r2 = varref (13, 96);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1907; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                      L1907:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r0[3] = r1;
                      r1 = varref (4, 5);
                      r0[4] = r1;
                      r1 = varref (12, 98);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1908; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_rlabel_460;
                      L1908:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      varset (4, 5, r0);
                      r0 = allocate (TC_TUPLE, 4);
                      r1 = varref (0, 0);
                      r0[2] = r1;
                      r1 = varref (4, 2);
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = varref (1, 0);
                      r2[2] = r3;
                      r3 = varref (10, 1);
                      r2[3] = r3;
                      r3 = varref (11, 4);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L1909; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3358_i4249_i4326;
                      L1909:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r1 = varref (0, 0);
                      r2 = varref (1, 0);
                      ((pxll_vector*)r2)->val[5] = r1;
                      r1 = varref (0, 0);
                      lenv = lenv[1];
                      r1 = r1;
                      r0[4] = r1;
                      r1 = varref (12, 130);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1910; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                      L1910:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = (object *) 3;
                      r1 = varref (0, 0);
                      r0 = box(unbox(r1)+unbox(r0));
                      lenv[2] = r0;
                      goto FUN__24loop_3597_i2464_i4249_i4326;
                    }
                    PXLL_RETURN(0);
                  L1899:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN__24loop_3597_i2464_i4249_i4326; r1[2] = lenv;
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r1 = (object *) 1;
                  r0[2] = r1;
                  r1 = varref (0, 0);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1911; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3597_i2464_i4249_i4326;
                  L1911:
                  ; lenv = k[2]; k = k[1];
                  r0 = result;
                  lenv = lenv[1];
                  r0 = r0;
                  lenv = lenv[1];
                  r0 = varref (0, 4);
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 4);
                    r1 = varref (0, 0);
                    r0[2] = r1;
                    r1 = varref (0, 2);
                    r0[3] = r1;
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = allocate (TC_TUPLE, 3);
                    r3 = varref (1, 0);
                    r2[2] = r3;
                    r3 = varref (6, 1);
                    r2[3] = r3;
                    r3 = varref (7, 4);
                    t = allocate (TC_SAVE, 5);
                    t[1] = k; t[2] = lenv; t[3] = &&L1912; t[4] = r0; t[5] = r1; k = t;
                    r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3358_i4249_i4326;
                    L1912:
                    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                    r2 = result;
                    r1[2] = r2;
                    r1 = varref (0, 0);
                    r2 = varref (1, 0);
                    ((pxll_vector*)r2)->val[5] = r1;
                    r1 = varref (0, 0);
                    lenv = lenv[1];
                    r1 = r1;
                    r0[4] = r1;
                    r1 = varref (8, 130);
                    t = allocate (TC_SAVE, 3);
                    t[1] = k; t[2] = lenv; t[3] = &&L1913; ; k = t;
                    r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                    L1913:
                    ; lenv = k[2]; k = k[1];
                    r0 = result;
                  } else {
                    r0 = (object *) 14;
                  }
                  r0 = allocate (TC_TUPLE, 4);
                  r1 = varref (1, 0);
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = (object *) constructed_475[0];
                  r1[2] = r2;
                  r2 = allocate (TC_TUPLE, 2);
                  r2[1] = lenv; lenv = r2;
                  r3 = (object*)TC_NIL;
                  r2[2] = r3;
                  r2 = varref (0, 0);
                  r3 = varref (1, 5);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  lenv = lenv[1];
                  r2 = r2;
                  r1[3] = r2;
                  r2 = varref (8, 96);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L1914; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_pred_453;
                  L1914:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = varref (2, 0);
                  r2[2] = r3;
                  r3 = varref (6, 1);
                  r2[3] = r3;
                  r3 = varref (7, 4);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L1915; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3358_i4249_i4326;
                  L1915:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = varref (0, 0);
                  r2 = varref (2, 0);
                  ((pxll_vector*)r2)->val[5] = r1;
                  r1 = varref (0, 0);
                  lenv = lenv[1];
                  r1 = r1;
                  r0[4] = r1;
                  r1 = varref (8, 130);
                  t = allocate (TC_SAVE, 3);
                  t[1] = k; t[2] = lenv; t[3] = &&L1916; ; k = t;
                  r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                  L1916:
                  ; lenv = k[2]; k = k[1];
                  r0 = varref (0, 2);
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_94;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_94;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_94_over;
          fatbar_94:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_499;
          r0[2] = r1;
          r1 = varref (3, 0);
          r0[3] = r1;
          r1 = varref (6, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
          fatbar_94_over: ;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 10);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = varref (5, 0);
          r2 = ((pxll_vector*)r2)->val[1];
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = (object*) &constructed_500;
          r1[4] = r2;
          r2 = varref (6, 65);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1917; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
          L1917:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (3, 0);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1918; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L1918:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = (object *) 3;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1919; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L1919:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (0, 1);
          r2[2] = r3;
          r3 = varref (6, 18);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1920; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_319;
          L1920:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = varref (6, 18);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1921; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
          L1921:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 2);
          r1[2] = r2;
          r2 = varref (3, 1);
          r1[3] = r2;
          r2 = varref (4, 4);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1922; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_splat_3358_i4249_i4326;
          L1922:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r1 = varref (0, 5);
          r2 = varref (0, 2);
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = varref (0, 5);
          r0[8] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1923; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L1923:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[9] = r1;
          r1 = varref (6, 97);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1924; t[4] = r0; k = t;
          lenv = r1[2]; goto FUN_new_tvar_455;
          L1924:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[10] = r1;
          r0 = varref (0, 7);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 7);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 7);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = (object *) 262;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_96;
                }
              }
              r0=r0;
              goto fatbar_96_over;
              fatbar_96:
              r0 = (object *) 6;
              r0=r0;
              fatbar_96_over: ;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 4);
                r1 = varref (4, 0);
                r0[2] = r1;
                r1 = varref (1, 6);
                r0[3] = r1;
                r1 = varref (0, 1);
                r0[4] = r1;
                r1 = varref (7, 130);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L1925; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                L1925:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                r0=r0;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (1, 0);
                r1[2] = r2;
                r2 = varref (1, 1);
                r1[3] = r2;
                r2 = varref (6, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L1926; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3354_i4249_i4326;
                L1926:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 4);
                r1 = varref (5, 0);
                r0[2] = r1;
                r1 = varref (2, 6);
                r0[3] = r1;
                r1 = varref (0, 0);
                r0[4] = r1;
                r1 = varref (8, 130);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L1927; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                L1927:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                lenv = lenv[1];
                r0 = r0;
                r0=r0;
              }
              lenv = lenv[1];
              r0 = r0;
            } break;
          }
          r0 = allocate (TC_TUPLE, 3);
          // def lambda_22528_i2477_i4249_i4326
          goto L1928;
          FUN_lambda_22528_i2477_i4249_i4326:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (1, 8);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (5, 1);
            r2[3] = r3;
            r3 = varref (6, 4);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L1929; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3358_i4249_i4326;
            L1929:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = varref (0, 0);
            r2 = varref (1, 0);
            ((pxll_vector*)r2)->val[5] = r1;
            r1 = varref (0, 0);
            lenv = lenv[1];
            r1 = r1;
            r0[4] = r1;
            r1 = varref (7, 130);
            r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
          L1928:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_lambda_22528_i2477_i4249_i4326; r1[2] = lenv;
          r0[2] = r1;
          r1 = varref (0, 4);
          r0[3] = r1;
          r1 = varref (6, 33);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1930; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
          L1930:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (0, 3);
          r0[2] = r1;
          r1 = varref (0, 8);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r1[1] = lenv; lenv = r1;
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (1, 3);
          r2[2] = r3;
          r3 = varref (4, 1);
          r2[3] = r3;
          r3 = varref (5, 4);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L1931; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3358_i4249_i4326;
          L1931:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r1 = varref (0, 0);
          r2 = varref (1, 3);
          ((pxll_vector*)r2)->val[5] = r1;
          r1 = varref (0, 0);
          lenv = lenv[1];
          r1 = r1;
          r0[4] = r1;
          r1 = varref (6, 130);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L1932; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
          L1932:
          ; lenv = k[2]; k = k[1];
          r0 = varref (0, 8);
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_67;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_67_over;
    fatbar_67:
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (1, 0);
    r0[2] = r1;
    r1 = varref (4, 119);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1933; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_pp_node_510;
    L1933:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    r1 = (object*) &constructed_501;
    r0[2] = r1;
    r1 = varref (1, 0);
    r0[3] = r1;
    r1 = varref (4, 12);
    r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
    fatbar_67_over: ;
    PXLL_RETURN(0);
  L1715:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_type_of_splat_3358_i4249_i4326; r2[2] = lenv;
  r1[6] = r2;
  // def type-of-literal_3360_i4249_i4326
  goto L1934;
  FUN_type_of_literal_3360_i4249_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = varref (3, 169);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = varref (3, 167);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(2)): {
        r0 = varref (3, 168);
        PXLL_RETURN(0);
      } break;
      case (UITAG(3)): {
        r0 = varref (3, 170);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = varref (3, 172);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(5)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (3, 0);
        r2 = ((pxll_vector*)r2)->val[1];
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = (object*) &constructed_455;
        r1[4] = r2;
        r2 = varref (4, 65);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1935; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
        L1935:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (0, 3);
        r2 = ((pxll_vector*)r2)->val[2];
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1936; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto *r2[1];
        L1936:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[6] = r1;
        r0 = varref (0, 4);
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 4);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 4);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (0, 1);
            r1[3] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1937; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_instantiate_type_scheme_3354_i4249_i4326;
            L1937:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r0 = varref (0, 2);
            switch (get_case (r0)) {
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 2);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 2);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_95[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (TC_PAIR): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,1);
                      r0[3] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 1);
                      r1[2] = r2;
                      r2 = varref (8, 20);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L1938; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                      L1938:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      // def $loop_3452_i4249_i4326
                      goto L1939;
                      FUN__24loop_3452_i4249_i4326:
                        check_heap (0);
                        r0 = varref (2, 0);
                        r1 = varref (0, 0);
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = (object *) 14;
                          PXLL_RETURN(0);
                        } else {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 4);
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = varref (7, 2);
                          r2[2] = r3;
                          r3 = varref (1, 0);
                          r2[3] = r3;
                          r3 = varref (11, 25);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L1940; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                          L1940:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (8, 1);
                          r1[3] = r2;
                          r2 = varref (8, 2);
                          r1[4] = r2;
                          r2 = varref (9, 5);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1941; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_literal_3360_i4249_i4326;
                          L1941:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r0 = allocate (TC_TUPLE, 4);
                          r1 = varref (8, 1);
                          r0[2] = r1;
                          r1 = varref (0, 0);
                          r0[3] = r1;
                          r1 = allocate (TC_TUPLE, 3);
                          r2 = varref (4, 1);
                          r1[2] = r2;
                          r2 = varref (1, 0);
                          r1[3] = r2;
                          r2 = varref (11, 25);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1942; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                          L1942:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[4] = r1;
                          r1 = varref (11, 130);
                          t = allocate (TC_SAVE, 3);
                          t[1] = k; t[2] = lenv; t[3] = &&L1943; ; k = t;
                          r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
                          L1943:
                          ; lenv = k[2]; k = k[1];
                          r0 = result;
                          lenv = lenv[1];
                          r0 = (object *) 3;
                          r1 = varref (0, 0);
                          r0 = box(unbox(r1)+unbox(r0));
                          lenv[2] = r0;
                          goto FUN__24loop_3452_i4249_i4326;
                        }
                        PXLL_RETURN(0);
                      L1939:
                      r1 = allocate (TC_CLOSURE, 2);
                      r1[1] = &&FUN__24loop_3452_i4249_i4326; r1[2] = lenv;
                      r0[2] = r1;
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object *) 1;
                      r0[2] = r1;
                      r1 = varref (0, 0);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L1944; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_3452_i4249_i4326;
                      L1944:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = r0;
                      lenv = lenv[1];
                      r0 = varref (0, 0);
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_66;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_66;
                }
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_66;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_66_over;
            fatbar_66:
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_454;
            r0[2] = r1;
            r1 = varref (0, 2);
            r0[3] = r1;
            r1 = varref (5, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            fatbar_66_over: ;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (4, 97);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1945; t[4] = r0; k = t;
        lenv = r1[2]; goto FUN_new_tvar_455;
        L1945:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_21820_i4249_i4326
        goto L1946;
        FUN_lambda_21820_i4249_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 4);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (3, 1);
          r1[3] = r2;
          r2 = varref (3, 2);
          r1[4] = r2;
          r2 = varref (4, 5);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L1947; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_type_of_literal_3360_i4249_i4326;
          L1947:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 4);
          r1 = varref (3, 1);
          r0[2] = r1;
          r1 = varref (2, 1);
          r0[3] = r1;
          r1 = varref (0, 0);
          r0[4] = r1;
          r1 = varref (6, 130);
          r0[1] = r1[2]; lenv = r0; goto FUN_unify_532;
        L1946:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_21820_i4249_i4326; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (4, 33);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1948; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        L1948:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object *) constructed_413[0];
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = (object*)TC_NIL;
        r1[2] = r2;
        r1 = varref (0, 0);
        r2 = varref (1, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[3] = r1;
        r1 = varref (4, 96);
        r0[1] = r1[2]; lenv = r0; goto FUN_pred_453;
      } break;
    }
    PXLL_RETURN(0);
  L1934:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_type_of_literal_3360_i4249_i4326; r2[2] = lenv;
  r1[7] = r2;
  // def unraw_3361_i4249_i4326
  goto L1949;
  FUN_unraw_3361_i4249_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = (object *) constructed_453[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (TC_PAIR): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case (r0)) {
                case (TC_NIL): {
                  r0 = varref (0, 0);
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object **)lenv)[1][1];
                  goto fatbar_65;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              lenv = ((object *)lenv)[1];
              goto fatbar_65;
            }
          }
          PXLL_RETURN(0);
        } else {
          lenv = ((object *)lenv)[1];
          goto fatbar_65;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_65;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_65_over;
    fatbar_65:
    r0 = varref (0, 0);
    PXLL_RETURN(0);
    fatbar_65_over: ;
    PXLL_RETURN(0);
  L1949:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_unraw_3361_i4249_i4326; r2[2] = lenv;
  r1[8] = r2;
  // def apply-tenv_3367_i4249_i4326
  goto L1950;
  FUN_apply_tenv_3367_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 1);
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (4, 64);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1951; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
    L1951:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UITAG(1)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_451;
        r0[2] = r1;
        r1 = varref (1, 0);
        r0[3] = r1;
        r1 = varref (4, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case_noint (r0)) {
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (0, 1);
            r0[3] = r1;
            r1 = varref (4, 0);
            r0[1] = r1[2]; lenv = r0; goto FUN_instantiate_type_scheme_3354_i4249_i4326;
          } break;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1950:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_apply_tenv_3367_i4249_i4326; r2[2] = lenv;
  r1[9] = r2;
  // def n-tvars_3377_i4249_i4326
  goto L1952;
  FUN_n_tvars_3377_i4249_i4326:
    check_heap (0);
    r0 = (object *) 1;
    r1 = varref (0, 0);
    if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
      r0 = (object *) constructed_450[0];
      PXLL_RETURN(0);
    } else {
      goto fatbar_64;
    }
    PXLL_RETURN(0);
    goto fatbar_64_over;
    fatbar_64:
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = varref (4, 97);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1953; t[4] = r0; k = t;
    lenv = r1[2]; goto FUN_new_tvar_455;
    L1953:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = (object *) 3;
    r3 = varref (1, 0);
    r2 = box(unbox(r3)-unbox(r2));
    r1[2] = r2;
    r2 = varref (2, 8);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1954; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_n_tvars_3377_i4249_i4326;
    L1954:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_64_over: ;
    PXLL_RETURN(0);
  L1952:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_n_tvars_3377_i4249_i4326; r2[2] = lenv;
  r1[10] = r2;
  // def apply-subst-to-program_3381_i4249_i4326
  goto L1955;
  FUN_apply_subst_to_program_3381_i4249_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[5];
    r0[2] = r1;
    r1 = varref (3, 131);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L1956; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_apply_subst_533;
    L1956:
    ; lenv = k[2]; k = k[1];
    r0 = result;
    r1 = varref (0, 0);
    ((pxll_vector*)r1)->val[5] = r0;
    r0 = allocate (TC_TUPLE, 3);
    r1 = varref (1, 9);
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[3];
    r0[3] = r1;
    r1 = varref (3, 33);
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
  L1955:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_apply_subst_to_program_3381_i4249_i4326; r2[2] = lenv;
  r1[11] = r2;
  r2 = varref (2, 97);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1957; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_455;
  L1957:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[12] = r2;
  r2 = varref (2, 97);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1958; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_455;
  L1958:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[13] = r2;
  r2 = varref (2, 97);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1959; t[4] = r0; t[5] = r1; k = t;
  lenv = r2[2]; goto FUN_new_tvar_455;
  L1959:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[14] = r2;
  r1 = allocate (TC_TUPLE, 4);
  r1[1] = lenv; lenv = r1;
  r2 = (object*)UITAG(0);
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = varref (2, 18);
  r2[2] = r3;
  r3 = varref (0, 0);
  r2[3] = r3;
  r3 = varref (1, 4);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L1960; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_type_of_splat_3358_i4249_i4326;
  L1960:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = varref (0, 1);
  r3 = varref (2, 18);
  ((pxll_vector*)r3)->val[5] = r2;
  r2 = varref (0, 1);
  r1[4] = r2;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (2, 18);
  r2 = ((pxll_vector*)r2)->val[5];
  r1[2] = r2;
  r2 = varref (3, 131);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1961; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_apply_subst_533;
  L1961:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r2 = varref (2, 18);
  ((pxll_vector*)r2)->val[5] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (1, 9);
  r1[2] = r2;
  r2 = varref (2, 18);
  r2 = ((pxll_vector*)r2)->val[3];
  r1[3] = r2;
  r2 = varref (3, 33);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L1962; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_for_each_338;
  L1962:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = varref (0, 2);
  lenv = lenv[1];
  r1 = r1;
  lenv = lenv[1];
  r1 = r1;
  r0[30] = r1;
  r1 = (object *) constructed_449[0];
  r0[31] = r1;
  r1 = allocate (TC_TUPLE, 21);
  r1[1] = lenv; lenv = r1;
  // def cont_2673_i4250_i4326
  goto L1963;
  FUN_cont_2673_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 3);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (3, 0);
    r2 = ((pxll_vector*)r2)->val[9];
    r2 = ((pxll_vector*)r2)->val[0];
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1964; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1964:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (1, 1);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L1965; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto *r2[1];
    L1965:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r0 = varref (1, 0);
    r1 = varref (0, 1);
    r2 = varref (0, 0);
    t = alloc_no_clear (UOTAG(0),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L1963:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_cont_2673_i4250_i4326; r2[2] = lenv;
  r1[2] = r2;
  // def compile_2675_i4250_i4326
  goto L1966;
  FUN_compile_2675_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 3);
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 3);
      r1[2] = r2;
      r2 = varref (3, 128);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L1967; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
      L1967:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (1, 16);
      r0[3] = r1;
      r1 = varref (1, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L1968; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_cont_2673_i4250_i4326;
      L1968:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      varset (0, 3, r0);
    } else {
      r0 = (object *) 14;
    }
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 1);
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(2)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[1];
        r0[3] = r1;
        r1 = varref (2, 3);
        r0[4] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (4, 4);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1969; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_symbol_index_2678_i4250_i4326;
            L1969:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) constructed_59[0];
            r1 = varref (1, 2);
            r2 = varref (0, 1);
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (1, 1);
            r1[3] = r2;
            r2 = varref (4, 3);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1970; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2677_i4250_i4326;
            L1970:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = (object *) constructed_84[0];
            r1 = varref (1, 2);
            r2 = varref (0, 1);
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (4, 5);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1971; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2679_i4250_i4326;
            L1971:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 0);
            r1[2] = r2;
            r2 = varref (2, 1);
            r1[3] = r2;
            r2 = varref (5, 3);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1972; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2677_i4250_i4326;
            L1972:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) constructed_413[0];
            r1 = varref (2, 2);
            r2 = varref (0, 0);
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 4);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r0 = (object *) constructed_47[0];
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
              r0 = varref (1, 2);
              r1 = varref (1, 0);
              t = alloc_no_clear (UOTAG(1),2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              PXLL_RETURN(0);
            } else {
              goto fatbar_43;
            }
            PXLL_RETURN(0);
            goto fatbar_43_over;
            fatbar_43:
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 2);
            r0[2] = r1;
            r1 = varref (4, 5);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L1973; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2679_i4250_i4326;
            L1973:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 0);
            r1[2] = r2;
            r2 = varref (2, 1);
            r1[3] = r2;
            r2 = varref (5, 3);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L1974; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_get_literal_index_2677_i4250_i4326;
            L1974:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) constructed_415[0];
            r1 = varref (2, 2);
            r2 = varref (0, 0);
            t = alloc_no_clear (UOTAG(2),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
            fatbar_43_over: ;
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_42;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_42_over;
        fatbar_42:
        r0 = varref (0, 2);
        r1 = varref (0, 0);
        t = alloc_no_clear (UOTAG(1),2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        PXLL_RETURN(0);
        fatbar_42_over: ;
        PXLL_RETURN(0);
      } break;
      case (UITAG(5)): {
        r0 = allocate (TC_TUPLE, 5);
        r1 = varref (1, 0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r1 = varref (1, 2);
        r0[4] = r1;
        r1 = varref (1, 3);
        r0[5] = r1;
        r1 = varref (2, 6);
        r0[1] = r1[2]; lenv = r0; goto FUN_c_sequence_2681_i4250_i4326;
      } break;
      case (UITAG(6)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 3);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (5, 129);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1975; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_525;
        L1975:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (5, 128);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1976; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
        L1976:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = varref (0, 3);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 3);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 3);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (TC_PAIR): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_PAIR): {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = varref (0, 1);
                    switch (get_case (r0)) {
                      case (TC_NIL): {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (3, 0);
                        r1 = ((pxll_vector*)r1)->val[4];
                        r0[2] = r1;
                        r0 = varref (0, 0);
                        switch (get_case (r0)) {
                          case (UOTAG(3)): {
                            r0 = allocate (TC_TUPLE, 5);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (1, 0);
                            r1 = UOBJ_GET(r1,1);
                            r0[2] = r1;
                            r1 = varref (1, 0);
                            r1 = UOBJ_GET(r1,2);
                            r0[3] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = varref (5, 0);
                            r1[2] = r2;
                            r2 = varref (10, 128);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1977; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
                            L1977:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = varref (5, 0);
                            r1[2] = r2;
                            r2 = varref (10, 129);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L1978; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_525;
                            L1978:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[5] = r1;
                            r0 = allocate (TC_TUPLE, 2);
                            r0[1] = lenv; lenv = r0;
                            // def finish_2806_i1878_i4250_i4326
                            goto L1979;
                            FUN_finish_2806_i1878_i4250_i4326:
                              check_heap (0);
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 5);
                              r2 = varref (10, 0);
                              r1[2] = r2;
                              r2 = varref (6, 0);
                              r1[3] = r2;
                              r2 = varref (10, 2);
                              r1[4] = r2;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = varref (3, 2);
                              r2[2] = r3;
                              // def lambda_17400_i1878_i4250_i4326
                              goto L1980;
                              FUN_lambda_17400_i1878_i4250_i4326:
                                check_heap (0);
                                r0 = varref (4, 3);
                                r1 = varref (0, 0);
                                t = alloc_no_clear (UOTAG(6),2);
                                t[1] = r1;
                                t[2] = r0;
                                r0 = t;
                                PXLL_RETURN(0);
                              L1980:
                              r3 = allocate (TC_CLOSURE, 2);
                              r3[1] = &&FUN_lambda_17400_i1878_i4250_i4326; r3[2] = lenv;
                              r2[3] = r3;
                              r3 = varref (11, 0);
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L1981; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
                              L1981:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[5] = r2;
                              r2 = varref (11, 1);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1982; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
                              L1982:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 5);
                              r2 = varref (10, 0);
                              r1[2] = r2;
                              r2 = varref (5, 0);
                              r1[3] = r2;
                              r2 = varref (10, 2);
                              r1[4] = r2;
                              r2 = allocate (TC_TUPLE, 3);
                              r3 = varref (3, 2);
                              r2[2] = r3;
                              // def lambda_17414_i1878_i4250_i4326
                              goto L1983;
                              FUN_lambda_17414_i1878_i4250_i4326:
                                check_heap (0);
                                r0 = varref (4, 3);
                                r1 = varref (0, 0);
                                t = alloc_no_clear (UOTAG(6),2);
                                t[1] = r1;
                                t[2] = r0;
                                r0 = t;
                                PXLL_RETURN(0);
                              L1983:
                              r3 = allocate (TC_CLOSURE, 2);
                              r3[1] = &&FUN_lambda_17414_i1878_i4250_i4326; r3[2] = lenv;
                              r2[3] = r3;
                              r3 = varref (11, 0);
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L1984; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
                              L1984:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[5] = r2;
                              r2 = varref (11, 1);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L1985; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
                              L1985:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r0 = varref (0, 0);
                              r1 = varref (8, 0);
                              r2 = varref (3, 0);
                              r3 = varref (3, 1);
                              r4 = varref (0, 1);
                              r5 = varref (1, 0);
                              t = alloc_no_clear (UOTAG(5),6);
                              t[1] = r5;
                              t[2] = r2;
                              t[3] = r3;
                              t[4] = r0;
                              t[5] = r4;
                              t[6] = r1;
                              r0 = t;
                              PXLL_RETURN(0);
                            L1979:
                            r1 = allocate (TC_CLOSURE, 2);
                            r1[1] = &&FUN_finish_2806_i1878_i4250_i4326; r1[2] = lenv;
                            r0[2] = r1;
                            r0 = allocate (TC_TUPLE, 5);
                            r1 = varref (5, 0);
                            r1 = ((pxll_vector*)r1)->val[3];
                            r0[2] = r1;
                            r1 = varref (8, 2);
                            r0[3] = r1;
                            r1 = varref (6, 0);
                            r0[4] = r1;
                            r1 = varref (0, 0);
                            r0[5] = r1;
                            r1 = varref (9, 10);
                            r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2692_i4250_i4326;
                          } break;
                          default: {
                            goto fatbar_45;
                          }
                        }
                        PXLL_RETURN(0);
                        goto fatbar_45_over;
                        fatbar_45:
                        r0 = allocate (TC_TUPLE, 5);
                        r1 = (object *) 6;
                        r0[2] = r1;
                        r1 = varref (3, 0);
                        r0[3] = r1;
                        r1 = varref (6, 2);
                        r0[4] = r1;
                        r1 = allocate (TC_TUPLE, 3);
                        r2 = varref (4, 2);
                        r1[2] = r2;
                        // def lambda_17345_i1877_i4250_i4326
                        goto L1986;
                        FUN_lambda_17345_i1877_i4250_i4326:
                          check_heap (0);
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = allocate (TC_TUPLE, 5);
                          r2 = varref (8, 0);
                          r1[2] = r2;
                          r2 = varref (4, 0);
                          r1[3] = r2;
                          r2 = varref (8, 2);
                          r1[4] = r2;
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = varref (6, 2);
                          r2[2] = r3;
                          // def lambda_17325_i1877_i4250_i4326
                          goto L1987;
                          FUN_lambda_17325_i1877_i4250_i4326:
                            check_heap (0);
                            r0 = varref (7, 1);
                            r1 = varref (0, 0);
                            t = alloc_no_clear (UOTAG(6),2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            PXLL_RETURN(0);
                          L1987:
                          r3 = allocate (TC_CLOSURE, 2);
                          r3[1] = &&FUN_lambda_17325_i1877_i4250_i4326; r3[2] = lenv;
                          r2[3] = r3;
                          r3 = varref (9, 0);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L1988; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
                          L1988:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[5] = r2;
                          r2 = varref (9, 1);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1989; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
                          L1989:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[2] = r1;
                          r1 = allocate (TC_TUPLE, 5);
                          r2 = varref (8, 0);
                          r1[2] = r2;
                          r2 = varref (3, 0);
                          r1[3] = r2;
                          r2 = varref (8, 2);
                          r1[4] = r2;
                          r2 = allocate (TC_TUPLE, 3);
                          r3 = varref (6, 2);
                          r2[2] = r3;
                          // def lambda_17339_i1877_i4250_i4326
                          goto L1990;
                          FUN_lambda_17339_i1877_i4250_i4326:
                            check_heap (0);
                            r0 = varref (7, 1);
                            r1 = varref (0, 0);
                            t = alloc_no_clear (UOTAG(6),2);
                            t[1] = r1;
                            t[2] = r0;
                            r0 = t;
                            PXLL_RETURN(0);
                          L1990:
                          r3 = allocate (TC_CLOSURE, 2);
                          r3[1] = &&FUN_lambda_17339_i1877_i4250_i4326; r3[2] = lenv;
                          r2[3] = r3;
                          r3 = varref (9, 0);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L1991; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
                          L1991:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[5] = r2;
                          r2 = varref (9, 1);
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L1992; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
                          L1992:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r0[3] = r1;
                          r0 = varref (6, 0);
                          r1 = varref (0, 0);
                          r2 = varref (0, 1);
                          r3 = varref (1, 0);
                          t = alloc_no_clear (UOTAG(4),4);
                          t[1] = r3;
                          t[2] = r1;
                          t[3] = r2;
                          t[4] = r0;
                          r0 = t;
                          PXLL_RETURN(0);
                        L1986:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN_lambda_17345_i1877_i4250_i4326; r2[2] = lenv;
                        r1[3] = r2;
                        r2 = varref (7, 0);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L1993; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
                        L1993:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[5] = r1;
                        r1 = varref (7, 1);
                        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
                        fatbar_45_over: ;
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        lenv = ((object ***)lenv)[1][1][1];
                        goto fatbar_44;
                      }
                    }
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    lenv = ((object **)lenv)[1][1];
                    goto fatbar_44;
                  }
                }
                PXLL_RETURN(0);
              } break;
              default: {
                lenv = ((object *)lenv)[1];
                goto fatbar_44;
              }
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_44;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_44_over;
        fatbar_44:
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_416;
        r0[2] = r1;
        r1 = varref (2, 1);
        r0[3] = r1;
        r1 = varref (5, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
        fatbar_44_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(7)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[1];
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 1);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1994; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L1994:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = varref (2, 3);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 4);
        r1 = varref (4, 0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (4, 29);
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1995; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L1995:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (5, 145);
        r0[4] = r1;
        r1 = varref (5, 4);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L1996; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
        L1996:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 29);
        r0[2] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (4, 29, r0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 5);
        r2 = (object *) 262;
        r1[2] = r2;
        r2 = varref (1, 3);
        r1[3] = r2;
        r2 = varref (1, 1);
        switch (get_case (r2)) {
          case (TC_NIL): {
            r2 = varref (3, 2);
            r2=r2;
          } break;
          default: {
            goto fatbar_46;
          }
        }
        r2=r2;
        goto fatbar_46_over;
        fatbar_46:
        r2 = varref (3, 2);
        r3 = varref (1, 1);
        t = alloc_no_clear (UOTAG(1),2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r2=r2;
        fatbar_46_over: ;
        r1[4] = r2;
        r2 = allocate (TC_TUPLE, 3);
        r3 = (object *) constructed_418[0];
        r2[2] = r3;
        r3 = varref (4, 16);
        r2[3] = r3;
        r3 = varref (4, 0);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L1997; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
        L1997:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[5] = r2;
        r2 = varref (4, 1);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1998; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
        L1998:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (0, 0);
        r2 = varref (1, 4);
        r3 = varref (1, 0);
        t = alloc_no_clear (UOTAG(7),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        r0[3] = r1;
        r0 = varref (5, 29);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = (object*) &constructed_69;
            r0 = box(((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_417;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_417;
            r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (6, 29);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (6, 29);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 1);
            varset (6, 29, r0);
            r0 = varref (0, 0);
            lenv = lenv[1];
            r0 = r0;
          } break;
        }
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (2, 3);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = varref (2, 2);
        r1[4] = r2;
        r2 = varref (3, 9);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L1999; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2687_i4250_i4326;
        L1999:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = varref (0, 2);
        switch (get_case_noint (r0)) {
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = (object *) -1;
            r1 = varref (1, 1);
            r2 = varref (0, 0);
            t = alloc_no_clear (UOTAG(19),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 2);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (0, 1);
            r1 = varref (1, 1);
            r2 = varref (0, 0);
            t = alloc_no_clear (UOTAG(8),3);
            t[1] = r2;
            t[2] = r0;
            t[3] = r1;
            r0 = t;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 1);
        r2 = ((pxll_vector*)r2)->val[3];
        r1[2] = r2;
        r2 = varref (5, 17);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2000; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
        L2000:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = varref (2, 3);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = varref (2, 2);
        r1[4] = r2;
        r2 = varref (3, 9);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2001; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2687_i4250_i4326;
        L2001:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = varref (0, 3);
        switch (get_case_noint (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 3);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (1, 3);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            // def lambda_17666_i1893_i4250_i4326
            goto L2002;
            FUN_lambda_17666_i1893_i4250_i4326:
              check_heap (0);
              r0 = varref (2, 2);
              r1 = varref (1, 1);
              r2 = varref (0, 0);
              r3 = varref (1, 0);
              t = alloc_no_clear (UOTAG(9),4);
              t[1] = r3;
              t[2] = r1;
              t[3] = r2;
              t[4] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2002:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17666_i1893_i4250_i4326; r1[2] = lenv;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 3);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            // def lambda_17679_i1893_i4250_i4326
            goto L2003;
            FUN_lambda_17679_i1893_i4250_i4326:
              check_heap (0);
              r0 = varref (1, 0);
              r1 = varref (2, 2);
              r2 = varref (0, 0);
              t = alloc_no_clear (UOTAG(19),3);
              t[1] = r2;
              t[2] = r0;
              t[3] = r1;
              r0 = t;
              PXLL_RETURN(0);
            L2003:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_17679_i1893_i4250_i4326; r1[2] = lenv;
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = varref (0, 1);
        r0[3] = r1;
        r1 = varref (2, 2);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (0, 2);
        r2[2] = r3;
        r3 = varref (5, 128);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2004; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_524;
        L2004:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = varref (0, 4);
        r1[3] = r2;
        r2 = varref (3, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2005; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
        L2005:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = varref (3, 1);
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 6);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r1 = varref (2, 3);
        r0[6] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = varref (0, 3);
        r0[2] = r1;
        r1 = varref (2, 2);
        r0[3] = r1;
        r1 = varref (0, 4);
        r0[4] = r1;
        // def lambda_17868_i1896_i4250_i4326
        goto L2006;
        FUN_lambda_17868_i1896_i4250_i4326:
          check_heap (0);
          r0 = varref (1, 4);
          r1 = varref (1, 2);
          r2 = varref (0, 0);
          r3 = varref (1, 1);
          t = alloc_no_clear (UOTAG(3),4);
          t[1] = r3;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          r0 = t;
          PXLL_RETURN(0);
        L2006:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_17868_i1896_i4250_i4326; r1[2] = lenv;
        r0[5] = r1;
        r1 = varref (3, 10);
        r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2692_i4250_i4326;
      } break;
      case (UITAG(8)): {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (2, 3);
        r0[2] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_PAIR): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 1);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r0 = varref (3, 0);
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (UOTAG(0)): {
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r0 = allocate (TC_TUPLE, 2);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (6, 1);
                  r1 = ((pxll_vector*)r1)->val[0];
                  r0[2] = r1;
                  r0 = varref (9, 179);
                  r1 = varref (0, 0);
                  r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
                  lenv = lenv[1];
                  r0 = r0;
                  if PXLL_IS_TRUE(r0) {
                    r0 = allocate (TC_TUPLE, 5);
                    r0[1] = lenv; lenv = r0;
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (8, 29);
                    r1[2] = r2;
                    r2 = varref (9, 17);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2007; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
                    L2007:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (8, 0);
                    r1[2] = r2;
                    r2 = varref (0, 0);
                    r1[3] = r2;
                    r2 = varref (9, 3);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2008; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
                    L2008:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[3] = r1;
                    r1 = varref (0, 1);
                    r1 = ((pxll_vector*)r1)->val[1];
                    r0[4] = r1;
                    r1 = varref (9, 143);
                    r2 = varref (0, 2);
                    r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                    r0[5] = r1;
                    r0 = (object *) 6;
                    r1 = varref (0, 3);
                    r0 = PXLL_TEST(r1==r0);
                    lenv = lenv[1];
                    r0 = r0;
                    r0=r0;
                  } else {
                    r0 = (object *) 6;
                    r0=r0;
                  }
                  lenv = lenv[1];
                  r0 = r0;
                  r0=r0;
                } break;
                default: {
                  goto fatbar_49;
                }
              }
              r0=r0;
              goto fatbar_49_over;
              fatbar_49:
              r0 = (object *) 6;
              r0=r0;
              fatbar_49_over: ;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } else {
              r0 = (object *) 6;
              r0=r0;
            }
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 0);
              r2 = ((pxll_vector*)r2)->val[4];
              r1[2] = r2;
              r2 = varref (7, 111);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2009; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_varref__3ename_491;
              L2009:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 4);
              r2 = varref (0, 0);
              r1[2] = r2;
              r2 = (object *) 1;
              r1[3] = r2;
              r2 = varref (4, 2);
              r1[4] = r2;
              r2 = varref (5, 9);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2010; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_lexical_address_2687_i4250_i4326;
              L2010:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r0 = varref (0, 1);
              switch (get_case_noint (r0)) {
                case (UOTAG(6)): {
                  r0 = (object*) &constructed_69;
                  r0 = box(((pxll_string*)(r0))->len);
                  r1 = (object*) &constructed_69;
                  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                  r0 = (object*) &constructed_419;
                  dump_object (r0, 0); fprintf (stdout, "\n");
                  r0 = (object*) &constructed_419;
                  r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                  PXLL_RETURN(0);
                } break;
                default: {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 1);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = varref (2, 1);
                  r0[2] = r1;
                  r1 = varref (5, 2);
                  r0[3] = r1;
                  r1 = varref (3, 0);
                  r0[4] = r1;
                  // def lambda_18121_i1904_i4250_i4326
                  goto L2011;
                  FUN_lambda_18121_i1904_i4250_i4326:
                    check_heap (0);
                    r0 = varref (2, 0);
                    r1 = varref (0, 0);
                    r2 = varref (1, 0);
                    t = alloc_no_clear (UOTAG(15),3);
                    t[1] = r2;
                    t[2] = r0;
                    t[3] = r1;
                    r0 = t;
                    PXLL_RETURN(0);
                  L2011:
                  r1 = allocate (TC_CLOSURE, 2);
                  r1[1] = &&FUN_lambda_18121_i1904_i4250_i4326; r1[2] = lenv;
                  r0[5] = r1;
                  r1 = varref (6, 10);
                  r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2692_i4250_i4326;
                } break;
              }
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = varref (4, 0);
              if PXLL_IS_TRUE(r1) {
                r1 = varref (5, 18);
                r1=r1;
              } else {
                r1 = varref (5, 17);
                r1=r1;
              }
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = ((pxll_vector*)r1)->val[4];
              r0[3] = r1;
              r1 = varref (0, 1);
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (1, 1);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = varref (8, 0);
                  r2[2] = r3;
                  r3 = varref (1, 0);
                  r2[3] = r3;
                  r3 = varref (9, 3);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2012; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_vars_get_var_255;
                  L2012:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  r2 = ((pxll_vector*)r2)->val[1];
                  r1[3] = r2;
                  r1 = varref (9, 144);
                  r2 = varref (0, 1);
                  r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
                  lenv = lenv[1];
                  r1 = r1;
                  if PXLL_IS_TRUE(r1) {
                    r1 = varref (0, 0);
                    t = alloc_no_clear (UOTAG(0),1);
                    t[1] = r1;
                    r1 = t;
                    r1=r1;
                  } else {
                    r1 = (object*)UITAG(1);
                    r1=r1;
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_48;
                }
              }
              r1=r1;
              goto fatbar_48_over;
              fatbar_48:
              r1 = (object*)UITAG(1);
              r1=r1;
              fatbar_48_over: ;
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              // def make-call_2937_i1898_i4250_i4326
              goto L2013;
              FUN_make_call_2937_i1898_i4250_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = (object *) 6;
                r0[2] = r1;
                r1 = varref (3, 0);
                r0[3] = r1;
                r1 = varref (6, 2);
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = varref (5, 0);
                r3[2] = r4;
                r4 = varref (10, 128);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2014; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_524;
                L2014:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r2 = varref (0, 0);
                r3 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                // def lambda_18222_i1898_i4250_i4326
                goto L2015;
                FUN_lambda_18222_i1898_i4250_i4326:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 5);
                  r1 = varref (3, 2);
                  r0[2] = r1;
                  r1 = varref (0, 0);
                  r0[3] = r1;
                  r1 = varref (1, 0);
                  r0[4] = r1;
                  r1 = varref (5, 0);
                  r0[5] = r1;
                  r1 = varref (3, 0);
                  r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2015:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_lambda_18222_i1898_i4250_i4326; r2[2] = lenv;
                r1[3] = r2;
                r2 = varref (7, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2016; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
                L2016:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = varref (7, 1);
                r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
              L2013:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_make_call_2937_i1898_i4250_i4326; r1[2] = lenv;
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (3, 1);
              r1[2] = r2;
              r2 = varref (9, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2017; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L2017:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = (object *) 1;
              r1 = varref (0, 0);
              r0 = PXLL_TEST(unbox(r1)>unbox(r0));
              lenv = lenv[1];
              r0 = r0;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (4, 0);
                r2[2] = r3;
                r3 = varref (9, 128);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2018; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_524;
                L2018:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (7, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2019; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
                L2019:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 4);
                r1 = varref (8, 0);
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (8, 29);
                r1[2] = r2;
                r2 = varref (9, 17);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2020; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
                L2020:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = varref (9, 145);
                r0[4] = r1;
                r1 = varref (9, 4);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2021; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
                L2021:
                ; lenv = k[2]; k = k[1];
                r0 = varref (3, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = varref (0, 0);
                    r1 = (object *) 1;
                    t = alloc_no_clear (UOTAG(10),2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    PXLL_RETURN(0);
                  } break;
                  default: {
                    goto fatbar_47;
                  }
                }
                PXLL_RETURN(0);
                goto fatbar_47_over;
                fatbar_47:
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (4, 1);
                r1[2] = r2;
                r2 = varref (10, 20);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2022; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                L2022:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (1, 0);
                r2[2] = r3;
                r3 = varref (10, 128);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2023; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_524;
                L2023:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                // def lambda_18299_i1912_i4250_i4326
                goto L2024;
                FUN_lambda_18299_i1912_i4250_i4326:
                  check_heap (0);
                  r0 = allocate (TC_TUPLE, 8);
                  r1 = (object *) 1;
                  r0[2] = r1;
                  r1 = (object *) 3;
                  r0[3] = r1;
                  r1 = varref (5, 1);
                  r0[4] = r1;
                  r1 = varref (0, 0);
                  r0[5] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = varref (3, 0);
                  r2[2] = r3;
                  r3 = varref (12, 128);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2025; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_524;
                  L2025:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = varref (0, 0);
                  r2 = varref (1, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r2;
                  t[2] = r1;
                  r1 = t;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[6] = r1;
                  r1 = varref (8, 2);
                  r0[7] = r1;
                  r1 = varref (2, 0);
                  r0[8] = r1;
                  r1 = varref (9, 13);
                  r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2700_i4250_i4326;
                L2024:
                r2 = allocate (TC_CLOSURE, 2);
                r2[1] = &&FUN_lambda_18299_i1912_i4250_i4326; r2[2] = lenv;
                r1[3] = r2;
                r2 = varref (8, 0);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2026; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
                L2026:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r0 = varref (0, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(10),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
                fatbar_47_over: ;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object *) -1;
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[1] = r1[2]; lenv = r0; goto FUN_make_call_2937_i1898_i4250_i4326;
              }
              PXLL_RETURN(0);
            }
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object*) &constructed_69;
            r0 = box(((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_420;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_420;
            r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(12)): {
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (2, 3);
        r0[4] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[5] = r1;
        r0 = (object *) constructed_422[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 3);
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2027; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L2027:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = varref (6, 104);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2028; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_record_sig_471;
          L2028:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 1);
          r1[2] = r2;
          r2 = varref (0, 2);
          r1[3] = r2;
          r2 = varref (6, 30);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2029; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
          L2029:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = varref (0, 3);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = allocate (TC_TUPLE, 6);
          r1 = varref (1, 3);
          r0[2] = r1;
          r1 = (object *) constructed_210[0];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = varref (0, 0);
          r3 = varref (1, 4);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = varref (0, 1);
          r3 = varref (2, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = varref (0, 2);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[4] = r1;
          r1 = varref (3, 2);
          r0[5] = r1;
          r1 = varref (1, 2);
          r0[6] = r1;
          r1 = varref (4, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2694_i4250_i4326;
        } else {
          goto fatbar_50;
        }
        PXLL_RETURN(0);
        goto fatbar_50_over;
        fatbar_50:
        r0 = (object *) constructed_424[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 6);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 3);
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2030; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L2030:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (0, 0);
          r1 = ((pxll_vector*)r1)->val[5];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = varref (6, 104);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2031; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_get_record_sig_471;
          L2031:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (6, 1);
          r1[2] = r2;
          r2 = varref (0, 2);
          r1[3] = r2;
          r2 = varref (6, 30);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2032; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
          L2032:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = varref (0, 3);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          r0[6] = r1;
          r0 = allocate (TC_TUPLE, 6);
          r1 = varref (1, 3);
          r0[2] = r1;
          r1 = (object *) constructed_221[0];
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 4);
          r1[1] = lenv; lenv = r1;
          r2 = (object*)TC_NIL;
          r1[2] = r2;
          r2 = varref (0, 0);
          r3 = varref (1, 4);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[3] = r2;
          r2 = varref (0, 1);
          r3 = varref (2, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          r1[4] = r2;
          r1 = varref (0, 2);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r1;
          r1 = t;
          lenv = lenv[1];
          r1 = r1;
          r0[4] = r1;
          r1 = varref (3, 2);
          r0[5] = r1;
          r1 = varref (1, 2);
          r0[6] = r1;
          r1 = varref (4, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2694_i4250_i4326;
        } else {
          goto fatbar_51;
        }
        PXLL_RETURN(0);
        goto fatbar_51_over;
        fatbar_51:
        r0 = (object *) constructed_430[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_3053_i1932_i4250_i4326
          goto L2033;
          FUN_loop_3053_i1932_i4250_i4326:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = ((pxll_vector*)r1)->val[4];
            r0[2] = r1;
            r0 = varref (0, 0);
            switch (get_case (r0)) {
              case (UOTAG(12)): {
                r0 = allocate (TC_TUPLE, 3);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r1 = UOBJ_GET(r1,1);
                r0[3] = r1;
                r0 = (object *) constructed_427[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = allocate (TC_TUPLE, 9);
                  r0[1] = lenv; lenv = r0;
                  r1 = allocate (TC_TUPLE, 3);
                  // def lambda_18959_i1932_i4250_i4326
                  goto L2034;
                  FUN_lambda_18959_i1932_i4250_i4326:
                    check_heap (0);
                    r0 = varref (0, 0);
                    switch (get_case_noint (r0)) {
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r0 = varref (1, 1);
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 5);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (2, 1);
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = varref (1, 0);
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = varref (2, 0);
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r1 = varref (0, 0);
                            lenv = lenv[1];
                            r1 = r1;
                            r1=r1;
                            r0[3] = r1;
                            r1 = varref (0, 0);
                            r1 = allocate (TC_TUPLE, 2);
                            r1[1] = lenv; lenv = r1;
                            r2 = varref (1, 0);
                            r2 = UOBJ_GET(r2,0);
                            r1[2] = r2;
                            r1 = varref (0, 0);
                            lenv = lenv[1];
                            r1 = r1;
                            r1=r1;
                            r0[4] = r1;
                            r1 = allocate (TC_TUPLE, 3);
                            r2 = varref (0, 1);
                            r1[2] = r2;
                            r2 = varref (0, 2);
                            r1[3] = r2;
                            r2 = varref (13, 48);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2035; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
                            L2035:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[5] = r1;
                            r0 = (object *) 1;
                            r1 = varref (0, 3);
                            r0 = PXLL_TEST(unbox(r1)<unbox(r0));
                            PXLL_RETURN(0);
                          } break;
                        }
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                  L2034:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_lambda_18959_i1932_i4250_i4326; r2[2] = lenv;
                  r1[2] = r2;
                  r2 = varref (3, 1);
                  r1[3] = r2;
                  r2 = varref (10, 42);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2036; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_sort_350;
                  L2036:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[2] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (10, 15);
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  r1[3] = r2;
                  r2 = varref (10, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2037; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L2037:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[3] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (10, 16);
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  r1[3] = r2;
                  r2 = varref (10, 30);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2038; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
                  L2038:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[4] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def loop_3090_i1935_i4250_i4326
                  goto L2039;
                  FUN_loop_3090_i1935_i4250_i4326:
                    check_heap (0);
                    r0 = varref (0, 0);
                    switch (get_case (r0)) {
                      case (TC_PAIR): {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,0);
                        r0[2] = r1;
                        r1 = varref (1, 0);
                        r1 = UOBJ_GET(r1,1);
                        r0[3] = r1;
                        r0 = varref (0, 0);
                        switch (get_case_noint (r0)) {
                          default: {
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = varref (1, 0);
                            r1 = UOBJ_GET(r1,0);
                            r0[2] = r1;
                            r1 = varref (1, 0);
                            r1 = UOBJ_GET(r1,1);
                            r0[3] = r1;
                            r0 = allocate (TC_TUPLE, 3);
                            r0[1] = lenv; lenv = r0;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = varref (1, 0);
                            r1[2] = r2;
                            r2 = varref (15, 20);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2040; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                            L2040:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = varref (5, 1);
                            r1[2] = r2;
                            r2 = varref (15, 20);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2041; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                            L2041:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[3] = r1;
                            r0 = varref (0, 1);
                            r1 = varref (0, 0);
                            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                            lenv = lenv[1];
                            r0 = r0;
                            if PXLL_IS_TRUE(r0) {
                              r0 = allocate (TC_TUPLE, 4);
                              r1 = varref (14, 11);
                              r0[2] = r1;
                              r1 = varref (0, 0);
                              r0[3] = r1;
                              r1 = varref (4, 1);
                              r0[4] = r1;
                              r1 = varref (14, 39);
                              t = allocate (TC_SAVE, 3);
                              t[1] = k; t[2] = lenv; t[3] = &&L2042; ; k = t;
                              r0[1] = r1[2]; lenv = r0; goto FUN_every2_question_344;
                              L2042:
                              ; lenv = k[2]; k = k[1];
                              r0 = result;
                              r0=r0;
                            } else {
                              r0 = (object *) 6;
                              r0=r0;
                            }
                            if PXLL_IS_TRUE(r0) {
                              r0 = varref (0, 1);
                              PXLL_RETURN(0);
                            } else {
                              r0 = varref (1, 1);
                              lenv = ((object **)lenv)[1][1];
                              lenv[2] = r0;
                              goto FUN_loop_3090_i1935_i4250_i4326;
                            }
                            PXLL_RETURN(0);
                          } break;
                        }
                        PXLL_RETURN(0);
                      } break;
                      default: {
                        r0 = allocate (TC_TUPLE, 2);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = varref (12, 0);
                        r2 = ((pxll_vector*)r2)->val[8];
                        r1[2] = r2;
                        r2 = varref (13, 20);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2043; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                        L2043:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r0 = allocate (TC_TUPLE, 3);
                        r1 = varref (11, 15);
                        r0[2] = r1;
                        r1 = varref (3, 1);
                        r0[3] = r1;
                        r1 = varref (13, 33);
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2044; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
                        L2044:
                        ; lenv = k[2]; k = k[1];
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (UOTAG(0), 2);
                        r2 = varref (4, 1);
                        r1[1] = r2;
                        r2 = varref (1, 0);
                        r1[2] = r2;
                        r0[2] = r1;
                        r1 = varref (13, 0);
                        r1 = ((pxll_vector*)r1)->val[8];
                        r0[3] = r1;
                        r0 = varref (0, 1);
                        r1 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r1;
                        t[2] = r0;
                        r0 = t;
                        lenv = lenv[1];
                        r0 = r0;
                        r1 = varref (12, 0);
                        ((pxll_vector*)r1)->val[8] = r0;
                        r0 = varref (0, 0);
                        PXLL_RETURN(0);
                      } break;
                    }
                    PXLL_RETURN(0);
                  L2039:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_loop_3090_i1935_i4250_i4326; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (10, 0);
                  r2 = ((pxll_vector*)r2)->val[8];
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2045; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_loop_3090_i1935_i4250_i4326;
                  L2045:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r0[5] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (5, 2);
                  r1[2] = r2;
                  r2 = varref (10, 128);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2046; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
                  L2046:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[6] = r1;
                  r1 = varref (0, 3);
                  t = alloc_no_clear (UOTAG(1),1);
                  t[1] = r1;
                  r1 = t;
                  r0[7] = r1;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = varref (0, 2);
                  r1[2] = r2;
                  r2 = varref (10, 20);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2047; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                  L2047:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[8] = r1;
                  r1 = allocate (TC_TUPLE, 3);
                  r2 = varref (0, 4);
                  r1[2] = r2;
                  // def lambda_18998_i1932_i4250_i4326
                  goto L2048;
                  FUN_lambda_18998_i1932_i4250_i4326:
                    check_heap (0);
                    r0 = allocate (TC_TUPLE, 8);
                    r1 = (object *) 1;
                    r0[2] = r1;
                    r1 = (object *) 1;
                    r0[3] = r1;
                    r1 = varref (1, 2);
                    r0[4] = r1;
                    r1 = varref (0, 0);
                    r0[5] = r1;
                    r1 = varref (1, 4);
                    r2 = varref (0, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r2;
                    t[2] = r1;
                    r1 = t;
                    r0[6] = r1;
                    r1 = varref (8, 2);
                    r0[7] = r1;
                    r1 = varref (6, 2);
                    r0[8] = r1;
                    r1 = varref (9, 13);
                    r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2700_i4250_i4326;
                  L2048:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN_lambda_18998_i1932_i4250_i4326; r2[2] = lenv;
                  r1[3] = r2;
                  r2 = varref (8, 0);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2049; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
                  L2049:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r0[9] = r1;
                  r0 = varref (0, 6);
                  r1 = varref (0, 7);
                  r2 = varref (0, 5);
                  t = alloc_no_clear (UOTAG(11),3);
                  t[1] = r2;
                  t[2] = r0;
                  t[3] = r1;
                  r0 = t;
                  PXLL_RETURN(0);
                } else {
                  goto fatbar_54;
                }
                PXLL_RETURN(0);
                goto fatbar_54_over;
                fatbar_54:
                r0 = (object *) constructed_430[0];
                r1 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                  r0 = varref (0, 1);
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 3);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 1);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r1 = varref (3, 0);
                      r1 = ((pxll_vector*)r1)->val[3];
                      r0[3] = r1;
                      r0 = varref (0, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 3);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,0);
                          r0[2] = r1;
                          r1 = varref (1, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[3] = r1;
                          r0 = varref (0, 1);
                          switch (get_case (r0)) {
                            case (TC_PAIR): {
                              r0 = allocate (TC_TUPLE, 3);
                              r0[1] = lenv; lenv = r0;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,0);
                              r0[2] = r1;
                              r1 = varref (1, 1);
                              r1 = UOBJ_GET(r1,1);
                              r0[3] = r1;
                              r0 = varref (0, 1);
                              switch (get_case (r0)) {
                                case (TC_NIL): {
                                  r0 = allocate (TC_TUPLE, 2);
                                  r0[1] = lenv; lenv = r0;
                                  r1 = allocate (UOTAG(0), 2);
                                  r2 = varref (3, 0);
                                  r1[1] = r2;
                                  r2 = varref (1, 0);
                                  r1[2] = r2;
                                  r0[2] = r1;
                                  r0 = varref (6, 1);
                                  r1 = varref (0, 0);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r1;
                                  t[2] = r0;
                                  r0 = t;
                                  lenv = lenv[1];
                                  r0 = r0;
                                  r1 = varref (1, 0);
                                  lenv = ((object *****)lenv)[1][1][1][1][1];
                                  lenv[2] = r1;
                                  lenv[3] = r0;
                                  goto FUN_loop_3053_i1932_i4250_i4326;
                                } break;
                                default: {
                                  lenv = ((object **)lenv)[1][1];
                                  goto fatbar_55;
                                }
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object *)lenv)[1];
                              goto fatbar_55;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          goto fatbar_55;
                        }
                      }
                      PXLL_RETURN(0);
                      goto fatbar_55_over;
                      fatbar_55:
                      r0 = allocate (TC_TUPLE, 3);
                      r1 = (object*) &constructed_428;
                      r0[2] = r1;
                      r1 = varref (3, 0);
                      r0[3] = r1;
                      r1 = varref (10, 12);
                      r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
                      fatbar_55_over: ;
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_53;
                    }
                  }
                  PXLL_RETURN(0);
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_53;
                }
                PXLL_RETURN(0);
                fatbar_54_over: ;
                PXLL_RETURN(0);
              } break;
              default: {
                goto fatbar_53;
              }
            }
            PXLL_RETURN(0);
            goto fatbar_53_over;
            fatbar_53:
            r0 = (object*) &constructed_69;
            r0 = box(((pxll_string*)(r0))->len);
            r1 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
            r0 = (object*) &constructed_431;
            dump_object (r0, 0); fprintf (stdout, "\n");
            r0 = (object*) &constructed_431;
            r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
            PXLL_RETURN(0);
            fatbar_53_over: ;
            PXLL_RETURN(0);
          L2033:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_3053_i1932_i4250_i4326; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = varref (3, 1);
          r0[2] = r1;
          r1 = (object *) constructed_425[0];
          r0[3] = r1;
          r1 = varref (0, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_3053_i1932_i4250_i4326;
        } else {
          goto fatbar_52;
        }
        PXLL_RETURN(0);
        goto fatbar_52_over;
        fatbar_52:
        r0 = (object *) constructed_435[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (0, 1);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              switch (get_case (r0)) {
                case (TC_PAIR): {
                  r0 = allocate (TC_TUPLE, 3);
                  r0[1] = lenv; lenv = r0;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,0);
                  r0[2] = r1;
                  r1 = varref (1, 0);
                  r1 = UOBJ_GET(r1,1);
                  r0[3] = r1;
                  r0 = varref (0, 0);
                  switch (get_case (r0)) {
                    case (UOTAG(1)): {
                      r0 = allocate (TC_TUPLE, 2);
                      r0[1] = lenv; lenv = r0;
                      r1 = varref (1, 0);
                      r1 = UOBJ_GET(r1,0);
                      r0[2] = r1;
                      r0 = varref (1, 1);
                      switch (get_case (r0)) {
                        case (TC_PAIR): {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = varref (2, 1);
                          r1 = UOBJ_GET(r1,1);
                          r0[2] = r1;
                          r0 = varref (0, 0);
                          switch (get_case (r0)) {
                            case (TC_NIL): {
                              r0 = allocate (TC_TUPLE, 4);
                              r0[1] = lenv; lenv = r0;
                              r1 = allocate (TC_TUPLE, 4);
                              r2 = varref (9, 0);
                              r2 = ((pxll_vector*)r2)->val[13];
                              r1[2] = r2;
                              r2 = varref (2, 0);
                              r1[3] = r2;
                              r2 = (object*) &constructed_432;
                              r1[4] = r2;
                              r2 = varref (10, 65);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2050; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
                              L2050:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[2] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = varref (5, 2);
                              r1[2] = r2;
                              r2 = varref (10, 128);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2051; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
                              L2051:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[3] = r1;
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = varref (5, 3);
                              r1[2] = r2;
                              r2 = varref (10, 20);
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2052; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                              L2052:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r0[4] = r1;
                              r0 = (object *) 1;
                              r1 = varref (0, 2);
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 4);
                                r1 = varref (9, 0);
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 2);
                                r2 = varref (9, 29);
                                r1[2] = r2;
                                r2 = varref (10, 17);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2053; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
                                L2053:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r1 = varref (10, 145);
                                r0[4] = r1;
                                r1 = varref (10, 4);
                                t = allocate (TC_SAVE, 3);
                                t[1] = k; t[2] = lenv; t[3] = &&L2054; ; k = t;
                                r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
                                L2054:
                                ; lenv = k[2]; k = k[1];
                                r0 = result;
                              } else {
                                r0 = (object *) 14;
                              }
                              r0 = (object *) 1;
                              r1 = varref (0, 2);
                              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
                                r0 = allocate (TC_TUPLE, 3);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (1, 0);
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r1;
                                r1 = t;
                                r0[2] = r1;
                                r1 = allocate (TC_TUPLE, 3);
                                r2 = varref (1, 1);
                                r1[2] = r2;
                                // def lambda_18886_i1947_i4250_i4326
                                goto L2055;
                                FUN_lambda_18886_i1947_i4250_i4326:
                                  check_heap (0);
                                  r0 = allocate (TC_TUPLE, 8);
                                  r1 = (object *) 1;
                                  r0[2] = r1;
                                  r1 = (object *) 1;
                                  r0[3] = r1;
                                  r1 = varref (7, 3);
                                  r0[4] = r1;
                                  r1 = varref (0, 0);
                                  r0[5] = r1;
                                  r1 = varref (2, 1);
                                  r2 = varref (0, 0);
                                  t = alloc_no_clear (TC_PAIR,2);
                                  t[1] = r2;
                                  t[2] = r1;
                                  r1 = t;
                                  r0[6] = r1;
                                  r1 = varref (9, 2);
                                  r0[7] = r1;
                                  r1 = varref (7, 2);
                                  r0[8] = r1;
                                  r1 = varref (10, 13);
                                  r0[1] = r1[2]; lenv = r0; goto FUN_compile_store_args_2700_i4250_i4326;
                                L2055:
                                r2 = allocate (TC_CLOSURE, 2);
                                r2[1] = &&FUN_lambda_18886_i1947_i4250_i4326; r2[2] = lenv;
                                r1[3] = r2;
                                r2 = varref (9, 0);
                                t = allocate (TC_SAVE, 4);
                                t[1] = k; t[2] = lenv; t[3] = &&L2056; t[4] = r0; k = t;
                                r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
                                L2056:
                                r0 = k[4]; lenv = k[2]; k = k[1];
                                r1 = result;
                                r0[3] = r1;
                                r0 = varref (1, 2);
                                r1 = varref (0, 1);
                                r2 = varref (0, 0);
                                t = alloc_no_clear (UOTAG(11),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                PXLL_RETURN(0);
                              } else {
                                r0 = allocate (TC_TUPLE, 2);
                                r0[1] = lenv; lenv = r0;
                                r1 = varref (1, 0);
                                t = alloc_no_clear (UOTAG(1),1);
                                t[1] = r1;
                                r1 = t;
                                r0[2] = r1;
                                r0 = (object *) 1;
                                r1 = varref (6, 2);
                                r2 = varref (0, 0);
                                t = alloc_no_clear (UOTAG(11),3);
                                t[1] = r2;
                                t[2] = r0;
                                t[3] = r1;
                                r0 = t;
                                PXLL_RETURN(0);
                              }
                              PXLL_RETURN(0);
                            } break;
                            default: {
                              lenv = ((object ****)lenv)[1][1][1][1];
                              goto fatbar_57;
                            }
                          }
                          PXLL_RETURN(0);
                        } break;
                        default: {
                          lenv = ((object ***)lenv)[1][1][1];
                          goto fatbar_57;
                        }
                      }
                      PXLL_RETURN(0);
                    } break;
                    default: {
                      lenv = ((object **)lenv)[1][1];
                      goto fatbar_57;
                    }
                  }
                  PXLL_RETURN(0);
                } break;
                default: {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_57;
                }
              }
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_57;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_57_over;
          fatbar_57:
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object*) &constructed_433;
          r0[2] = r1;
          r1 = varref (0, 1);
          r0[3] = r1;
          r1 = varref (5, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
          fatbar_57_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_56;
        }
        PXLL_RETURN(0);
        goto fatbar_56_over;
        fatbar_56:
        r0 = (object *) constructed_272[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 3);
          r1[2] = r2;
          r2 = varref (6, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2057; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L2057:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 1;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(unbox(r1)>unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 4);
            r1 = varref (4, 0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (4, 29);
            r1[2] = r2;
            r2 = varref (5, 17);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2058; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
            L2058:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = varref (5, 145);
            r0[4] = r1;
            r1 = varref (5, 4);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2059; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
            L2059:
            ; lenv = k[2]; k = k[1];
            r0 = result;
          } else {
            r0 = (object *) 14;
          }
          r0 = allocate (TC_TUPLE, 6);
          r1 = varref (0, 3);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (0, 1);
          r0[4] = r1;
          r1 = varref (2, 2);
          r0[5] = r1;
          r1 = varref (0, 2);
          r0[6] = r1;
          r1 = varref (3, 12);
          r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2694_i4250_i4326;
        } else {
          goto fatbar_58;
        }
        PXLL_RETURN(0);
        goto fatbar_58_over;
        fatbar_58:
        r0 = (object *) constructed_437[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 7);
          r0[1] = lenv; lenv = r0;
          r1 = varref (4, 19);
          r1 = ((pxll_vector*)r1)->val[1];
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2060; t[4] = r0; k = t;
          lenv = r1[2]; goto *r1[1];
          L2060:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (3, 2);
          r2 = varref (0, 0);
          t = alloc_no_clear (UOTAG(3),2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 2);
          r1[2] = r2;
          r2 = varref (6, 128);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2061; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
          L2061:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 2);
          r1[2] = r2;
          r2 = varref (6, 129);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2062; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_525;
          L2062:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 5);
          r2 = varref (3, 0);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (1, 3);
          r2[2] = r3;
          r3 = (object *) 1;
          r2[3] = r3;
          r3 = varref (6, 25);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2063; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
          L2063:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (0, 1);
          r1[4] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (0, 2);
          r2[2] = r3;
          // def lambda_18754_i1960_i4250_i4326
          goto L2064;
          FUN_lambda_18754_i1960_i4250_i4326:
            check_heap (0);
            r0 = varref (1, 3);
            r1 = varref (0, 0);
            t = alloc_no_clear (UOTAG(6),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          L2064:
          r3 = allocate (TC_CLOSURE, 2);
          r3[1] = &&FUN_lambda_18754_i1960_i4250_i4326; r3[2] = lenv;
          r2[3] = r3;
          r3 = varref (4, 0);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2065; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
          L2065:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[5] = r2;
          r2 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2066; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
          L2066:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 5);
          r2 = varref (3, 0);
          r1[2] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (1, 3);
          r2[2] = r3;
          r3 = (object *) 3;
          r2[3] = r3;
          r3 = varref (6, 25);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2067; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
          L2067:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[3] = r2;
          r2 = varref (3, 2);
          r1[4] = r2;
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (0, 2);
          r2[2] = r3;
          // def lambda_18771_i1960_i4250_i4326
          goto L2068;
          FUN_lambda_18771_i1960_i4250_i4326:
            check_heap (0);
            r0 = varref (1, 3);
            r1 = varref (0, 0);
            t = alloc_no_clear (UOTAG(6),2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            PXLL_RETURN(0);
          L2068:
          r3 = allocate (TC_CLOSURE, 2);
          r3[1] = &&FUN_lambda_18771_i1960_i4250_i4326; r3[2] = lenv;
          r2[3] = r3;
          r3 = varref (4, 0);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2069; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
          L2069:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[5] = r2;
          r2 = varref (4, 1);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2070; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
          L2070:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r0 = varref (1, 2);
          r1 = varref (0, 4);
          r2 = varref (0, 5);
          r3 = varref (0, 0);
          t = alloc_no_clear (UOTAG(20),4);
          t[1] = r3;
          t[2] = r1;
          t[3] = r2;
          t[4] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          goto fatbar_59;
        }
        PXLL_RETURN(0);
        goto fatbar_59_over;
        fatbar_59:
        r0 = (object *) constructed_440[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_3031_i1966_i4250_i4326
          goto L2071;
          FUN_loop_3031_i1966_i4250_i4326:
            check_heap (0);
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (UITAG(0)): {
                r0 = (object*) &constructed_69;
                r0 = box(((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_69;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_438;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_438;
                r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                PXLL_RETURN(0);
              } break;
              case (UOTAG(1)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,1);
                r0[2] = r1;
                r0 = (object *) 3;
                r1 = varref (1, 0);
                r0 = box(unbox(r1)+unbox(r0));
                r1 = varref (0, 0);
                lenv = ((object *)lenv)[1];
                lenv[2] = r0;
                lenv[3] = r1;
                goto FUN_loop_3031_i1966_i4250_i4326;
              } break;
              case (UOTAG(2)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,2);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                lenv = ((object *)lenv)[1];
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN_loop_3031_i1966_i4250_i4326;
              } break;
              default: {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = varref (1, 0);
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(21),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          L2071:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_3031_i1966_i4250_i4326; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = varref (3, 2);
          r0[3] = r1;
          r1 = varref (0, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_3031_i1966_i4250_i4326;
        } else {
          goto fatbar_60;
        }
        PXLL_RETURN(0);
        goto fatbar_60_over;
        fatbar_60:
        r0 = allocate (TC_TUPLE, 6);
        r1 = varref (0, 3);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (0, 1);
        r0[4] = r1;
        r1 = varref (2, 2);
        r0[5] = r1;
        r1 = varref (0, 2);
        r0[6] = r1;
        r1 = varref (3, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_c_primargs_2694_i4250_i4326;
        fatbar_60_over: ;
        PXLL_RETURN(0);
        fatbar_59_over: ;
        PXLL_RETURN(0);
        fatbar_58_over: ;
        PXLL_RETURN(0);
        fatbar_56_over: ;
        PXLL_RETURN(0);
        fatbar_52_over: ;
        PXLL_RETURN(0);
        fatbar_51_over: ;
        PXLL_RETURN(0);
        fatbar_50_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(4)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = (object *) constructed_50[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (TC_TUPLE, 7);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = varref (3, 3);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = varref (6, 128);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2072; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
          L2072:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2073; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L2073:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 0);
          r1[2] = r2;
          r2 = (object *) 3;
          r1[3] = r2;
          r2 = varref (6, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2074; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L2074:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[6] = r1;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 2);
          r3 = varref (0, 0);
          r2[2] = r3;
          r3 = varref (6, 18);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2075; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_cdr_319;
          L2075:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = varref (6, 18);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2076; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
          L2076:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[7] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def finish_3008_i1971_i4250_i4326
          goto L2077;
          FUN_finish_3008_i1971_i4250_i4326:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 2);
            r1[2] = r2;
            // def lambda_18648_i1971_i4250_i4326
            goto L2078;
            FUN_lambda_18648_i1971_i4250_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (5, 1);
              r1[2] = r2;
              r2 = varref (11, 129);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2079; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_525;
              L2079:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r0 = varref (0, 0);
              r1 = varref (1, 0);
              t = alloc_no_clear (UOTAG(6),2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              PXLL_RETURN(0);
            L2078:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18648_i1971_i4250_i4326; r2[2] = lenv;
            r1[3] = r2;
            r2 = varref (7, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2080; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
            L2080:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_18658_i1971_i4250_i4326
            goto L2081;
            FUN_lambda_18658_i1971_i4250_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 5);
              r1 = varref (7, 0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (7, 2);
              r0[4] = r1;
              r1 = varref (1, 0);
              r0[5] = r1;
              r1 = varref (8, 1);
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
            L2081:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18658_i1971_i4250_i4326; r2[2] = lenv;
            r1[2] = r2;
            r2 = varref (3, 5);
            r1[3] = r2;
            r2 = varref (9, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2082; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L2082:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = varref (3, 4);
            r1 = ((pxll_vector*)r1)->val[4];
            r0[4] = r1;
            r1 = varref (0, 2);
            switch (get_case (r1)) {
              case (UOTAG(12)): {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (1, 2);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = (object *) constructed_442[0];
                r2 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = (object *) 6;
                  r1=r1;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_62;
                }
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                goto fatbar_62;
              }
            }
            r1=r1;
            goto fatbar_62_over;
            fatbar_62:
            r1 = (object *) 262;
            r1=r1;
            fatbar_62_over: ;
            r0[5] = r1;
            r1 = varref (0, 3);
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 5);
              r3 = varref (7, 0);
              r2[2] = r3;
              r3 = varref (4, 4);
              r2[3] = r3;
              r3 = varref (7, 2);
              r2[4] = r3;
              r3 = varref (1, 0);
              r2[5] = r3;
              r3 = varref (8, 1);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2083; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_compile_2675_i4250_i4326;
              L2083:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = varref (0, 0);
              t = alloc_no_clear (UOTAG(0),1);
              t[1] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            } else {
              r1 = (object*)UITAG(1);
              r1=r1;
            }
            r0[6] = r1;
            r0 = varref (0, 1);
            r1 = varref (3, 1);
            r2 = varref (4, 1);
            r3 = varref (4, 2);
            r4 = varref (0, 4);
            r5 = varref (1, 0);
            t = alloc_no_clear (UOTAG(23),6);
            t[1] = r5;
            t[2] = r2;
            t[3] = r3;
            t[4] = r0;
            t[5] = r4;
            t[6] = r1;
            r0 = t;
            PXLL_RETURN(0);
          L2077:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_finish_3008_i1971_i4250_i4326; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 5);
          r1 = (object *) 6;
          r0[2] = r1;
          r1 = varref (1, 3);
          r0[3] = r1;
          r1 = varref (4, 2);
          r0[4] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 2);
          r1[2] = r2;
          r2 = varref (0, 0);
          r1[3] = r2;
          r2 = varref (5, 0);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2084; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
          L2084:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[5] = r1;
          r1 = varref (5, 1);
          r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
        } else {
          goto fatbar_61;
        }
        PXLL_RETURN(0);
        goto fatbar_61_over;
        fatbar_61:
        r0 = allocate (TC_TUPLE, 5);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[2] = r1;
        r1 = varref (3, 3);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 1);
        r1[2] = r2;
        r2 = varref (6, 128);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2085; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
        L2085:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (5, 0);
        r2 = ((pxll_vector*)r2)->val[1];
        r1[2] = r2;
        r2 = varref (1, 0);
        r1[3] = r2;
        r2 = varref (6, 64);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2086; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
        L2086:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r0 = varref (0, 3);
        switch (get_case (r0)) {
          case (UITAG(1)): {
            r0 = allocate (TC_TUPLE, 3);
            r1 = (object*) &constructed_443;
            r0[2] = r1;
            r1 = varref (1, 0);
            r0[3] = r1;
            r1 = varref (6, 12);
            r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
          } break;
          default: {
            r0 = allocate (TC_TUPLE, 5);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 3);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = (object *) 1;
            r1[3] = r2;
            r2 = varref (7, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2087; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L2087:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = (object *) 3;
            r1[3] = r2;
            r2 = varref (7, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2088; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L2088:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (7, 18);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2089; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_cdr_319;
            L2089:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 18);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2090; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
            L2090:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            // def finish_2989_i1977_i4250_i4326
            goto L2091;
            FUN_finish_2989_i1977_i4250_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (4, 2);
              r1[2] = r2;
              // def lambda_18531_i1977_i4250_i4326
              goto L2092;
              FUN_lambda_18531_i1977_i4250_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (6, 1);
                r1[2] = r2;
                r2 = varref (12, 129);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2093; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_k_2ftarget_525;
                L2093:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (UOTAG(6),2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                PXLL_RETURN(0);
              L2092:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18531_i1977_i4250_i4326; r2[2] = lenv;
              r1[3] = r2;
              r2 = varref (8, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2094; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
              L2094:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 3);
              // def lambda_18541_i1977_i4250_i4326
              goto L2095;
              FUN_lambda_18541_i1977_i4250_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = varref (8, 0);
                r0[2] = r1;
                r1 = varref (0, 0);
                r0[3] = r1;
                r1 = varref (8, 2);
                r0[4] = r1;
                r1 = varref (1, 0);
                r0[5] = r1;
                r1 = varref (9, 1);
                r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
              L2095:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18541_i1977_i4250_i4326; r2[2] = lenv;
              r1[2] = r2;
              r2 = varref (3, 3);
              r1[3] = r2;
              r2 = varref (10, 30);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2096; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
              L2096:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = allocate (TC_TUPLE, 4);
              r1[1] = lenv; lenv = r1;
              r2 = varref (4, 0);
              r2 = ((pxll_vector*)r2)->val[3];
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2097; t[4] = r0; t[5] = r1; k = t;
              lenv = r2[2]; goto *r2[1];
              L2097:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (1, 1);
              r2[2] = r3;
              r3 = varref (11, 20);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2098; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
              L2098:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = varref (0, 1);
              r3 = varref (0, 0);
              r2 = PXLL_TEST(unbox(r3)==unbox(r2));
              r1[4] = r2;
              r1 = (object *) 6;
              r2 = varref (0, 2);
              r1 = PXLL_TEST(r2==r1);
              lenv = lenv[1];
              r1 = r1;
              if PXLL_IS_TRUE(r1) {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (4, 2);
                r2 = ((pxll_vector*)r2)->val[4];
                r1[2] = r2;
                r1 = varref (0, 0);
                switch (get_case (r1)) {
                  case (UOTAG(12)): {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = varref (1, 0);
                    r2 = UOBJ_GET(r2,0);
                    r1[2] = r2;
                    r1 = (object *) constructed_442[0];
                    r2 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object*) &constructed_444;
                      r1[2] = r2;
                      r2 = varref (7, 1);
                      r1[3] = r2;
                      r2 = varref (12, 12);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2099; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                      L2099:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r1=r1;
                    } else {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_63;
                    }
                    lenv = lenv[1];
                    r1 = r1;
                    r1=r1;
                  } break;
                  default: {
                    goto fatbar_63;
                  }
                }
                r1=r1;
                goto fatbar_63_over;
                fatbar_63:
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 5);
                r3 = varref (9, 0);
                r2[2] = r3;
                r3 = varref (5, 2);
                r2[3] = r3;
                r3 = varref (9, 2);
                r2[4] = r3;
                r3 = varref (2, 0);
                r2[5] = r3;
                r3 = varref (10, 1);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2100; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_compile_2675_i4250_i4326;
                L2100:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = varref (0, 0);
                t = alloc_no_clear (UOTAG(0),1);
                t[1] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
                fatbar_63_over: ;
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } else {
                r1 = (object*)UITAG(1);
                r1=r1;
              }
              r0[4] = r1;
              r0 = varref (0, 1);
              r1 = varref (4, 1);
              r2 = varref (5, 0);
              r3 = varref (5, 1);
              r4 = varref (0, 2);
              r5 = varref (1, 0);
              t = alloc_no_clear (UOTAG(22),6);
              t[1] = r5;
              t[2] = r2;
              t[3] = r3;
              t[4] = r0;
              t[5] = r4;
              t[6] = r1;
              r0 = t;
              PXLL_RETURN(0);
            L2091:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_finish_2989_i1977_i4250_i4326; r1[2] = lenv;
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 5);
            r1 = (object *) 6;
            r0[2] = r1;
            r1 = varref (1, 1);
            r0[3] = r1;
            r1 = varref (5, 2);
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 2);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (6, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2101; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
            L2101:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = varref (6, 1);
            r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
          } break;
        }
        PXLL_RETURN(0);
        fatbar_61_over: ;
        PXLL_RETURN(0);
      } break;
      case (UOTAG(10)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 6);
        r1 = varref (2, 0);
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (2, 1);
        r1 = ((pxll_vector*)r1)->val[3];
        r0[4] = r1;
        r1 = varref (2, 2);
        r0[5] = r1;
        r1 = varref (2, 3);
        r0[6] = r1;
        r1 = varref (3, 14);
        r0[1] = r1[2]; lenv = r0; goto FUN_c_let_splat_2702_i4250_i4326;
      } break;
      case (UOTAG(9)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (3, 1);
        r1 = ((pxll_vector*)r1)->val[0];
        r0[2] = r1;
        r0 = varref (6, 180);
        r1 = varref (0, 0);
        r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (6, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2102; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L2102:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = (object *) 11;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(unbox(r1)<unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            // def lambda_18074_i1985_i4250_i4326
            goto L2103;
            FUN_lambda_18074_i1985_i4250_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (7, 0);
              r1[2] = r2;
              r2 = varref (1, 0);
              r1[3] = r2;
              r2 = varref (8, 3);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2104; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_vars_get_var_255;
              L2104:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[1];
              r0[3] = r1;
              r0 = varref (8, 143);
              r1 = varref (0, 1);
              r0 = PXLL_TEST((unbox(r1)&(1<<unbox(r0)))>0);
              PXLL_RETURN(0);
            L2103:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_lambda_18074_i1985_i4250_i4326; r2[2] = lenv;
            r1[2] = r2;
            r2 = varref (1, 0);
            r1[3] = r2;
            r2 = varref (6, 37);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2105; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_some_question_342;
            L2105:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = (object *) 6;
            r1 = varref (0, 0);
            r0 = PXLL_TEST(r1==r0);
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } else {
            r0 = (object *) 6;
            r0=r0;
          }
          r0=r0;
        } else {
          r0 = (object *) 6;
          r0=r0;
        }
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (3, 1);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[2] = r1;
          r1 = varref (3, 3);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def loop_2958_i1990_i4250_i4326
          goto L2106;
          FUN_loop_2958_i1990_i4250_i4326:
            check_heap (0);
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (9, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2107; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L2107:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (0, 0);
            r1 = (object *) 1;
            r0 = PXLL_TEST(unbox(r1)==unbox(r0));
            lenv = lenv[1];
            r0 = r0;
            if PXLL_IS_TRUE(r0) {
              r0 = allocate (TC_TUPLE, 5);
              r1 = varref (5, 0);
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (0, 1);
              r1[2] = r2;
              r2 = varref (8, 17);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2108; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
              L2108:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = varref (0, 2);
              r0[4] = r1;
              r1 = varref (2, 1);
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 5);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,2);
                  r1[4] = r2;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = allocate (TC_TUPLE, 3);
                  r4 = varref (0, 1);
                  r3[2] = r4;
                  r4 = (object *) constructed_37[0];
                  r3[3] = r4;
                  r4 = varref (9, 19);
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L2109; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
                  L2109:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r3 = varref (1, 3);
                  r2[3] = r3;
                  r3 = varref (9, 19);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2110; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
                  L2110:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[5] = r2;
                  r1 = varref (0, 3);
                  r2 = varref (0, 2);
                  r3 = varref (0, 0);
                  t = alloc_no_clear (UOTAG(0),3);
                  t[1] = r3;
                  t[2] = r1;
                  t[3] = r2;
                  r1 = t;
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  r1 = (object*) &constructed_69;
                  r1 = box(((pxll_string*)(r1))->len);
                  r2 = (object*) &constructed_69;
                  (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
                  r1 = (object*) &constructed_446;
                  dump_object (r1, 0); fprintf (stdout, "\n");
                  r1 = (object*) &constructed_446;
                  r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
                  r1=r1;
                } break;
              }
              r0[5] = r1;
              r1 = varref (6, 1);
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
            } else {
              r0 = allocate (TC_TUPLE, 5);
              r1 = (object *) 6;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (0, 1);
              r1[2] = r2;
              r2 = varref (8, 17);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2111; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
              L2111:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = varref (0, 2);
              r0[4] = r1;
              r1 = allocate (TC_TUPLE, 3);
              r2 = allocate (TC_TUPLE, 2);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (3, 1);
              r3[2] = r4;
              r4 = varref (9, 128);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2112; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_524;
              L2112:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r2 = allocate (TC_TUPLE, 3);
              r3 = allocate (TC_TUPLE, 3);
              r4 = varref (1, 3);
              r3[2] = r4;
              r4 = (object *) constructed_37[0];
              r3[3] = r4;
              r4 = varref (9, 19);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2113; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
              L2113:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = varref (0, 0);
              r2[3] = r3;
              r3 = varref (9, 19);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2114; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
              L2114:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              // def lambda_18402_i1990_i4250_i4326
              goto L2115;
              FUN_lambda_18402_i1990_i4250_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 5);
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (1, 0);
                r1[2] = r2;
                r2 = varref (9, 18);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2116; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
                L2116:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = varref (1, 1);
                r1[2] = r2;
                r2 = varref (9, 18);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2117; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
                L2117:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (2, 0);
                r2[2] = r3;
                r3 = varref (10, 17);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2118; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_car_318;
                L2118:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = varref (1, 0);
                r2 = varref (2, 2);
                r3 = varref (0, 0);
                t = alloc_no_clear (UOTAG(2),3);
                t[1] = r3;
                t[2] = r1;
                t[3] = r2;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[4] = r1;
                r1 = varref (1, 3);
                r2 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                r0[5] = r1;
                r1 = varref (2, 0);
                r0[1] = r1[2]; lenv = r0; goto FUN_loop_2958_i1990_i4250_i4326;
              L2115:
              r2 = allocate (TC_CLOSURE, 2);
              r2[1] = &&FUN_lambda_18402_i1990_i4250_i4326; r2[2] = lenv;
              r1[3] = r2;
              r2 = varref (6, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2119; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
              L2119:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[5] = r1;
              r1 = varref (6, 1);
              r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
            }
            PXLL_RETURN(0);
          L2106:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN_loop_2958_i1990_i4250_i4326; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 5);
          r1 = varref (2, 0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r0[3] = r1;
          r1 = varref (4, 2);
          r0[4] = r1;
          r1 = (object *) constructed_445[0];
          r0[5] = r1;
          r1 = varref (0, 0);
          r0[1] = r1[2]; lenv = r0; goto FUN_loop_2958_i1990_i4250_i4326;
        } else {
          r0 = allocate (TC_TUPLE, 6);
          r1 = varref (2, 0);
          r0[2] = r1;
          r1 = varref (0, 0);
          r0[3] = r1;
          r1 = varref (2, 1);
          r1 = ((pxll_vector*)r1)->val[3];
          r0[4] = r1;
          r1 = varref (2, 2);
          r0[5] = r1;
          r1 = varref (2, 3);
          r0[6] = r1;
          r1 = varref (3, 14);
          r0[1] = r1[2]; lenv = r0; goto FUN_c_let_splat_2702_i4250_i4326;
        }
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_68;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_68;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L1966:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_compile_2675_i4250_i4326; r2[2] = lenv;
  r1[3] = r2;
  // def add-literal_2676_i4250_i4326
  goto L2120;
  FUN_add_literal_2676_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (3, 0);
    r2 = ((pxll_vector*)r2)->val[6];
    r1[2] = r2;
    r2 = varref (4, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2121; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L2121:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (4, 0);
    r1 = ((pxll_vector*)r1)->val[6];
    r0[2] = r1;
    r0 = varref (0, 0);
    r1 = varref (2, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    lenv = lenv[1];
    r0 = r0;
    r1 = varref (3, 0);
    ((pxll_vector*)r1)->val[6] = r0;
    r0 = varref (0, 0);
    PXLL_RETURN(0);
  L2120:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_add_literal_2676_i4250_i4326; r2[2] = lenv;
  r1[4] = r2;
  // def get-literal-index_2677_i4250_i4326
  goto L2122;
  FUN_get_literal_index_2677_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 4);
    r2 = varref (3, 0);
    r2 = ((pxll_vector*)r2)->val[5];
    r1[2] = r2;
    r2 = varref (4, 9);
    r1[3] = r2;
    r2 = varref (1, 1);
    r1[4] = r2;
    r2 = varref (4, 70);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2123; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_tree_2fmember_415;
    L2123:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2124; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2676_i4250_i4326;
        L2124:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = varref (4, 0);
        r1 = ((pxll_vector*)r1)->val[5];
        r0[2] = r1;
        r1 = varref (5, 9);
        r0[3] = r1;
        r1 = varref (2, 1);
        r0[4] = r1;
        r1 = varref (0, 0);
        r0[5] = r1;
        r1 = varref (5, 69);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2125; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_tree_2finsert_414;
        L2125:
        ; lenv = k[2]; k = k[1];
        r0 = result;
        r1 = varref (4, 0);
        ((pxll_vector*)r1)->val[5] = r0;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2122:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_literal_index_2677_i4250_i4326; r2[2] = lenv;
  r1[5] = r2;
  // def get-symbol-index_2678_i4250_i4326
  goto L2126;
  FUN_get_symbol_index_2678_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (3, 0);
    r2 = ((pxll_vector*)r2)->val[12];
    r1[2] = r2;
    r2 = varref (1, 0);
    r1[3] = r2;
    r2 = varref (4, 64);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2127; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
    L2127:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (UOTAG(0)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r0 = varref (0, 0);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = varref (3, 0);
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        r4 = varref (4, 0);
        r4 = UOBJ_GET(r4,0);
        r3[2] = r4;
        r3 = varref (0, 0);
        lenv = lenv[1];
        r3 = r3;
        r3=r3;
        r2[2] = r3;
        r2 = varref (0, 0);
        t = alloc_no_clear (UOTAG(0),1);
        t[1] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2128; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2676_i4250_i4326;
        L2128:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (2, 0);
        t = alloc_no_clear (UOTAG(4),1);
        t[1] = r2;
        r2 = t;
        r1[2] = r2;
        r2 = varref (3, 2);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2129; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_add_literal_2676_i4250_i4326;
        L2129:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (5, 0);
        r1 = ((pxll_vector*)r1)->val[12];
        r0[2] = r1;
        r0 = varref (1, 1);
        r1 = varref (0, 0);
        r2 = varref (3, 0);
        t = alloc_no_clear (UOTAG(1),3);
        t[1] = r2;
        t[2] = r0;
        t[3] = r1;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = varref (4, 0);
        ((pxll_vector*)r1)->val[12] = r0;
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2126:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_get_symbol_index_2678_i4250_i4326; r2[2] = lenv;
  r1[6] = r2;
  // def scan-literals_2679_i4250_i4326
  goto L2130;
  FUN_scan_literals_2679_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object *) 1;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (3, 4);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2131; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_get_symbol_index_2678_i4250_i4326;
            L2131:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (3, 2);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2132; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_add_literal_2676_i4250_i4326;
            L2132:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (3, 5);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2133; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2679_i4250_i4326;
            L2133:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = varref (0, 0);
            r0[2] = r1;
            r1 = varref (3, 5);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2134; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_scan_literals_2679_i4250_i4326;
            L2134:
            ; lenv = k[2]; k = k[1];
            r0 = result;
            lenv = lenv[1];
            r0 = r0;
            r0=r0;
          } break;
          default: {
            goto fatbar_41;
          }
        }
        goto fatbar_41_over;
        fatbar_41:
        r0 = (object *) 1;
        fatbar_41_over: ;
        r0 = varref (0, 1);
        lenv = ((object *)lenv)[1];
        lenv[2] = r0;
        goto FUN_scan_literals_2679_i4250_i4326;
      } break;
    }
    PXLL_RETURN(0);
  L2130:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_scan_literals_2679_i4250_i4326; r2[2] = lenv;
  r1[7] = r2;
  // def c-sequence_2681_i4250_i4326
  goto L2135;
  FUN_c_sequence_2681_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 1);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*) &constructed_69;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_69;
        (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
        r0 = (object*) &constructed_411;
        dump_object (r0, 0); fprintf (stdout, "\n");
        r0 = (object*) &constructed_411;
        r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 1);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 1);
        switch (get_case (r0)) {
          case (TC_NIL): {
            r0 = allocate (TC_TUPLE, 5);
            r1 = varref (1, 0);
            r0[2] = r1;
            r1 = varref (0, 0);
            r0[3] = r1;
            r1 = varref (1, 2);
            r0[4] = r1;
            r1 = varref (1, 3);
            r0[5] = r1;
            r1 = varref (2, 1);
            r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
          } break;
          default: {
            goto fatbar_40;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_40_over;
        fatbar_40:
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (1, 2);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (2, 3);
        r2[2] = r3;
        r3 = varref (5, 128);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2136; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_k_2ffree_524;
        L2136:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 5);
        r3 = varref (2, 0);
        r2[2] = r3;
        r3 = varref (1, 1);
        r2[3] = r3;
        r3 = varref (2, 2);
        r2[4] = r3;
        r3 = varref (2, 3);
        r2[5] = r3;
        r3 = varref (3, 6);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2137; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_c_sequence_2681_i4250_i4326;
        L2137:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r1 = varref (0, 0);
        r2 = varref (0, 1);
        r3 = (object *) -1;
        t = alloc_no_clear (UOTAG(0),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[5] = r1;
        r1 = varref (2, 1);
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
        fatbar_40_over: ;
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2135:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_sequence_2681_i4250_i4326; r2[2] = lenv;
  r1[8] = r2;
  // def extend-lenv_2684_i4250_i4326
  goto L2138;
  FUN_extend_lenv_2684_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = varref (0, 1);
        PXLL_RETURN(0);
      } break;
      default: {
        goto fatbar_39;
      }
    }
    PXLL_RETURN(0);
    goto fatbar_39_over;
    fatbar_39:
    r0 = varref (0, 1);
    r1 = varref (0, 0);
    t = alloc_no_clear (UOTAG(1),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
    fatbar_39_over: ;
    PXLL_RETURN(0);
  L2138:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_extend_lenv_2684_i4250_i4326; r2[2] = lenv;
  r1[9] = r2;
  // def search-rib_2686_i4250_i4326
  goto L2139;
  FUN_search_rib_2686_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 2);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = (object*)UITAG(1);
        PXLL_RETURN(0);
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = varref (1, 1);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) 3;
          r1 = varref (1, 1);
          r0 = box(unbox(r1)+unbox(r0));
          r1 = varref (0, 1);
          r2 = varref (1, 0);
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_search_rib_2686_i4250_i4326;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2139:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_search_rib_2686_i4250_i4326; r2[2] = lenv;
  r1[10] = r2;
  // def lexical-address_2687_i4250_i4326
  goto L2140;
  FUN_lexical_address_2687_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 2);
    switch (get_case (r0)) {
      case (UITAG(0)): {
        r0 = allocate (TC_TUPLE, 3);
        r1 = (object*) &constructed_410;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (3, 12);
        r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
      } break;
      case (UOTAG(1)): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 4);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = (object *) 1;
        r1[3] = r2;
        r2 = varref (0, 0);
        r1[4] = r2;
        r2 = varref (2, 8);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2141; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_search_rib_2686_i4250_i4326;
        L2141:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[4] = r1;
        r0 = varref (0, 2);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 2);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r0 = allocate (UOTAG(0), 2);
            r1 = varref (2, 1);
            r0[1] = r1;
            r1 = varref (0, 0);
            r0[2] = r1;
            PXLL_RETURN(0);
          } break;
          default: {
            r0 = (object *) 3;
            r1 = varref (1, 1);
            r0 = box(unbox(r1)+unbox(r0));
            r1 = varref (0, 1);
            r2 = varref (1, 0);
            lenv = ((object *)lenv)[1];
            lenv[2] = r2;
            lenv[3] = r0;
            lenv[4] = r1;
            goto FUN_lexical_address_2687_i4250_i4326;
          } break;
        }
        PXLL_RETURN(0);
      } break;
      case (UOTAG(3)): {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,1);
        r0[2] = r1;
        r0 = varref (1, 1);
        r1 = varref (0, 0);
        r2 = varref (1, 0);
        lenv = ((object *)lenv)[1];
        lenv[2] = r2;
        lenv[3] = r0;
        lenv[4] = r1;
        goto FUN_lexical_address_2687_i4250_i4326;
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r1 = varref (1, 2);
        r1 = UOBJ_GET(r1,2);
        r0[4] = r1;
        r0 = varref (0, 0);
        r1 = varref (1, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = allocate (UOTAG(6), 1);
          r1 = varref (0, 1);
          r0[1] = r1;
          PXLL_RETURN(0);
        } else {
          r0 = varref (1, 1);
          r1 = varref (0, 2);
          r2 = varref (1, 0);
          lenv = ((object *)lenv)[1];
          lenv[2] = r2;
          lenv[3] = r0;
          lenv[4] = r1;
          goto FUN_lexical_address_2687_i4250_i4326;
        }
        PXLL_RETURN(0);
      } break;
    }
    PXLL_RETURN(0);
  L2140:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_lexical_address_2687_i4250_i4326; r2[2] = lenv;
  r1[11] = r2;
  // def collect-primargs_2692_i4250_i4326
  goto L2142;
  FUN_collect_primargs_2692_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 6);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (4, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2143; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L2143:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r1[1] = lenv; lenv = r1;
    // def $loop_2877_i4250_i4326
    goto L2144;
    FUN__24loop_2877_i4250_i4326:
      check_heap (0);
      r0 = varref (2, 0);
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
        r0 = allocate (TC_TUPLE, 3);
        r1 = varref (0, 1);
        r0[2] = r1;
        r1 = (object *) constructed_37[0];
        r0[3] = r1;
        r1 = varref (6, 19);
        r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
      } else {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (UOTAG(0), 2);
        r2 = allocate (TC_TUPLE, 3);
        r3 = varref (4, 0);
        r2[2] = r3;
        r3 = varref (1, 0);
        r2[3] = r3;
        r3 = varref (7, 25);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2145; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
        L2145:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[1] = r2;
        r2 = varref (1, 0);
        r1[2] = r2;
        r0[2] = r1;
        r0 = varref (1, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        r1 = (object *) 3;
        r2 = varref (0, 0);
        r1 = box(unbox(r2)+unbox(r1));
        lenv[2] = r1;
        lenv[3] = r0;
        goto FUN__24loop_2877_i4250_i4326;
      }
      PXLL_RETURN(0);
    L2144:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN__24loop_2877_i4250_i4326; r2[2] = lenv;
    r1[2] = r2;
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object *) 1;
    r1[2] = r2;
    r2 = (object*)TC_NIL;
    r1[3] = r2;
    r2 = varref (0, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2146; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2877_i4250_i4326;
    L2146:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    lenv = lenv[1];
    r1 = r1;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 3);
    // def lambda_17933_i4250_i4326
    goto L2147;
    FUN_lambda_17933_i4250_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r0 = varref (1, 1);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = varref (2, 1);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = ((pxll_vector*)r1)->val[2];
              r0[3] = r1;
              r1 = varref (0, 0);
              r1 = ((pxll_vector*)r1)->val[2];
              r0[4] = r1;
              r0 = varref (0, 2);
              r1 = varref (0, 1);
              r0 = PXLL_TEST(unbox(r1)>unbox(r0));
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L2147:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_17933_i4250_i4326; r2[2] = lenv;
    r1[2] = r2;
    r2 = varref (0, 1);
    r1[3] = r2;
    r2 = varref (4, 42);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2148; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_sort_350;
    L2148:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (4, 16);
    r1[2] = r2;
    r2 = varref (0, 2);
    r1[3] = r2;
    r2 = varref (4, 30);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2149; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
    L2149:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (4, 15);
    r1[2] = r2;
    r2 = varref (0, 2);
    r1[3] = r2;
    r2 = varref (4, 30);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2150; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
    L2150:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r0 = allocate (TC_TUPLE, 7);
    r1 = varref (0, 4);
    r0[2] = r1;
    r1 = (object *) constructed_409[0];
    r0[3] = r1;
    r1 = varref (0, 3);
    r0[4] = r1;
    r1 = varref (1, 1);
    r0[5] = r1;
    r1 = varref (1, 2);
    r0[6] = r1;
    r1 = varref (1, 3);
    r0[7] = r1;
    r1 = varref (2, 11);
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_splat_2693_i4250_i4326;
  L2142:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_collect_primargs_2692_i4250_i4326; r2[2] = lenv;
  r1[12] = r2;
  // def collect-primargs*_2693_i4250_i4326
  goto L2151;
  FUN_collect_primargs_splat_2693_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    switch (get_case (r0)) {
      case (TC_NIL): {
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 1);
        r1[2] = r2;
        r2 = (object *) constructed_37[0];
        r1[3] = r2;
        r2 = varref (4, 19);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2152; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
        L2152:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (1, 2);
        r1[2] = r2;
        r2 = varref (4, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2153; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L2153:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        // def $loop_2896_i4250_i4326
        goto L2154;
        FUN__24loop_2896_i4250_i4326:
          check_heap (0);
          r0 = varref (2, 1);
          r1 = varref (0, 0);
          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
            r0 = allocate (TC_TUPLE, 3);
            r1 = varref (0, 1);
            r0[2] = r1;
            r1 = (object *) constructed_37[0];
            r0[3] = r1;
            r1 = varref (6, 19);
            r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 0);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (4, 2);
            r2[3] = r3;
            r3 = varref (7, 26);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2155; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_index_eq_331;
            L2155:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = varref (7, 25);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2156; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
            L2156:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r0 = varref (1, 1);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = varref (0, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN__24loop_2896_i4250_i4326;
          }
          PXLL_RETURN(0);
        L2154:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN__24loop_2896_i4250_i4326; r2[2] = lenv;
        r1[2] = r2;
        r1 = allocate (TC_TUPLE, 3);
        r2 = (object *) 1;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2157; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_2896_i4250_i4326;
        L2157:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        lenv = lenv[1];
        r1 = r1;
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r1 = varref (0, 2);
        r0[2] = r1;
        r1 = varref (1, 5);
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      } break;
      default: {
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,0);
        r0[2] = r1;
        r1 = varref (1, 0);
        r1 = UOBJ_GET(r1,1);
        r0[3] = r1;
        r0 = allocate (TC_TUPLE, 5);
        r1 = (object *) 6;
        r0[2] = r1;
        r1 = varref (0, 0);
        r0[3] = r1;
        r1 = varref (1, 3);
        r0[4] = r1;
        r1 = allocate (TC_TUPLE, 3);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (2, 4);
        r3[2] = r4;
        r4 = varref (5, 128);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2158; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_524;
        L2158:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = allocate (TC_TUPLE, 3);
        r4 = varref (0, 0);
        r3[2] = r4;
        r4 = (object *) constructed_37[0];
        r3[3] = r4;
        r4 = varref (5, 19);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2159; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_reverse_onto_320;
        L2159:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = varref (2, 1);
        r2[3] = r3;
        r3 = varref (5, 19);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2160; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
        L2160:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        // def lambda_18030_i4250_i4326
        goto L2161;
        FUN_lambda_18030_i4250_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 7);
          r1 = varref (1, 1);
          r0[2] = r1;
          r1 = varref (2, 1);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[3] = r1;
          r1 = varref (2, 2);
          r0[4] = r1;
          r1 = varref (2, 3);
          r0[5] = r1;
          r1 = varref (2, 4);
          r0[6] = r1;
          r1 = varref (2, 5);
          r0[7] = r1;
          r1 = varref (3, 11);
          r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_splat_2693_i4250_i4326;
        L2161:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_18030_i4250_i4326; r2[2] = lenv;
        r1[3] = r2;
        r2 = varref (2, 0);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2162; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
        L2162:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[5] = r1;
        r1 = varref (2, 1);
        r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
      } break;
    }
    PXLL_RETURN(0);
  L2151:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_collect_primargs_splat_2693_i4250_i4326; r2[2] = lenv;
  r1[13] = r2;
  // def c-primargs_2694_i4250_i4326
  goto L2163;
  FUN_c_primargs_2694_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = varref (0, 0);
    r0[2] = r1;
    r1 = varref (0, 3);
    r0[3] = r1;
    r1 = varref (0, 4);
    r0[4] = r1;
    // def lambda_18052_i4250_i4326
    goto L2164;
    FUN_lambda_18052_i4250_i4326:
      check_heap (0);
      r0 = varref (1, 4);
      r1 = varref (1, 2);
      r2 = varref (0, 0);
      r3 = varref (1, 1);
      t = alloc_no_clear (UOTAG(18),4);
      t[1] = r3;
      t[2] = r1;
      t[3] = r2;
      t[4] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2164:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_18052_i4250_i4326; r1[2] = lenv;
    r0[5] = r1;
    r1 = varref (1, 10);
    r0[1] = r1[2]; lenv = r0; goto FUN_collect_primargs_2692_i4250_i4326;
  L2163:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_primargs_2694_i4250_i4326; r2[2] = lenv;
  r1[14] = r2;
  // def compile-store-args_2700_i4250_i4326
  goto L2165;
  FUN_compile_store_args_2700_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 5);
    r1 = (object *) 6;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 2);
    r1[2] = r2;
    r2 = varref (3, 17);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2166; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
    L2166:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (0, 5);
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (0, 4);
    r1[2] = r2;
    // def lambda_18347_i4250_i4326
    goto L2167;
    FUN_lambda_18347_i4250_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (3, 2);
      r2[2] = r3;
      r3 = varref (6, 18);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2168; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_cdr_319;
      L2168:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = varref (0, 0);
      switch (get_case (r1)) {
        case (TC_NIL): {
          r1 = (object *) 262;
          r1=r1;
        } break;
        default: {
          goto fatbar_38;
        }
      }
      r1=r1;
      goto fatbar_38_over;
      fatbar_38:
      r1 = (object *) 6;
      r1=r1;
      fatbar_38_over: ;
      lenv = lenv[1];
      r1 = r1;
      if PXLL_IS_TRUE(r1) {
        r1 = varref (2, 6);
        r1=r1;
      } else {
        r1 = allocate (TC_TUPLE, 2);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 8);
        r3 = (object *) 3;
        r4 = varref (3, 0);
        r3 = box(unbox(r4)+unbox(r3));
        r2[2] = r3;
        r3 = varref (3, 1);
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (3, 2);
        r3[2] = r4;
        r4 = varref (6, 18);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2169; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_cdr_319;
        L2169:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = varref (3, 3);
        r2[5] = r3;
        r3 = varref (3, 4);
        r2[6] = r3;
        r3 = varref (3, 5);
        r2[7] = r3;
        r3 = varref (3, 6);
        r2[8] = r3;
        r3 = varref (4, 13);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2170; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_compile_store_args_2700_i4250_i4326;
        L2170:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r1 = varref (3, 4);
        r2 = varref (0, 0);
        r3 = (object *) -1;
        t = alloc_no_clear (UOTAG(0),3);
        t[1] = r3;
        t[2] = r1;
        t[3] = r2;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r1=r1;
      }
      r0[2] = r1;
      r0 = varref (2, 0);
      r1 = varref (1, 0);
      r2 = varref (2, 3);
      r3 = varref (0, 0);
      r4 = varref (2, 1);
      t = alloc_no_clear (UOTAG(12),5);
      t[1] = r4;
      t[2] = r1;
      t[3] = r2;
      t[4] = r0;
      t[5] = r3;
      r0 = t;
      PXLL_RETURN(0);
    L2167:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18347_i4250_i4326; r2[2] = lenv;
    r1[3] = r2;
    r2 = varref (1, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2171; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
    L2171:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = varref (1, 1);
    r0[1] = r1[2]; lenv = r0; goto FUN_compile_2675_i4250_i4326;
  L2165:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_compile_store_args_2700_i4250_i4326; r2[2] = lenv;
  r1[15] = r2;
  // def c-let-splat_2702_i4250_i4326
  goto L2172;
  FUN_c_let_splat_2702_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 9);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 2);
    r1[2] = r2;
    r2 = (object *) constructed_37[0];
    r1[3] = r2;
    r2 = varref (4, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2173; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L2173:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (4, 17);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2174; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
    L2174:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (0, 0);
    r1[2] = r2;
    r2 = varref (4, 18);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2175; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cdr_319;
    L2175:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[4] = r1;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (0, 2);
    r1[2] = r2;
    r2 = (object *) constructed_37[0];
    r1[3] = r2;
    r2 = varref (4, 19);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2176; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
    L2176:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[5] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 1);
    r1[2] = r2;
    r2 = varref (4, 20);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2177; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
    L2177:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[6] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (1, 4);
    r1[2] = r2;
    r2 = varref (4, 128);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2178; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_k_2ffree_524;
    L2178:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[7] = r1;
    r1 = allocate (TC_TUPLE, 5);
    r2 = varref (1, 0);
    r1[2] = r2;
    r2 = varref (0, 1);
    r1[3] = r2;
    r2 = varref (1, 1);
    switch (get_case (r2)) {
      case (TC_NIL): {
        r2 = varref (1, 3);
        r2=r2;
      } break;
      default: {
        goto fatbar_37;
      }
    }
    r2=r2;
    goto fatbar_37_over;
    fatbar_37:
    r2 = varref (1, 3);
    r3 = varref (1, 1);
    t = alloc_no_clear (UOTAG(1),2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    r2=r2;
    fatbar_37_over: ;
    r1[4] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (1, 4);
    r3[2] = r4;
    r4 = varref (4, 128);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L2179; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_524;
    L2179:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    // def lambda_18453_i4250_i4326
    goto L2180;
    FUN_lambda_18453_i4250_i4326:
      check_heap (0);
      r0 = varref (2, 4);
      r1 = varref (0, 0);
      t = alloc_no_clear (UOTAG(17),2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2180:
    r3 = allocate (TC_CLOSURE, 2);
    r3[1] = &&FUN_lambda_18453_i4250_i4326; r3[2] = lenv;
    r2[3] = r3;
    r3 = varref (2, 0);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2181; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
    L2181:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[5] = r2;
    r2 = varref (2, 1);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2182; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
    L2182:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[8] = r1;
    r1 = varref (0, 5);
    r2 = varref (0, 6);
    r3 = (object *) -1;
    t = alloc_no_clear (UOTAG(0),3);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    r1 = t;
    r0[9] = r1;
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (3, 0);
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (3, 29);
    r1[2] = r2;
    r2 = varref (4, 17);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2183; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
    L2183:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (4, 145);
    r0[4] = r1;
    r1 = varref (4, 4);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2184; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
    L2184:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 3);
    r2 = varref (1, 5);
    r1[2] = r2;
    // def lambda_18486_i4250_i4326
    goto L2185;
    FUN_lambda_18486_i4250_i4326:
      check_heap (0);
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = allocate (TC_TUPLE, 8);
      r2 = (object *) 1;
      r1[2] = r2;
      r2 = (object *) 3;
      r1[3] = r2;
      r2 = varref (3, 3);
      r1[4] = r2;
      r2 = varref (1, 0);
      r1[5] = r2;
      r2 = varref (3, 5);
      r3 = varref (1, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      r1[6] = r2;
      r2 = varref (4, 1);
      switch (get_case (r2)) {
        case (TC_NIL): {
          r2 = varref (4, 3);
          r2=r2;
        } break;
        default: {
          goto fatbar_36;
        }
      }
      r2=r2;
      goto fatbar_36_over;
      fatbar_36:
      r2 = varref (4, 3);
      r3 = varref (4, 1);
      t = alloc_no_clear (UOTAG(1),2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      r2=r2;
      fatbar_36_over: ;
      r1[7] = r2;
      r2 = varref (3, 7);
      r1[8] = r2;
      r2 = varref (5, 13);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2186; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_compile_store_args_2700_i4250_i4326;
      L2186:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (3, 5);
      r2 = varref (0, 0);
      r3 = (object *) -1;
      t = alloc_no_clear (UOTAG(0),3);
      t[1] = r3;
      t[2] = r1;
      t[3] = r2;
      r1 = t;
      r0[3] = r1;
      r0 = varref (0, 1);
      r1 = varref (1, 0);
      t = alloc_no_clear (UOTAG(16),2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      PXLL_RETURN(0);
    L2185:
    r2 = allocate (TC_CLOSURE, 2);
    r2[1] = &&FUN_lambda_18486_i4250_i4326; r2[2] = lenv;
    r1[3] = r2;
    r2 = varref (3, 0);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2187; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_cont_2673_i4250_i4326;
    L2187:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    r1 = varref (1, 4);
    t = alloc_no_clear (UOTAG(10),2);
    t[1] = r1;
    t[2] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2172:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_c_let_splat_2702_i4250_i4326; r2[2] = lenv;
  r1[16] = r2;
  // def record-label-tag_2710_i4250_i4326
  goto L2188;
  FUN_record_label_tag_2710_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_3080_i4250_i4326
    goto L2189;
    FUN_loop_3080_i4250_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case (r0)) {
        case (TC_PAIR): {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = varref (0, 0);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = varref (4, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = varref (1, 1);
                lenv = ((object **)lenv)[1][1];
                lenv[2] = r0;
                goto FUN_loop_3080_i4250_i4326;
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        } break;
        default: {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (5, 0);
          r2 = ((pxll_vector*)r2)->val[4];
          r1[2] = r2;
          r2 = varref (6, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2190; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L2190:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (UOTAG(0), 2);
          r2 = varref (4, 0);
          r1[1] = r2;
          r2 = varref (1, 0);
          r1[2] = r2;
          r0[2] = r1;
          r1 = varref (6, 0);
          r1 = ((pxll_vector*)r1)->val[4];
          r0[3] = r1;
          r0 = varref (0, 1);
          r1 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r1;
          t[2] = r0;
          r0 = t;
          lenv = lenv[1];
          r0 = r0;
          r1 = varref (5, 0);
          ((pxll_vector*)r1)->val[4] = r0;
          PXLL_RETURN(0);
        } break;
      }
      PXLL_RETURN(0);
    L2189:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_3080_i4250_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (3, 0);
    r1 = ((pxll_vector*)r1)->val[4];
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_3080_i4250_i4326;
  L2188:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_record_label_tag_2710_i4250_i4326; r2[2] = lenv;
  r1[17] = r2;
  // def gen-return_2713_i4250_i4326
  goto L2191;
  FUN_gen_return_2713_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 0);
    t = alloc_no_clear (UOTAG(0),1);
    t[1] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2191:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_return_2713_i4250_i4326; r2[2] = lenv;
  r1[18] = r2;
  // def gen-invoke_2714_i4250_i4326
  goto L2192;
  FUN_gen_invoke_2714_i4250_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 4);
    r1 = varref (2, 0);
    r0[2] = r1;
    r1 = allocate (TC_TUPLE, 2);
    r2 = varref (2, 29);
    r1[2] = r2;
    r2 = varref (3, 17);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2193; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_car_318;
    L2193:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[3] = r1;
    r1 = varref (3, 145);
    r0[4] = r1;
    r1 = varref (3, 4);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2194; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_vars_set_flag_bang_257;
    L2194:
    ; lenv = k[2]; k = k[1];
    r0 = varref (0, 3);
    r1 = varref (0, 1);
    r2 = varref (0, 2);
    r3 = varref (0, 0);
    t = alloc_no_clear (UOTAG(13),4);
    t[1] = r3;
    t[2] = r1;
    t[3] = r2;
    t[4] = r0;
    r0 = t;
    PXLL_RETURN(0);
  L2192:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_invoke_2714_i4250_i4326; r2[2] = lenv;
  r1[19] = r2;
  // def gen-tail_2715_i4250_i4326
  goto L2195;
  FUN_gen_tail_2715_i4250_i4326:
    check_heap (0);
    r0 = varref (0, 1);
    r1 = varref (0, 2);
    r2 = varref (0, 0);
    t = alloc_no_clear (UOTAG(14),3);
    t[1] = r2;
    t[2] = r0;
    t[3] = r1;
    r0 = t;
    PXLL_RETURN(0);
  L2195:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_gen_tail_2715_i4250_i4326; r2[2] = lenv;
  r1[20] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = (object *) 1;
  r2[2] = r3;
  r3 = varref (2, 105);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2196; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_make_counter_474;
  L2196:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[21] = r2;
  r1 = allocate (TC_TUPLE, 5);
  r2 = (object *) 262;
  r1[2] = r2;
  r2 = varref (1, 18);
  r1[3] = r2;
  r2 = (object*)UITAG(0);
  r1[4] = r2;
  r2 = allocate (TC_TUPLE, 3);
  r3 = (object *) constructed_408[0];
  r2[2] = r3;
  r3 = varref (0, 16);
  r2[3] = r3;
  r3 = varref (0, 0);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2197; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_cont_2673_i4250_i4326;
  L2197:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[5] = r2;
  r2 = varref (0, 1);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2198; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_compile_2675_i4250_i4326;
  L2198:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[32] = r1;
  r1 = allocate (UOTAG(2), 3);
  r2 = (object *) 32769;
  r2 = box(string_tuple_length (unbox(r2)));
  ensure_heap (2, unbox(r2));
  r2 = (object *) 32769;
  r2 = (t=alloc_no_clear (TC_STRING, string_tuple_length (unbox(r2))), ((pxll_string*)(t))->len = unbox(r2), t);
  r1[1] = r2;
  r2 = allocate (TC_TUPLE, 4);
  r3 = varref (0, 6);
  r2[2] = r3;
  r3 = allocate (TC_TUPLE, 2);
  r3[1] = lenv; lenv = r3;
  r4 = varref (2, 150);
  r5 = varref (2, 149);
  r4 = box(unbox(r5)|unbox(r4));
  r3[2] = r4;
  r3 = varref (0, 0);
  r4 = varref (2, 151);
  r3 = box(unbox(r4)|unbox(r3));
  lenv = lenv[1];
  r3 = r3;
  r2[3] = r3;
  r3 = (object *) 841;
  r2[4] = r3;
  r3 = varref (1, 59);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2199; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_open_383;
  L2199:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = (object *) 1;
  r1[3] = r2;
  r0[33] = r1;
  r1 = (object *) 3;
  r0[34] = r1;
  r1 = allocate (TC_TUPLE, 7);
  r1[1] = lenv; lenv = r1;
  // def write-indent_4106_i4252_i4326
  goto L2200;
  FUN_write_indent_4106_i4252_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    // def loop_4112_i4252_i4326
    goto L2201;
    FUN_loop_4112_i4252_i4326:
      check_heap (0);
      r0 = (object *) 1;
      r1 = varref (0, 0);
      if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (4, 31);
        r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
        r0[2] = r1;
        r0 = (object*) &constructed_407;
        r0 = box(((pxll_string*)(r0))->len);
        r1 = (object*) &constructed_407;
        r2 = varref (0, 0);
        r0 = box(write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
        lenv = lenv[1];
        r0 = (object *) 3;
        r1 = varref (0, 0);
        r0 = box(unbox(r1)-unbox(r0));
        lenv[2] = r0;
        goto FUN_loop_4112_i4252_i4326;
      } else {
        r0 = (object *) 14;
        PXLL_RETURN(0);
      }
      PXLL_RETURN(0);
    L2201:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_loop_4112_i4252_i4326; r1[2] = lenv;
    r0[2] = r1;
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (2, 32);
    r0[2] = r1;
    r1 = varref (0, 0);
    r0[1] = r1[2]; lenv = r0; goto FUN_loop_4112_i4252_i4326;
  L2200:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_write_indent_4106_i4252_i4326; r2[2] = lenv;
  r1[2] = r2;
  // def write-string_4107_i4252_i4326
  goto L2202;
  FUN_write_string_4107_i4252_i4326:
    check_heap (0);
    r0 = varref (1, 0);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2203; ; k = t;
    lenv = r0[2]; goto FUN_write_indent_4106_i4252_i4326;
    L2203:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (3, 31);
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = varref (1, 0);
    r0 = box(((pxll_string*)(r0))->len);
    r1 = varref (1, 0);
    r2 = varref (0, 0);
    r0 = box(write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    lenv = lenv[1];
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (3, 31);
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = (object*) &constructed_406;
    r0 = box(((pxll_string*)(r0))->len);
    r1 = (object*) &constructed_406;
    r2 = varref (0, 0);
    r0 = box(write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    lenv = lenv[1];
    r0 = (object *) 14;
    PXLL_RETURN(0);
  L2202:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_write_string_4107_i4252_i4326; r2[2] = lenv;
  r1[3] = r2;
  // def copy_4108_i4252_i4326
  goto L2204;
  FUN_copy_4108_i4252_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (3, 31);
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = varref (1, 0);
    r0 = box(((pxll_string*)(r0))->len);
    r1 = varref (1, 0);
    r2 = varref (0, 0);
    r0 = box(write (unbox(r2), ((pxll_string*)(r1))->data, unbox(r0)));
    PXLL_RETURN(0);
  L2204:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_copy_4108_i4252_i4326; r2[2] = lenv;
  r1[4] = r2;
  // def indent_4109_i4252_i4326
  goto L2205;
  FUN_indent_4109_i4252_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 32);
    r0[2] = r1;
    r0 = (object *) 3;
    r1 = varref (0, 0);
    r0 = box(unbox(r1)+unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    varset (1, 32, r0);
    PXLL_RETURN(0);
  L2205:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_indent_4109_i4252_i4326; r2[2] = lenv;
  r1[5] = r2;
  // def dedent_4110_i4252_i4326
  goto L2206;
  FUN_dedent_4110_i4252_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 32);
    r0[2] = r1;
    r0 = (object *) 3;
    r1 = varref (0, 0);
    r0 = box(unbox(r1)-unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    varset (1, 32, r0);
    PXLL_RETURN(0);
  L2206:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_dedent_4110_i4252_i4326; r2[2] = lenv;
  r1[6] = r2;
  // def close-file_4111_i4252_i4326
  goto L2207;
  FUN_close_file_4111_i4252_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (2, 31);
    r1 = ((pxll_vector*)r1)->val[lookup_field((GET_TYPECODE(*r1)-TC_USEROBJ)>>2,11)];
    r0[2] = r1;
    r0 = varref (0, 0);
    r0 = box(close (unbox(r0)));
    PXLL_RETURN(0);
  L2207:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_close_file_4111_i4252_i4326; r2[2] = lenv;
  r1[7] = r2;
  r1 = allocate (UOTAG(1), 5);
  r2 = varref (0, 5);
  r1[1] = r2;
  r2 = varref (0, 2);
  r1[2] = r2;
  r2 = varref (0, 4);
  r1[3] = r2;
  r2 = varref (0, 3);
  r1[4] = r2;
  r2 = varref (0, 1);
  r1[5] = r2;
  lenv = lenv[1];
  r1 = r1;
  r0[35] = r1;
  r0 = (object*) &constructed_405;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_405;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = allocate (TC_TUPLE, 3);
  // def lambda_32707_i4326
  goto L2208;
  FUN_lambda_32707_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = varref (0, 1);
    r0[2] = r1;
    r1 = varref (2, 109);
    r0[1] = r1[2]; lenv = r0; goto FUN_print_datatype_483;
  L2208:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_32707_i4326; r1[2] = lenv;
  r0[2] = r1;
  r1 = varref (0, 0);
  r1 = ((pxll_vector*)r1)->val[1];
  r0[3] = r1;
  r1 = varref (1, 66);
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2209; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
  L2209:
  ; lenv = k[2]; k = k[1];
  r0 = (object*) &constructed_404;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_404;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = varref (1, 0);
  r1 = ((pxll_vector*)r1)->val[4];
  r0[2] = r1;
  r0 = varref (0, 0);
  r0 = dump_object (r0, 0); fprintf (stdout, "\n");
  lenv = lenv[1];
  r0 = (object*) &constructed_403;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_403;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = varref (1, 0);
  r1 = ((pxll_vector*)r1)->val[8];
  r0[2] = r1;
  r0 = varref (0, 0);
  r0 = dump_object (r0, 0); fprintf (stdout, "\n");
  lenv = lenv[1];
  r0 = (object*) &constructed_402;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_402;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = allocate (TC_TUPLE, 3);
  // def lambda_32755_i4326
  goto L2210;
  FUN_lambda_32755_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 8);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (2, 1);
    r3[2] = r4;
    r4 = varref (4, 54);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L2211; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
    L2211:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = varref (2, 0);
    r3 = allocate (TC_TUPLE, 2);
    r3[1] = lenv; lenv = r3;
    r4 = varref (3, 0);
    r4 = UOBJ_GET(r4,0);
    r3[2] = r4;
    r3 = varref (0, 0);
    lenv = lenv[1];
    r3 = r3;
    r3=r3;
    r2[3] = r3;
    r3 = (object*)TC_NIL;
    r2[4] = r3;
    r3 = varref (0, 2);
    r4 = (object*) &constructed_401;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r3 = varref (0, 3);
    r4 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[6] = r3;
    r3 = varref (0, 4);
    r4 = (object*) &constructed_400;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[7] = r3;
    r3 = varref (0, 5);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[8] = r3;
    r2 = varref (0, 6);
    r3 = (object*) &constructed_399;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (3, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2212; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2212:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    r0 = box(((pxll_string*)(r0))->len);
    r1 = varref (0, 0);
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    PXLL_RETURN(0);
  L2210:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_32755_i4326; r1[2] = lenv;
  r0[2] = r1;
  r1 = varref (0, 0);
  r1 = ((pxll_vector*)r1)->val[12];
  r0[3] = r1;
  r1 = varref (1, 66);
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2213; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
  L2213:
  ; lenv = k[2]; k = k[1];
  r0 = (object*) &constructed_398;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_398;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = allocate (TC_TUPLE, 3);
  // def lambda_32789_i4326
  goto L2214;
  FUN_lambda_32789_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 8);
    r2[1] = lenv; lenv = r2;
    r3 = allocate (TC_TUPLE, 2);
    r4 = varref (2, 1);
    r3[2] = r4;
    r4 = varref (4, 54);
    t = allocate (TC_SAVE, 6);
    t[1] = k; t[2] = lenv; t[3] = &&L2215; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
    r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
    L2215:
    r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
    r3 = result;
    r2[2] = r3;
    r3 = varref (2, 0);
    r3 = allocate (TC_TUPLE, 2);
    r3[1] = lenv; lenv = r3;
    r4 = varref (3, 0);
    r4 = UOBJ_GET(r4,0);
    r3[2] = r4;
    r3 = varref (0, 0);
    lenv = lenv[1];
    r3 = r3;
    r3=r3;
    r2[3] = r3;
    r3 = (object*)TC_NIL;
    r2[4] = r3;
    r3 = varref (0, 2);
    r4 = (object*) &constructed_397;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[5] = r3;
    r3 = varref (0, 3);
    r4 = varref (0, 1);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[6] = r3;
    r3 = varref (0, 4);
    r4 = (object*) &constructed_396;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[7] = r3;
    r3 = varref (0, 5);
    r4 = varref (0, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[8] = r3;
    r2 = varref (0, 6);
    r3 = (object*) &constructed_395;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (3, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2216; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2216:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r0 = varref (0, 0);
    r0 = box(((pxll_string*)(r0))->len);
    r1 = varref (0, 0);
    r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
    PXLL_RETURN(0);
  L2214:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_32789_i4326; r1[2] = lenv;
  r0[2] = r1;
  r1 = varref (0, 0);
  r1 = ((pxll_vector*)r1)->val[13];
  r0[3] = r1;
  r1 = varref (1, 66);
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2217; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
  L2217:
  ; lenv = k[2]; k = k[1];
  r0 = (object*) &constructed_394;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_394;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = (object*) &constructed_393;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_393;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = varref (0, 6);
  r0 = box(((pxll_string*)(r0))->len);
  r1 = varref (0, 6);
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = (object *) 2562;
  box(fputc (GET_CHAR(r0), stdout));
  r0 = allocate (TC_TUPLE, 3);
  // def lambda_32822_i4326
  goto L2218;
  FUN_lambda_32822_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 4);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = varref (0, 0);
    r4 = (object*) &constructed_392;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r3 = varref (0, 1);
    r4 = varref (1, 0);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[4] = r3;
    r2 = varref (0, 2);
    r3 = (object*) &constructed_391;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (2, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2219; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2219:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r0[2] = r1;
    r1 = varref (1, 33);
    r1 = ((pxll_vector*)r1)->val[4];
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
  L2218:
  r1 = allocate (TC_CLOSURE, 2);
  r1[1] = &&FUN_lambda_32822_i4326; r1[2] = lenv;
  r0[2] = r1;
  r1 = varref (0, 0);
  r1 = ((pxll_vector*)r1)->val[0];
  r0[3] = r1;
  r1 = varref (1, 33);
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2220; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
  L2220:
  ; lenv = k[2]; k = k[1];
  r0 = allocate (TC_TUPLE, 6);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = (object*) &constructed_390;
  r1[2] = r2;
  r2 = varref (2, 60);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2221; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_file_2fopen_read_390;
  L2221:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  // def loop_4581_i4202_i4284_i4326
  goto L2222;
  FUN_loop_4581_i4202_i4284_i4326:
    check_heap (0);
    r0 = allocate (TC_TUPLE, 2);
    r0[1] = lenv; lenv = r0;
    r1 = varref (1, 0);
    r1 = box(((pxll_string*)(r1))->len);
    r0[2] = r1;
    r0 = (object *) 1;
    r1 = varref (0, 0);
    r0 = PXLL_TEST(unbox(r1)==unbox(r0));
    lenv = lenv[1];
    r0 = r0;
    if PXLL_IS_TRUE(r0) {
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (0, 1);
      r1[2] = r2;
      r2 = (object *) constructed_37[0];
      r1[3] = r2;
      r2 = varref (4, 19);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2223; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
      L2223:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (4, 45);
      r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
    } else {
      r0 = varref (0, 1);
      r1 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r1;
      t[2] = r0;
      r0 = t;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (2, 0);
      r1[2] = r2;
      r2 = varref (4, 62);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2224; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_file_2fread_buffer_396;
      L2224:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv[2] = r1;
      lenv[3] = r0;
      goto FUN_loop_4581_i4202_i4284_i4326;
    }
    PXLL_RETURN(0);
  L2222:
  r2 = allocate (TC_CLOSURE, 2);
  r2[1] = &&FUN_loop_4581_i4202_i4284_i4326; r2[2] = lenv;
  r1[2] = r2;
  r1 = allocate (TC_TUPLE, 3);
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (1, 0);
  r2[2] = r3;
  r3 = varref (3, 62);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2225; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_file_2fread_buffer_396;
  L2225:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = (object *) constructed_389[0];
  r1[3] = r2;
  r2 = varref (0, 0);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2226; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_loop_4581_i4202_i4284_i4326;
  L2226:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  lenv = lenv[1];
  r1 = r1;
  r0[3] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (2, 188);
  r1[2] = r2;
  r2 = varref (0, 1);
  r1[3] = r2;
  r2 = varref (2, 49);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2227; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_find_366;
  L2227:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[4] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = varref (2, 189);
  r1[2] = r2;
  r2 = varref (0, 1);
  r1[3] = r2;
  r2 = varref (2, 49);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2228; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_find_366;
  L2228:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[5] = r1;
  r1 = (object *) -1;
  r2 = varref (0, 2);
  if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
    r1 = (object *) 262;
    r1=r1;
  } else {
    r1 = (object *) -1;
    r2 = varref (0, 3);
    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
    r1=r1;
  }
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r2 = (object*) &constructed_388;
    r1[2] = r2;
    r2 = allocate (UOTAG(0), 2);
    r3 = varref (0, 2);
    r2[1] = r3;
    r3 = varref (0, 3);
    r2[2] = r3;
    r1[3] = r2;
    r2 = varref (2, 12);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2229; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
    L2229:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  } else {
    r1 = allocate (TC_TUPLE, 8);
    r1[1] = lenv; lenv = r1;
    r2 = varref (3, 188);
    r2 = box(((pxll_string*)(r2))->len);
    r1[2] = r2;
    r2 = varref (0, 0);
    r3 = varref (1, 2);
    r2 = box(unbox(r3)+unbox(r2));
    r1[3] = r2;
    r2 = varref (3, 189);
    r2 = box(((pxll_string*)(r2))->len);
    r1[4] = r2;
    r2 = varref (0, 2);
    r3 = varref (1, 3);
    r2 = box(unbox(r3)+unbox(r2));
    r1[5] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = varref (1, 1);
    r2[2] = r3;
    r3 = (object *) 1;
    r2[3] = r3;
    r3 = varref (0, 1);
    r2[4] = r3;
    r3 = varref (3, 43);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2230; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_355;
    L2230:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[6] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = varref (1, 1);
    r2[2] = r3;
    r3 = varref (0, 1);
    r2[3] = r3;
    r3 = varref (0, 3);
    r2[4] = r3;
    r3 = varref (3, 43);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2231; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_355;
    L2231:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[7] = r2;
    r2 = allocate (TC_TUPLE, 4);
    r3 = varref (1, 1);
    r2[2] = r3;
    r3 = varref (0, 3);
    r2[3] = r3;
    r3 = varref (1, 1);
    r3 = box(((pxll_string*)(r3))->len);
    r2[4] = r3;
    r3 = varref (3, 43);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2232; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_substring_355;
    L2232:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[8] = r2;
    r1 = allocate (UOTAG(7), 3);
    r2 = varref (0, 4);
    r1[1] = r2;
    r2 = varref (0, 5);
    r1[2] = r2;
    r2 = varref (0, 6);
    r1[3] = r2;
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
  }
  r0[6] = r1;
  r0 = varref (0, 4);
  switch (get_case_noint (r0)) {
    default: {
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 4);
      r1 = UOBJ_GET(r1,0);
      r0[2] = r1;
      r1 = varref (1, 4);
      r1 = UOBJ_GET(r1,1);
      r0[3] = r1;
      r1 = varref (1, 4);
      r1 = UOBJ_GET(r1,2);
      r0[4] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 0);
      r0[2] = r1;
      r1 = varref (2, 33);
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2233; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2233:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 7);
      r0[1] = lenv; lenv = r0;
      r1 = varref (3, 0);
      r1 = ((pxll_vector*)r1)->val[6];
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = (object *) constructed_37[0];
      r1[3] = r2;
      r2 = varref (4, 19);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2234; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
      L2234:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[3] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r2 = varref (0, 1);
      r1[2] = r2;
      r2 = varref (4, 20);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2235; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
      L2235:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[4] = r1;
      r1 = (object*)UITAG(0);
      r0[5] = r1;
      r1 = (object *) constructed_387[0];
      r0[6] = r1;
      r1 = (object *) 1;
      r0[7] = r1;
      r0 = allocate (TC_TUPLE, 4);
      r0[1] = lenv; lenv = r0;
      // def uohead_4518_i4285_i4326
      goto L2236;
      FUN_uohead_4518_i4285_i4326:
        check_heap (0);
        r0 = (object *) constructed_52[0];
        r1 = varref (0, 1);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_62[0];
          r1 = varref (0, 2);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_383;
            PXLL_RETURN(0);
          } else {
            goto fatbar_35;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_35;
        }
        PXLL_RETURN(0);
        goto fatbar_35_over;
        fatbar_35:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 8);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r2[2] = r3;
        r3 = varref (7, 54);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2237; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2237:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 3);
        r2[2] = r3;
        r3 = varref (7, 54);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2238; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2238:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[3] = r2;
        r2 = (object*)TC_NIL;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = (object*) &constructed_386;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r2 = varref (0, 3);
        r3 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[6] = r2;
        r2 = varref (0, 4);
        r3 = (object*) &constructed_385;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[7] = r2;
        r2 = varref (0, 5);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[8] = r2;
        r1 = varref (0, 6);
        r2 = (object*) &constructed_384;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (6, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_35_over: ;
        PXLL_RETURN(0);
      L2236:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_uohead_4518_i4285_i4326; r1[2] = lenv;
      r0[2] = r1;
      // def uitag_4519_i4285_i4326
      goto L2239;
      FUN_uitag_4519_i4285_i4326:
        check_heap (0);
        r0 = (object *) constructed_52[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_50[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_380;
            PXLL_RETURN(0);
          } else {
            goto fatbar_34;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_34;
        }
        PXLL_RETURN(0);
        goto fatbar_34_over;
        fatbar_34:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 2);
        r2[2] = r3;
        r3 = varref (7, 54);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2240; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2240:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_382;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_381;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (6, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_34_over: ;
        PXLL_RETURN(0);
      L2239:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_uitag_4519_i4285_i4326; r1[2] = lenv;
      r0[3] = r1;
      // def walk_4520_i4285_i4326
      goto L2241;
      FUN_walk_4520_i4285_i4326:
        check_heap (0);
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(5)): {
            r0 = allocate (TC_TUPLE, 7);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,1);
            r0[3] = r1;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,2);
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = varref (6, 0);
            r2 = ((pxll_vector*)r2)->val[1];
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = (object*) &constructed_368;
            r1[4] = r2;
            r2 = varref (7, 65);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2242; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
            L2242:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (0, 3);
            r2 = ((pxll_vector*)r2)->val[1];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2243; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2243:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[6] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 2);
            r1[2] = r2;
            r2 = varref (7, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2244; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L2244:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[7] = r1;
            r0 = (object *) 1;
            r1 = varref (0, 5);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)>unbox(r0))) {
              r0 = allocate (TC_TUPLE, 4);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 3);
              r2 = varref (3, 2);
              r1[2] = r2;
              r2 = varref (1, 2);
              r1[3] = r2;
              r2 = varref (8, 30);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2245; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
              L2245:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (4, 4);
              r1[2] = r2;
              r2 = varref (8, 20);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2246; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
              L2246:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[3] = r1;
              r1 = varref (0, 1);
              r2 = (object *) 3;
              r1 = box(unbox(r2)+unbox(r1));
              r0[4] = r1;
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = allocate (TC_TUPLE, 5);
              r2 = varref (2, 5);
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (2, 1);
              r1[4] = r2;
              r2 = varref (2, 4);
              r2 = ((pxll_vector*)r2)->val[1];
              r1[5] = r2;
              r2 = varref (4, 0);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2247; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_uohead_4518_i4285_i4326;
              L2247:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (5, 4);
              r0[3] = r1;
              r0 = varref (0, 1);
              r1 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              varset (4, 4, r0);
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_31638_i4285_i4326
              goto L2248;
              FUN_lambda_31638_i4285_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (6, 4);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (5, 4, r0);
                PXLL_RETURN(0);
              L2248:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_31638_i4285_i4326; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (0, 0);
              r0[3] = r1;
              r1 = varref (8, 33);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2249; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
              L2249:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 8);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (5, 5);
              r2[2] = r3;
              r3 = varref (9, 54);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2250; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
              L2250:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = allocate (TC_TUPLE, 2);
              r3 = varref (1, 2);
              r2[2] = r3;
              r3 = varref (9, 54);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2251; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
              L2251:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[3] = r2;
              r2 = (object*)TC_NIL;
              r1[4] = r2;
              r2 = varref (0, 2);
              r3 = (object*) &constructed_367;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[5] = r2;
              r2 = varref (0, 3);
              r3 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[6] = r2;
              r2 = varref (0, 4);
              r3 = (object*) &constructed_366;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[7] = r2;
              r2 = varref (0, 5);
              r3 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              r1[8] = r2;
              r1 = varref (0, 6);
              r2 = (object*) &constructed_365;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r2;
              t[2] = r1;
              r1 = t;
              lenv = lenv[1];
              r1 = r1;
              r0[2] = r1;
              r1 = varref (8, 45);
              r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
            } else {
              r0 = allocate (TC_TUPLE, 4);
              r1 = varref (0, 0);
              r0[2] = r1;
              r1 = varref (0, 1);
              r0[3] = r1;
              r1 = varref (0, 4);
              r1 = ((pxll_vector*)r1)->val[1];
              r0[4] = r1;
              r1 = varref (2, 1);
              r0[1] = r1[2]; lenv = r0; goto FUN_uitag_4519_i4285_i4326;
            }
            PXLL_RETURN(0);
          } break;
          case (UOTAG(6)): {
            r0 = allocate (TC_TUPLE, 6);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (2, 2);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (7, 30);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2252; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
            L2252:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 0);
            r1[2] = r2;
            r2 = varref (7, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2253; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L2253:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[4] = r1;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (3, 4);
            r1[2] = r2;
            r2 = varref (7, 20);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2254; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
            L2254:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[5] = r1;
            r1 = varref (0, 3);
            r2 = (object *) 3;
            r1 = box(unbox(r2)+unbox(r1));
            r0[6] = r1;
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 5);
            r2[1] = lenv; lenv = r2;
            r3 = allocate (TC_TUPLE, 2);
            r4 = varref (2, 2);
            r3[2] = r4;
            r4 = varref (9, 54);
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L2255; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
            L2255:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = varref (0, 1);
            r4 = (object*) &constructed_373;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[4] = r3;
            r3 = varref (0, 2);
            r4 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            r2[5] = r3;
            r2 = varref (0, 3);
            r3 = (object*) &constructed_372;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            lenv = lenv[1];
            r2 = r2;
            r1[2] = r2;
            r2 = varref (8, 45);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2256; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
            L2256:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[2] = r1;
            r1 = varref (4, 4);
            r0[3] = r1;
            r0 = varref (0, 1);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            varset (3, 4, r0);
            r0 = allocate (TC_TUPLE, 3);
            // def lambda_31722_i4285_i4326
            goto L2257;
            FUN_lambda_31722_i4285_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (5, 4);
              r0[2] = r1;
              r0 = varref (0, 0);
              r1 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r1;
              t[2] = r0;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              varset (4, 4, r0);
              PXLL_RETURN(0);
            L2257:
            r1 = allocate (TC_CLOSURE, 2);
            r1[1] = &&FUN_lambda_31722_i4285_i4326; r1[2] = lenv;
            r0[2] = r1;
            r1 = varref (0, 1);
            r0[3] = r1;
            r1 = varref (7, 33);
            t = allocate (TC_SAVE, 3);
            t[1] = k; t[2] = lenv; t[3] = &&L2258; ; k = t;
            r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
            L2258:
            ; lenv = k[2]; k = k[1];
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 8);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (4, 5);
            r2[2] = r3;
            r3 = varref (8, 54);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2259; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
            L2259:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 4);
            r2[2] = r3;
            r3 = varref (8, 54);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2260; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
            L2260:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = (object*)TC_NIL;
            r1[4] = r2;
            r2 = varref (0, 2);
            r3 = (object*) &constructed_371;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r2 = varref (0, 3);
            r3 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[6] = r2;
            r2 = varref (0, 4);
            r3 = (object*) &constructed_370;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[7] = r2;
            r2 = varref (0, 5);
            r3 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[8] = r2;
            r1 = varref (0, 6);
            r2 = (object*) &constructed_369;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (7, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } break;
          case (UOTAG(4)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 4);
            r2 = varref (6, 0);
            r2 = ((pxll_vector*)r2)->val[12];
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = (object*) &constructed_376;
            r1[4] = r2;
            r2 = varref (7, 65);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2261; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2fget_407;
            L2261:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 1);
            r2[2] = r3;
            r3 = varref (8, 54);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2262; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
            L2262:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = (object*)TC_NIL;
            r1[3] = r2;
            r2 = varref (0, 1);
            r3 = (object*) &constructed_375;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[4] = r2;
            r2 = varref (0, 2);
            r3 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r3;
            t[2] = r2;
            r2 = t;
            r1[5] = r2;
            r1 = varref (0, 3);
            r2 = (object*) &constructed_374;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r2;
            t[2] = r1;
            r1 = t;
            lenv = lenv[1];
            r1 = r1;
            r0[2] = r1;
            r1 = varref (7, 45);
            r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
          } break;
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 3);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,0);
            r0[2] = r1;
            r1 = allocate (TC_TUPLE, 3);
            r2 = varref (3, 3);
            r1[2] = r2;
            r2 = varref (0, 0);
            r1[3] = r2;
            r2 = varref (7, 64);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2263; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
            L2263:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r0[3] = r1;
            r0 = varref (0, 1);
            switch (get_case (r0)) {
              case (UOTAG(0)): {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (1, 1);
                r1 = UOBJ_GET(r1,0);
                r0[2] = r1;
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 5);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (1, 0);
                r2[2] = r3;
                r3 = varref (9, 54);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2264; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                L2264:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = (object*)TC_NIL;
                r1[3] = r2;
                r2 = varref (0, 1);
                r3 = (object*) &constructed_378;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[4] = r2;
                r2 = varref (0, 2);
                r3 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                r1[5] = r2;
                r1 = varref (0, 3);
                r2 = (object*) &constructed_377;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r2;
                t[2] = r1;
                r1 = t;
                lenv = lenv[1];
                r1 = r1;
                r0[2] = r1;
                r1 = varref (8, 45);
                r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
              } break;
              default: {
                r0 = (object*) &constructed_69;
                r0 = box(((pxll_string*)(r0))->len);
                r1 = (object*) &constructed_69;
                (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
                r0 = (object*) &constructed_379;
                dump_object (r0, 0); fprintf (stdout, "\n");
                r0 = (object*) &constructed_379;
                r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
                PXLL_RETURN(0);
              } break;
            }
            PXLL_RETURN(0);
          } break;
          default: {
            goto fatbar_33;
          }
        }
        PXLL_RETURN(0);
        goto fatbar_33_over;
        fatbar_33:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (0, 0);
        r1[2] = r2;
        r2 = varref (6, 137);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2265; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_encode_immediate_557;
        L2265:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (6, 54);
        r0[1] = r1[2]; lenv = r0; goto FUN_int__3estring_374;
        fatbar_33_over: ;
        PXLL_RETURN(0);
      L2241:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_walk_4520_i4285_i4326; r1[2] = lenv;
      r0[4] = r1;
      r0 = varref (4, 33);
      r0 = ((pxll_vector*)r0)->val[2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2266; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2266:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (2, 2);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_4549_i4285_i4326
      goto L2267;
      FUN__24loop_4549_i4285_i4326:
        check_heap (0);
        r0 = varref (2, 0);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = (object *) constructed_364[0];
          varset (4, 4, r0);
          r0 = varref (0, 0);
          varset (4, 5, r0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (5, 1);
          r1[2] = r2;
          r2 = varref (1, 0);
          r1[3] = r2;
          r2 = varref (9, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2268; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L2268:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(0)): {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (0, 0);
              r1 = box(((pxll_string*)(r1))->len);
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (7, 3);
              r0[2] = r1;
              r0 = varref (3, 0);
              r1 = varref (0, 0);
              r2 = varref (1, 0);
              t = alloc_no_clear (UOTAG(1),3);
              t[1] = r2;
              t[2] = r0;
              t[3] = r1;
              r0 = t;
              lenv = lenv[1];
              r0 = r0;
              varset (6, 3, r0);
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 14);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (3, 0);
              r3[2] = r4;
              r4 = varref (11, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2269; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2269:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (1, 1);
              r3[2] = r4;
              r4 = varref (11, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2270; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2270:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (1, 1);
              r3[2] = r4;
              r4 = varref (11, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2271; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2271:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              // def loop_4564_i4110_i4285_i4326
              goto L2272;
              FUN_loop_4564_i4110_i4285_i4326:
                check_heap (0);
                r0 = varref (0, 1);
                switch (get_case (r0)) {
                  case (TC_NIL): {
                    r0 = allocate (TC_TUPLE, 2);
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = varref (0, 0);
                    r1[2] = r2;
                    r2 = (object *) constructed_37[0];
                    r1[3] = r2;
                    r2 = varref (13, 19);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2273; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
                    L2273:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r0[2] = r1;
                    r1 = varref (13, 45);
                    r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                  } break;
                  default: {
                    r0 = allocate (TC_TUPLE, 3);
                    r0[1] = lenv; lenv = r0;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,0);
                    r0[2] = r1;
                    r1 = varref (1, 1);
                    r1 = UOBJ_GET(r1,1);
                    r0[3] = r1;
                    r0 = allocate (TC_TUPLE, 2);
                    r0[1] = lenv; lenv = r0;
                    r1 = (object *) 8706;
                    r2 = varref (1, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_345;
                      r1=r1;
                    } else {
                      goto fatbar_25;
                    }
                    r1=r1;
                    goto fatbar_25_over;
                    fatbar_25:
                    r1 = (object *) 23554;
                    r2 = varref (1, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_346;
                      r1=r1;
                    } else {
                      goto fatbar_26;
                    }
                    r1=r1;
                    goto fatbar_26_over;
                    fatbar_26:
                    r1 = (object *) 2306;
                    r2 = varref (1, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_347;
                      r1=r1;
                    } else {
                      goto fatbar_27;
                    }
                    r1=r1;
                    goto fatbar_27_over;
                    fatbar_27:
                    r1 = (object *) 2562;
                    r2 = varref (1, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_348;
                      r1=r1;
                    } else {
                      goto fatbar_28;
                    }
                    r1=r1;
                    goto fatbar_28_over;
                    fatbar_28:
                    r1 = (object *) 3330;
                    r2 = varref (1, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                      r1 = (object*) &constructed_349;
                      r1=r1;
                    } else {
                      goto fatbar_29;
                    }
                    r1=r1;
                    goto fatbar_29_over;
                    fatbar_29:
                    r1 = allocate (TC_TUPLE, 2);
                    r2 = varref (1, 0);
                    r1[2] = r2;
                    r2 = varref (15, 187);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2274; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto *r2[1];
                    L2274:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    if PXLL_IS_TRUE(r1) {
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (1, 0);
                      r1[2] = r2;
                      r2 = varref (15, 44);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2275; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_char__3estring_358;
                      L2275:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r1=r1;
                    } else {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (2, 0);
                      r2 = box(GET_CHAR(r2));
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r2[1] = lenv; lenv = r2;
                      // def loop_1043_i4119_i4285_i4326
                      goto L2276;
                      FUN_loop_1043_i4119_i4285_i4326:
                        check_heap (0);
                        r0 = varref (0, 0);
                        r1 = (object *) 1;
                        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                          r0 = allocate (TC_TUPLE, 2);
                          r1 = (object *) 1;
                          r2 = varref (2, 0);
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)<unbox(r1))) {
                            r1 = varref (0, 1);
                            r2 = (object *) 11522;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r2;
                            t[2] = r1;
                            r1 = t;
                            r1=r1;
                          } else {
                            r1 = varref (0, 1);
                            r1=r1;
                          }
                          r0[2] = r1;
                          r1 = varref (18, 52);
                          r0[1] = r1[2]; lenv = r0; goto FUN_list__3estring_371;
                        } else {
                          r0 = allocate (TC_TUPLE, 2);
                          r0[1] = lenv; lenv = r0;
                          r1 = (object *) 15;
                          r2 = varref (1, 0);
                          r1 = box(unbox(r2)&unbox(r1));
                          r2 = varref (19, 147);
                          range_check (GET_TUPLE_LENGTH(*(object*)r2), unbox(r1));
                          r1 = ((pxll_vector*)r2)->val[unbox(r1)];
                          r0[2] = r1;
                          r0 = varref (1, 1);
                          r1 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r1;
                          t[2] = r0;
                          r0 = t;
                          lenv = lenv[1];
                          r0 = r0;
                          r1 = (object *) 7;
                          r2 = varref (0, 0);
                          r1 = box(unbox(r2)>>unbox(r1));
                          lenv[2] = r1;
                          lenv[3] = r0;
                          goto FUN_loop_1043_i4119_i4285_i4326;
                        }
                        PXLL_RETURN(0);
                      L2276:
                      r3 = allocate (TC_CLOSURE, 2);
                      r3[1] = &&FUN_loop_1043_i4119_i4285_i4326; r3[2] = lenv;
                      r2[2] = r3;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = (object *) 1;
                      r4 = varref (1, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r4)<unbox(r3))) {
                        r3 = varref (1, 0);
                        r4 = (object *) 1;
                        r3 = box(unbox(r4)-unbox(r3));
                        r3=r3;
                      } else {
                        r3 = varref (1, 0);
                        r3=r3;
                      }
                      r2[2] = r3;
                      r3 = (object *) constructed_354[0];
                      r2[3] = r3;
                      r3 = varref (0, 0);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2277; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_loop_1043_i4119_i4285_i4326;
                      L2277:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      lenv = lenv[1];
                      r2 = r2;
                      r1[3] = r2;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = varref (1, 1);
                      r3 = box(((pxll_string*)(r3))->len);
                      r2[2] = r3;
                      r3 = (object *) 5;
                      r4 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_350;
                        r3=r3;
                      } else {
                        goto fatbar_30;
                      }
                      r3=r3;
                      goto fatbar_30_over;
                      fatbar_30:
                      r3 = (object *) 3;
                      r4 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_351;
                        r3=r3;
                      } else {
                        goto fatbar_31;
                      }
                      r3=r3;
                      goto fatbar_31_over;
                      fatbar_31:
                      r3 = (object *) 1;
                      r4 = varref (0, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r4==r3)) {
                        r3 = (object*) &constructed_352;
                        r3=r3;
                      } else {
                        goto fatbar_32;
                      }
                      r3=r3;
                      goto fatbar_32_over;
                      fatbar_32:
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = (object*) &constructed_353;
                      r3[2] = r4;
                      r4 = varref (3, 0);
                      r3[3] = r4;
                      r4 = varref (17, 12);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2278; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_error1_303;
                      L2278:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r3=r3;
                      fatbar_32_over: ;
                      r3=r3;
                      fatbar_31_over: ;
                      r3=r3;
                      fatbar_30_over: ;
                      r2[3] = r3;
                      r3 = (object*)TC_NIL;
                      r2[4] = r3;
                      r3 = varref (0, 2);
                      r4 = varref (1, 1);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      r2[5] = r3;
                      r2 = varref (0, 3);
                      r3 = varref (0, 1);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r3;
                      t[2] = r2;
                      r2 = t;
                      lenv = lenv[1];
                      r2 = r2;
                      r1[2] = r2;
                      r2 = varref (16, 45);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2279; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                      L2279:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    }
                    r1=r1;
                    fatbar_29_over: ;
                    r1=r1;
                    fatbar_28_over: ;
                    r1=r1;
                    fatbar_27_over: ;
                    r1=r1;
                    fatbar_26_over: ;
                    r1=r1;
                    fatbar_25_over: ;
                    r0[2] = r1;
                    r0 = varref (2, 0);
                    r1 = varref (0, 0);
                    t = alloc_no_clear (TC_PAIR,2);
                    t[1] = r1;
                    t[2] = r0;
                    r0 = t;
                    lenv = lenv[1];
                    r0 = r0;
                    r1 = varref (0, 1);
                    lenv = ((object *)lenv)[1];
                    lenv[2] = r0;
                    lenv[3] = r1;
                    goto FUN_loop_4564_i4110_i4285_i4326;
                  } break;
                }
                PXLL_RETURN(0);
              L2272:
              r4 = allocate (TC_CLOSURE, 2);
              r4[1] = &&FUN_loop_4564_i4110_i4285_i4326; r4[2] = lenv;
              r3[2] = r4;
              r3 = allocate (TC_TUPLE, 3);
              r4 = (object *) constructed_344[0];
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 0);
              r4[2] = r5;
              r5 = varref (12, 53);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2280; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string__3elist_372;
              L2280:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = varref (0, 0);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2281; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_loop_4564_i4110_i4285_i4326;
              L2281:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              lenv = lenv[1];
              r3 = r3;
              r2[5] = r3;
              r3 = (object*)TC_NIL;
              r2[6] = r3;
              r3 = varref (0, 4);
              r4 = (object*) &constructed_343;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = varref (0, 5);
              r4 = varref (0, 3);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_342;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[9] = r3;
              r3 = varref (0, 7);
              r4 = varref (0, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[10] = r3;
              r3 = varref (0, 8);
              r4 = (object*) &constructed_341;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[11] = r3;
              r3 = varref (0, 9);
              r4 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[12] = r3;
              r3 = varref (0, 10);
              r4 = (object*) &constructed_340;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[13] = r3;
              r3 = varref (0, 11);
              r4 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[14] = r3;
              r2 = varref (0, 12);
              r3 = (object*) &constructed_339;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (10, 45);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2282; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2282:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (9, 33);
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2283; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2283:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            case (UOTAG(4)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 4);
              r2[1] = lenv; lenv = r2;
              r3 = varref (1, 0);
              r3 = allocate (TC_TUPLE, 2);
              r3[1] = lenv; lenv = r3;
              r4 = varref (2, 0);
              r4 = UOBJ_GET(r4,0);
              r3[2] = r4;
              r3 = varref (0, 0);
              lenv = lenv[1];
              r3 = r3;
              r3=r3;
              r2[2] = r3;
              r3 = (object*)TC_NIL;
              r2[3] = r3;
              r3 = varref (0, 1);
              r4 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[4] = r3;
              r2 = varref (0, 2);
              r3 = (object*) &constructed_359;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (10, 45);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2284; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2284:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (9, 33);
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2285; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2285:
              ; lenv = k[2]; k = k[1];
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 11);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (3, 0);
              r3[2] = r4;
              r4 = varref (11, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2286; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2286:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (3, 0);
              r3[2] = r4;
              r4 = varref (11, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2287; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2287:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 2);
              r4[1] = lenv; lenv = r4;
              r5 = varref (8, 5);
              r4[2] = r5;
              r4 = (object *) 3;
              r5 = varref (0, 0);
              r4 = box(unbox(r5)-unbox(r4));
              lenv = lenv[1];
              r4 = r4;
              r3[2] = r4;
              r4 = varref (11, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2288; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2288:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[4] = r3;
              r3 = (object*)TC_NIL;
              r2[5] = r3;
              r3 = varref (0, 3);
              r4 = (object*) &constructed_358;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r3 = varref (0, 4);
              r4 = varref (0, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = varref (0, 5);
              r4 = (object*) &constructed_357;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r3 = varref (0, 6);
              r4 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[9] = r3;
              r3 = varref (0, 7);
              r4 = (object*) &constructed_356;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[10] = r3;
              r3 = varref (0, 8);
              r4 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[11] = r3;
              r2 = varref (0, 9);
              r3 = (object*) &constructed_355;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (10, 45);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2289; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2289:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (9, 33);
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2290; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2290:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              lenv = lenv[1];
              r0 = r0;
              r0=r0;
            } break;
            default: {
              goto fatbar_24;
            }
          }
          r0=r0;
          goto fatbar_24_over;
          fatbar_24:
          r0 = allocate (TC_TUPLE, 5);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 3);
          r3 = varref (6, 1);
          r2[2] = r3;
          r3 = varref (2, 0);
          r2[3] = r3;
          r3 = varref (10, 25);
          t = allocate (TC_SAVE, 5);
          t[1] = k; t[2] = lenv; t[3] = &&L2291; t[4] = r0; t[5] = r1; k = t;
          r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
          L2291:
          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
          r2 = result;
          r1[2] = r2;
          r2 = varref (5, 2);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2292; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_walk_4520_i4285_i4326;
          L2292:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (6, 4);
          r0[3] = r1;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (0, 1);
          r1[2] = r2;
          r2 = (object *) constructed_37[0];
          r1[3] = r2;
          r2 = varref (10, 19);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2293; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
          L2293:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[4] = r1;
          r1 = varref (0, 2);
          r2 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r2;
          t[2] = r1;
          r1 = t;
          r0[5] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 8);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (3, 0);
          r3[2] = r4;
          r4 = varref (11, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2294; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L2294:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = allocate (TC_TUPLE, 3);
          r4 = allocate (TC_TUPLE, 3);
          r5 = varref (11, 13);
          r4[2] = r5;
          r5 = varref (1, 3);
          r4[3] = r5;
          r5 = varref (11, 30);
          t = allocate (TC_SAVE, 7);
          t[1] = k; t[2] = lenv; t[3] = &&L2295; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
          r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
          L2295:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
          r4 = result;
          r3[2] = r4;
          r4 = (object*) &constructed_363;
          r3[3] = r4;
          r4 = varref (11, 46);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2296; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
          L2296:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[3] = r3;
          r3 = (object*)TC_NIL;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = (object*) &constructed_362;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r3 = varref (0, 3);
          r4 = varref (0, 1);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[6] = r3;
          r3 = varref (0, 4);
          r4 = (object*) &constructed_361;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[7] = r3;
          r3 = varref (0, 5);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[8] = r3;
          r2 = varref (0, 6);
          r3 = (object*) &constructed_360;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (10, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2297; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L2297:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (9, 33);
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2298; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2298:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          r0=r0;
          fatbar_24_over: ;
          lenv = lenv[1];
          r0 = (object *) 3;
          r1 = varref (0, 0);
          r0 = box(unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_4549_i4285_i4326;
        }
        PXLL_RETURN(0);
      L2267:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_4549_i4285_i4326; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = varref (0, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2299; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4549_i4285_i4326;
      L2299:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = (object *) constructed_338[0];
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_32052_i4285_i4326
      goto L2300;
      FUN_lambda_32052_i4285_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 3);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 5);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (2, 1);
        r3[2] = r4;
        r4 = varref (9, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2301; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2301:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = (object*)TC_NIL;
        r2[3] = r3;
        r3 = varref (0, 1);
        r4 = (object*) &constructed_337;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[4] = r3;
        r3 = varref (0, 2);
        r4 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[5] = r3;
        r2 = varref (0, 3);
        r3 = (object*) &constructed_336;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (8, 45);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2302; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2302:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (2, 0);
        r0[3] = r1;
        r0 = varref (0, 1);
        r1 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r1;
        t[2] = r0;
        r0 = t;
        lenv = lenv[1];
        r0 = r0;
        varset (1, 0, r0);
        PXLL_RETURN(0);
      L2300:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_32052_i4285_i4326; r1[2] = lenv;
      r0[2] = r1;
      r1 = varref (5, 0);
      r1 = ((pxll_vector*)r1)->val[12];
      r0[3] = r1;
      r1 = varref (6, 66);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2303; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_alist_2fiterate_408;
      L2303:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = allocate (TC_TUPLE, 2);
      r2 = allocate (TC_TUPLE, 8);
      r2[1] = lenv; lenv = r2;
      r3 = allocate (TC_TUPLE, 2);
      r4 = allocate (TC_TUPLE, 2);
      r5 = varref (1, 0);
      r4[2] = r5;
      r5 = varref (7, 20);
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2304; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_length_323;
      L2304:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = varref (7, 54);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2305; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
      L2305:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = allocate (TC_TUPLE, 3);
      r4 = allocate (TC_TUPLE, 3);
      r5 = varref (7, 13);
      r4[2] = r5;
      r5 = varref (1, 0);
      r4[3] = r5;
      r5 = varref (7, 30);
      t = allocate (TC_SAVE, 7);
      t[1] = k; t[2] = lenv; t[3] = &&L2306; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
      r4[1] = r5[2]; lenv = r4; goto FUN_map_335;
      L2306:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
      r4 = result;
      r3[2] = r4;
      r4 = (object*) &constructed_335;
      r3[3] = r4;
      r4 = varref (7, 46);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2307; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string_join_363;
      L2307:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[3] = r3;
      r3 = (object*)TC_NIL;
      r2[4] = r3;
      r3 = varref (0, 2);
      r4 = (object*) &constructed_334;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[5] = r3;
      r3 = varref (0, 3);
      r4 = varref (0, 1);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[6] = r3;
      r3 = varref (0, 4);
      r4 = (object*) &constructed_333;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[7] = r3;
      r3 = varref (0, 5);
      r4 = varref (0, 0);
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r4;
      t[2] = r3;
      r3 = t;
      r2[8] = r3;
      r2 = varref (0, 6);
      r3 = (object*) &constructed_332;
      t = alloc_no_clear (TC_PAIR,2);
      t[1] = r3;
      t[2] = r2;
      r2 = t;
      lenv = lenv[1];
      r2 = r2;
      r1[2] = r2;
      r2 = varref (6, 45);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2308; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
      L2308:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (5, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2309; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2309:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = varref (4, 33);
      r0 = ((pxll_vector*)r0)->val[3];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2310; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2310:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 1);
      r0[2] = r1;
      r1 = varref (2, 33);
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2311; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2311:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      r0[1] = lenv; lenv = r0;
      r1 = varref (3, 0);
      r1 = ((pxll_vector*)r1)->val[9];
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2312; t[4] = r0; k = t;
      lenv = r1[2]; goto *r1[1];
      L2312:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      r0[2] = r1;
      r1 = varref (0, 0);
      r2 = (object *) 3;
      r1 = box(unbox(r2)+unbox(r1));
      r0[3] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      r1 = varref (1, 1);
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r0[1] = lenv; lenv = r0;
      // def $loop_4507_i4286_i4326
      goto L2313;
      FUN__24loop_4507_i4286_i4326:
        check_heap (0);
        r0 = varref (2, 0);
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
          r0 = (object *) 14;
          PXLL_RETURN(0);
        } else {
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (1, 0);
          r3[2] = r4;
          r4 = varref (8, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2314; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L2314:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = (object*) &constructed_331;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = varref (0, 3);
          r3 = (object*) &constructed_330;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (7, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2315; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L2315:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (6, 33);
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2316; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2316:
          ; lenv = k[2]; k = k[1];
          r0 = (object *) 3;
          r1 = varref (0, 0);
          r0 = box(unbox(r1)+unbox(r0));
          lenv[2] = r0;
          goto FUN__24loop_4507_i4286_i4326;
        }
        PXLL_RETURN(0);
      L2313:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN__24loop_4507_i4286_i4326; r1[2] = lenv;
      r0[2] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object *) 1;
      r0[2] = r1;
      r1 = varref (0, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2317; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4507_i4286_i4326;
      L2317:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_329;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2318; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2318:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_328;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2319; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2319:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_31428_i4286_i4326
      goto L2320;
      FUN_lambda_31428_i4286_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 11);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 3;
        r5 = varref (1, 0);
        r4 = box(unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = varref (6, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2321; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2321:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 7;
        r5 = varref (1, 0);
        r4 = box(unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = varref (6, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2322; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2322:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (1, 0);
        r3[2] = r4;
        r4 = varref (6, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2323; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2323:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = (object*)TC_NIL;
        r2[5] = r3;
        r3 = varref (0, 3);
        r4 = (object*) &constructed_327;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[6] = r3;
        r3 = varref (0, 4);
        r4 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[7] = r3;
        r3 = varref (0, 5);
        r4 = (object*) &constructed_326;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[8] = r3;
        r3 = varref (0, 6);
        r4 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = varref (0, 7);
        r4 = (object*) &constructed_325;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = varref (0, 8);
        r4 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r2 = varref (0, 9);
        r3 = (object*) &constructed_324;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (5, 45);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2324; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2324:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (4, 33);
        r1 = ((pxll_vector*)r1)->val[4];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2320:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_31428_i4286_i4326; r1[2] = lenv;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (1, 1);
      r2[2] = r3;
      r3 = varref (5, 28);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2325; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_range_333;
      L2325:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = (object *) constructed_37[0];
      r1[3] = r2;
      r2 = varref (5, 19);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2326; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
      L2326:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv = lenv[1];
      r1 = r1;
      r0[3] = r1;
      r1 = varref (4, 33);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2327; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      L2327:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_323;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2328; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2328:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_322;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2329; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2329:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_321;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2330; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2330:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 3);
      // def lambda_31489_i4286_i4326
      goto L2331;
      FUN_lambda_31489_i4286_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 11);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 3;
        r5 = varref (1, 0);
        r4 = box(unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = varref (6, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2332; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2332:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[2] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = varref (1, 0);
        r3[2] = r4;
        r4 = varref (6, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2333; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2333:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[3] = r3;
        r3 = allocate (TC_TUPLE, 2);
        r4 = (object *) 7;
        r5 = varref (1, 0);
        r4 = box(unbox(r5)+unbox(r4));
        r3[2] = r4;
        r4 = varref (6, 54);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2334; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
        L2334:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        r2[4] = r3;
        r3 = (object*)TC_NIL;
        r2[5] = r3;
        r3 = varref (0, 3);
        r4 = (object*) &constructed_320;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[6] = r3;
        r3 = varref (0, 4);
        r4 = varref (0, 2);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[7] = r3;
        r3 = varref (0, 5);
        r4 = (object*) &constructed_319;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[8] = r3;
        r3 = varref (0, 6);
        r4 = varref (0, 1);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[9] = r3;
        r3 = varref (0, 7);
        r4 = (object*) &constructed_318;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[10] = r3;
        r3 = varref (0, 8);
        r4 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r4;
        t[2] = r3;
        r3 = t;
        r2[11] = r3;
        r2 = varref (0, 9);
        r3 = (object*) &constructed_317;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (5, 45);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2335; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2335:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = varref (4, 33);
        r1 = ((pxll_vector*)r1)->val[4];
        r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2331:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_lambda_31489_i4286_i4326; r1[2] = lenv;
      r0[2] = r1;
      r1 = allocate (TC_TUPLE, 2);
      r1[1] = lenv; lenv = r1;
      r2 = allocate (TC_TUPLE, 2);
      r3 = varref (1, 1);
      r2[2] = r3;
      r3 = varref (5, 28);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2336; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_range_333;
      L2336:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[2] = r2;
      r1 = allocate (TC_TUPLE, 3);
      r2 = varref (0, 0);
      r1[2] = r2;
      r2 = (object *) constructed_37[0];
      r1[3] = r2;
      r2 = varref (5, 19);
      t = allocate (TC_SAVE, 4);
      t[1] = k; t[2] = lenv; t[3] = &&L2337; t[4] = r0; k = t;
      r1[1] = r2[2]; lenv = r1; goto FUN_reverse_onto_320;
      L2337:
      r0 = k[4]; lenv = k[2]; k = k[1];
      r1 = result;
      lenv = lenv[1];
      r1 = r1;
      r0[3] = r1;
      r1 = varref (4, 33);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2338; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
      L2338:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_316;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2339; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2339:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (0, 2);
      r0[2] = r1;
      r1 = varref (2, 33);
      r1 = ((pxll_vector*)r1)->val[1];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2340; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2340:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 7);
      r0[1] = lenv; lenv = r0;
      // def emit_4163_i4287_i4326
      goto L2341;
      FUN_emit_4163_i4287_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = varref (1, 0);
        switch (get_case (r1)) {
          case (UOTAG(0)): {
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2342; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2342:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_72;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_71;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2343; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2343:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2344; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2344:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(1)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 1);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2345; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2345:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (8, 137);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2346; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_encode_immediate_557;
            L2346:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = (object *) -1;
            r3 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r3)==unbox(r2))) {
              r2 = (object*) &constructed_75;
              r2=r2;
            } else {
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 4);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2347; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2347:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r3 = varref (0, 2);
              r4 = (object*) &constructed_76;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2348; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2348:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r2=r2;
            }
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 6);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 1);
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2349; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2349:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_74;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = (object*) &constructed_73;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r3 = varref (0, 4);
            r4 = varref (1, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2350; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2350:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2351; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2351:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = varref (0, 1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(2)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2352; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2352:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = (object *) constructed_84[0];
              r2 = varref (1, 1);
              if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (1, 0);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2353; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2353:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (2, 0);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2354; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2354:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = (object*) &constructed_79;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = varref (0, 3);
                r5 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = varref (0, 4);
                r5 = (object*) &constructed_78;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = varref (0, 5);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = varref (0, 6);
                r4 = (object*) &constructed_77;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (8, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2355; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2355:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (7, 33);
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2356; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2356:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } else {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (1, 0);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2357; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2357:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (2, 0);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2358; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2358:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = (object*) &constructed_82;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = varref (0, 3);
                r5 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = varref (0, 4);
                r5 = (object*) &constructed_81;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = varref (0, 5);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = varref (0, 6);
                r4 = (object*) &constructed_80;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (8, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2359; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2359:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (7, 33);
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2360; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2360:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              }
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 2);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(4)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2361; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2361:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_88;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_87;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2362; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2362:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2363; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2363:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (6, 33);
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2364; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2364:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2365; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
            L2365:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (6, 33);
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2366; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2366:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_86;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2367; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2367:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (6, 33);
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2368; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2368:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 2);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2369; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
            L2369:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (6, 33);
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2370; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2370:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_85;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2371; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2371:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (0, 3);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(5)): {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = varref (0, 1);
            switch (get_case (r1)) {
              case (UOTAG(1)): {
                r1 = allocate (TC_TUPLE, 3);
                r1[1] = lenv; lenv = r1;
                r2 = varref (1, 1);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r2 = varref (1, 1);
                r2 = UOBJ_GET(r2,1);
                r1[3] = r2;
                r1 = (object *) constructed_95[0];
                r2 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
                  r1 = varref (0, 1);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 6);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      // def lambda_28264_i3043_i4287_i4326
                      goto L2372;
                      FUN_lambda_28264_i3043_i4287_i4326:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = varref (1, 0);
                        r2[2] = r3;
                        r3 = varref (11, 54);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2373; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                        L2373:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = varref (0, 1);
                        r3 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = varref (0, 2);
                        r2 = (object*) &constructed_93;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[2] = r1;
                        r1 = varref (10, 45);
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                      L2372:
                      r3 = allocate (TC_CLOSURE, 2);
                      r3[1] = &&FUN_lambda_28264_i3043_i4287_i4326; r3[2] = lenv;
                      r2[2] = r3;
                      r3 = varref (2, 0);
                      r2[3] = r3;
                      r3 = varref (9, 30);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2374; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_map_335;
                      L2374:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[4] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = varref (0, 1);
                      r2[2] = r3;
                      r3 = varref (0, 2);
                      r2[3] = r3;
                      r3 = varref (9, 138);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2375; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_in_558;
                      L2375:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[5] = r2;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = varref (0, 0);
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = varref (2, 2);
                      r3[2] = r4;
                      r4 = varref (0, 3);
                      r3[3] = r4;
                      r4 = varref (9, 140);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2376; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_cexp_subst_560;
                      L2376:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = varref (9, 139);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2377; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_559;
                      L2377:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[6] = r2;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = allocate (TC_TUPLE, 4);
                      r3[1] = lenv; lenv = r3;
                      r4 = (object*)TC_NIL;
                      r3[2] = r4;
                      r4 = varref (0, 0);
                      r5 = (object*) &constructed_92;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r5;
                      t[2] = r4;
                      r4 = t;
                      r3[3] = r4;
                      r4 = varref (0, 1);
                      r5 = varref (1, 4);
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r5;
                      t[2] = r4;
                      r4 = t;
                      r3[4] = r4;
                      r3 = varref (0, 2);
                      r4 = (object*) &constructed_91;
                      t = alloc_no_clear (TC_PAIR,2);
                      t[1] = r4;
                      t[2] = r3;
                      r3 = t;
                      lenv = lenv[1];
                      r3 = r3;
                      r2[2] = r3;
                      r3 = varref (9, 45);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2378; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                      L2378:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[2] = r2;
                      r2 = varref (8, 33);
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2379; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2379:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (8, 33);
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2380; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2380:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (2, 3);
                      r1[2] = r2;
                      r2 = varref (5, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2381; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
                      L2381:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (8, 33);
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2382; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2382:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_90;
                      r1[2] = r2;
                      r2 = varref (8, 33);
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2383; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2383:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (8, 33);
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2384; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2384:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (2, 4);
                      r1[2] = r2;
                      r2 = varref (5, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2385; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
                      L2385:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (8, 33);
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2386; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2386:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_89;
                      r1[2] = r2;
                      r2 = varref (8, 33);
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2387; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2387:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_6;
                    }
                  }
                  r1=r1;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_6;
                }
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
              default: {
                goto fatbar_6;
              }
            }
            goto fatbar_6_over;
            fatbar_6:
            r1 = (object*) &constructed_69;
            r1 = box(((pxll_string*)(r1))->len);
            r2 = (object*) &constructed_69;
            (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
            r1 = (object*) &constructed_68;
            dump_object (r1, 0); fprintf (stdout, "\n");
            r1 = (object*) &constructed_68;
            r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
            fatbar_6_over: ;
            r1 = varref (0, 5);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(6)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = varref (0, 1);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 1);
              r4[2] = r5;
              r5 = varref (8, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2388; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2388:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (8, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2389; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2389:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_98;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_97;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_96;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (7, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2390; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2390:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (6, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2391; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2391:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(3)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 3);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2392; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2392:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (1, 0);
            switch (get_case (r2)) {
              case (UOTAG(1)): {
                r2 = allocate (TC_TUPLE, 3);
                r2[1] = lenv; lenv = r2;
                r3 = varref (2, 0);
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r3 = varref (2, 0);
                r3 = UOBJ_GET(r3,1);
                r2[3] = r3;
                r2 = (object *) constructed_95[0];
                r3 = varref (0, 0);
                if PXLL_IS_TRUE(PXLL_TEST(r3==r2)) {
                  r2 = varref (0, 1);
                  switch (get_case (r2)) {
                    case (TC_PAIR): {
                      r2 = allocate (TC_TUPLE, 5);
                      r2[1] = lenv; lenv = r2;
                      r3 = varref (1, 1);
                      r3 = UOBJ_GET(r3,0);
                      r2[2] = r3;
                      r3 = varref (1, 1);
                      r3 = UOBJ_GET(r3,1);
                      r2[3] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      // def lambda_28402_i3062_i4287_i4326
                      goto L2393;
                      FUN_lambda_28402_i3062_i4287_i4326:
                        check_heap (0);
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 4);
                        r1[1] = lenv; lenv = r1;
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = varref (1, 0);
                        r2[2] = r3;
                        r3 = varref (12, 54);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2394; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                        L2394:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = (object*)TC_NIL;
                        r1[3] = r2;
                        r2 = varref (0, 1);
                        r3 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        r1[4] = r2;
                        r1 = varref (0, 2);
                        r2 = (object*) &constructed_103;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r2;
                        t[2] = r1;
                        r1 = t;
                        lenv = lenv[1];
                        r1 = r1;
                        r0[2] = r1;
                        r1 = varref (11, 45);
                        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
                      L2393:
                      r4 = allocate (TC_CLOSURE, 2);
                      r4[1] = &&FUN_lambda_28402_i3062_i4287_i4326; r4[2] = lenv;
                      r3[2] = r4;
                      r4 = varref (3, 2);
                      r3[3] = r4;
                      r4 = varref (10, 30);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2395; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_map_335;
                      L2395:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[4] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = varref (0, 1);
                      r3[2] = r4;
                      r4 = varref (0, 2);
                      r3[3] = r4;
                      r4 = varref (10, 138);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2396; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_wrap_in_558;
                      L2396:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[5] = r3;
                      r2 = allocate (TC_TUPLE, 3);
                      r3 = varref (0, 0);
                      r2[2] = r3;
                      r3 = allocate (TC_TUPLE, 3);
                      r4 = varref (3, 1);
                      r3[2] = r4;
                      r4 = varref (0, 3);
                      r3[3] = r4;
                      r4 = varref (10, 140);
                      t = allocate (TC_SAVE, 6);
                      t[1] = k; t[2] = lenv; t[3] = &&L2397; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                      r3[1] = r4[2]; lenv = r3; goto FUN_cexp_subst_560;
                      L2397:
                      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                      r3 = result;
                      r2[3] = r3;
                      r3 = varref (10, 139);
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2398; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_559;
                      L2398:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      lenv = lenv[1];
                      r2 = r2;
                      r2=r2;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_7;
                    }
                  }
                  r2=r2;
                } else {
                  lenv = ((object *)lenv)[1];
                  goto fatbar_7;
                }
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
              default: {
                goto fatbar_7;
              }
            }
            r2=r2;
            goto fatbar_7_over;
            fatbar_7:
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (1, 1);
            r2[3] = r3;
            r3 = varref (8, 139);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2399; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_wrap_out_559;
            L2399:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r2=r2;
            fatbar_7_over: ;
            r1[3] = r2;
            r1 = (object *) -1;
            r2 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 3);
              r3[1] = lenv; lenv = r3;
              r4 = (object*)TC_NIL;
              r3[2] = r4;
              r4 = varref (0, 0);
              r5 = (object*) &constructed_99;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[3] = r4;
              r3 = varref (0, 1);
              r4 = varref (1, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2400; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2400:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2401; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2401:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 7);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2402; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2402:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = (object*) &constructed_102;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = varref (1, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = (object*) &constructed_101;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r3 = varref (0, 5);
              r4 = (object*) &constructed_100;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2403; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2403:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2404; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2404:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 3);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(7)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2405; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2405:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 0);
            r2[2] = r3;
            r3 = varref (4, 1);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2406; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_gen_function_label_4170_i4287_i4326;
            L2406:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = varref (8, 186);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2407; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L2407:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = varref (2, 0);
            r4 = allocate (TC_TUPLE, 2);
            r4[1] = lenv; lenv = r4;
            r5 = varref (3, 0);
            r5 = UOBJ_GET(r5,0);
            r4[2] = r5;
            r4 = varref (0, 0);
            lenv = lenv[1];
            r4 = r4;
            r4=r4;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = varref (0, 2);
            r4 = (object*) &constructed_115;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2408; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2408:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2409; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2409:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = varref (0, 0);
            r5 = (object*) &constructed_114;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = varref (1, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = varref (0, 2);
            r4 = (object*) &constructed_113;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2410; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2410:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2411; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2411:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = varref (0, 0);
            r5 = (object*) &constructed_112;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = varref (0, 1);
            r4 = varref (1, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2412; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2412:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2413; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2413:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (7, 33);
            r1 = ((pxll_vector*)r1)->val[3];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2414; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2414:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (8, 0);
            r2[2] = r3;
            r3 = varref (2, 0);
            r2[3] = r3;
            r3 = varref (9, 3);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2415; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_vars_get_var_255;
            L2415:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (0, 0);
            r2 = ((pxll_vector*)r2)->val[1];
            r1[3] = r2;
            r1 = varref (9, 145);
            r2 = varref (0, 1);
            r1 = PXLL_TEST((unbox(r2)&(1<<unbox(r1)))>0);
            lenv = lenv[1];
            r1 = r1;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = (object*) &constructed_111;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2416; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2416:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 1);
            r1[2] = r2;
            r2 = varref (4, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2417; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
            L2417:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (7, 33);
            r1 = ((pxll_vector*)r1)->val[2];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2418; t[4] = r0; k = t;
            lenv = r1[2]; goto *r1[1];
            L2418:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = varref (0, 0);
            r5 = (object*) &constructed_110;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = varref (0, 1);
            r4 = varref (1, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2419; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2419:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2420; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2420:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2421; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2421:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_109;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_108;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2422; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2422:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2423; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2423:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 10);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2424; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2424:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2425; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2425:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = (object*) &constructed_107;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = varref (0, 4);
            r5 = (object*) &constructed_106;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = varref (0, 5);
            r5 = varref (1, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = varref (0, 6);
            r5 = (object*) &constructed_105;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = varref (0, 7);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r3 = varref (0, 8);
            r4 = (object*) &constructed_104;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2426; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2426:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2427; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2427:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = varref (0, 2);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(8)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2428; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2428:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 11);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2429; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2429:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2430; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2430:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 1);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2431; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2431:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = (object*) &constructed_119;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = varref (0, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = (object*) &constructed_118;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = varref (0, 6);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = varref (0, 7);
              r5 = (object*) &constructed_117;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = varref (0, 8);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r3 = varref (0, 9);
              r4 = (object*) &constructed_116;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2432; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2432:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2433; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2433:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 2);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(9)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 11);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2434; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2434:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 1);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2435; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2435:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 2);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2436; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2436:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[4] = r4;
            r4 = (object*)TC_NIL;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = (object*) &constructed_123;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = varref (0, 4);
            r5 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = varref (0, 5);
            r5 = (object*) &constructed_122;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = varref (0, 6);
            r5 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = varref (0, 7);
            r5 = (object*) &constructed_121;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r4 = varref (0, 8);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[11] = r4;
            r3 = varref (0, 9);
            r4 = (object*) &constructed_120;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2437; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2437:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2438; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2438:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (0, 3);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(10)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 1);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2439; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2439:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 8);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2440; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2440:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = (object *) 3;
            r6 = varref (2, 0);
            r5 = box(unbox(r6)+unbox(r5));
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2441; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2441:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = (object*) &constructed_126;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = varref (0, 4);
            r5 = (object*) &constructed_125;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = varref (0, 5);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r3 = varref (0, 6);
            r4 = (object*) &constructed_124;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2442; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2442:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2443; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2443:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = varref (0, 1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(11)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2444; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2444:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (1, 0);
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = varref (2, 0);
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (0, 0);
                r2[2] = r3;
                r3 = varref (9, 54);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2445; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
                L2445:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = varref (2, 0);
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 6);
                r3[1] = lenv; lenv = r3;
                r4 = (object *) 1;
                r5 = varref (3, 1);
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r5)==unbox(r4))) {
                  r4 = (object*) &constructed_135;
                  r4=r4;
                } else {
                  r4 = (object*) &constructed_136;
                  r4=r4;
                }
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (1, 0);
                r4[2] = r5;
                r5 = varref (10, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2446; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2446:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = (object*) &constructed_134;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = varref (0, 3);
                r5 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r3 = varref (0, 4);
                r4 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (9, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2447; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2447:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
            }
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = varref (1, 1);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 7);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2448; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2448:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = (object*) &constructed_129;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = varref (1, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = (object*) &constructed_128;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r3 = varref (0, 5);
              r4 = (object*) &constructed_127;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2449; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2449:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2450; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2450:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 10);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2451; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2451:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 1);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2452; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2452:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_133;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_132;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (1, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = varref (0, 6);
              r5 = (object*) &constructed_131;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = varref (0, 7);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r3 = varref (0, 8);
              r4 = (object*) &constructed_130;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2453; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2453:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2454; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2454:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 2);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(12)): {
            r1 = allocate (TC_TUPLE, 6);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 11);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 2);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2455; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2455:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = allocate (TC_TUPLE, 2);
            r5[1] = lenv; lenv = r5;
            r6 = varref (2, 0);
            r7 = varref (2, 3);
            r6 = box(unbox(r7)+unbox(r6));
            r5[2] = r6;
            r5 = varref (0, 0);
            r6 = (object *) 3;
            r5 = box(unbox(r6)+unbox(r5));
            lenv = lenv[1];
            r5 = r5;
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2456; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2456:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 1);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2457; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2457:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[4] = r4;
            r4 = (object*)TC_NIL;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = (object*) &constructed_140;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = varref (0, 4);
            r5 = varref (0, 2);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = varref (0, 5);
            r5 = (object*) &constructed_139;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r4 = varref (0, 6);
            r5 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[9] = r4;
            r4 = varref (0, 7);
            r5 = (object*) &constructed_138;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[10] = r4;
            r4 = varref (0, 8);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[11] = r4;
            r3 = varref (0, 9);
            r4 = (object*) &constructed_137;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2458; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2458:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2459; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2459:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (0, 4);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(13)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (8, 9);
            r2[2] = r3;
            r3 = allocate (TC_TUPLE, 2);
            r4 = varref (1, 3);
            r3[2] = r4;
            r4 = varref (8, 128);
            t = allocate (TC_SAVE, 6);
            t[1] = k; t[2] = lenv; t[3] = &&L2460; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
            r3[1] = r4[2]; lenv = r3; goto FUN_k_2ffree_524;
            L2460:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
            r3 = result;
            r2[3] = r3;
            r3 = varref (8, 42);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2461; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_sort_350;
            L2461:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (8, 186);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2462; t[4] = r0; t[5] = r1; k = t;
            lenv = r2[2]; goto *r2[1];
            L2462:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (0, 0);
            r2[2] = r3;
            r3 = varref (8, 20);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2463; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
            L2463:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[4] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 3);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2464; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2464:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 2);
            r6 = (object *) 7;
            r5 = box(unbox(r6)+unbox(r5));
            r4[2] = r5;
            r5 = varref (9, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2465; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2465:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_166;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_165;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2466; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2466:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2467; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2467:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 2);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_4353_i3164_i4287_i4326
            goto L2468;
            FUN__24loop_4353_i3164_i4287_i4326:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (0, 1);
                r0[2] = r1;
                r1 = (object *) constructed_37[0];
                r0[3] = r1;
                r1 = varref (11, 19);
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 7);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = (object *) 9;
                r5 = varref (2, 0);
                r4 = box(unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = varref (13, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2469; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2469:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = varref (5, 0);
                r4[2] = r5;
                r5 = varref (2, 0);
                r4[3] = r5;
                r5 = varref (13, 25);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2470; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_330;
                L2470:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = varref (13, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2471; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2471:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = varref (0, 2);
                r4 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = varref (0, 3);
                r4 = (object*) &constructed_164;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = varref (0, 4);
                r4 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r2 = varref (0, 5);
                r3 = (object*) &constructed_163;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (12, 45);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2472; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2472:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (1, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = (object *) 3;
                r2 = varref (0, 0);
                r1 = box(unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_4353_i3164_i4287_i4326;
              }
              PXLL_RETURN(0);
            L2468:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_4353_i3164_i4287_i4326; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = varref (0, 0);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2473; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_4353_i3164_i4287_i4326;
            L2473:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 7);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 3);
            r5 = varref (1, 1);
            r4[2] = r5;
            r5 = (object*) &constructed_162;
            r4[3] = r5;
            r5 = varref (10, 46);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2474; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_string_join_363;
            L2474:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_161;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = (object*) &constructed_160;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = varref (0, 4);
            r5 = varref (2, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r3 = varref (0, 5);
            r4 = (object*) &constructed_159;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (9, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2475; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2475:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (8, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2476; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2476:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            switch (get_case (r2)) {
              case (UITAG(1)): {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (3, 1);
                r4[2] = r5;
                r5 = varref (10, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2477; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2477:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = varref (0, 1);
                r5 = (object*) &constructed_156;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = varref (0, 3);
                r4 = (object*) &constructed_155;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (9, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2478; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2478:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = varref (3, 0);
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (1, 0);
                r4[2] = r5;
                r5 = varref (7, 1);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2479; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4170_i4287_i4326;
                L2479:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = varref (0, 1);
                r5 = (object*) &constructed_158;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = varref (0, 3);
                r4 = (object*) &constructed_157;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (10, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2480; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2480:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
            }
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = varref (2, 2);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 12);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (3, 2);
              r4[2] = r5;
              r5 = varref (10, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2481; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2481:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (3, 1);
              r4[2] = r5;
              r5 = varref (10, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2482; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2482:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (3, 2);
              r4[2] = r5;
              r5 = varref (10, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2483; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2483:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_152;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = varref (0, 6);
              r5 = (object*) &constructed_151;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = varref (0, 7);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = varref (0, 8);
              r5 = (object*) &constructed_150;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = varref (0, 9);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r3 = varref (0, 10);
              r4 = (object*) &constructed_149;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (9, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2484; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2484:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (8, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2485; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2485:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (3, 1);
              r4[2] = r5;
              r5 = varref (10, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2486; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2486:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_154;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = varref (0, 4);
              r4 = (object*) &constructed_153;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (9, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2487; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2487:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (8, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2488; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2488:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 3);
            r3[1] = lenv; lenv = r3;
            r4 = (object*)TC_NIL;
            r3[2] = r4;
            r4 = varref (0, 0);
            r5 = (object*) &constructed_148;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[3] = r4;
            r3 = varref (0, 1);
            r4 = varref (1, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2489; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2489:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2490; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2490:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 2);
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r2[1] = lenv; lenv = r2;
            // def $loop_4360_i3164_i4287_i4326
            goto L2491;
            FUN__24loop_4360_i3164_i4287_i4326:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (0, 1);
                r0[2] = r1;
                r1 = (object *) constructed_37[0];
                r0[3] = r1;
                r1 = varref (11, 19);
                r0[1] = r1[2]; lenv = r0; goto FUN_reverse_onto_320;
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 8);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = varref (5, 0);
                r4[2] = r5;
                r5 = varref (2, 0);
                r4[3] = r5;
                r5 = varref (13, 25);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2492; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_330;
                L2492:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = varref (13, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2493; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2493:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = (object *) 9;
                r5 = varref (2, 0);
                r4 = box(unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = varref (13, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2494; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2494:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = varref (0, 2);
                r4 = (object*) &constructed_147;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = varref (0, 3);
                r4 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = varref (0, 4);
                r4 = (object*) &constructed_146;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r3 = varref (0, 5);
                r4 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[8] = r3;
                r2 = varref (0, 6);
                r3 = (object*) &constructed_145;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (12, 45);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2495; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2495:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r0 = varref (1, 1);
                r1 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                r1 = (object *) 3;
                r2 = varref (0, 0);
                r1 = box(unbox(r2)+unbox(r1));
                lenv[2] = r1;
                lenv[3] = r0;
                goto FUN__24loop_4360_i3164_i4287_i4326;
              }
              PXLL_RETURN(0);
            L2491:
            r3 = allocate (TC_CLOSURE, 2);
            r3[1] = &&FUN__24loop_4360_i3164_i4287_i4326; r3[2] = lenv;
            r2[2] = r3;
            r2 = allocate (TC_TUPLE, 3);
            r3 = (object *) 1;
            r2[2] = r3;
            r3 = (object*)TC_NIL;
            r2[3] = r3;
            r3 = varref (0, 0);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2496; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN__24loop_4360_i3164_i4287_i4326;
            L2496:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            lenv = lenv[1];
            r2 = r2;
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 4);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 3);
            r5 = varref (1, 1);
            r4[2] = r5;
            r5 = (object*) &constructed_144;
            r4[3] = r5;
            r5 = varref (10, 46);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2497; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_string_join_363;
            L2497:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_143;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r3 = varref (0, 2);
            r4 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (9, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2498; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2498:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (8, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2499; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2499:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = (object *) 1;
            r2 = varref (0, 3);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 5);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 3);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2500; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2500:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = (object*) &constructed_142;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r3 = varref (0, 3);
              r4 = (object*) &constructed_141;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2501; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2501:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2502; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2502:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 3);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(14)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            switch (get_case (r2)) {
              case (UITAG(1)): {
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (2, 1);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2503; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2503:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = varref (0, 1);
                r5 = (object*) &constructed_174;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = varref (0, 3);
                r4 = (object*) &constructed_173;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (8, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2504; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2504:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r2=r2;
              } break;
              default: {
                r2 = allocate (TC_TUPLE, 2);
                r2[1] = lenv; lenv = r2;
                r3 = varref (2, 0);
                r3 = UOBJ_GET(r3,0);
                r2[2] = r3;
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 5);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (1, 0);
                r4[2] = r5;
                r5 = varref (6, 1);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2505; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4170_i4287_i4326;
                L2505:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = (object*)TC_NIL;
                r3[3] = r4;
                r4 = varref (0, 1);
                r5 = (object*) &constructed_176;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r3 = varref (0, 3);
                r4 = (object*) &constructed_175;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (9, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2506; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2506:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                lenv = lenv[1];
                r2 = r2;
                r2=r2;
              } break;
            }
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = varref (1, 2);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 12);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 2);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2507; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2507:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 1);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2508; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2508:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 2);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2509; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2509:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[4] = r4;
              r4 = (object*)TC_NIL;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_170;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 2);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r4 = varref (0, 6);
              r5 = (object*) &constructed_169;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[9] = r4;
              r4 = varref (0, 7);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[10] = r4;
              r4 = varref (0, 8);
              r5 = (object*) &constructed_168;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[11] = r4;
              r4 = varref (0, 9);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[12] = r4;
              r3 = varref (0, 10);
              r4 = (object*) &constructed_167;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2510; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2510:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2511; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2511:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 6);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 1);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2512; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2512:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = (object*)TC_NIL;
              r3[3] = r4;
              r4 = varref (0, 1);
              r5 = varref (1, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_172;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r3 = varref (0, 4);
              r4 = (object*) &constructed_171;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2513; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2513:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2514; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2514:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(15)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 20);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2515; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
            L2515:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = (object *) 3;
            r3 = varref (1, 0);
            r2 = box(unbox(r3)-unbox(r2));
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
              r1 = (object *) 3;
              r2 = varref (0, 1);
              r1 = box(unbox(r2)+unbox(r1));
              varset (0, 1, r1);
            } else {
              r1 = (object *) 14;
            }
            r1 = (object *) 1;
            r2 = varref (0, 1);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = varref (1, 1);
              r5[2] = r6;
              r6 = (object*) &constructed_186;
              r5[3] = r6;
              r6 = varref (9, 29);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2516; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_334;
              L2516:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (9, 45);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2517; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2517:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = varref (1, 1);
              r5[2] = r6;
              r6 = (object*) &constructed_185;
              r5[3] = r6;
              r6 = varref (9, 29);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2518; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_334;
              L2518:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (9, 45);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2519; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2519:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_184;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_183;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_182;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2520; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2520:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2521; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2521:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4370_i3258_i4287_i4326
            goto L2522;
            FUN__24loop_4370_i3258_i4287_i4326:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 2);
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 8);
                r2[1] = lenv; lenv = r2;
                r3 = allocate (TC_TUPLE, 2);
                r4 = varref (1, 0);
                r5 = (object *) 5;
                r4 = box(unbox(r5)+unbox(r4));
                r3[2] = r4;
                r4 = varref (12, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2523; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2523:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = allocate (TC_TUPLE, 3);
                r5 = varref (5, 2);
                r4[2] = r5;
                r5 = varref (1, 0);
                r4[3] = r5;
                r5 = varref (12, 25);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2524; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_nth_330;
                L2524:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = varref (12, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2525; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2525:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = varref (0, 2);
                r4 = (object*) &constructed_181;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = varref (0, 3);
                r4 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r3 = varref (0, 4);
                r4 = (object*) &constructed_180;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[7] = r3;
                r3 = varref (0, 5);
                r4 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[8] = r3;
                r2 = varref (0, 6);
                r3 = (object*) &constructed_179;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (11, 45);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2526; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2526:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = varref (10, 33);
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2527; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2527:
                ; lenv = k[2]; k = k[1];
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4370_i3258_i4287_i4326;
              }
              PXLL_RETURN(0);
            L2522:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4370_i3258_i4287_i4326; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = varref (0, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2528; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4370_i3258_i4287_i4326;
            L2528:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (2, 1);
            r4[2] = r5;
            r5 = varref (5, 1);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2529; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_gen_function_label_4170_i4287_i4326;
            L2529:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_178;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_177;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (8, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2530; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2530:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2531; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2531:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(16)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 8);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2532; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2532:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2533; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2533:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[3] = r4;
            r4 = (object*)TC_NIL;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = (object*) &constructed_189;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r4 = varref (0, 3);
            r5 = varref (0, 1);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[6] = r4;
            r4 = varref (0, 4);
            r5 = (object*) &constructed_188;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[7] = r4;
            r4 = varref (0, 5);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[8] = r4;
            r3 = varref (0, 6);
            r4 = (object*) &constructed_187;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2534; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2534:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2535; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2535:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (0, 1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(17)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 1);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2536; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2536:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_193;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2537; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2537:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object *) 1;
            r2 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (1, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2538; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2538:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2539; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2539:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_192;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_191;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_190;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2540; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2540:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2541; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2541:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 14;
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(18)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def primop-error_4398_i3298_i4287_i4326
            goto L2542;
            FUN_primop_error_4398_i3298_i4287_i4326:
              check_heap (0);
              r0 = allocate (TC_TUPLE, 3);
              r1 = (object*) &constructed_208;
              r0[2] = r1;
              r1 = varref (1, 0);
              r0[3] = r1;
              r1 = varref (8, 12);
              r0[1] = r1[2]; lenv = r0; goto FUN_error1_303;
            L2542:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN_primop_error_4398_i3298_i4287_i4326; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (2, 3);
            r2[2] = r3;
            r3 = varref (9, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2543; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2543:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (2, 2);
            r2[2] = r3;
            r3 = varref (9, 20);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2544; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
            L2544:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = (object *) constructed_198[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = allocate (TC_TUPLE, 2);
              r7 = varref (3, 3);
              r6[2] = r7;
              r7 = varref (10, 128);
              t = allocate (TC_SAVE, 9);
              t[1] = k; t[2] = lenv; t[3] = &&L2545; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; t[9] = r5; k = t;
              r6[1] = r7[2]; lenv = r6; goto FUN_k_2ffree_524;
              L2545:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; r5 = k[9]; lenv = k[2]; k = k[1];
              r6 = result;
              r5[2] = r6;
              r6 = varref (10, 20);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2546; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_length_323;
              L2546:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (10, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2547; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2547:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 2);
              r6 = varref (3, 2);
              r5[2] = r6;
              r6 = varref (10, 17);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2548; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_car_318;
              L2548:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (10, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2549; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2549:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_196;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_195;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_194;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (9, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2550; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2550:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (8, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2551; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2551:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              goto fatbar_8;
            }
            r1=r1;
            goto fatbar_8_over;
            fatbar_8:
            r1 = (object *) constructed_210[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 1);
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = varref (0, 0);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = varref (0, 0);
                      switch (get_case (r1)) {
                        case (UOTAG(1)): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (1, 0);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = varref (1, 1);
                          switch (get_case (r1)) {
                            case (TC_PAIR): {
                              r1 = allocate (TC_TUPLE, 3);
                              r1[1] = lenv; lenv = r1;
                              r2 = varref (2, 1);
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r2 = varref (2, 1);
                              r2 = UOBJ_GET(r2,1);
                              r1[3] = r2;
                              r1 = varref (0, 0);
                              switch (get_case (r1)) {
                                case (UOTAG(0)): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = varref (1, 0);
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r1 = varref (1, 1);
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = varref (7, 2);
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = varref (8, 2);
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = varref (8, 2);
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = varref (0, 1);
                                          switch (get_case (r1)) {
                                            case (TC_PAIR): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = varref (1, 1);
                                              r2 = UOBJ_GET(r2,0);
                                              r1[2] = r2;
                                              r2 = varref (1, 1);
                                              r2 = UOBJ_GET(r2,1);
                                              r1[3] = r2;
                                              r1 = varref (0, 1);
                                              switch (get_case (r1)) {
                                                case (TC_NIL): {
                                                  r1 = allocate (TC_TUPLE, 3);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = allocate (TC_TUPLE, 3);
                                                  r3 = varref (5, 0);
                                                  r2[2] = r3;
                                                  r3 = varref (16, 0);
                                                  r2[3] = r3;
                                                  r3 = varref (17, 7);
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2552; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_lookup_label_code_262;
                                                  L2552:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = varref (3, 0);
                                                  r2[2] = r3;
                                                  r3 = varref (13, 2);
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2553; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_guess_record_type_4183_i4287_i4326;
                                                  L2553:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[3] = r2;
                                                  r1 = varref (0, 1);
                                                  switch (get_case (r1)) {
                                                    case (UOTAG(0)): {
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r1[1] = lenv; lenv = r1;
                                                      r2 = varref (1, 1);
                                                      r2 = UOBJ_GET(r2,0);
                                                      r1[2] = r2;
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = allocate (TC_TUPLE, 2);
                                                      r3 = allocate (TC_TUPLE, 11);
                                                      r3[1] = lenv; lenv = r3;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = varref (4, 0);
                                                      r4[2] = r5;
                                                      r5 = varref (19, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2554; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2554:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[2] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = allocate (TC_TUPLE, 3);
                                                      r6 = varref (7, 0);
                                                      r5[2] = r6;
                                                      r6 = varref (1, 0);
                                                      r5[3] = r6;
                                                      r6 = varref (19, 26);
                                                      t = allocate (TC_SAVE, 8);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2555; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                                      r5[1] = r6[2]; lenv = r5; goto FUN_index_eq_331;
                                                      L2555:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                                      r5 = result;
                                                      r4[2] = r5;
                                                      r5 = varref (19, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2556; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2556:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[3] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = varref (3, 0);
                                                      r4[2] = r5;
                                                      r5 = varref (19, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2557; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2557:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[4] = r4;
                                                      r4 = (object*)TC_NIL;
                                                      r3[5] = r4;
                                                      r4 = varref (0, 3);
                                                      r5 = (object*) &constructed_202;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[6] = r4;
                                                      r4 = varref (0, 4);
                                                      r5 = varref (0, 2);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[7] = r4;
                                                      r4 = varref (0, 5);
                                                      r5 = (object*) &constructed_201;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[8] = r4;
                                                      r4 = varref (0, 6);
                                                      r5 = varref (0, 1);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[9] = r4;
                                                      r4 = varref (0, 7);
                                                      r5 = (object*) &constructed_200;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[10] = r4;
                                                      r4 = varref (0, 8);
                                                      r5 = varref (0, 0);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[11] = r4;
                                                      r3 = varref (0, 9);
                                                      r4 = (object*) &constructed_199;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r4;
                                                      t[2] = r3;
                                                      r3 = t;
                                                      lenv = lenv[1];
                                                      r3 = r3;
                                                      r2[2] = r3;
                                                      r3 = varref (18, 45);
                                                      t = allocate (TC_SAVE, 5);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2558; t[4] = r0; t[5] = r1; k = t;
                                                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                      L2558:
                                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                      r2 = result;
                                                      r1[2] = r2;
                                                      r2 = varref (17, 33);
                                                      r2 = ((pxll_vector*)r2)->val[4];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2559; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                      L2559:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      lenv = lenv[1];
                                                      r1 = r1;
                                                      r1=r1;
                                                    } break;
                                                    default: {
                                                      r1 = allocate (TC_TUPLE, 2);
                                                      r2 = allocate (TC_TUPLE, 2);
                                                      r3 = allocate (TC_TUPLE, 14);
                                                      r3[1] = lenv; lenv = r3;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = varref (3, 0);
                                                      r4[2] = r5;
                                                      r5 = varref (18, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2560; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2560:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[2] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = varref (3, 0);
                                                      r4[2] = r5;
                                                      r5 = varref (18, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2561; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2561:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[3] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = varref (1, 0);
                                                      r4[2] = r5;
                                                      r5 = varref (18, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2562; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2562:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[4] = r4;
                                                      r4 = allocate (TC_TUPLE, 2);
                                                      r5 = varref (2, 0);
                                                      r4[2] = r5;
                                                      r5 = varref (18, 54);
                                                      t = allocate (TC_SAVE, 7);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2563; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                      r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                      L2563:
                                                      r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                      r4 = result;
                                                      r3[5] = r4;
                                                      r4 = (object*)TC_NIL;
                                                      r3[6] = r4;
                                                      r4 = varref (0, 4);
                                                      r5 = (object*) &constructed_207;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[7] = r4;
                                                      r4 = varref (0, 5);
                                                      r5 = varref (0, 3);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[8] = r4;
                                                      r4 = varref (0, 6);
                                                      r5 = (object*) &constructed_206;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[9] = r4;
                                                      r4 = varref (0, 7);
                                                      r5 = varref (0, 2);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[10] = r4;
                                                      r4 = varref (0, 8);
                                                      r5 = (object*) &constructed_205;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[11] = r4;
                                                      r4 = varref (0, 9);
                                                      r5 = varref (0, 1);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[12] = r4;
                                                      r4 = varref (0, 10);
                                                      r5 = (object*) &constructed_204;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[13] = r4;
                                                      r4 = varref (0, 11);
                                                      r5 = varref (0, 0);
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r5;
                                                      t[2] = r4;
                                                      r4 = t;
                                                      r3[14] = r4;
                                                      r3 = varref (0, 12);
                                                      r4 = (object*) &constructed_203;
                                                      t = alloc_no_clear (TC_PAIR,2);
                                                      t[1] = r4;
                                                      t[2] = r3;
                                                      r3 = t;
                                                      lenv = lenv[1];
                                                      r3 = r3;
                                                      r2[2] = r3;
                                                      r3 = varref (17, 45);
                                                      t = allocate (TC_SAVE, 5);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2564; t[4] = r0; t[5] = r1; k = t;
                                                      r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                      L2564:
                                                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                      r2 = result;
                                                      r1[2] = r2;
                                                      r2 = varref (16, 33);
                                                      r2 = ((pxll_vector*)r2)->val[4];
                                                      t = allocate (TC_SAVE, 4);
                                                      t[1] = k; t[2] = lenv; t[3] = &&L2565; t[4] = r0; k = t;
                                                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                      L2565:
                                                      r0 = k[4]; lenv = k[2]; k = k[1];
                                                      r1 = result;
                                                      r1=r1;
                                                    } break;
                                                  }
                                                  lenv = lenv[1];
                                                  r1 = r1;
                                                  r1=r1;
                                                } break;
                                                default: {
                                                  lenv = ((object *******)lenv)[1][1][1][1][1][1][1];
                                                  goto fatbar_10;
                                                }
                                              }
                                              lenv = lenv[1];
                                              r1 = r1;
                                              r1=r1;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_10;
                                            }
                                          }
                                          lenv = lenv[1];
                                          r1 = r1;
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_10;
                                        }
                                      }
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_10;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_10;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_10;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_10;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_10;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_10;
                }
              }
              r1=r1;
              goto fatbar_10_over;
              fatbar_10:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2566; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2566:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_10_over: ;
              r1=r1;
            } else {
              goto fatbar_9;
            }
            r1=r1;
            goto fatbar_9_over;
            fatbar_9:
            r1 = (object *) constructed_221[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 1);
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = varref (0, 0);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = varref (0, 0);
                      switch (get_case (r1)) {
                        case (UOTAG(1)): {
                          r1 = allocate (TC_TUPLE, 2);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (1, 0);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r1 = varref (1, 1);
                          switch (get_case (r1)) {
                            case (TC_PAIR): {
                              r1 = allocate (TC_TUPLE, 3);
                              r1[1] = lenv; lenv = r1;
                              r2 = varref (2, 1);
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r2 = varref (2, 1);
                              r2 = UOBJ_GET(r2,1);
                              r1[3] = r2;
                              r1 = varref (0, 0);
                              switch (get_case (r1)) {
                                case (UOTAG(0)): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = varref (1, 0);
                                  r2 = UOBJ_GET(r2,0);
                                  r1[2] = r2;
                                  r1 = varref (1, 1);
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = varref (7, 2);
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = varref (8, 2);
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = varref (8, 2);
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = varref (0, 1);
                                          switch (get_case (r1)) {
                                            case (TC_NIL): {
                                              r1 = allocate (TC_TUPLE, 3);
                                              r1[1] = lenv; lenv = r1;
                                              r2 = allocate (TC_TUPLE, 3);
                                              r3 = varref (4, 0);
                                              r2[2] = r3;
                                              r3 = varref (15, 0);
                                              r2[3] = r3;
                                              r3 = varref (16, 7);
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2567; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_lookup_label_code_262;
                                              L2567:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[2] = r2;
                                              r2 = allocate (TC_TUPLE, 2);
                                              r3 = varref (2, 0);
                                              r2[2] = r3;
                                              r3 = varref (12, 2);
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2568; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_guess_record_type_4183_i4287_i4326;
                                              L2568:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[3] = r2;
                                              r1 = varref (0, 1);
                                              switch (get_case (r1)) {
                                                case (UOTAG(0)): {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r1[1] = lenv; lenv = r1;
                                                  r2 = varref (1, 1);
                                                  r2 = UOBJ_GET(r2,0);
                                                  r1[2] = r2;
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = allocate (TC_TUPLE, 11);
                                                  r3[1] = lenv; lenv = r3;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = varref (9, 0);
                                                  r4[2] = r5;
                                                  r5 = varref (18, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2569; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2569:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[2] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = varref (3, 0);
                                                  r4[2] = r5;
                                                  r5 = varref (18, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2570; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2570:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[3] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = allocate (TC_TUPLE, 3);
                                                  r6 = varref (6, 0);
                                                  r5[2] = r6;
                                                  r6 = varref (1, 0);
                                                  r5[3] = r6;
                                                  r6 = varref (18, 26);
                                                  t = allocate (TC_SAVE, 8);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2571; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
                                                  r5[1] = r6[2]; lenv = r5; goto FUN_index_eq_331;
                                                  L2571:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
                                                  r5 = result;
                                                  r4[2] = r5;
                                                  r5 = varref (18, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2572; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2572:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[4] = r4;
                                                  r4 = (object*)TC_NIL;
                                                  r3[5] = r4;
                                                  r4 = varref (0, 3);
                                                  r5 = (object*) &constructed_214;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[6] = r4;
                                                  r4 = varref (0, 4);
                                                  r5 = varref (0, 2);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[7] = r4;
                                                  r4 = varref (0, 5);
                                                  r5 = (object*) &constructed_213;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[8] = r4;
                                                  r4 = varref (0, 6);
                                                  r5 = varref (0, 1);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[9] = r4;
                                                  r4 = varref (0, 7);
                                                  r5 = (object*) &constructed_212;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[10] = r4;
                                                  r4 = varref (0, 8);
                                                  r5 = varref (0, 0);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[11] = r4;
                                                  r3 = varref (0, 9);
                                                  r4 = (object*) &constructed_211;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r4;
                                                  t[2] = r3;
                                                  r3 = t;
                                                  lenv = lenv[1];
                                                  r3 = r3;
                                                  r2[2] = r3;
                                                  r3 = varref (17, 45);
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2573; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                  L2573:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = varref (16, 33);
                                                  r2 = ((pxll_vector*)r2)->val[4];
                                                  t = allocate (TC_SAVE, 4);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2574; t[4] = r0; k = t;
                                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                  L2574:
                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                  r1 = result;
                                                  lenv = lenv[1];
                                                  r1 = r1;
                                                  r1=r1;
                                                } break;
                                                default: {
                                                  r1 = allocate (TC_TUPLE, 2);
                                                  r2 = allocate (TC_TUPLE, 2);
                                                  r3 = allocate (TC_TUPLE, 14);
                                                  r3[1] = lenv; lenv = r3;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = varref (8, 0);
                                                  r4[2] = r5;
                                                  r5 = varref (17, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2575; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2575:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[2] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = varref (2, 0);
                                                  r4[2] = r5;
                                                  r5 = varref (17, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2576; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2576:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[3] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = varref (2, 0);
                                                  r4[2] = r5;
                                                  r5 = varref (17, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2577; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2577:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[4] = r4;
                                                  r4 = allocate (TC_TUPLE, 2);
                                                  r5 = varref (1, 0);
                                                  r4[2] = r5;
                                                  r5 = varref (17, 54);
                                                  t = allocate (TC_SAVE, 7);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2578; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                                  L2578:
                                                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                                  r4 = result;
                                                  r3[5] = r4;
                                                  r4 = (object*)TC_NIL;
                                                  r3[6] = r4;
                                                  r4 = varref (0, 4);
                                                  r5 = (object*) &constructed_219;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[7] = r4;
                                                  r4 = varref (0, 5);
                                                  r5 = varref (0, 3);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[8] = r4;
                                                  r4 = varref (0, 6);
                                                  r5 = (object*) &constructed_218;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[9] = r4;
                                                  r4 = varref (0, 7);
                                                  r5 = varref (0, 2);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[10] = r4;
                                                  r4 = varref (0, 8);
                                                  r5 = (object*) &constructed_217;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[11] = r4;
                                                  r4 = varref (0, 9);
                                                  r5 = varref (0, 1);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[12] = r4;
                                                  r4 = varref (0, 10);
                                                  r5 = (object*) &constructed_216;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[13] = r4;
                                                  r4 = varref (0, 11);
                                                  r5 = varref (0, 0);
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r5;
                                                  t[2] = r4;
                                                  r4 = t;
                                                  r3[14] = r4;
                                                  r3 = varref (0, 12);
                                                  r4 = (object*) &constructed_215;
                                                  t = alloc_no_clear (TC_PAIR,2);
                                                  t[1] = r4;
                                                  t[2] = r3;
                                                  r3 = t;
                                                  lenv = lenv[1];
                                                  r3 = r3;
                                                  r2[2] = r3;
                                                  r3 = varref (16, 45);
                                                  t = allocate (TC_SAVE, 5);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2579; t[4] = r0; t[5] = r1; k = t;
                                                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                                  L2579:
                                                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                                  r2 = result;
                                                  r1[2] = r2;
                                                  r2 = varref (15, 33);
                                                  r2 = ((pxll_vector*)r2)->val[4];
                                                  t = allocate (TC_SAVE, 4);
                                                  t[1] = k; t[2] = lenv; t[3] = &&L2580; t[4] = r0; k = t;
                                                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                                  L2580:
                                                  r0 = k[4]; lenv = k[2]; k = k[1];
                                                  r1 = result;
                                                  r1=r1;
                                                } break;
                                              }
                                              lenv = lenv[1];
                                              r1 = r1;
                                              r1=r1;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_12;
                                            }
                                          }
                                          lenv = lenv[1];
                                          r1 = r1;
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_12;
                                        }
                                      }
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_12;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_12;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_12;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_12;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_12;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_12;
                }
              }
              r1=r1;
              goto fatbar_12_over;
              fatbar_12:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2581; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2581:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_12_over: ;
              r1=r1;
            } else {
              goto fatbar_11;
            }
            r1=r1;
            goto fatbar_11_over;
            fatbar_11:
            r1 = (object *) constructed_230[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 2);
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 2);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (3, 2);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = varref (0, 1);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = varref (0, 1);
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (1, 1);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = varref (1, 1);
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = varref (0, 1);
                          switch (get_case (r1)) {
                            case (TC_NIL): {
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 2);
                              r3 = allocate (TC_TUPLE, 8);
                              r3[1] = lenv; lenv = r3;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = varref (3, 0);
                              r4[2] = r5;
                              r5 = varref (13, 54);
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2582; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2582:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[2] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = varref (2, 0);
                              r4[2] = r5;
                              r5 = varref (13, 54);
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2583; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2583:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[3] = r4;
                              r4 = (object*)TC_NIL;
                              r3[4] = r4;
                              r4 = varref (0, 2);
                              r5 = (object*) &constructed_228;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[5] = r4;
                              r4 = varref (0, 3);
                              r5 = varref (0, 1);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[6] = r4;
                              r4 = varref (0, 4);
                              r5 = (object*) &constructed_227;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[7] = r4;
                              r4 = varref (0, 5);
                              r5 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[8] = r4;
                              r3 = varref (0, 6);
                              r4 = (object*) &constructed_226;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              lenv = lenv[1];
                              r3 = r3;
                              r2[2] = r3;
                              r3 = varref (12, 45);
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2584; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                              L2584:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r2 = varref (11, 33);
                              r2 = ((pxll_vector*)r2)->val[4];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2585; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                              L2585:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = allocate (TC_TUPLE, 2);
                              r2 = allocate (TC_TUPLE, 2);
                              r3 = allocate (TC_TUPLE, 11);
                              r3[1] = lenv; lenv = r3;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = varref (3, 0);
                              r4[2] = r5;
                              r5 = varref (13, 54);
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2586; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2586:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[2] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = varref (2, 0);
                              r4[2] = r5;
                              r5 = varref (13, 54);
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2587; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2587:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[3] = r4;
                              r4 = allocate (TC_TUPLE, 2);
                              r5 = varref (1, 0);
                              r4[2] = r5;
                              r5 = varref (13, 54);
                              t = allocate (TC_SAVE, 7);
                              t[1] = k; t[2] = lenv; t[3] = &&L2588; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                              L2588:
                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                              r4 = result;
                              r3[4] = r4;
                              r4 = (object*)TC_NIL;
                              r3[5] = r4;
                              r4 = varref (0, 3);
                              r5 = (object*) &constructed_225;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[6] = r4;
                              r4 = varref (0, 4);
                              r5 = varref (0, 2);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[7] = r4;
                              r4 = varref (0, 5);
                              r5 = (object*) &constructed_224;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[8] = r4;
                              r4 = varref (0, 6);
                              r5 = varref (0, 1);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[9] = r4;
                              r4 = varref (0, 7);
                              r5 = (object*) &constructed_223;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[10] = r4;
                              r4 = varref (0, 8);
                              r5 = varref (0, 0);
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r5;
                              t[2] = r4;
                              r4 = t;
                              r3[11] = r4;
                              r3 = varref (0, 9);
                              r4 = (object*) &constructed_222;
                              t = alloc_no_clear (TC_PAIR,2);
                              t[1] = r4;
                              t[2] = r3;
                              r3 = t;
                              lenv = lenv[1];
                              r3 = r3;
                              r2[2] = r3;
                              r3 = varref (12, 45);
                              t = allocate (TC_SAVE, 5);
                              t[1] = k; t[2] = lenv; t[3] = &&L2589; t[4] = r0; t[5] = r1; k = t;
                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                              L2589:
                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                              r2 = result;
                              r1[2] = r2;
                              r2 = varref (11, 33);
                              r2 = ((pxll_vector*)r2)->val[4];
                              t = allocate (TC_SAVE, 4);
                              t[1] = k; t[2] = lenv; t[3] = &&L2590; t[4] = r0; k = t;
                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                              L2590:
                              r0 = k[4]; lenv = k[2]; k = k[1];
                              r1 = result;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_14;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_14;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_14;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_14;
                }
              }
              r1=r1;
              goto fatbar_14_over;
              fatbar_14:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2591; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2591:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_14_over: ;
              r1=r1;
            } else {
              goto fatbar_13;
            }
            r1=r1;
            goto fatbar_13_over;
            fatbar_13:
            r1 = (object *) constructed_239[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 2);
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 2);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (3, 2);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = varref (0, 1);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = varref (0, 1);
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (2, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2592; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2592:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (1, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2593; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2593:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = varref (0, 2);
                          r5 = (object*) &constructed_237;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = varref (0, 3);
                          r5 = varref (0, 1);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = varref (0, 4);
                          r5 = (object*) &constructed_236;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = varref (0, 5);
                          r5 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = varref (0, 6);
                          r4 = (object*) &constructed_235;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = varref (11, 45);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2594; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2594:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2595; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2595:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 11);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (3, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2596; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2596:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (2, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2597; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2597:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (1, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2598; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2598:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[4] = r4;
                          r4 = (object*)TC_NIL;
                          r3[5] = r4;
                          r4 = varref (0, 3);
                          r5 = (object*) &constructed_234;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = varref (0, 4);
                          r5 = varref (0, 2);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = varref (0, 5);
                          r5 = (object*) &constructed_233;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r4 = varref (0, 6);
                          r5 = varref (0, 1);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[9] = r4;
                          r4 = varref (0, 7);
                          r5 = (object*) &constructed_232;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[10] = r4;
                          r4 = varref (0, 8);
                          r5 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[11] = r4;
                          r3 = varref (0, 9);
                          r4 = (object*) &constructed_231;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = varref (11, 45);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2599; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2599:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2600; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2600:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_16;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_16;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_16;
                }
              }
              r1=r1;
              goto fatbar_16_over;
              fatbar_16:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2601; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2601:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_16_over: ;
              r1=r1;
            } else {
              goto fatbar_15;
            }
            r1=r1;
            goto fatbar_15_over;
            fatbar_15:
            r1 = (object *) constructed_252[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 2);
              switch (get_case (r1)) {
                case (TC_PAIR): {
                  r1 = allocate (TC_TUPLE, 3);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 2);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (3, 2);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r1 = varref (0, 1);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = varref (1, 1);
                      r2 = UOBJ_GET(r2,1);
                      r1[3] = r2;
                      r1 = varref (0, 1);
                      switch (get_case (r1)) {
                        case (TC_NIL): {
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (2, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2602; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2602:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (3, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2603; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2603:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = varref (0, 2);
                          r5 = (object*) &constructed_250;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = varref (0, 3);
                          r5 = varref (0, 1);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = varref (0, 4);
                          r5 = (object*) &constructed_249;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = varref (0, 5);
                          r5 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = varref (0, 6);
                          r4 = (object*) &constructed_248;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = varref (11, 45);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2604; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2604:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2605; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2605:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (2, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2606; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2606:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = varref (0, 1);
                          r5 = (object*) &constructed_247;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = varref (0, 2);
                          r5 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = varref (0, 3);
                          r4 = (object*) &constructed_246;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = varref (11, 45);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2607; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2607:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2608; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2608:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 8);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (2, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2609; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2609:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (1, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2610; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2610:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[3] = r4;
                          r4 = (object*)TC_NIL;
                          r3[4] = r4;
                          r4 = varref (0, 2);
                          r5 = (object*) &constructed_245;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r4 = varref (0, 3);
                          r5 = varref (0, 1);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[6] = r4;
                          r4 = varref (0, 4);
                          r5 = (object*) &constructed_244;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[7] = r4;
                          r4 = varref (0, 5);
                          r5 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[8] = r4;
                          r3 = varref (0, 6);
                          r4 = (object*) &constructed_243;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = varref (11, 45);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2611; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2611:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2612; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2612:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = allocate (TC_TUPLE, 2);
                          r3 = allocate (TC_TUPLE, 5);
                          r3[1] = lenv; lenv = r3;
                          r4 = allocate (TC_TUPLE, 2);
                          r5 = varref (3, 0);
                          r4[2] = r5;
                          r5 = varref (12, 54);
                          t = allocate (TC_SAVE, 7);
                          t[1] = k; t[2] = lenv; t[3] = &&L2613; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                          r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                          L2613:
                          r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                          r4 = result;
                          r3[2] = r4;
                          r4 = (object*)TC_NIL;
                          r3[3] = r4;
                          r4 = varref (0, 1);
                          r5 = (object*) &constructed_242;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[4] = r4;
                          r4 = varref (0, 2);
                          r5 = varref (0, 0);
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r5;
                          t[2] = r4;
                          r4 = t;
                          r3[5] = r4;
                          r3 = varref (0, 3);
                          r4 = (object*) &constructed_241;
                          t = alloc_no_clear (TC_PAIR,2);
                          t[1] = r4;
                          t[2] = r3;
                          r3 = t;
                          lenv = lenv[1];
                          r3 = r3;
                          r2[2] = r3;
                          r3 = varref (11, 45);
                          t = allocate (TC_SAVE, 5);
                          t[1] = k; t[2] = lenv; t[3] = &&L2614; t[4] = r0; t[5] = r1; k = t;
                          r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                          L2614:
                          r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                          r2 = result;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2615; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2615:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = allocate (TC_TUPLE, 2);
                          r2 = (object*) &constructed_240;
                          r1[2] = r2;
                          r2 = varref (10, 33);
                          r2 = ((pxll_vector*)r2)->val[4];
                          t = allocate (TC_SAVE, 4);
                          t[1] = k; t[2] = lenv; t[3] = &&L2616; t[4] = r0; k = t;
                          r1[1] = r2[2]; lenv = r1; goto *r2[1];
                          L2616:
                          r0 = k[4]; lenv = k[2]; k = k[1];
                          r1 = result;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_18;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_18;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_18;
                }
              }
              r1=r1;
              goto fatbar_18_over;
              fatbar_18:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2617; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2617:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_18_over: ;
              r1=r1;
            } else {
              goto fatbar_17;
            }
            r1=r1;
            goto fatbar_17_over;
            fatbar_17:
            r1 = (object *) constructed_258[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 1);
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = varref (0, 0);
                  switch (get_case (r1)) {
                    case (TC_PAIR): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 0);
                      r2 = UOBJ_GET(r2,1);
                      r1[2] = r2;
                      r1 = varref (0, 0);
                      switch (get_case (r1)) {
                        case (TC_PAIR): {
                          r1 = allocate (TC_TUPLE, 3);
                          r1[1] = lenv; lenv = r1;
                          r2 = varref (1, 0);
                          r2 = UOBJ_GET(r2,0);
                          r1[2] = r2;
                          r2 = varref (1, 0);
                          r2 = UOBJ_GET(r2,1);
                          r1[3] = r2;
                          r1 = varref (0, 0);
                          switch (get_case (r1)) {
                            case (UOTAG(5)): {
                              r1 = allocate (TC_TUPLE, 2);
                              r1[1] = lenv; lenv = r1;
                              r2 = varref (1, 0);
                              r2 = UOBJ_GET(r2,0);
                              r1[2] = r2;
                              r1 = varref (1, 1);
                              switch (get_case (r1)) {
                                case (TC_PAIR): {
                                  r1 = allocate (TC_TUPLE, 2);
                                  r1[1] = lenv; lenv = r1;
                                  r2 = varref (2, 1);
                                  r2 = UOBJ_GET(r2,1);
                                  r1[2] = r2;
                                  r1 = varref (0, 0);
                                  switch (get_case (r1)) {
                                    case (TC_NIL): {
                                      r1 = varref (7, 2);
                                      switch (get_case (r1)) {
                                        case (TC_PAIR): {
                                          r1 = allocate (TC_TUPLE, 3);
                                          r1[1] = lenv; lenv = r1;
                                          r2 = varref (8, 2);
                                          r2 = UOBJ_GET(r2,0);
                                          r1[2] = r2;
                                          r2 = varref (8, 2);
                                          r2 = UOBJ_GET(r2,1);
                                          r1[3] = r2;
                                          r1 = varref (0, 1);
                                          switch (get_case (r1)) {
                                            case (TC_NIL): {
                                              r1 = allocate (TC_TUPLE, 2);
                                              r2 = allocate (TC_TUPLE, 2);
                                              r3 = allocate (TC_TUPLE, 11);
                                              r3[1] = lenv; lenv = r3;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = varref (7, 0);
                                              r4[2] = r5;
                                              r5 = varref (16, 54);
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2618; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                              L2618:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[2] = r4;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = varref (1, 0);
                                              r4[2] = r5;
                                              r5 = varref (16, 54);
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2619; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                              L2619:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[3] = r4;
                                              r4 = allocate (TC_TUPLE, 2);
                                              r5 = varref (3, 0);
                                              r4[2] = r5;
                                              r5 = varref (16, 54);
                                              t = allocate (TC_SAVE, 7);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2620; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                                              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                                              L2620:
                                              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                                              r4 = result;
                                              r3[4] = r4;
                                              r4 = (object*)TC_NIL;
                                              r3[5] = r4;
                                              r4 = varref (0, 3);
                                              r5 = (object*) &constructed_256;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[6] = r4;
                                              r4 = varref (0, 4);
                                              r5 = varref (0, 2);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[7] = r4;
                                              r4 = varref (0, 5);
                                              r5 = (object*) &constructed_255;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[8] = r4;
                                              r4 = varref (0, 6);
                                              r5 = varref (0, 1);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[9] = r4;
                                              r4 = varref (0, 7);
                                              r5 = (object*) &constructed_254;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[10] = r4;
                                              r4 = varref (0, 8);
                                              r5 = varref (0, 0);
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r5;
                                              t[2] = r4;
                                              r4 = t;
                                              r3[11] = r4;
                                              r3 = varref (0, 9);
                                              r4 = (object*) &constructed_253;
                                              t = alloc_no_clear (TC_PAIR,2);
                                              t[1] = r4;
                                              t[2] = r3;
                                              r3 = t;
                                              lenv = lenv[1];
                                              r3 = r3;
                                              r2[2] = r3;
                                              r3 = varref (15, 45);
                                              t = allocate (TC_SAVE, 5);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2621; t[4] = r0; t[5] = r1; k = t;
                                              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                                              L2621:
                                              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                                              r2 = result;
                                              r1[2] = r2;
                                              r2 = varref (14, 33);
                                              r2 = ((pxll_vector*)r2)->val[4];
                                              t = allocate (TC_SAVE, 4);
                                              t[1] = k; t[2] = lenv; t[3] = &&L2622; t[4] = r0; k = t;
                                              r1[1] = r2[2]; lenv = r1; goto *r2[1];
                                              L2622:
                                              r0 = k[4]; lenv = k[2]; k = k[1];
                                              r1 = result;
                                              r1=r1;
                                            } break;
                                            default: {
                                              lenv = ((object ******)lenv)[1][1][1][1][1][1];
                                              goto fatbar_20;
                                            }
                                          }
                                          lenv = lenv[1];
                                          r1 = r1;
                                          r1=r1;
                                        } break;
                                        default: {
                                          lenv = ((object *****)lenv)[1][1][1][1][1];
                                          goto fatbar_20;
                                        }
                                      }
                                      r1=r1;
                                    } break;
                                    default: {
                                      lenv = ((object *****)lenv)[1][1][1][1][1];
                                      goto fatbar_20;
                                    }
                                  }
                                  lenv = lenv[1];
                                  r1 = r1;
                                  r1=r1;
                                } break;
                                default: {
                                  lenv = ((object ****)lenv)[1][1][1][1];
                                  goto fatbar_20;
                                }
                              }
                              lenv = lenv[1];
                              r1 = r1;
                              r1=r1;
                            } break;
                            default: {
                              lenv = ((object ***)lenv)[1][1][1];
                              goto fatbar_20;
                            }
                          }
                          lenv = lenv[1];
                          r1 = r1;
                          r1=r1;
                        } break;
                        default: {
                          lenv = ((object **)lenv)[1][1];
                          goto fatbar_20;
                        }
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      lenv = ((object *)lenv)[1];
                      goto fatbar_20;
                    }
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_20;
                }
              }
              r1=r1;
              goto fatbar_20_over;
              fatbar_20:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2623; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2623:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_20_over: ;
              r1=r1;
            } else {
              goto fatbar_19;
            }
            r1=r1;
            goto fatbar_19_over;
            fatbar_19:
            r1 = (object *) constructed_272[0];
            r2 = varref (2, 0);
            if PXLL_IS_TRUE(PXLL_TEST(r2==r1)) {
              r1 = varref (2, 1);
              switch (get_case (r1)) {
                case (UOTAG(9)): {
                  r1 = allocate (TC_TUPLE, 4);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r2 = varref (3, 1);
                  r2 = UOBJ_GET(r2,1);
                  r1[3] = r2;
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = varref (9, 0);
                  r3 = ((pxll_vector*)r3)->val[1];
                  r2[2] = r3;
                  r3 = varref (0, 0);
                  r2[3] = r3;
                  r3 = varref (10, 64);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2624; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
                  L2624:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[4] = r2;
                  r1 = varref (0, 2);
                  switch (get_case (r1)) {
                    case (UITAG(1)): {
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = (object*) &constructed_259;
                      r1[2] = r2;
                      r2 = varref (0, 0);
                      r1[3] = r2;
                      r2 = varref (10, 12);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2625; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                      L2625:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r1=r1;
                    } break;
                    default: {
                      r1 = allocate (TC_TUPLE, 3);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (1, 2);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r2 = allocate (TC_TUPLE, 2);
                      r3 = varref (1, 1);
                      r2[2] = r3;
                      r3 = varref (0, 0);
                      r3 = ((pxll_vector*)r3)->val[1];
                      t = allocate (TC_SAVE, 5);
                      t[1] = k; t[2] = lenv; t[3] = &&L2626; t[4] = r0; t[5] = r1; k = t;
                      r2[1] = r3[2]; lenv = r2; goto *r3[1];
                      L2626:
                      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                      r2 = result;
                      r1[3] = r2;
                      r1 = (object *) 1;
                      r2 = varref (2, 1);
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 8);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = varref (3, 0);
                        r4[2] = r5;
                        r5 = varref (12, 54);
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2627; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                        L2627:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = allocate (TC_TUPLE, 4);
                        r5 = varref (2, 0);
                        r4[2] = r5;
                        r5 = varref (2, 1);
                        r4[3] = r5;
                        r5 = varref (1, 1);
                        r5 = ((pxll_vector*)r5)->val[1];
                        r4[4] = r5;
                        r5 = varref (8, 4);
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2628; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_get_uitag_4185_i4287_i4326;
                        L2628:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[3] = r4;
                        r4 = (object*)TC_NIL;
                        r3[4] = r4;
                        r4 = varref (0, 2);
                        r5 = (object*) &constructed_262;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r4 = varref (0, 3);
                        r5 = varref (0, 1);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[6] = r4;
                        r4 = varref (0, 4);
                        r5 = (object*) &constructed_261;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[7] = r4;
                        r4 = varref (0, 5);
                        r5 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[8] = r4;
                        r3 = varref (0, 6);
                        r4 = (object*) &constructed_260;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r3 = r3;
                        r2[2] = r3;
                        r3 = varref (11, 45);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2629; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                        L2629:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = varref (10, 33);
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2630; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2630:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      } else {
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 8);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 4);
                        r5 = varref (2, 0);
                        r4[2] = r5;
                        r5 = varref (2, 1);
                        r4[3] = r5;
                        r5 = varref (1, 1);
                        r5 = ((pxll_vector*)r5)->val[1];
                        r4[4] = r5;
                        r5 = varref (8, 3);
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2631; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_get_uotag_4184_i4287_i4326;
                        L2631:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = varref (3, 1);
                        r4[2] = r5;
                        r5 = varref (12, 54);
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2632; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                        L2632:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[3] = r4;
                        r4 = (object*)TC_NIL;
                        r3[4] = r4;
                        r4 = varref (0, 2);
                        r5 = (object*) &constructed_270;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r4 = varref (0, 3);
                        r5 = varref (0, 1);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[6] = r4;
                        r4 = varref (0, 4);
                        r5 = (object*) &constructed_269;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[7] = r4;
                        r4 = varref (0, 5);
                        r5 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[8] = r4;
                        r3 = varref (0, 6);
                        r4 = (object*) &constructed_268;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r3 = r3;
                        r2[2] = r3;
                        r3 = varref (11, 45);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2633; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                        L2633:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = varref (10, 33);
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2634; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2634:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        r2 = varref (3, 1);
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 2);
                        r1[1] = lenv; lenv = r1;
                        // def $loop_4455_i3298_i4287_i4326
                        goto L2635;
                        FUN__24loop_4455_i3298_i4287_i4326:
                          check_heap (0);
                          r0 = varref (2, 0);
                          r1 = varref (0, 0);
                          if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                            r0 = (object *) 14;
                            PXLL_RETURN(0);
                          } else {
                            r0 = allocate (TC_TUPLE, 2);
                            r1 = allocate (TC_TUPLE, 2);
                            r2 = allocate (TC_TUPLE, 8);
                            r2[1] = lenv; lenv = r2;
                            r3 = allocate (TC_TUPLE, 2);
                            r4 = (object *) 3;
                            r5 = varref (1, 0);
                            r4 = box(unbox(r5)+unbox(r4));
                            r3[2] = r4;
                            r4 = varref (15, 54);
                            t = allocate (TC_SAVE, 6);
                            t[1] = k; t[2] = lenv; t[3] = &&L2636; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                            L2636:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                            r3 = result;
                            r2[2] = r3;
                            r3 = allocate (TC_TUPLE, 2);
                            r4 = allocate (TC_TUPLE, 3);
                            r5 = varref (8, 2);
                            r4[2] = r5;
                            r5 = varref (1, 0);
                            r4[3] = r5;
                            r5 = varref (15, 25);
                            t = allocate (TC_SAVE, 7);
                            t[1] = k; t[2] = lenv; t[3] = &&L2637; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                            r4[1] = r5[2]; lenv = r4; goto FUN_nth_330;
                            L2637:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                            r4 = result;
                            r3[2] = r4;
                            r4 = varref (15, 54);
                            t = allocate (TC_SAVE, 6);
                            t[1] = k; t[2] = lenv; t[3] = &&L2638; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                            r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                            L2638:
                            r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                            r3 = result;
                            r2[3] = r3;
                            r3 = (object*)TC_NIL;
                            r2[4] = r3;
                            r3 = varref (0, 2);
                            r4 = (object*) &constructed_267;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[5] = r3;
                            r3 = varref (0, 3);
                            r4 = varref (0, 1);
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[6] = r3;
                            r3 = varref (0, 4);
                            r4 = (object*) &constructed_266;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[7] = r3;
                            r3 = varref (0, 5);
                            r4 = varref (0, 0);
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r4;
                            t[2] = r3;
                            r3 = t;
                            r2[8] = r3;
                            r2 = varref (0, 6);
                            r3 = (object*) &constructed_265;
                            t = alloc_no_clear (TC_PAIR,2);
                            t[1] = r3;
                            t[2] = r2;
                            r2 = t;
                            lenv = lenv[1];
                            r2 = r2;
                            r1[2] = r2;
                            r2 = varref (14, 45);
                            t = allocate (TC_SAVE, 4);
                            t[1] = k; t[2] = lenv; t[3] = &&L2639; t[4] = r0; k = t;
                            r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                            L2639:
                            r0 = k[4]; lenv = k[2]; k = k[1];
                            r1 = result;
                            r0[2] = r1;
                            r1 = varref (13, 33);
                            r1 = ((pxll_vector*)r1)->val[4];
                            t = allocate (TC_SAVE, 3);
                            t[1] = k; t[2] = lenv; t[3] = &&L2640; ; k = t;
                            r0[1] = r1[2]; lenv = r0; goto *r1[1];
                            L2640:
                            ; lenv = k[2]; k = k[1];
                            r0 = (object *) 3;
                            r1 = varref (0, 0);
                            r0 = box(unbox(r1)+unbox(r0));
                            lenv[2] = r0;
                            goto FUN__24loop_4455_i3298_i4287_i4326;
                          }
                          PXLL_RETURN(0);
                        L2635:
                        r2 = allocate (TC_CLOSURE, 2);
                        r2[1] = &&FUN__24loop_4455_i3298_i4287_i4326; r2[2] = lenv;
                        r1[2] = r2;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = (object *) 1;
                        r1[2] = r2;
                        r2 = varref (0, 0);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2641; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4455_i3298_i4287_i4326;
                        L2641:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        lenv = lenv[1];
                        r1 = r1;
                        lenv = lenv[1];
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 2);
                        r3 = allocate (TC_TUPLE, 5);
                        r3[1] = lenv; lenv = r3;
                        r4 = allocate (TC_TUPLE, 2);
                        r5 = varref (3, 0);
                        r4[2] = r5;
                        r5 = varref (12, 54);
                        t = allocate (TC_SAVE, 7);
                        t[1] = k; t[2] = lenv; t[3] = &&L2642; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                        r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                        L2642:
                        r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                        r4 = result;
                        r3[2] = r4;
                        r4 = (object*)TC_NIL;
                        r3[3] = r4;
                        r4 = varref (0, 1);
                        r5 = (object*) &constructed_264;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[4] = r4;
                        r4 = varref (0, 2);
                        r5 = varref (0, 0);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r5;
                        t[2] = r4;
                        r4 = t;
                        r3[5] = r4;
                        r3 = varref (0, 3);
                        r4 = (object*) &constructed_263;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        lenv = lenv[1];
                        r3 = r3;
                        r2[2] = r3;
                        r3 = varref (11, 45);
                        t = allocate (TC_SAVE, 5);
                        t[1] = k; t[2] = lenv; t[3] = &&L2643; t[4] = r0; t[5] = r1; k = t;
                        r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                        L2643:
                        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                        r2 = result;
                        r1[2] = r2;
                        r2 = varref (10, 33);
                        r2 = ((pxll_vector*)r2)->val[4];
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2644; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto *r2[1];
                        L2644:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      }
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                  }
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  goto fatbar_22;
                }
              }
              r1=r1;
              goto fatbar_22_over;
              fatbar_22:
              r1 = allocate (TC_TUPLE, 3);
              r2 = (object*) &constructed_208;
              r1[2] = r2;
              r2 = varref (2, 0);
              r1[3] = r2;
              r2 = varref (9, 12);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2645; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
              L2645:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
              fatbar_22_over: ;
              r1=r1;
            } else {
              goto fatbar_21;
            }
            r1=r1;
            goto fatbar_21_over;
            fatbar_21:
            r1 = allocate (TC_TUPLE, 3);
            r2 = (object*) &constructed_208;
            r1[2] = r2;
            r2 = varref (2, 0);
            r1[3] = r2;
            r2 = varref (9, 12);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2646; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
            L2646:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            r1=r1;
            fatbar_21_over: ;
            r1=r1;
            fatbar_19_over: ;
            r1=r1;
            fatbar_17_over: ;
            r1=r1;
            fatbar_15_over: ;
            r1=r1;
            fatbar_13_over: ;
            r1=r1;
            fatbar_11_over: ;
            r1=r1;
            fatbar_9_over: ;
            r1=r1;
            fatbar_8_over: ;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = varref (0, 3);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(19)): {
            r1 = allocate (TC_TUPLE, 4);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 2);
            r2[2] = r3;
            r3 = varref (8, 129);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2647; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_k_2ftarget_525;
            L2647:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = (object *) 1;
            r2 = varref (1, 1);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 0);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2648; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2648:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = varref (2, 1);
              r4[2] = r5;
              r5 = varref (9, 54);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2649; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
              L2649:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_275;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_274;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_273;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (8, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2650; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2650:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (7, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2651; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2651:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = (object *) 1;
              r2 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>=unbox(r1))) {
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 2);
                r3 = allocate (TC_TUPLE, 8);
                r3[1] = lenv; lenv = r3;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (1, 0);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2652; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2652:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[2] = r4;
                r4 = allocate (TC_TUPLE, 2);
                r5 = varref (2, 0);
                r4[2] = r5;
                r5 = varref (9, 54);
                t = allocate (TC_SAVE, 7);
                t[1] = k; t[2] = lenv; t[3] = &&L2653; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                L2653:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                r4 = result;
                r3[3] = r4;
                r4 = (object*)TC_NIL;
                r3[4] = r4;
                r4 = varref (0, 2);
                r5 = (object*) &constructed_278;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[5] = r4;
                r4 = varref (0, 3);
                r5 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[6] = r4;
                r4 = varref (0, 4);
                r5 = (object*) &constructed_277;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[7] = r4;
                r4 = varref (0, 5);
                r5 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r5;
                t[2] = r4;
                r4 = t;
                r3[8] = r4;
                r3 = varref (0, 6);
                r4 = (object*) &constructed_276;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                lenv = lenv[1];
                r3 = r3;
                r2[2] = r3;
                r3 = varref (8, 45);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2654; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                L2654:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r2 = varref (7, 33);
                r2 = ((pxll_vector*)r2)->val[4];
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2655; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto *r2[1];
                L2655:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } else {
                r1 = (object *) 14;
                r1=r1;
              }
              r1=r1;
            }
            lenv = lenv[1];
            r1 = varref (0, 2);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(20)): {
            r1 = allocate (TC_TUPLE, 5);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 1);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2656; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
            L2656:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2657; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2657:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_284;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_283;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2658; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2658:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2659; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2659:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2660; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2660:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_282;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_281;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2661; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2661:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2662; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2662:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (0, 2);
            r1[2] = r2;
            r2 = varref (3, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2663; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
            L2663:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2664; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2664:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_280;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_279;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2665; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2665:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2666; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2666:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = varref (0, 3);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(21)): {
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r1 = (object *) 1;
            r2 = varref (0, 1);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)>unbox(r1))) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 2);
              r3 = allocate (TC_TUPLE, 8);
              r3[1] = lenv; lenv = r3;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = varref (1, 1);
              r5[2] = r6;
              r6 = (object*) &constructed_291;
              r5[3] = r6;
              r6 = varref (8, 29);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2667; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_334;
              L2667:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (8, 45);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2668; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2668:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = allocate (TC_TUPLE, 2);
              r5 = allocate (TC_TUPLE, 3);
              r6 = varref (1, 1);
              r5[2] = r6;
              r6 = (object*) &constructed_290;
              r5[3] = r6;
              r6 = varref (8, 29);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2669; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_n_of_334;
              L2669:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (8, 45);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2670; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_string_concat_362;
              L2670:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[3] = r4;
              r4 = (object*)TC_NIL;
              r3[4] = r4;
              r4 = varref (0, 2);
              r5 = (object*) &constructed_289;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[5] = r4;
              r4 = varref (0, 3);
              r5 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[6] = r4;
              r4 = varref (0, 4);
              r5 = (object*) &constructed_288;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[7] = r4;
              r4 = varref (0, 5);
              r5 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r5;
              t[2] = r4;
              r4 = t;
              r3[8] = r4;
              r3 = varref (0, 6);
              r4 = (object*) &constructed_287;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              lenv = lenv[1];
              r3 = r3;
              r2[2] = r3;
              r3 = varref (7, 45);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2671; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
              L2671:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r2 = varref (6, 33);
              r2 = ((pxll_vector*)r2)->val[4];
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2672; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto *r2[1];
              L2672:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
            } else {
              r1 = (object *) 14;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2673; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2673:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_286;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_285;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2674; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2674:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2675; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2675:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = (object*)UITAG(1);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          case (UOTAG(22)): {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = allocate (TC_TUPLE, 3);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 4);
            switch (get_case (r2)) {
              case (UOTAG(0)): {
                r2 = (object *) 262;
                r2=r2;
              } break;
              default: {
                r2 = (object *) 6;
                r2=r2;
              } break;
            }
            r1[2] = r2;
            r2 = allocate (TC_TUPLE, 3);
            r3 = varref (7, 0);
            r3 = ((pxll_vector*)r3)->val[1];
            r2[2] = r3;
            r3 = varref (1, 1);
            r2[3] = r3;
            r3 = varref (8, 64);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2676; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
            L2676:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[3] = r2;
            r1 = varref (0, 1);
            switch (get_case (r1)) {
              case (UITAG(1)): {
                r1 = allocate (TC_TUPLE, 3);
                r2 = (object*) &constructed_292;
                r1[2] = r2;
                r2 = varref (1, 1);
                r1[3] = r2;
                r2 = varref (8, 12);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2677; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                L2677:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r1=r1;
              } break;
              default: {
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = varref (1, 1);
                r2 = UOBJ_GET(r2,0);
                r1[2] = r2;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = allocate (TC_TUPLE, 2);
                r3 = varref (3, 3);
                r2[2] = r3;
                r3 = varref (10, 20);
                t = allocate (TC_SAVE, 5);
                t[1] = k; t[2] = lenv; t[3] = &&L2678; t[4] = r0; t[5] = r1; k = t;
                r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
                L2678:
                r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                r2 = result;
                r1[2] = r2;
                r1 = (object *) 3;
                r2 = varref (0, 0);
                r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                lenv = lenv[1];
                r1 = r1;
                if PXLL_IS_TRUE(r1) {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (1, 0);
                  r2 = ((pxll_vector*)r2)->val[3];
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2679; t[4] = r0; t[5] = r1; k = t;
                  lenv = r2[2]; goto *r2[1];
                  L2679:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = (object *) 3;
                  r2 = varref (0, 0);
                  r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } else {
                  r1 = (object *) 6;
                  r1=r1;
                }
                if PXLL_IS_TRUE(r1) {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 3);
                  r3 = varref (2, 3);
                  r2[2] = r3;
                  r3 = (object *) 1;
                  r2[3] = r3;
                  r3 = varref (9, 25);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2680; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_nth_330;
                  L2680:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = varref (5, 0);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2681; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
                  L2681:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                } else {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = (object*) &constructed_303;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = allocate (TC_TUPLE, 7);
                  r3[1] = lenv; lenv = r3;
                  r4 = allocate (TC_TUPLE, 2);
                  r5 = varref (4, 0);
                  r4[2] = r5;
                  r5 = varref (11, 54);
                  t = allocate (TC_SAVE, 7);
                  t[1] = k; t[2] = lenv; t[3] = &&L2682; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
                  r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
                  L2682:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
                  r4 = result;
                  r3[2] = r4;
                  r4 = (object*)TC_NIL;
                  r3[3] = r4;
                  r4 = varref (0, 1);
                  r5 = (object*) &constructed_302;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[4] = r4;
                  r4 = varref (0, 2);
                  r5 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[5] = r4;
                  r4 = varref (0, 3);
                  r5 = (object*) &constructed_301;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[6] = r4;
                  r4 = varref (0, 4);
                  r5 = varref (1, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r5;
                  t[2] = r4;
                  r4 = t;
                  r3[7] = r4;
                  r3 = varref (0, 5);
                  r4 = (object*) &constructed_300;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  lenv = lenv[1];
                  r3 = r3;
                  r2[2] = r3;
                  r3 = varref (10, 45);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2683; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
                  L2683:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r2 = varref (9, 33);
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2684; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2684:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = allocate (TC_TUPLE, 2);
                  r3 = varref (4, 2);
                  r2[2] = r3;
                  r3 = varref (11, 20);
                  t = allocate (TC_SAVE, 5);
                  t[1] = k; t[2] = lenv; t[3] = &&L2685; t[4] = r0; t[5] = r1; k = t;
                  r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
                  L2685:
                  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
                  r2 = result;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  // def $loop_4476_i3472_i4287_i4326
                  goto L2686;
                  FUN__24loop_4476_i3472_i4287_i4326:
                    check_heap (0);
                    r0 = varref (2, 0);
                    r1 = varref (0, 0);
                    if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                      r0 = (object *) 14;
                      PXLL_RETURN(0);
                    } else {
                      r0 = allocate (TC_TUPLE, 7);
                      r0[1] = lenv; lenv = r0;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (7, 2);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r1[3] = r2;
                      r2 = varref (14, 25);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2687; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                      L2687:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[2] = r1;
                      r1 = allocate (TC_TUPLE, 3);
                      r2 = varref (7, 3);
                      r1[2] = r2;
                      r2 = varref (1, 0);
                      r1[3] = r2;
                      r2 = varref (14, 25);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2688; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                      L2688:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[3] = r1;
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (0, 0);
                      r1[2] = r2;
                      r2 = varref (5, 0);
                      r2 = ((pxll_vector*)r2)->val[1];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2689; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2689:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      r0[4] = r1;
                      r1 = varref (0, 2);
                      r1 = ((pxll_vector*)r1)->val[0];
                      r0[5] = r1;
                      r1 = (object *) 6;
                      r0[6] = r1;
                      r1 = (object *) 1;
                      r2 = varref (0, 3);
                      if PXLL_IS_TRUE(PXLL_TEST(unbox(r2)==unbox(r1))) {
                        r1 = allocate (TC_TUPLE, 4);
                        r2 = varref (7, 1);
                        r1[2] = r2;
                        r2 = varref (0, 0);
                        r1[3] = r2;
                        r2 = varref (0, 2);
                        r2 = ((pxll_vector*)r2)->val[1];
                        r1[4] = r2;
                        r2 = varref (10, 4);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2690; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_uitag_4185_i4287_i4326;
                        L2690:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      } else {
                        r1 = allocate (TC_TUPLE, 4);
                        r2 = varref (7, 1);
                        r1[2] = r2;
                        r2 = varref (0, 0);
                        r1[3] = r2;
                        r2 = varref (0, 2);
                        r2 = ((pxll_vector*)r2)->val[1];
                        r1[4] = r2;
                        r2 = varref (10, 3);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2691; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_get_uotag_4184_i4287_i4326;
                        L2691:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r1=r1;
                      }
                      r0[7] = r1;
                      r0 = varref (13, 33);
                      r0 = ((pxll_vector*)r0)->val[3];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2692; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2692:
                      ; lenv = k[2]; k = k[1];
                      r0 = (object *) 6;
                      r1 = varref (6, 0);
                      if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
                        r0 = allocate (TC_TUPLE, 3);
                        r0[1] = lenv; lenv = r0;
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = varref (8, 2);
                        r1[2] = r2;
                        r2 = varref (15, 20);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2693; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
                        L2693:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = (object *) 3;
                        r2 = varref (0, 0);
                        r1 = box(unbox(r2)-unbox(r1));
                        r0[3] = r1;
                        r0 = varref (0, 1);
                        r1 = varref (2, 0);
                        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
                        lenv = lenv[1];
                        r0 = r0;
                        r0=r0;
                      } else {
                        r0 = (object *) 6;
                        r0=r0;
                      }
                      if PXLL_IS_TRUE(r0) {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = (object*) &constructed_297;
                        r0[2] = r1;
                        r1 = varref (13, 33);
                        r1 = ((pxll_vector*)r1)->val[4];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2694; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto *r1[1];
                        L2694:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      } else {
                        r0 = allocate (TC_TUPLE, 2);
                        r1 = allocate (TC_TUPLE, 2);
                        r2 = allocate (TC_TUPLE, 4);
                        r2[1] = lenv; lenv = r2;
                        r3 = (object*)TC_NIL;
                        r2[2] = r3;
                        r3 = varref (0, 0);
                        r4 = (object*) &constructed_299;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        r2[3] = r3;
                        r3 = varref (0, 1);
                        r4 = varref (1, 5);
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r4;
                        t[2] = r3;
                        r3 = t;
                        r2[4] = r3;
                        r2 = varref (0, 2);
                        r3 = (object*) &constructed_298;
                        t = alloc_no_clear (TC_PAIR,2);
                        t[1] = r3;
                        t[2] = r2;
                        r2 = t;
                        lenv = lenv[1];
                        r2 = r2;
                        r1[2] = r2;
                        r2 = varref (14, 45);
                        t = allocate (TC_SAVE, 4);
                        t[1] = k; t[2] = lenv; t[3] = &&L2695; t[4] = r0; k = t;
                        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                        L2695:
                        r0 = k[4]; lenv = k[2]; k = k[1];
                        r1 = result;
                        r0[2] = r1;
                        r1 = varref (13, 33);
                        r1 = ((pxll_vector*)r1)->val[4];
                        t = allocate (TC_SAVE, 3);
                        t[1] = k; t[2] = lenv; t[3] = &&L2696; ; k = t;
                        r0[1] = r1[2]; lenv = r0; goto *r1[1];
                        L2696:
                        ; lenv = k[2]; k = k[1];
                        r0 = result;
                      }
                      r0 = varref (13, 33);
                      r0 = ((pxll_vector*)r0)->val[3];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2697; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2697:
                      ; lenv = k[2]; k = k[1];
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = varref (0, 1);
                      r0[2] = r1;
                      r1 = varref (10, 0);
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2698; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto FUN_emit_4163_i4287_i4326;
                      L2698:
                      ; lenv = k[2]; k = k[1];
                      r0 = varref (13, 33);
                      r0 = ((pxll_vector*)r0)->val[2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2699; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2699:
                      ; lenv = k[2]; k = k[1];
                      r0 = allocate (TC_TUPLE, 2);
                      r1 = (object*) &constructed_296;
                      r0[2] = r1;
                      r1 = varref (13, 33);
                      r1 = ((pxll_vector*)r1)->val[4];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2700; ; k = t;
                      r0[1] = r1[2]; lenv = r0; goto *r1[1];
                      L2700:
                      ; lenv = k[2]; k = k[1];
                      r0 = varref (13, 33);
                      r0 = ((pxll_vector*)r0)->val[2];
                      t = allocate (TC_SAVE, 3);
                      t[1] = k; t[2] = lenv; t[3] = &&L2701; ; k = t;
                      lenv = r0[2]; goto *r0[1];
                      L2701:
                      ; lenv = k[2]; k = k[1];
                      r0 = result;
                      lenv = lenv[1];
                      r0 = (object *) 3;
                      r1 = varref (0, 0);
                      r0 = box(unbox(r1)+unbox(r0));
                      lenv[2] = r0;
                      goto FUN__24loop_4476_i3472_i4287_i4326;
                    }
                    PXLL_RETURN(0);
                  L2686:
                  r2 = allocate (TC_CLOSURE, 2);
                  r2[1] = &&FUN__24loop_4476_i3472_i4287_i4326; r2[2] = lenv;
                  r1[2] = r2;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = (object *) 1;
                  r1[2] = r2;
                  r2 = varref (0, 0);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2702; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4476_i3472_i4287_i4326;
                  L2702:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  lenv = lenv[1];
                  r1 = varref (3, 4);
                  switch (get_case (r1)) {
                    case (UOTAG(0)): {
                      r1 = allocate (TC_TUPLE, 2);
                      r1[1] = lenv; lenv = r1;
                      r2 = varref (4, 4);
                      r2 = UOBJ_GET(r2,0);
                      r1[2] = r2;
                      r1 = varref (10, 33);
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2703; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2703:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_295;
                      r1[2] = r2;
                      r2 = varref (10, 33);
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2704; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2704:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (10, 33);
                      r1 = ((pxll_vector*)r1)->val[3];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2705; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2705:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = varref (0, 0);
                      r1[2] = r2;
                      r2 = varref (7, 0);
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2706; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto FUN_emit_4163_i4287_i4326;
                      L2706:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (10, 33);
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2707; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2707:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = allocate (TC_TUPLE, 2);
                      r2 = (object*) &constructed_294;
                      r1[2] = r2;
                      r2 = varref (10, 33);
                      r2 = ((pxll_vector*)r2)->val[4];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2708; t[4] = r0; k = t;
                      r1[1] = r2[2]; lenv = r1; goto *r2[1];
                      L2708:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = varref (10, 33);
                      r1 = ((pxll_vector*)r1)->val[2];
                      t = allocate (TC_SAVE, 4);
                      t[1] = k; t[2] = lenv; t[3] = &&L2709; t[4] = r0; k = t;
                      lenv = r1[2]; goto *r1[1];
                      L2709:
                      r0 = k[4]; lenv = k[2]; k = k[1];
                      r1 = result;
                      lenv = lenv[1];
                      r1 = r1;
                      r1=r1;
                    } break;
                    default: {
                      goto fatbar_23;
                    }
                  }
                  goto fatbar_23_over;
                  fatbar_23:
                  r1 = (object *) 14;
                  fatbar_23_over: ;
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = (object*) &constructed_293;
                  r1[2] = r2;
                  r2 = varref (9, 33);
                  r2 = ((pxll_vector*)r2)->val[4];
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2710; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto *r2[1];
                  L2710:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                }
                lenv = lenv[1];
                r1 = r1;
                r1=r1;
              } break;
            }
            lenv = lenv[1];
            r1 = varref (0, 5);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
          default: {
            r1 = allocate (TC_TUPLE, 7);
            r1[1] = lenv; lenv = r1;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,0);
            r1[2] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,1);
            r1[3] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,2);
            r1[4] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,3);
            r1[5] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,4);
            r1[6] = r2;
            r2 = varref (2, 0);
            r2 = UOBJ_GET(r2,5);
            r1[7] = r2;
            r1 = varref (0, 4);
            switch (get_case (r1)) {
              case (UOTAG(0)): {
                r1 = (object*) &constructed_69;
                r1 = box(((pxll_string*)(r1))->len);
                r2 = (object*) &constructed_69;
                (fwrite (((pxll_string*)(r2))->data, 1, unbox(r1), stdout), PXLL_UNDEFINED);
                r1 = (object*) &constructed_315;
                dump_object (r1, 0); fprintf (stdout, "\n");
                r1 = (object*) &constructed_315;
                r1 = PXLL_UNDEFINED; result = r1; goto Lreturn;
              } break;
              default: {
                r1 = (object *) 14;
              } break;
            }
            r1 = allocate (TC_TUPLE, 2);
            r2 = allocate (TC_TUPLE, 2);
            r3 = allocate (TC_TUPLE, 5);
            r3[1] = lenv; lenv = r3;
            r4 = allocate (TC_TUPLE, 2);
            r5 = varref (1, 0);
            r4[2] = r5;
            r5 = varref (8, 54);
            t = allocate (TC_SAVE, 7);
            t[1] = k; t[2] = lenv; t[3] = &&L2711; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
            r4[1] = r5[2]; lenv = r4; goto FUN_int__3estring_374;
            L2711:
            r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
            r4 = result;
            r3[2] = r4;
            r4 = (object*)TC_NIL;
            r3[3] = r4;
            r4 = varref (0, 1);
            r5 = (object*) &constructed_314;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[4] = r4;
            r4 = varref (0, 2);
            r5 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r5;
            t[2] = r4;
            r4 = t;
            r3[5] = r4;
            r3 = varref (0, 3);
            r4 = (object*) &constructed_313;
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r4;
            t[2] = r3;
            r3 = t;
            lenv = lenv[1];
            r3 = r3;
            r2[2] = r3;
            r3 = varref (7, 45);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2712; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_string_concat_362;
            L2712:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r2 = varref (6, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2713; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2713:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = allocate (TC_TUPLE, 2);
            r3 = varref (1, 3);
            r2[2] = r3;
            r3 = varref (8, 20);
            t = allocate (TC_SAVE, 5);
            t[1] = k; t[2] = lenv; t[3] = &&L2714; t[4] = r0; t[5] = r1; k = t;
            r2[1] = r3[2]; lenv = r2; goto FUN_length_323;
            L2714:
            r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
            r2 = result;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            r2 = varref (1, 0);
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r1[1] = lenv; lenv = r1;
            // def $loop_4492_i3493_i4287_i4326
            goto L2715;
            FUN__24loop_4492_i3493_i4287_i4326:
              check_heap (0);
              r0 = varref (2, 0);
              r1 = varref (0, 0);
              if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              } else {
                r0 = allocate (TC_TUPLE, 9);
                r0[1] = lenv; lenv = r0;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (5, 1);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (12, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2716; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L2716:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[2] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (5, 2);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (12, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2717; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L2717:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[3] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (5, 3);
                r1[2] = r2;
                r2 = varref (1, 0);
                r1[3] = r2;
                r2 = varref (12, 25);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2718; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
                L2718:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[4] = r1;
                r1 = allocate (TC_TUPLE, 3);
                r2 = varref (11, 0);
                r2 = ((pxll_vector*)r2)->val[13];
                r1[2] = r2;
                r2 = varref (0, 0);
                r1[3] = r2;
                r2 = varref (12, 64);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2719; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_alist_2flookup_405;
                L2719:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[5] = r1;
                r1 = varref (0, 3);
                switch (get_case (r1)) {
                  case (UOTAG(0)): {
                    r1 = allocate (TC_TUPLE, 2);
                    r1[1] = lenv; lenv = r1;
                    r2 = varref (1, 3);
                    r2 = UOBJ_GET(r2,0);
                    r1[2] = r2;
                    r1 = varref (0, 0);
                    lenv = lenv[1];
                    r1 = r1;
                    r1=r1;
                  } break;
                  default: {
                    r1 = allocate (TC_TUPLE, 3);
                    r2 = (object*) &constructed_312;
                    r1[2] = r2;
                    r2 = varref (0, 0);
                    r1[3] = r2;
                    r2 = varref (12, 12);
                    t = allocate (TC_SAVE, 4);
                    t[1] = k; t[2] = lenv; t[3] = &&L2720; t[4] = r0; k = t;
                    r1[1] = r2[2]; lenv = r1; goto FUN_error1_303;
                    L2720:
                    r0 = k[4]; lenv = k[2]; k = k[1];
                    r1 = result;
                    r1=r1;
                  } break;
                }
                r0[6] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 6);
                r2[1] = lenv; lenv = r2;
                r3 = (object *) 1;
                r4 = varref (1, 1);
                if PXLL_IS_TRUE(PXLL_TEST(unbox(r4)==unbox(r3))) {
                  r3 = (object*) &constructed_310;
                  r3=r3;
                } else {
                  r3 = (object*) &constructed_311;
                  r3=r3;
                }
                r2[2] = r3;
                r3 = allocate (TC_TUPLE, 2);
                r4 = varref (1, 4);
                r3[2] = r4;
                r4 = varref (13, 54);
                t = allocate (TC_SAVE, 6);
                t[1] = k; t[2] = lenv; t[3] = &&L2721; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
                L2721:
                r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                r3 = result;
                r2[3] = r3;
                r3 = (object*)TC_NIL;
                r2[4] = r3;
                r3 = varref (0, 2);
                r4 = (object*) &constructed_309;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[5] = r3;
                r3 = varref (0, 3);
                r4 = varref (0, 1);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[6] = r3;
                r2 = varref (0, 4);
                r3 = varref (0, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (12, 45);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2722; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2722:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[7] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r2 = allocate (TC_TUPLE, 4);
                r2[1] = lenv; lenv = r2;
                r3 = (object*)TC_NIL;
                r2[2] = r3;
                r3 = varref (0, 0);
                r4 = (object*) &constructed_308;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[3] = r3;
                r3 = varref (0, 1);
                r4 = varref (1, 5);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r4;
                t[2] = r3;
                r3 = t;
                r2[4] = r3;
                r2 = varref (0, 2);
                r3 = (object*) &constructed_307;
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r3;
                t[2] = r2;
                r2 = t;
                lenv = lenv[1];
                r2 = r2;
                r1[2] = r2;
                r2 = varref (12, 45);
                t = allocate (TC_SAVE, 4);
                t[1] = k; t[2] = lenv; t[3] = &&L2723; t[4] = r0; k = t;
                r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                L2723:
                r0 = k[4]; lenv = k[2]; k = k[1];
                r1 = result;
                r0[8] = r1;
                r1 = allocate (TC_TUPLE, 2);
                r1[1] = lenv; lenv = r1;
                r2 = (object *) 3;
                r3 = varref (5, 0);
                r2 = box(unbox(r3)-unbox(r2));
                r1[2] = r2;
                r1 = varref (0, 0);
                r2 = varref (2, 0);
                r1 = PXLL_TEST(unbox(r2)==unbox(r1));
                lenv = lenv[1];
                r1 = r1;
                if PXLL_IS_TRUE(r1) {
                  r1 = (object*) &constructed_306;
                  r1=r1;
                } else {
                  r1 = varref (0, 6);
                  r1=r1;
                }
                r0[9] = r1;
                r0 = varref (11, 33);
                r0 = ((pxll_vector*)r0)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2724; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2724:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (0, 7);
                r0[2] = r1;
                r1 = varref (11, 33);
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2725; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2725:
                ; lenv = k[2]; k = k[1];
                r0 = varref (11, 33);
                r0 = ((pxll_vector*)r0)->val[3];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2726; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2726:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = varref (0, 2);
                r0[2] = r1;
                r1 = varref (8, 0);
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2727; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto FUN_emit_4163_i4287_i4326;
                L2727:
                ; lenv = k[2]; k = k[1];
                r0 = varref (11, 33);
                r0 = ((pxll_vector*)r0)->val[2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2728; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2728:
                ; lenv = k[2]; k = k[1];
                r0 = allocate (TC_TUPLE, 2);
                r1 = (object*) &constructed_305;
                r0[2] = r1;
                r1 = varref (11, 33);
                r1 = ((pxll_vector*)r1)->val[4];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2729; ; k = t;
                r0[1] = r1[2]; lenv = r0; goto *r1[1];
                L2729:
                ; lenv = k[2]; k = k[1];
                r0 = varref (11, 33);
                r0 = ((pxll_vector*)r0)->val[2];
                t = allocate (TC_SAVE, 3);
                t[1] = k; t[2] = lenv; t[3] = &&L2730; ; k = t;
                lenv = r0[2]; goto *r0[1];
                L2730:
                ; lenv = k[2]; k = k[1];
                r0 = result;
                lenv = lenv[1];
                r0 = (object *) 3;
                r1 = varref (0, 0);
                r0 = box(unbox(r1)+unbox(r0));
                lenv[2] = r0;
                goto FUN__24loop_4492_i3493_i4287_i4326;
              }
              PXLL_RETURN(0);
            L2715:
            r2 = allocate (TC_CLOSURE, 2);
            r2[1] = &&FUN__24loop_4492_i3493_i4287_i4326; r2[2] = lenv;
            r1[2] = r2;
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object *) 1;
            r1[2] = r2;
            r2 = varref (0, 0);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2731; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto FUN__24loop_4492_i3493_i4287_i4326;
            L2731:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = r1;
            lenv = lenv[1];
            r1 = allocate (TC_TUPLE, 2);
            r2 = (object*) &constructed_304;
            r1[2] = r2;
            r2 = varref (7, 33);
            r2 = ((pxll_vector*)r2)->val[4];
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2732; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2732:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            lenv = lenv[1];
            r1 = varref (0, 5);
            lenv = lenv[1];
            r1 = r1;
            r1=r1;
          } break;
        }
        r0[2] = r1;
        r0 = varref (0, 0);
        switch (get_case (r0)) {
          case (UOTAG(0)): {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r1 = UOBJ_GET(r1,2);
            r0[2] = r1;
            r0 = varref (0, 0);
            lenv = ((object **)lenv)[1][1];
            lenv[2] = r0;
            goto FUN_emit_4163_i4287_i4326;
          } break;
          default: {
            r0 = (object *) 14;
            PXLL_RETURN(0);
          } break;
        }
        PXLL_RETURN(0);
      L2341:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_emit_4163_i4287_i4326; r1[2] = lenv;
      r0[2] = r1;
      // def gen-function-label_4170_i4287_i4326
      goto L2733;
      FUN_gen_function_label_4170_i4287_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 4);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 0);
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        r4 = varref (2, 0);
        r4 = UOBJ_GET(r4,0);
        r3[2] = r4;
        r3 = varref (0, 0);
        lenv = lenv[1];
        r3 = r3;
        r3=r3;
        r2[2] = r3;
        r3 = varref (2, 5);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2734; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto *r3[1];
        L2734:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r1 = varref (0, 2);
        r2 = (object*) &constructed_70;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (5, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
      L2733:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_gen_function_label_4170_i4287_i4326; r1[2] = lenv;
      r0[3] = r1;
      // def guess-record-type_4183_i4287_i4326
      goto L2735;
      FUN_guess_record_type_4183_i4287_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 4);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_29558_i4287_i4326
        goto L2736;
        FUN_lambda_29558_i4287_i4326:
          check_heap (0);
          r0 = varref (0, 0);
          switch (get_case (r0)) {
            case (UOTAG(1)): {
              r0 = allocate (TC_TUPLE, 2);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r0 = varref (0, 0);
              PXLL_RETURN(0);
            } break;
            default: {
              goto fatbar_5;
            }
          }
          PXLL_RETURN(0);
          goto fatbar_5_over;
          fatbar_5:
          r0 = (object*) &constructed_69;
          r0 = box(((pxll_string*)(r0))->len);
          r1 = (object*) &constructed_69;
          (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
          r0 = (object*) &constructed_68;
          dump_object (r0, 0); fprintf (stdout, "\n");
          r0 = (object*) &constructed_68;
          r0 = PXLL_UNDEFINED; result = r0; goto Lreturn;
          PXLL_RETURN(0);
          fatbar_5_over: ;
          PXLL_RETURN(0);
        L2736:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_29558_i4287_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (1, 0);
        r1[3] = r2;
        r2 = varref (6, 30);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2737; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_map_335;
        L2737:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r1 = allocate (TC_TUPLE, 3);
        // def lambda_29569_i4287_i4326
        goto L2738;
        FUN_lambda_29569_i4287_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = (object *) constructed_67[0];
          r2 = varref (1, 0);
          r1 = PXLL_TEST(r2==r1);
          r0[2] = r1;
          r0 = (object *) 6;
          r1 = varref (0, 0);
          r0 = PXLL_TEST(r1==r0);
          PXLL_RETURN(0);
        L2738:
        r2 = allocate (TC_CLOSURE, 2);
        r2[1] = &&FUN_lambda_29569_i4287_i4326; r2[2] = lenv;
        r1[2] = r2;
        r2 = varref (0, 0);
        r1[3] = r2;
        r2 = varref (6, 32);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2739; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_filter_337;
        L2739:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[3] = r1;
        r1 = (object *) constructed_65[0];
        r0[4] = r1;
        r0 = allocate (TC_TUPLE, 3);
        // def lambda_29597_i4287_i4326
        goto L2740;
        FUN_lambda_29597_i4287_i4326:
          check_heap (0);
          r0 = varref (0, 0);
          switch (get_case_noint (r0)) {
            default: {
              r0 = allocate (TC_TUPLE, 3);
              r0[1] = lenv; lenv = r0;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,0);
              r0[2] = r1;
              r1 = varref (1, 0);
              r1 = UOBJ_GET(r1,1);
              r0[3] = r1;
              r0 = allocate (TC_TUPLE, 3);
              // def lambda_29539_i3784_i4287_i4326
              goto L2741;
              FUN_lambda_29539_i3784_i4287_i4326:
                check_heap (0);
                r0 = allocate (TC_TUPLE, 3);
                r1 = varref (0, 0);
                r0[2] = r1;
                r1 = varref (1, 0);
                r0[3] = r1;
                r1 = varref (9, 23);
                r0[1] = r1[2]; lenv = r0; goto FUN_member_eq_question_328;
              L2741:
              r1 = allocate (TC_CLOSURE, 2);
              r1[1] = &&FUN_lambda_29539_i3784_i4287_i4326; r1[2] = lenv;
              r0[2] = r1;
              r1 = varref (2, 1);
              r0[3] = r1;
              r1 = varref (8, 38);
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2742; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto FUN_every_question_343;
              L2742:
              ; lenv = k[2]; k = k[1];
              r0 = result;
              if PXLL_IS_TRUE(r0) {
                r0 = allocate (TC_TUPLE, 2);
                r0[1] = lenv; lenv = r0;
                r1 = varref (3, 2);
                r0[2] = r1;
                r0 = varref (0, 0);
                r1 = varref (1, 0);
                t = alloc_no_clear (TC_PAIR,2);
                t[1] = r1;
                t[2] = r0;
                r0 = t;
                lenv = lenv[1];
                r0 = r0;
                varset (2, 2, r0);
                PXLL_RETURN(0);
              } else {
                r0 = (object *) 14;
                PXLL_RETURN(0);
              }
              PXLL_RETURN(0);
            } break;
          }
          PXLL_RETURN(0);
        L2740:
        r1 = allocate (TC_CLOSURE, 2);
        r1[1] = &&FUN_lambda_29597_i4287_i4326; r1[2] = lenv;
        r0[2] = r1;
        r1 = varref (5, 0);
        r1 = ((pxll_vector*)r1)->val[8];
        r0[3] = r1;
        r1 = varref (6, 33);
        t = allocate (TC_SAVE, 3);
        t[1] = k; t[2] = lenv; t[3] = &&L2743; ; k = t;
        r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
        L2743:
        ; lenv = k[2]; k = k[1];
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = varref (1, 2);
        r1[2] = r2;
        r2 = varref (7, 20);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2744; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
        L2744:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = varref (0, 0);
        r1 = (object *) 3;
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 3);
          r2 = varref (1, 2);
          r1[2] = r2;
          r2 = (object *) 1;
          r1[3] = r2;
          r2 = varref (7, 25);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2745; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_nth_330;
          L2745:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = varref (0, 0);
          t = alloc_no_clear (UOTAG(0),1);
          t[1] = r0;
          r0 = t;
          PXLL_RETURN(0);
        } else {
          r0 = (object*)UITAG(1);
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2735:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_guess_record_type_4183_i4287_i4326; r1[2] = lenv;
      r0[4] = r1;
      // def get-uotag_4184_i4287_i4326
      goto L2746;
      FUN_get_uotag_4184_i4287_i4326:
        check_heap (0);
        r0 = (object *) constructed_59[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_57[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_55;
            PXLL_RETURN(0);
          } else {
            goto fatbar_3;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_3;
        }
        PXLL_RETURN(0);
        goto fatbar_3_over;
        fatbar_3:
        r0 = (object *) constructed_52[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_62[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_60;
            PXLL_RETURN(0);
          } else {
            goto fatbar_4;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_4;
        }
        PXLL_RETURN(0);
        goto fatbar_4_over;
        fatbar_4:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 2);
        r2[2] = r3;
        r3 = varref (6, 54);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2747; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2747:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_64;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_63;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (5, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_4_over: ;
        PXLL_RETURN(0);
        fatbar_3_over: ;
        PXLL_RETURN(0);
      L2746:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_get_uotag_4184_i4287_i4326; r1[2] = lenv;
      r0[5] = r1;
      // def get-uitag_4185_i4287_i4326
      goto L2748;
      FUN_get_uitag_4185_i4287_i4326:
        check_heap (0);
        r0 = (object *) constructed_47[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_42[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_40;
            PXLL_RETURN(0);
          } else {
            goto fatbar_1;
          }
          PXLL_RETURN(0);
          goto fatbar_1_over;
          fatbar_1:
          r0 = (object *) constructed_45[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_43;
            PXLL_RETURN(0);
          } else {
            goto fatbar_0;
          }
          PXLL_RETURN(0);
          fatbar_1_over: ;
          PXLL_RETURN(0);
        } else {
          goto fatbar_0;
        }
        PXLL_RETURN(0);
        goto fatbar_0_over;
        fatbar_0:
        r0 = (object *) constructed_52[0];
        r1 = varref (0, 0);
        if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
          r0 = (object *) constructed_50[0];
          r1 = varref (0, 1);
          if PXLL_IS_TRUE(PXLL_TEST(r1==r0)) {
            r0 = (object*) &constructed_48;
            PXLL_RETURN(0);
          } else {
            goto fatbar_2;
          }
          PXLL_RETURN(0);
        } else {
          goto fatbar_2;
        }
        PXLL_RETURN(0);
        goto fatbar_2_over;
        fatbar_2:
        r0 = allocate (TC_TUPLE, 2);
        r1 = allocate (TC_TUPLE, 5);
        r1[1] = lenv; lenv = r1;
        r2 = allocate (TC_TUPLE, 2);
        r3 = varref (1, 2);
        r2[2] = r3;
        r3 = varref (6, 54);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2749; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_int__3estring_374;
        L2749:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        r1[2] = r2;
        r2 = (object*)TC_NIL;
        r1[3] = r2;
        r2 = varref (0, 1);
        r3 = (object*) &constructed_54;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[4] = r2;
        r2 = varref (0, 2);
        r3 = varref (0, 0);
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r3;
        t[2] = r2;
        r2 = t;
        r1[5] = r2;
        r1 = varref (0, 3);
        r2 = (object*) &constructed_53;
        t = alloc_no_clear (TC_PAIR,2);
        t[1] = r2;
        t[2] = r1;
        r1 = t;
        lenv = lenv[1];
        r1 = r1;
        r0[2] = r1;
        r1 = varref (5, 45);
        r0[1] = r1[2]; lenv = r0; goto FUN_string_concat_362;
        fatbar_2_over: ;
        PXLL_RETURN(0);
        fatbar_0_over: ;
        PXLL_RETURN(0);
      L2748:
      r1 = allocate (TC_CLOSURE, 2);
      r1[1] = &&FUN_get_uitag_4185_i4287_i4326; r1[2] = lenv;
      r0[6] = r1;
      r1 = allocate (TC_TUPLE, 4);
      r1[1] = lenv; lenv = r1;
      // def frob-name_4116_i4021_i4287_i4326
      goto L2750;
      FUN_frob_name_4116_i4021_i4287_i4326:
        check_heap (0);
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 2);
        r2 = allocate (TC_TUPLE, 2);
        r2[1] = lenv; lenv = r2;
        r3 = allocate (TC_TUPLE, 2);
        r3[1] = lenv; lenv = r3;
        // def loop_4121_i2943_i4021_i4287_i4326
        goto L2751;
        FUN_loop_4121_i2943_i4021_i4287_i4326:
          check_heap (0);
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = varref (5, 0);
          r1 = box(((pxll_string*)(r1))->len);
          r0[2] = r1;
          r0 = varref (0, 0);
          r1 = varref (1, 0);
          r0 = PXLL_TEST(unbox(r1)==unbox(r0));
          lenv = lenv[1];
          r0 = r0;
          if PXLL_IS_TRUE(r0) {
            r0 = varref (0, 1);
            PXLL_RETURN(0);
          } else {
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = varref (1, 0);
            r2 = varref (5, 0);
            range_check (((pxll_string *)(((pxll_string*)(r2))))->len, unbox(r1));
            r1 = varref (1, 0);
            r2 = varref (5, 0);
            r1 = TO_CHAR(((unsigned char *)((pxll_string*)(r2))->data)[unbox(r1)]);
            r0[2] = r1;
            r0 = allocate (TC_TUPLE, 2);
            r0[1] = lenv; lenv = r0;
            r1 = allocate (TC_TUPLE, 2);
            r2 = varref (1, 0);
            r1[2] = r2;
            r2 = varref (7, 2);
            t = allocate (TC_SAVE, 4);
            t[1] = k; t[2] = lenv; t[3] = &&L2752; t[4] = r0; k = t;
            r1[1] = r2[2]; lenv = r1; goto *r2[1];
            L2752:
            r0 = k[4]; lenv = k[2]; k = k[1];
            r1 = result;
            if PXLL_IS_TRUE(r1) {
              r1 = allocate (TC_TUPLE, 2);
              r2 = varref (1, 0);
              r1[2] = r2;
              r2 = varref (12, 44);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2753; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_char__3estring_358;
              L2753:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r1=r1;
            } else {
              r1 = allocate (TC_TUPLE, 2);
              r1[1] = lenv; lenv = r1;
              r2 = allocate (TC_TUPLE, 3);
              r3 = varref (8, 1);
              r2[2] = r3;
              r3 = varref (2, 0);
              r2[3] = r3;
              r3 = varref (13, 64);
              t = allocate (TC_SAVE, 5);
              t[1] = k; t[2] = lenv; t[3] = &&L2754; t[4] = r0; t[5] = r1; k = t;
              r2[1] = r3[2]; lenv = r2; goto FUN_alist_2flookup_405;
              L2754:
              r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
              r2 = result;
              r1[2] = r2;
              r1 = varref (0, 0);
              switch (get_case (r1)) {
                case (UOTAG(0)): {
                  r1 = allocate (TC_TUPLE, 2);
                  r1[1] = lenv; lenv = r1;
                  r2 = varref (1, 0);
                  r2 = UOBJ_GET(r2,0);
                  r1[2] = r2;
                  r1 = varref (0, 0);
                  lenv = lenv[1];
                  r1 = r1;
                  r1=r1;
                } break;
                default: {
                  r1 = allocate (TC_TUPLE, 2);
                  r2 = allocate (TC_TUPLE, 4);
                  r2[1] = lenv; lenv = r2;
                  r3 = allocate (TC_TUPLE, 2);
                  r4 = varref (3, 0);
                  r4 = box(GET_CHAR(r4));
                  r3[2] = r4;
                  r4 = varref (14, 55);
                  t = allocate (TC_SAVE, 6);
                  t[1] = k; t[2] = lenv; t[3] = &&L2755; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
                  r3[1] = r4[2]; lenv = r3; goto FUN_int__3ehex_string_375;
                  L2755:
                  r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
                  r3 = result;
                  r2[2] = r3;
                  r3 = (object*)TC_NIL;
                  r2[3] = r3;
                  r3 = varref (0, 1);
                  r4 = varref (0, 0);
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r4;
                  t[2] = r3;
                  r3 = t;
                  r2[4] = r3;
                  r2 = varref (0, 2);
                  r3 = (object*) &constructed_39;
                  t = alloc_no_clear (TC_PAIR,2);
                  t[1] = r3;
                  t[2] = r2;
                  r2 = t;
                  lenv = lenv[1];
                  r2 = r2;
                  r1[2] = r2;
                  r2 = varref (13, 45);
                  t = allocate (TC_SAVE, 4);
                  t[1] = k; t[2] = lenv; t[3] = &&L2756; t[4] = r0; k = t;
                  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
                  L2756:
                  r0 = k[4]; lenv = k[2]; k = k[1];
                  r1 = result;
                  r1=r1;
                } break;
              }
              lenv = lenv[1];
              r1 = r1;
              r1=r1;
            }
            r0[2] = r1;
            r0 = varref (2, 1);
            r1 = varref (0, 0);
            t = alloc_no_clear (TC_PAIR,2);
            t[1] = r1;
            t[2] = r0;
            r0 = t;
            lenv = lenv[1];
            r0 = r0;
            r1 = (object *) 3;
            r2 = varref (1, 0);
            r1 = box(unbox(r2)+unbox(r1));
            lenv = ((object *)lenv)[1];
            lenv[2] = r1;
            lenv[3] = r0;
            goto FUN_loop_4121_i2943_i4021_i4287_i4326;
          }
          PXLL_RETURN(0);
        L2751:
        r4 = allocate (TC_CLOSURE, 2);
        r4[1] = &&FUN_loop_4121_i2943_i4021_i4287_i4326; r4[2] = lenv;
        r3[2] = r4;
        r3 = allocate (TC_TUPLE, 3);
        r4 = (object *) 1;
        r3[2] = r4;
        r4 = (object *) constructed_38[0];
        r3[3] = r4;
        r4 = varref (0, 0);
        t = allocate (TC_SAVE, 6);
        t[1] = k; t[2] = lenv; t[3] = &&L2757; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
        r3[1] = r4[2]; lenv = r3; goto FUN_loop_4121_i2943_i4021_i4287_i4326;
        L2757:
        r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
        r3 = result;
        lenv = lenv[1];
        r3 = r3;
        r2[2] = r3;
        r2 = allocate (TC_TUPLE, 3);
        r3 = varref (0, 0);
        r2[2] = r3;
        r3 = (object *) constructed_37[0];
        r2[3] = r3;
        r3 = varref (8, 19);
        t = allocate (TC_SAVE, 5);
        t[1] = k; t[2] = lenv; t[3] = &&L2758; t[4] = r0; t[5] = r1; k = t;
        r2[1] = r3[2]; lenv = r2; goto FUN_reverse_onto_320;
        L2758:
        r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
        r2 = result;
        lenv = lenv[1];
        r2 = r2;
        r1[2] = r2;
        r2 = varref (7, 45);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2759; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
        L2759:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = allocate (TC_TUPLE, 2);
        r0[1] = lenv; lenv = r0;
        r1 = allocate (TC_TUPLE, 3);
        r2 = varref (1, 0);
        r1[2] = r2;
        r2 = (object*) &constructed_36;
        r1[3] = r2;
        r2 = varref (8, 48);
        t = allocate (TC_SAVE, 4);
        t[1] = k; t[2] = lenv; t[3] = &&L2760; t[4] = r0; k = t;
        r1[1] = r2[2]; lenv = r1; goto FUN_string_compare_365;
        L2760:
        r0 = k[4]; lenv = k[2]; k = k[1];
        r1 = result;
        r0[2] = r1;
        r0 = (object *) 1;
        r1 = varref (0, 0);
        r0 = PXLL_TEST(unbox(r1)==unbox(r0));
        lenv = lenv[1];
        r0 = r0;
        if PXLL_IS_TRUE(r0) {
          r0 = (object*) &constructed_35;
          PXLL_RETURN(0);
        } else {
          r0 = varref (0, 0);
          PXLL_RETURN(0);
        }
        PXLL_RETURN(0);
      L2750:
      r2 = allocate (TC_CLOSURE, 2);
      r2[1] = &&FUN_frob_name_4116_i4021_i4287_i4326; r2[2] = lenv;
      r1[2] = r2;
      r2 = (object *) constructed_34[0];
      r1[3] = r2;
      r2 = allocate (TC_TUPLE, 2);
      r3 = allocate (TC_TUPLE, 2);
      r4 = (object*) &constructed_27;
      r3[2] = r4;
      r4 = varref (5, 53);
      t = allocate (TC_SAVE, 6);
      t[1] = k; t[2] = lenv; t[3] = &&L2761; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
      r3[1] = r4[2]; lenv = r3; goto FUN_string__3elist_372;
      L2761:
      r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
      r3 = result;
      r2[2] = r3;
      r3 = varref (5, 75);
      t = allocate (TC_SAVE, 5);
      t[1] = k; t[2] = lenv; t[3] = &&L2762; t[4] = r0; t[5] = r1; k = t;
      r2[1] = r3[2]; lenv = r2; goto FUN_char_class_425;
      L2762:
      r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
      r2 = result;
      r1[4] = r2;
      r1 = varref (0, 0);
      lenv = lenv[1];
      r1 = r1;
      r0[7] = r1;
      r0 = allocate (TC_TUPLE, 2);
      r1 = varref (3, 30);
      r0[2] = r1;
      r1 = varref (0, 0);
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2763; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto FUN_emit_4163_i4287_i4326;
      L2763:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_26;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2764; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2764:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_25;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2765; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2765:
      ; lenv = k[2]; k = k[1];
      r0 = varref (3, 33);
      r0 = ((pxll_vector*)r0)->val[2];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2766; ; k = t;
      lenv = r0[2]; goto *r0[1];
      L2766:
      ; lenv = k[2]; k = k[1];
      r0 = allocate (TC_TUPLE, 2);
      r1 = (object*) &constructed_24;
      r0[2] = r1;
      r1 = varref (3, 33);
      r1 = ((pxll_vector*)r1)->val[4];
      t = allocate (TC_SAVE, 3);
      t[1] = k; t[2] = lenv; t[3] = &&L2767; ; k = t;
      r0[1] = r1[2]; lenv = r0; goto *r1[1];
      L2767:
      ; lenv = k[2]; k = k[1];
      r0 = result;
      lenv = lenv[1];
      r0 = r0;
      lenv = lenv[1];
      r0 = r0;
      r0=r0;
    } break;
  }
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = varref (1, 0);
  r2 = ((pxll_vector*)r2)->val[8];
  r1[2] = r2;
  r2 = varref (2, 20);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2768; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
  L2768:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r0 = (object *) 1;
  r1 = varref (0, 0);
  r0 = PXLL_TEST(unbox(r1)>unbox(r0));
  lenv = lenv[1];
  r0 = r0;
  if PXLL_IS_TRUE(r0) {
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_23;
    r0[2] = r1;
    r1 = varref (0, 33);
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2769; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L2769:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_22;
    r0[2] = r1;
    r1 = varref (0, 33);
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2770; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L2770:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 3);
    // def lambda_32353_i4288_i4326
    goto L2771;
    FUN_lambda_32353_i4288_i4326:
      check_heap (0);
      r0 = varref (0, 0);
      switch (get_case_noint (r0)) {
        default: {
          r0 = allocate (TC_TUPLE, 3);
          r0[1] = lenv; lenv = r0;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,0);
          r0[2] = r1;
          r1 = varref (1, 0);
          r1 = UOBJ_GET(r1,1);
          r0[3] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = allocate (TC_TUPLE, 2);
          r2 = allocate (TC_TUPLE, 5);
          r2[1] = lenv; lenv = r2;
          r3 = allocate (TC_TUPLE, 2);
          r4 = varref (1, 1);
          r3[2] = r4;
          r4 = varref (4, 54);
          t = allocate (TC_SAVE, 6);
          t[1] = k; t[2] = lenv; t[3] = &&L2772; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
          r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
          L2772:
          r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
          r3 = result;
          r2[2] = r3;
          r3 = (object*)TC_NIL;
          r2[3] = r3;
          r3 = varref (0, 1);
          r4 = (object*) &constructed_21;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[4] = r3;
          r3 = varref (0, 2);
          r4 = varref (0, 0);
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r4;
          t[2] = r3;
          r3 = t;
          r2[5] = r3;
          r2 = varref (0, 3);
          r3 = (object*) &constructed_20;
          t = alloc_no_clear (TC_PAIR,2);
          t[1] = r3;
          t[2] = r2;
          r2 = t;
          lenv = lenv[1];
          r2 = r2;
          r1[2] = r2;
          r2 = varref (3, 45);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2773; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
          L2773:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r1 = varref (2, 33);
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2774; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2774:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object*) &constructed_19;
          r0[2] = r1;
          r1 = varref (2, 33);
          r1 = ((pxll_vector*)r1)->val[4];
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2775; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
          L2775:
          ; lenv = k[2]; k = k[1];
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          r1 = allocate (TC_TUPLE, 2);
          r2 = varref (1, 0);
          r1[2] = r2;
          r2 = varref (4, 20);
          t = allocate (TC_SAVE, 4);
          t[1] = k; t[2] = lenv; t[3] = &&L2776; t[4] = r0; k = t;
          r1[1] = r2[2]; lenv = r1; goto FUN_length_323;
          L2776:
          r0 = k[4]; lenv = k[2]; k = k[1];
          r1 = result;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r0[1] = lenv; lenv = r0;
          // def $loop_4575_i4288_i4326
          goto L2777;
          FUN__24loop_4575_i4288_i4326:
            check_heap (0);
            r0 = varref (2, 0);
            r1 = varref (0, 0);
            if PXLL_IS_TRUE(PXLL_TEST(unbox(r1)==unbox(r0))) {
              r0 = (object *) 14;
              PXLL_RETURN(0);
            } else {
              r0 = allocate (TC_TUPLE, 2);
              r1 = allocate (TC_TUPLE, 2);
              r2 = allocate (TC_TUPLE, 8);
              r2[1] = lenv; lenv = r2;
              r3 = allocate (TC_TUPLE, 2);
              r4 = allocate (TC_TUPLE, 3);
              r5 = allocate (TC_TUPLE, 3);
              r6 = varref (4, 0);
              r5[2] = r6;
              r6 = varref (1, 0);
              r5[3] = r6;
              r6 = varref (7, 25);
              t = allocate (TC_SAVE, 8);
              t[1] = k; t[2] = lenv; t[3] = &&L2778; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; t[8] = r4; k = t;
              r5[1] = r6[2]; lenv = r5; goto FUN_nth_330;
              L2778:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; r4 = k[8]; lenv = k[2]; k = k[1];
              r5 = result;
              r4[2] = r5;
              r5 = varref (6, 0);
              r4[3] = r5;
              r5 = varref (7, 7);
              t = allocate (TC_SAVE, 7);
              t[1] = k; t[2] = lenv; t[3] = &&L2779; t[4] = r0; t[5] = r1; t[6] = r2; t[7] = r3; k = t;
              r4[1] = r5[2]; lenv = r4; goto FUN_lookup_label_code_262;
              L2779:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; r3 = k[7]; lenv = k[2]; k = k[1];
              r4 = result;
              r3[2] = r4;
              r4 = varref (7, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2780; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2780:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[2] = r3;
              r3 = allocate (TC_TUPLE, 2);
              r4 = varref (1, 0);
              r3[2] = r4;
              r4 = varref (7, 54);
              t = allocate (TC_SAVE, 6);
              t[1] = k; t[2] = lenv; t[3] = &&L2781; t[4] = r0; t[5] = r1; t[6] = r2; k = t;
              r3[1] = r4[2]; lenv = r3; goto FUN_int__3estring_374;
              L2781:
              r0 = k[4]; r1 = k[5]; r2 = k[6]; lenv = k[2]; k = k[1];
              r3 = result;
              r2[3] = r3;
              r3 = (object*)TC_NIL;
              r2[4] = r3;
              r3 = varref (0, 2);
              r4 = (object*) &constructed_18;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[5] = r3;
              r3 = varref (0, 3);
              r4 = varref (0, 1);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[6] = r3;
              r3 = varref (0, 4);
              r4 = (object*) &constructed_17;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[7] = r3;
              r3 = varref (0, 5);
              r4 = varref (0, 0);
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r4;
              t[2] = r3;
              r3 = t;
              r2[8] = r3;
              r2 = varref (0, 6);
              r3 = (object*) &constructed_16;
              t = alloc_no_clear (TC_PAIR,2);
              t[1] = r3;
              t[2] = r2;
              r2 = t;
              lenv = lenv[1];
              r2 = r2;
              r1[2] = r2;
              r2 = varref (6, 45);
              t = allocate (TC_SAVE, 4);
              t[1] = k; t[2] = lenv; t[3] = &&L2782; t[4] = r0; k = t;
              r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
              L2782:
              r0 = k[4]; lenv = k[2]; k = k[1];
              r1 = result;
              r0[2] = r1;
              r1 = varref (5, 33);
              r1 = ((pxll_vector*)r1)->val[4];
              t = allocate (TC_SAVE, 3);
              t[1] = k; t[2] = lenv; t[3] = &&L2783; ; k = t;
              r0[1] = r1[2]; lenv = r0; goto *r1[1];
              L2783:
              ; lenv = k[2]; k = k[1];
              r0 = (object *) 3;
              r1 = varref (0, 0);
              r0 = box(unbox(r1)+unbox(r0));
              lenv[2] = r0;
              goto FUN__24loop_4575_i4288_i4326;
            }
            PXLL_RETURN(0);
          L2777:
          r1 = allocate (TC_CLOSURE, 2);
          r1[1] = &&FUN__24loop_4575_i4288_i4326; r1[2] = lenv;
          r0[2] = r1;
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object *) 1;
          r0[2] = r1;
          r1 = varref (0, 0);
          t = allocate (TC_SAVE, 3);
          t[1] = k; t[2] = lenv; t[3] = &&L2784; ; k = t;
          r0[1] = r1[2]; lenv = r0; goto FUN__24loop_4575_i4288_i4326;
          L2784:
          ; lenv = k[2]; k = k[1];
          r0 = result;
          lenv = lenv[1];
          r0 = r0;
          lenv = lenv[1];
          r0 = allocate (TC_TUPLE, 2);
          r1 = (object*) &constructed_15;
          r0[2] = r1;
          r1 = varref (2, 33);
          r1 = ((pxll_vector*)r1)->val[4];
          r0[1] = r1[2]; lenv = r0; goto *r1[1];
        } break;
      }
      PXLL_RETURN(0);
    L2771:
    r1 = allocate (TC_CLOSURE, 2);
    r1[1] = &&FUN_lambda_32353_i4288_i4326; r1[2] = lenv;
    r0[2] = r1;
    r1 = varref (0, 0);
    r1 = ((pxll_vector*)r1)->val[8];
    r0[3] = r1;
    r1 = varref (1, 33);
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2785; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto FUN_for_each_338;
    L2785:
    ; lenv = k[2]; k = k[1];
    r0 = allocate (TC_TUPLE, 2);
    r1 = (object*) &constructed_14;
    r0[2] = r1;
    r1 = varref (0, 33);
    r1 = ((pxll_vector*)r1)->val[4];
    t = allocate (TC_SAVE, 3);
    t[1] = k; t[2] = lenv; t[3] = &&L2786; ; k = t;
    r0[1] = r1[2]; lenv = r0; goto *r1[1];
    L2786:
    ; lenv = k[2]; k = k[1];
    r0 = result;
  } else {
    r0 = (object *) 14;
  }
  r0 = (object*) &constructed_13;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_13;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = varref (0, 33);
  r0 = ((pxll_vector*)r0)->val[0];
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2787; ; k = t;
  lenv = r0[2]; goto *r0[1];
  L2787:
  ; lenv = k[2]; k = k[1];
  r0 = (object*) &constructed_12;
  r0 = box(((pxll_string*)(r0))->len);
  r1 = (object*) &constructed_12;
  (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  r0 = allocate (TC_TUPLE, 7);
  r0[1] = lenv; lenv = r0;
  r1 = alloc_no_clear (TC_BUFFER, HOW_MANY (sizeof (struct utsname), sizeof (object)));
  r0[2] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = varref (1, 0);
  r2 = box(uname ((struct utsname *)(((pxll_vector*)r2)+1)));
  r1[2] = r2;
  r1 = varref (0, 0);
  r1 = dump_object (r1, 0); fprintf (stdout, "\n");
  lenv = lenv[1];
  r1 = allocate (UOTAG(0), 5);
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (0, 0);
  r3 = (object*)((struct utsname *)(((pxll_vector*)r3)+1))->machine;
  r2[2] = r3;
  r3 = varref (2, 58);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2788; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
  L2788:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[1] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (0, 0);
  r3 = (object*)((struct utsname *)(((pxll_vector*)r3)+1))->nodename;
  r2[2] = r3;
  r3 = varref (2, 58);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2789; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
  L2789:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (0, 0);
  r3 = (object*)((struct utsname *)(((pxll_vector*)r3)+1))->release;
  r2[2] = r3;
  r3 = varref (2, 58);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2790; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
  L2790:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[3] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (0, 0);
  r3 = (object*)((struct utsname *)(((pxll_vector*)r3)+1))->sysname;
  r2[2] = r3;
  r3 = varref (2, 58);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2791; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
  L2791:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[4] = r2;
  r2 = allocate (TC_TUPLE, 2);
  r3 = varref (0, 0);
  r3 = (object*)((struct utsname *)(((pxll_vector*)r3)+1))->version;
  r2[2] = r3;
  r3 = varref (2, 58);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2792; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_copy_cstring_382;
  L2792:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[5] = r2;
  r0[3] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object*) &constructed_11;
  r1[2] = r2;
  r2 = (object*) &constructed_10;
  r1[3] = r2;
  r2 = varref (2, 141);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2793; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_getenv_or_570;
  L2793:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[4] = r1;
  r1 = allocate (TC_TUPLE, 3);
  r2 = (object*) &constructed_9;
  r1[2] = r2;
  r2 = (object*) &constructed_8;
  r1[3] = r2;
  r2 = varref (2, 141);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2794; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_getenv_or_570;
  L2794:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[5] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r1[1] = lenv; lenv = r1;
  r2 = allocate (TC_TUPLE, 3);
  r3 = varref (1, 2);
  r2[2] = r3;
  r3 = (object*) &constructed_7;
  r2[3] = r3;
  r3 = varref (3, 48);
  t = allocate (TC_SAVE, 5);
  t[1] = k; t[2] = lenv; t[3] = &&L2795; t[4] = r0; t[5] = r1; k = t;
  r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
  L2795:
  r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
  r2 = result;
  r1[2] = r2;
  r1 = (object *) 1;
  r2 = varref (0, 0);
  r1 = PXLL_TEST(unbox(r2)==unbox(r1));
  lenv = lenv[1];
  r1 = r1;
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 3);
    r1[1] = lenv; lenv = r1;
    r2 = varref (1, 1);
    r2 = ((pxll_vector*)r2)->val[3];
    r1[2] = r2;
    r2 = allocate (TC_TUPLE, 3);
    r3 = varref (0, 0);
    r2[2] = r3;
    r3 = (object*) &constructed_6;
    r2[3] = r3;
    r3 = varref (3, 48);
    t = allocate (TC_SAVE, 5);
    t[1] = k; t[2] = lenv; t[3] = &&L2796; t[4] = r0; t[5] = r1; k = t;
    r2[1] = r3[2]; lenv = r2; goto FUN_string_compare_365;
    L2796:
    r0 = k[4]; r1 = k[5]; lenv = k[2]; k = k[1];
    r2 = result;
    r1[3] = r2;
    r1 = (object *) 1;
    r2 = varref (0, 1);
    r1 = PXLL_TEST(unbox(r2)==unbox(r1));
    lenv = lenv[1];
    r1 = r1;
    r1=r1;
  } else {
    r1 = (object *) 6;
    r1=r1;
  }
  if PXLL_IS_TRUE(r1) {
    r1 = allocate (TC_TUPLE, 2);
    r2 = allocate (TC_TUPLE, 3);
    r2[1] = lenv; lenv = r2;
    r3 = (object*)TC_NIL;
    r2[2] = r3;
    r3 = varref (0, 0);
    r4 = (object*) &constructed_5;
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r4;
    t[2] = r3;
    r3 = t;
    r2[3] = r3;
    r2 = varref (0, 1);
    r3 = varref (1, 3);
    t = alloc_no_clear (TC_PAIR,2);
    t[1] = r3;
    t[2] = r2;
    r2 = t;
    lenv = lenv[1];
    r2 = r2;
    r1[2] = r2;
    r2 = varref (2, 45);
    t = allocate (TC_SAVE, 4);
    t[1] = k; t[2] = lenv; t[3] = &&L2797; t[4] = r0; k = t;
    r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
    L2797:
    r0 = k[4]; lenv = k[2]; k = k[1];
    r1 = result;
    r1=r1;
  } else {
    r1 = varref (0, 3);
    r1=r1;
  }
  r0[6] = r1;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 8);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)TC_NIL;
  r2[2] = r3;
  r3 = varref (0, 0);
  r4 = varref (2, 5);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[3] = r3;
  r3 = varref (0, 1);
  r4 = (object*) &constructed_4;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[4] = r3;
  r3 = varref (0, 2);
  r4 = varref (2, 5);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[5] = r3;
  r3 = varref (0, 3);
  r4 = (object*) &constructed_3;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[6] = r3;
  r3 = varref (0, 4);
  r4 = varref (1, 4);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[7] = r3;
  r3 = varref (0, 5);
  r4 = (object*) &constructed_2;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[8] = r3;
  r2 = varref (0, 6);
  r3 = varref (1, 2);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[2] = r2;
  r2 = varref (2, 45);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2798; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
  L2798:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[7] = r1;
  r0 = allocate (TC_TUPLE, 2);
  r0[1] = lenv; lenv = r0;
  r1 = allocate (TC_TUPLE, 2);
  r2 = allocate (TC_TUPLE, 4);
  r2[1] = lenv; lenv = r2;
  r3 = (object*)TC_NIL;
  r2[2] = r3;
  r3 = varref (0, 0);
  r4 = (object*) &constructed_1;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[3] = r3;
  r3 = varref (0, 1);
  r4 = varref (2, 5);
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r4;
  t[2] = r3;
  r3 = t;
  r2[4] = r3;
  r2 = varref (0, 2);
  r3 = (object*) &constructed_0;
  t = alloc_no_clear (TC_PAIR,2);
  t[1] = r3;
  t[2] = r2;
  r2 = t;
  lenv = lenv[1];
  r2 = r2;
  r1[2] = r2;
  r2 = varref (3, 45);
  t = allocate (TC_SAVE, 4);
  t[1] = k; t[2] = lenv; t[3] = &&L2799; t[4] = r0; k = t;
  r1[1] = r2[2]; lenv = r1; goto FUN_string_concat_362;
  L2799:
  r0 = k[4]; lenv = k[2]; k = k[1];
  r1 = result;
  r0[2] = r1;
  r0 = varref (0, 0);
  r0 = box(((pxll_string*)(r0))->len);
  r1 = varref (0, 0);
  r0 = (fwrite (((pxll_string*)(r1))->data, 1, unbox(r0), stdout), PXLL_UNDEFINED);
  lenv = lenv[1];
  r0 = allocate (TC_TUPLE, 2);
  r1 = varref (0, 5);
  r0[2] = r1;
  r1 = varref (2, 51);
  t = allocate (TC_SAVE, 3);
  t[1] = k; t[2] = lenv; t[3] = &&L2800; ; k = t;
  r0[1] = r1[2]; lenv = r0; goto FUN_zero_terminate_370;
  L2800:
  ; lenv = k[2]; k = k[1];
  r0 = result;
  r0 = box(system (((pxll_string*)(r0))->data));
  PXLL_RETURN(0);
  Lreturn:
  return (pxll_int) result;
}
static int lookup_field (int tag, int label)
{ switch (tag) {
  case 22:
  switch (label) {
     case 78: return 0; break;
     case 63: return 1; break;
     case 79: return 2; break;
     case 61: return 3; break;
     case 80: return 4; break;
  } break;
  case 21:
  switch (label) {
     case 10: return 0; break;
     case 77: return 1; break;
     case 11: return 2; break;
     case 12: return 3; break;
  } break;
  case 20:
  switch (label) {
     case 74: return 0; break;
     case 75: return 1; break;
     case 76: return 2; break;
  } break;
  case 19:
  switch (label) {
     case 16: return 0; break;
     case 73: return 1; break;
  } break;
  case 18:
  switch (label) {
     case 16: return 0; break;
     case 69: return 1; break;
     case 70: return 2; break;
     case 71: return 3; break;
     case 72: return 4; break;
  } break;
  case 17:
  switch (label) {
     case 63: return 0; break;
     case 64: return 1; break;
     case 65: return 2; break;
     case 66: return 3; break;
     case 67: return 4; break;
     case 68: return 5; break;
  } break;
  case 16:
  switch (label) {
     case 59: return 0; break;
     case 21: return 1; break;
     case 60: return 2; break;
     case 61: return 3; break;
     case 62: return 4; break;
  } break;
  case 15:
  switch (label) {
     case 57: return 0; break;
     case 58: return 1; break;
  } break;
  case 14:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 56: return 2; break;
     case 30: return 3; break;
  } break;
  case 13:
  switch (label) {
     case 55: return 0; break;
     case 49: return 1; break;
  } break;
  case 12:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 50: return 2; break;
     case 51: return 3; break;
     case 30: return 4; break;
     case 52: return 5; break;
     case 53: return 6; break;
     case 54: return 7; break;
  } break;
  case 11:
  switch (label) {
     case 48: return 0; break;
     case 49: return 1; break;
  } break;
  case 10:
  switch (label) {
     case 46: return 0; break;
     case 47: return 1; break;
  } break;
  case 9:
  switch (label) {
     case 31: return 0; break;
     case 32: return 1; break;
     case 33: return 2; break;
     case 34: return 3; break;
     case 35: return 4; break;
     case 36: return 5; break;
     case 37: return 6; break;
     case 38: return 7; break;
     case 39: return 8; break;
     case 40: return 9; break;
     case 41: return 10; break;
     case 42: return 11; break;
     case 43: return 12; break;
     case 44: return 13; break;
     case 45: return 14; break;
  } break;
  case 8:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 26: return 2; break;
     case 27: return 3; break;
     case 28: return 4; break;
     case 29: return 5; break;
     case 30: return 6; break;
     case 21: return 7; break;
  } break;
  case 7:
  switch (label) {
     case 23: return 0; break;
     case 21: return 1; break;
     case 24: return 2; break;
     case 25: return 3; break;
  } break;
  case 6:
  switch (label) {
     case 20: return 0; break;
     case 14: return 1; break;
     case 21: return 2; break;
     case 22: return 3; break;
  } break;
  case 5:
  switch (label) {
     case 18: return 0; break;
     case 19: return 1; break;
  } break;
  case 4:
  switch (label) {
     case 15: return 0; break;
     case 16: return 1; break;
     case 17: return 2; break;
  } break;
  case 3:
  switch (label) {
     case 13: return 0; break;
     case 14: return 1; break;
  } break;
  case 2:
  switch (label) {
     case 10: return 0; break;
     case 11: return 1; break;
     case 12: return 2; break;
  } break;
  case 1:
  switch (label) {
     case 5: return 0; break;
     case 6: return 1; break;
     case 7: return 2; break;
     case 8: return 3; break;
     case 9: return 4; break;
  } break;
  case 0:
  switch (label) {
     case 0: return 0; break;
     case 1: return 1; break;
     case 2: return 2; break;
     case 3: return 3; break;
     case 4: return 4; break;
  } break;
}}
